diff --git a/dlls/kernel32/locale.c b/dlls/kernel32/locale.c
index 64966e540c..bfada13939 100644
--- a/dlls/kernel32/locale.c
+++ b/dlls/kernel32/locale.c
@@ -25,6 +25,7 @@
 #include "wine/port.h"
 
 #include <assert.h>
+#include <limits.h>
 #include <locale.h>
 #include <string.h>
 #include <stdarg.h>
@@ -4032,14 +4033,14 @@ INT WINAPI CompareStringOrdinal(const WCHAR *str1, INT len1, const WCHAR *str2,
 int WINAPI lstrcmpA(LPCSTR str1, LPCSTR str2)
 {
     int ret;
-    
+
     if ((str1 == NULL) && (str2 == NULL)) return 0;
     if (str1 == NULL) return -1;
     if (str2 == NULL) return 1;
 
     ret = CompareStringA(GetThreadLocale(), LOCALE_USE_CP_ACP, str1, -1, str2, -1);
     if (ret) ret -= 2;
-    
+
     return ret;
 }
 
@@ -4061,14 +4062,14 @@ int WINAPI lstrcmpA(LPCSTR str1, LPCSTR str2)
 int WINAPI lstrcmpiA(LPCSTR str1, LPCSTR str2)
 {
     int ret;
-    
+
     if ((str1 == NULL) && (str2 == NULL)) return 0;
     if (str1 == NULL) return -1;
     if (str2 == NULL) return 1;
 
     ret = CompareStringA(GetThreadLocale(), NORM_IGNORECASE|LOCALE_USE_CP_ACP, str1, -1, str2, -1);
     if (ret) ret -= 2;
-    
+
     return ret;
 }
 
@@ -4087,7 +4088,7 @@ int WINAPI lstrcmpW(LPCWSTR str1, LPCWSTR str2)
 
     ret = CompareStringW(GetThreadLocale(), 0, str1, -1, str2, -1);
     if (ret) ret -= 2;
-    
+
     return ret;
 }
 
@@ -4099,14 +4100,14 @@ int WINAPI lstrcmpW(LPCWSTR str1, LPCWSTR str2)
 int WINAPI lstrcmpiW(LPCWSTR str1, LPCWSTR str2)
 {
     int ret;
-    
+
     if ((str1 == NULL) && (str2 == NULL)) return 0;
     if (str1 == NULL) return -1;
     if (str2 == NULL) return 1;
 
     ret = CompareStringW(GetThreadLocale(), NORM_IGNORECASE, str1, -1, str2, -1);
     if (ret) ret -= 2;
-    
+
     return ret;
 }
 
@@ -5309,30 +5310,163 @@ INT WINAPI GetUserDefaultLocaleName(LPWSTR localename, int buffersize)
     LCID userlcid;
 
     TRACE("%p, %d\n", localename,  buffersize);
-    
+
     userlcid = GetUserDefaultLCID();
     return LCIDToLocaleName(userlcid, localename, buffersize, 0);
 }
 
 /******************************************************************************
  *           NormalizeString (KERNEL32.@)
+ *
+ * Normalize Unicode string
+ *
+ * PARAMS
+ *  NormForm    [I] Unicode normalization form
+ *  lpSrcString [I] String to be normalized
+ *  cwSrcLength [I] Length, in WCHARs, of the string to be normalized. If cwSrcLength
+ *                  is (-1), the length of the string will be calculated automatically
+ *                  (including the NUL-terminator)
+ *  lpDstString [O] Normalization output buffer. May be NULL if cwDstLength is zero
+ *  cwDstLength [I] Size of the output buffer. If cwDstLength is zero, the function
+ *                  returns the required buffer size
+ *
+ * RETURNS
+ *  Success: Length of the normalized string (or calulated required buffer size)
+ *  Failure: Value less than or equal to zero. Use GetLastError() to determine the cause.
+ *      In case of ERROR_NO_UNICODE_TRANSLATION, (-1)*index of invalid Unicode character in
+ *      in the input string is returned.
  */
 INT WINAPI NormalizeString(NORM_FORM NormForm, LPCWSTR lpSrcString, INT cwSrcLength,
                            LPWSTR lpDstString, INT cwDstLength)
 {
-    FIXME("%x %p %d %p %d\n", NormForm, lpSrcString, cwSrcLength, lpDstString, cwDstLength);
-    SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
-    return 0;
+    INT res, compat = 0;
+
+    /* Check parameters */
+    if (cwSrcLength < -1 || cwDstLength < 0 || lpSrcString == NULL) {
+        SetLastError(ERROR_INVALID_PARAMETER);
+        return -1;
+    } else if (cwSrcLength == 0) {
+        SetLastError(ERROR_SUCCESS);
+        return 0;
+    } else if (cwDstLength == 0) {
+        lpDstString = NULL;
+    } else if (lpDstString == NULL) {
+        SetLastError(ERROR_INSUFFICIENT_BUFFER);
+        return -1;
+    }
+
+    /* Input length calculation requested */
+    if (cwSrcLength == -1) {
+        size_t sz;
+        if ((sz = lstrlenW(lpSrcString)) == 0) {
+            SetLastError(ERROR_SUCCESS);
+            return 0;
+        }
+
+        if (++sz > INT_MAX || sz == 0) {
+            SetLastError(ERROR_INVALID_PARAMETER);
+            return -1;
+        } else {
+            cwSrcLength = (INT)sz;
+        }
+    }
+
+    switch (NormForm) {
+    case NormalizationKD:
+        compat = 1;
+        /* fall-through */
+    case NormalizationD:
+        res = wine_decompose_string(compat, lpSrcString, cwSrcLength, lpDstString, cwDstLength);
+        break;
+    case NormalizationKC:
+        compat = 1;
+        /* fall-through */
+    case NormalizationC:
+        res = wine_compose_string(compat, lpSrcString, cwSrcLength, lpDstString, cwDstLength);
+        break;
+    default:
+        SetLastError(ERROR_INVALID_PARAMETER);
+        return -1;
+    }
+
+    if (res <= 0) {
+        SetLastError(ERROR_NO_UNICODE_TRANSLATION);
+        return res;
+    } else if (cwDstLength == 0) {
+        return res;
+    } else if (res > cwDstLength) {
+        SetLastError(ERROR_INSUFFICIENT_BUFFER);
+        return -1;
+    } else {
+        return res;
+    }
 }
 
 /******************************************************************************
  *           IsNormalizedString (KERNEL32.@)
+ *
+ * Check if Unicode string is normalized
+ *
+ * PARAMS
+ *  NormForm    [I] Unicode normalization form
+ *  lpString    [I] Input string
+ *  cwLength    [I] Length, in WCHARs, of the input string. If cwLength is (-1), the string
+ *                  is assumed to be NUL-terminated and its length will be calculated
+ *
+ * RETURNS
+ *  Success: TRUE. The string is normalized
+ *  Failure: FALSE. Otherwise. To reliably distinguish error from unnormalized input,
+ *      call SetLastError(ERROR_SUCCESS) before calling this function
  */
 BOOL WINAPI IsNormalizedString(NORM_FORM NormForm, LPCWSTR lpString, INT cwLength)
 {
-    FIXME("%x %p %d\n", NormForm, lpString, cwLength);
-    SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
-    return FALSE;
+    INT res, compat = 0;
+
+    if (lpString == NULL || cwLength < -1) {
+        SetLastError(ERROR_INVALID_PARAMETER);
+        return FALSE;
+    } else if (cwLength == 0) {
+        SetLastError(ERROR_SUCCESS);
+        return TRUE;
+    }
+
+    /* Input length calculation requested */
+    if (cwLength == -1) {
+        size_t sz;
+        if ((sz = lstrlenW(lpString)) == 0) {
+            SetLastError(ERROR_SUCCESS);
+            return TRUE;
+        }
+
+        if (sz > INT_MAX) {
+            SetLastError(ERROR_INVALID_PARAMETER);
+            return FALSE;
+        } else {
+            cwLength = (INT)sz;
+        }
+    }
+
+    switch (NormForm) {
+    case NormalizationKD:
+        compat = 1;
+        /* fall-through */
+    case NormalizationD:
+        /*res = wine_is_decomposed_string(compat, lpString, cwLength);*/
+        res = 1; /* FIXME */
+        break;
+    case NormalizationKC:
+        compat = 1;
+        /* fall-through */
+    case NormalizationC:
+        /*res = wine_is_composed_string(compat, lpString, cwLength);*/
+        res = 1; /* FIXME */
+        break;
+    default:
+        SetLastError(ERROR_INVALID_PARAMETER);
+        return FALSE;
+    }
+
+    return res ? TRUE : FALSE;
 }
 
 enum {
diff --git a/include/wine/unicode.h b/include/wine/unicode.h
index 35c61666d2..8e73758032 100644
--- a/include/wine/unicode.h
+++ b/include/wine/unicode.h
@@ -101,6 +101,11 @@ extern int wine_compare_string( int flags, const WCHAR *str1, int len1, const WC
 extern int wine_get_sortkey( int flags, const WCHAR *src, int srclen, char *dst, int dstlen );
 extern int wine_fold_string( int flags, const WCHAR *src, int srclen , WCHAR *dst, int dstlen );
 
+extern WCHAR wine_compose( const WCHAR *str );
+extern unsigned int wine_decompose( WCHAR ch, WCHAR *dst, unsigned int dstlen );
+extern int wine_compose_string( int compat, const WCHAR *src, int srclen, WCHAR *dst, int dstlen );
+extern int wine_decompose_string( int compat, const WCHAR *src, int srclen, WCHAR *dst, int dstlen );
+
 extern int strcmpiW( const WCHAR *str1, const WCHAR *str2 );
 extern int strncmpiW( const WCHAR *str1, const WCHAR *str2, int n );
 extern int memicmpW( const WCHAR *str1, const WCHAR *str2, int n );
diff --git a/libs/port/compose.c b/libs/port/compose.c
index 71589f47c1..7e6c810aff 100644
--- a/libs/port/compose.c
+++ b/libs/port/compose.c
@@ -392,7 +392,7 @@ static inline int binary_search( WCHAR ch, int low, int high )
     return -1;
 }
 
-WCHAR DECLSPEC_HIDDEN wine_compose( const WCHAR *str )
+WCHAR wine_compose( const WCHAR *str )
 {
     int pos, idx = 1, start = 0, count = 70;
     for (;;)
@@ -403,3 +403,9 @@ WCHAR DECLSPEC_HIDDEN wine_compose( const WCHAR *str )
         count = table[2 * pos + 3];
     }
 }
+
+int wine_compose_string( int compat, const WCHAR *src, int srclen, WCHAR *dst, int dstlen )
+{
+    /* FIXME: Implement */
+    return 0;
+}
diff --git a/libs/port/decompose.c b/libs/port/decompose.c
index 221d2e0e92..f44f60275e 100644
--- a/libs/port/decompose.c
+++ b/libs/port/decompose.c
@@ -1,761 +1,4962 @@
-/* Unicode char composition */
+/* Unicode char decomposition */
 /* generated from http://www.unicode.org/Public/10.0.0/ucd/UnicodeData.txt */
 /* DO NOT EDIT!! */
 
 #include "wine/unicode.h"
 
-static const WCHAR table[4704] =
+static const UINT decomp_last = 0x2fa1d;
+
+static const UINT class_last = 0x1e94a;
+
+static const WCHAR decomp_data[10439] =
+{
+    0x0000, 0x0020, 0x0000, 0x0020, 0x0308, 0x0000, 0x0061, 0x0000,
+    0x0020, 0x0304, 0x0000, 0x0032, 0x0000, 0x0033, 0x0000, 0x0020,
+    0x0301, 0x0000, 0x03bc, 0x0000, 0x0020, 0x0327, 0x0000, 0x0031,
+    0x0000, 0x006f, 0x0000, 0x0031, 0x2044, 0x0034, 0x0000, 0x0031,
+    0x2044, 0x0032, 0x0000, 0x0033, 0x2044, 0x0034, 0x0000, 0x0041,
+    0x0300, 0x0000, 0x0041, 0x0301, 0x0000, 0x0041, 0x0302, 0x0000,
+    0x0041, 0x0303, 0x0000, 0x0041, 0x0308, 0x0000, 0x0041, 0x030a,
+    0x0000, 0x0043, 0x0327, 0x0000, 0x0045, 0x0300, 0x0000, 0x0045,
+    0x0301, 0x0000, 0x0045, 0x0302, 0x0000, 0x0045, 0x0308, 0x0000,
+    0x0049, 0x0300, 0x0000, 0x0049, 0x0301, 0x0000, 0x0049, 0x0302,
+    0x0000, 0x0049, 0x0308, 0x0000, 0x004e, 0x0303, 0x0000, 0x004f,
+    0x0300, 0x0000, 0x004f, 0x0301, 0x0000, 0x004f, 0x0302, 0x0000,
+    0x004f, 0x0303, 0x0000, 0x004f, 0x0308, 0x0000, 0x0055, 0x0300,
+    0x0000, 0x0055, 0x0301, 0x0000, 0x0055, 0x0302, 0x0000, 0x0055,
+    0x0308, 0x0000, 0x0059, 0x0301, 0x0000, 0x0061, 0x0300, 0x0000,
+    0x0061, 0x0301, 0x0000, 0x0061, 0x0302, 0x0000, 0x0061, 0x0303,
+    0x0000, 0x0061, 0x0308, 0x0000, 0x0061, 0x030a, 0x0000, 0x0063,
+    0x0327, 0x0000, 0x0065, 0x0300, 0x0000, 0x0065, 0x0301, 0x0000,
+    0x0065, 0x0302, 0x0000, 0x0065, 0x0308, 0x0000, 0x0069, 0x0300,
+    0x0000, 0x0069, 0x0301, 0x0000, 0x0069, 0x0302, 0x0000, 0x0069,
+    0x0308, 0x0000, 0x006e, 0x0303, 0x0000, 0x006f, 0x0300, 0x0000,
+    0x006f, 0x0301, 0x0000, 0x006f, 0x0302, 0x0000, 0x006f, 0x0303,
+    0x0000, 0x006f, 0x0308, 0x0000, 0x0075, 0x0300, 0x0000, 0x0075,
+    0x0301, 0x0000, 0x0075, 0x0302, 0x0000, 0x0075, 0x0308, 0x0000,
+    0x0079, 0x0301, 0x0000, 0x0079, 0x0308, 0x0000, 0x0041, 0x0304,
+    0x0000, 0x0061, 0x0304, 0x0000, 0x0041, 0x0306, 0x0000, 0x0061,
+    0x0306, 0x0000, 0x0041, 0x0328, 0x0000, 0x0061, 0x0328, 0x0000,
+    0x0043, 0x0301, 0x0000, 0x0063, 0x0301, 0x0000, 0x0043, 0x0302,
+    0x0000, 0x0063, 0x0302, 0x0000, 0x0043, 0x0307, 0x0000, 0x0063,
+    0x0307, 0x0000, 0x0043, 0x030c, 0x0000, 0x0063, 0x030c, 0x0000,
+    0x0044, 0x030c, 0x0000, 0x0064, 0x030c, 0x0000, 0x0045, 0x0304,
+    0x0000, 0x0065, 0x0304, 0x0000, 0x0045, 0x0306, 0x0000, 0x0065,
+    0x0306, 0x0000, 0x0045, 0x0307, 0x0000, 0x0065, 0x0307, 0x0000,
+    0x0045, 0x0328, 0x0000, 0x0065, 0x0328, 0x0000, 0x0045, 0x030c,
+    0x0000, 0x0065, 0x030c, 0x0000, 0x0047, 0x0302, 0x0000, 0x0067,
+    0x0302, 0x0000, 0x0047, 0x0306, 0x0000, 0x0067, 0x0306, 0x0000,
+    0x0047, 0x0307, 0x0000, 0x0067, 0x0307, 0x0000, 0x0047, 0x0327,
+    0x0000, 0x0067, 0x0327, 0x0000, 0x0048, 0x0302, 0x0000, 0x0068,
+    0x0302, 0x0000, 0x0049, 0x0303, 0x0000, 0x0069, 0x0303, 0x0000,
+    0x0049, 0x0304, 0x0000, 0x0069, 0x0304, 0x0000, 0x0049, 0x0306,
+    0x0000, 0x0069, 0x0306, 0x0000, 0x0049, 0x0328, 0x0000, 0x0069,
+    0x0328, 0x0000, 0x0049, 0x0307, 0x0000, 0x0049, 0x004a, 0x0000,
+    0x0069, 0x006a, 0x0000, 0x004a, 0x0302, 0x0000, 0x006a, 0x0302,
+    0x0000, 0x004b, 0x0327, 0x0000, 0x006b, 0x0327, 0x0000, 0x004c,
+    0x0301, 0x0000, 0x006c, 0x0301, 0x0000, 0x004c, 0x0327, 0x0000,
+    0x006c, 0x0327, 0x0000, 0x004c, 0x030c, 0x0000, 0x006c, 0x030c,
+    0x0000, 0x004c, 0x00b7, 0x0000, 0x006c, 0x00b7, 0x0000, 0x004e,
+    0x0301, 0x0000, 0x006e, 0x0301, 0x0000, 0x004e, 0x0327, 0x0000,
+    0x006e, 0x0327, 0x0000, 0x004e, 0x030c, 0x0000, 0x006e, 0x030c,
+    0x0000, 0x02bc, 0x006e, 0x0000, 0x004f, 0x0304, 0x0000, 0x006f,
+    0x0304, 0x0000, 0x004f, 0x0306, 0x0000, 0x006f, 0x0306, 0x0000,
+    0x004f, 0x030b, 0x0000, 0x006f, 0x030b, 0x0000, 0x0052, 0x0301,
+    0x0000, 0x0072, 0x0301, 0x0000, 0x0052, 0x0327, 0x0000, 0x0072,
+    0x0327, 0x0000, 0x0052, 0x030c, 0x0000, 0x0072, 0x030c, 0x0000,
+    0x0053, 0x0301, 0x0000, 0x0073, 0x0301, 0x0000, 0x0053, 0x0302,
+    0x0000, 0x0073, 0x0302, 0x0000, 0x0053, 0x0327, 0x0000, 0x0073,
+    0x0327, 0x0000, 0x0053, 0x030c, 0x0000, 0x0073, 0x030c, 0x0000,
+    0x0054, 0x0327, 0x0000, 0x0074, 0x0327, 0x0000, 0x0054, 0x030c,
+    0x0000, 0x0074, 0x030c, 0x0000, 0x0055, 0x0303, 0x0000, 0x0075,
+    0x0303, 0x0000, 0x0055, 0x0304, 0x0000, 0x0075, 0x0304, 0x0000,
+    0x0055, 0x0306, 0x0000, 0x0075, 0x0306, 0x0000, 0x0055, 0x030a,
+    0x0000, 0x0075, 0x030a, 0x0000, 0x0055, 0x030b, 0x0000, 0x0075,
+    0x030b, 0x0000, 0x0055, 0x0328, 0x0000, 0x0075, 0x0328, 0x0000,
+    0x0057, 0x0302, 0x0000, 0x0077, 0x0302, 0x0000, 0x0059, 0x0302,
+    0x0000, 0x0079, 0x0302, 0x0000, 0x0059, 0x0308, 0x0000, 0x005a,
+    0x0301, 0x0000, 0x007a, 0x0301, 0x0000, 0x005a, 0x0307, 0x0000,
+    0x007a, 0x0307, 0x0000, 0x005a, 0x030c, 0x0000, 0x007a, 0x030c,
+    0x0000, 0x0073, 0x0000, 0x004f, 0x031b, 0x0000, 0x006f, 0x031b,
+    0x0000, 0x0055, 0x031b, 0x0000, 0x0075, 0x031b, 0x0000, 0x0044,
+    0x005a, 0x030c, 0x0000, 0x0044, 0x007a, 0x030c, 0x0000, 0x0064,
+    0x007a, 0x030c, 0x0000, 0x004c, 0x004a, 0x0000, 0x004c, 0x006a,
+    0x0000, 0x006c, 0x006a, 0x0000, 0x004e, 0x004a, 0x0000, 0x004e,
+    0x006a, 0x0000, 0x006e, 0x006a, 0x0000, 0x0041, 0x030c, 0x0000,
+    0x0061, 0x030c, 0x0000, 0x0049, 0x030c, 0x0000, 0x0069, 0x030c,
+    0x0000, 0x004f, 0x030c, 0x0000, 0x006f, 0x030c, 0x0000, 0x0055,
+    0x030c, 0x0000, 0x0075, 0x030c, 0x0000, 0x0055, 0x0308, 0x0304,
+    0x0000, 0x0075, 0x0308, 0x0304, 0x0000, 0x0055, 0x0308, 0x0301,
+    0x0000, 0x0075, 0x0308, 0x0301, 0x0000, 0x0055, 0x0308, 0x030c,
+    0x0000, 0x0075, 0x0308, 0x030c, 0x0000, 0x0055, 0x0308, 0x0300,
+    0x0000, 0x0075, 0x0308, 0x0300, 0x0000, 0x0041, 0x0308, 0x0304,
+    0x0000, 0x0061, 0x0308, 0x0304, 0x0000, 0x0041, 0x0307, 0x0304,
+    0x0000, 0x0061, 0x0307, 0x0304, 0x0000, 0x00c6, 0x0304, 0x0000,
+    0x00e6, 0x0304, 0x0000, 0x0047, 0x030c, 0x0000, 0x0067, 0x030c,
+    0x0000, 0x004b, 0x030c, 0x0000, 0x006b, 0x030c, 0x0000, 0x004f,
+    0x0328, 0x0000, 0x006f, 0x0328, 0x0000, 0x004f, 0x0328, 0x0304,
+    0x0000, 0x006f, 0x0328, 0x0304, 0x0000, 0x01b7, 0x030c, 0x0000,
+    0x0292, 0x030c, 0x0000, 0x006a, 0x030c, 0x0000, 0x0044, 0x005a,
+    0x0000, 0x0044, 0x007a, 0x0000, 0x0064, 0x007a, 0x0000, 0x0047,
+    0x0301, 0x0000, 0x0067, 0x0301, 0x0000, 0x004e, 0x0300, 0x0000,
+    0x006e, 0x0300, 0x0000, 0x0041, 0x030a, 0x0301, 0x0000, 0x0061,
+    0x030a, 0x0301, 0x0000, 0x00c6, 0x0301, 0x0000, 0x00e6, 0x0301,
+    0x0000, 0x00d8, 0x0301, 0x0000, 0x00f8, 0x0301, 0x0000, 0x0041,
+    0x030f, 0x0000, 0x0061, 0x030f, 0x0000, 0x0041, 0x0311, 0x0000,
+    0x0061, 0x0311, 0x0000, 0x0045, 0x030f, 0x0000, 0x0065, 0x030f,
+    0x0000, 0x0045, 0x0311, 0x0000, 0x0065, 0x0311, 0x0000, 0x0049,
+    0x030f, 0x0000, 0x0069, 0x030f, 0x0000, 0x0049, 0x0311, 0x0000,
+    0x0069, 0x0311, 0x0000, 0x004f, 0x030f, 0x0000, 0x006f, 0x030f,
+    0x0000, 0x004f, 0x0311, 0x0000, 0x006f, 0x0311, 0x0000, 0x0052,
+    0x030f, 0x0000, 0x0072, 0x030f, 0x0000, 0x0052, 0x0311, 0x0000,
+    0x0072, 0x0311, 0x0000, 0x0055, 0x030f, 0x0000, 0x0075, 0x030f,
+    0x0000, 0x0055, 0x0311, 0x0000, 0x0075, 0x0311, 0x0000, 0x0053,
+    0x0326, 0x0000, 0x0073, 0x0326, 0x0000, 0x0054, 0x0326, 0x0000,
+    0x0074, 0x0326, 0x0000, 0x0048, 0x030c, 0x0000, 0x0068, 0x030c,
+    0x0000, 0x0041, 0x0307, 0x0000, 0x0061, 0x0307, 0x0000, 0x0045,
+    0x0327, 0x0000, 0x0065, 0x0327, 0x0000, 0x004f, 0x0308, 0x0304,
+    0x0000, 0x006f, 0x0308, 0x0304, 0x0000, 0x004f, 0x0303, 0x0304,
+    0x0000, 0x006f, 0x0303, 0x0304, 0x0000, 0x004f, 0x0307, 0x0000,
+    0x006f, 0x0307, 0x0000, 0x004f, 0x0307, 0x0304, 0x0000, 0x006f,
+    0x0307, 0x0304, 0x0000, 0x0059, 0x0304, 0x0000, 0x0079, 0x0304,
+    0x0000, 0x0068, 0x0000, 0x0266, 0x0000, 0x006a, 0x0000, 0x0072,
+    0x0000, 0x0279, 0x0000, 0x027b, 0x0000, 0x0281, 0x0000, 0x0077,
+    0x0000, 0x0079, 0x0000, 0x0020, 0x0306, 0x0000, 0x0020, 0x0307,
+    0x0000, 0x0020, 0x030a, 0x0000, 0x0020, 0x0328, 0x0000, 0x0020,
+    0x0303, 0x0000, 0x0020, 0x030b, 0x0000, 0x0263, 0x0000, 0x006c,
+    0x0000, 0x0078, 0x0000, 0x0295, 0x0000, 0x0300, 0x0000, 0x0301,
+    0x0000, 0x0313, 0x0000, 0x0308, 0x0301, 0x0000, 0x02b9, 0x0000,
+    0x0020, 0x0345, 0x0000, 0x003b, 0x0000, 0x00a8, 0x0301, 0x0000,
+    0x0020, 0x0308, 0x0301, 0x0000, 0x0391, 0x0301, 0x0000, 0x00b7,
+    0x0000, 0x0395, 0x0301, 0x0000, 0x0397, 0x0301, 0x0000, 0x0399,
+    0x0301, 0x0000, 0x039f, 0x0301, 0x0000, 0x03a5, 0x0301, 0x0000,
+    0x03a9, 0x0301, 0x0000, 0x03b9, 0x0308, 0x0301, 0x0000, 0x0399,
+    0x0308, 0x0000, 0x03a5, 0x0308, 0x0000, 0x03b1, 0x0301, 0x0000,
+    0x03b5, 0x0301, 0x0000, 0x03b7, 0x0301, 0x0000, 0x03b9, 0x0301,
+    0x0000, 0x03c5, 0x0308, 0x0301, 0x0000, 0x03b9, 0x0308, 0x0000,
+    0x03c5, 0x0308, 0x0000, 0x03bf, 0x0301, 0x0000, 0x03c5, 0x0301,
+    0x0000, 0x03c9, 0x0301, 0x0000, 0x03b2, 0x0000, 0x03b8, 0x0000,
+    0x03a5, 0x0000, 0x03d2, 0x0301, 0x0000, 0x03d2, 0x0308, 0x0000,
+    0x03c6, 0x0000, 0x03c0, 0x0000, 0x03ba, 0x0000, 0x03c1, 0x0000,
+    0x03c2, 0x0000, 0x0398, 0x0000, 0x03b5, 0x0000, 0x03a3, 0x0000,
+    0x0415, 0x0300, 0x0000, 0x0415, 0x0308, 0x0000, 0x0413, 0x0301,
+    0x0000, 0x0406, 0x0308, 0x0000, 0x041a, 0x0301, 0x0000, 0x0418,
+    0x0300, 0x0000, 0x0423, 0x0306, 0x0000, 0x0418, 0x0306, 0x0000,
+    0x0438, 0x0306, 0x0000, 0x0435, 0x0300, 0x0000, 0x0435, 0x0308,
+    0x0000, 0x0433, 0x0301, 0x0000, 0x0456, 0x0308, 0x0000, 0x043a,
+    0x0301, 0x0000, 0x0438, 0x0300, 0x0000, 0x0443, 0x0306, 0x0000,
+    0x0474, 0x030f, 0x0000, 0x0475, 0x030f, 0x0000, 0x0416, 0x0306,
+    0x0000, 0x0436, 0x0306, 0x0000, 0x0410, 0x0306, 0x0000, 0x0430,
+    0x0306, 0x0000, 0x0410, 0x0308, 0x0000, 0x0430, 0x0308, 0x0000,
+    0x0415, 0x0306, 0x0000, 0x0435, 0x0306, 0x0000, 0x04d8, 0x0308,
+    0x0000, 0x04d9, 0x0308, 0x0000, 0x0416, 0x0308, 0x0000, 0x0436,
+    0x0308, 0x0000, 0x0417, 0x0308, 0x0000, 0x0437, 0x0308, 0x0000,
+    0x0418, 0x0304, 0x0000, 0x0438, 0x0304, 0x0000, 0x0418, 0x0308,
+    0x0000, 0x0438, 0x0308, 0x0000, 0x041e, 0x0308, 0x0000, 0x043e,
+    0x0308, 0x0000, 0x04e8, 0x0308, 0x0000, 0x04e9, 0x0308, 0x0000,
+    0x042d, 0x0308, 0x0000, 0x044d, 0x0308, 0x0000, 0x0423, 0x0304,
+    0x0000, 0x0443, 0x0304, 0x0000, 0x0423, 0x0308, 0x0000, 0x0443,
+    0x0308, 0x0000, 0x0423, 0x030b, 0x0000, 0x0443, 0x030b, 0x0000,
+    0x0427, 0x0308, 0x0000, 0x0447, 0x0308, 0x0000, 0x042b, 0x0308,
+    0x0000, 0x044b, 0x0308, 0x0000, 0x0565, 0x0582, 0x0000, 0x0627,
+    0x0653, 0x0000, 0x0627, 0x0654, 0x0000, 0x0648, 0x0654, 0x0000,
+    0x0627, 0x0655, 0x0000, 0x064a, 0x0654, 0x0000, 0x0627, 0x0674,
+    0x0000, 0x0648, 0x0674, 0x0000, 0x06c7, 0x0674, 0x0000, 0x064a,
+    0x0674, 0x0000, 0x06d5, 0x0654, 0x0000, 0x06c1, 0x0654, 0x0000,
+    0x06d2, 0x0654, 0x0000, 0x0928, 0x093c, 0x0000, 0x0930, 0x093c,
+    0x0000, 0x0933, 0x093c, 0x0000, 0x0915, 0x093c, 0x0000, 0x0916,
+    0x093c, 0x0000, 0x0917, 0x093c, 0x0000, 0x091c, 0x093c, 0x0000,
+    0x0921, 0x093c, 0x0000, 0x0922, 0x093c, 0x0000, 0x092b, 0x093c,
+    0x0000, 0x092f, 0x093c, 0x0000, 0x09c7, 0x09be, 0x0000, 0x09c7,
+    0x09d7, 0x0000, 0x09a1, 0x09bc, 0x0000, 0x09a2, 0x09bc, 0x0000,
+    0x09af, 0x09bc, 0x0000, 0x0a32, 0x0a3c, 0x0000, 0x0a38, 0x0a3c,
+    0x0000, 0x0a16, 0x0a3c, 0x0000, 0x0a17, 0x0a3c, 0x0000, 0x0a1c,
+    0x0a3c, 0x0000, 0x0a2b, 0x0a3c, 0x0000, 0x0b47, 0x0b56, 0x0000,
+    0x0b47, 0x0b3e, 0x0000, 0x0b47, 0x0b57, 0x0000, 0x0b21, 0x0b3c,
+    0x0000, 0x0b22, 0x0b3c, 0x0000, 0x0b92, 0x0bd7, 0x0000, 0x0bc6,
+    0x0bbe, 0x0000, 0x0bc7, 0x0bbe, 0x0000, 0x0bc6, 0x0bd7, 0x0000,
+    0x0c46, 0x0c56, 0x0000, 0x0cbf, 0x0cd5, 0x0000, 0x0cc6, 0x0cd5,
+    0x0000, 0x0cc6, 0x0cd6, 0x0000, 0x0cc6, 0x0cc2, 0x0000, 0x0cc6,
+    0x0cc2, 0x0cd5, 0x0000, 0x0d46, 0x0d3e, 0x0000, 0x0d47, 0x0d3e,
+    0x0000, 0x0d46, 0x0d57, 0x0000, 0x0dd9, 0x0dca, 0x0000, 0x0dd9,
+    0x0dcf, 0x0000, 0x0dd9, 0x0dcf, 0x0dca, 0x0000, 0x0dd9, 0x0ddf,
+    0x0000, 0x0e4d, 0x0e32, 0x0000, 0x0ecd, 0x0eb2, 0x0000, 0x0eab,
+    0x0e99, 0x0000, 0x0eab, 0x0ea1, 0x0000, 0x0f0b, 0x0000, 0x0f42,
+    0x0fb7, 0x0000, 0x0f4c, 0x0fb7, 0x0000, 0x0f51, 0x0fb7, 0x0000,
+    0x0f56, 0x0fb7, 0x0000, 0x0f5b, 0x0fb7, 0x0000, 0x0f40, 0x0fb5,
+    0x0000, 0x0f71, 0x0f72, 0x0000, 0x0f71, 0x0f74, 0x0000, 0x0fb2,
+    0x0f80, 0x0000, 0x0fb2, 0x0f71, 0x0f80, 0x0000, 0x0fb3, 0x0f80,
+    0x0000, 0x0fb3, 0x0f71, 0x0f80, 0x0000, 0x0f71, 0x0f80, 0x0000,
+    0x0f92, 0x0fb7, 0x0000, 0x0f9c, 0x0fb7, 0x0000, 0x0fa1, 0x0fb7,
+    0x0000, 0x0fa6, 0x0fb7, 0x0000, 0x0fab, 0x0fb7, 0x0000, 0x0f90,
+    0x0fb5, 0x0000, 0x1025, 0x102e, 0x0000, 0x10dc, 0x0000, 0x1b05,
+    0x1b35, 0x0000, 0x1b07, 0x1b35, 0x0000, 0x1b09, 0x1b35, 0x0000,
+    0x1b0b, 0x1b35, 0x0000, 0x1b0d, 0x1b35, 0x0000, 0x1b11, 0x1b35,
+    0x0000, 0x1b3a, 0x1b35, 0x0000, 0x1b3c, 0x1b35, 0x0000, 0x1b3e,
+    0x1b35, 0x0000, 0x1b3f, 0x1b35, 0x0000, 0x1b42, 0x1b35, 0x0000,
+    0x0041, 0x0000, 0x00c6, 0x0000, 0x0042, 0x0000, 0x0044, 0x0000,
+    0x0045, 0x0000, 0x018e, 0x0000, 0x0047, 0x0000, 0x0048, 0x0000,
+    0x0049, 0x0000, 0x004a, 0x0000, 0x004b, 0x0000, 0x004c, 0x0000,
+    0x004d, 0x0000, 0x004e, 0x0000, 0x004f, 0x0000, 0x0222, 0x0000,
+    0x0050, 0x0000, 0x0052, 0x0000, 0x0054, 0x0000, 0x0055, 0x0000,
+    0x0057, 0x0000, 0x0250, 0x0000, 0x0251, 0x0000, 0x1d02, 0x0000,
+    0x0062, 0x0000, 0x0064, 0x0000, 0x0065, 0x0000, 0x0259, 0x0000,
+    0x025b, 0x0000, 0x025c, 0x0000, 0x0067, 0x0000, 0x006b, 0x0000,
+    0x006d, 0x0000, 0x014b, 0x0000, 0x0254, 0x0000, 0x1d16, 0x0000,
+    0x1d17, 0x0000, 0x0070, 0x0000, 0x0074, 0x0000, 0x0075, 0x0000,
+    0x1d1d, 0x0000, 0x026f, 0x0000, 0x0076, 0x0000, 0x1d25, 0x0000,
+    0x03b3, 0x0000, 0x03b4, 0x0000, 0x03c7, 0x0000, 0x0069, 0x0000,
+    0x043d, 0x0000, 0x0252, 0x0000, 0x0063, 0x0000, 0x0255, 0x0000,
+    0x00f0, 0x0000, 0x0066, 0x0000, 0x025f, 0x0000, 0x0261, 0x0000,
+    0x0265, 0x0000, 0x0268, 0x0000, 0x0269, 0x0000, 0x026a, 0x0000,
+    0x1d7b, 0x0000, 0x029d, 0x0000, 0x026d, 0x0000, 0x1d85, 0x0000,
+    0x029f, 0x0000, 0x0271, 0x0000, 0x0270, 0x0000, 0x0272, 0x0000,
+    0x0273, 0x0000, 0x0274, 0x0000, 0x0275, 0x0000, 0x0278, 0x0000,
+    0x0282, 0x0000, 0x0283, 0x0000, 0x01ab, 0x0000, 0x0289, 0x0000,
+    0x028a, 0x0000, 0x1d1c, 0x0000, 0x028b, 0x0000, 0x028c, 0x0000,
+    0x007a, 0x0000, 0x0290, 0x0000, 0x0291, 0x0000, 0x0292, 0x0000,
+    0x0041, 0x0325, 0x0000, 0x0061, 0x0325, 0x0000, 0x0042, 0x0307,
+    0x0000, 0x0062, 0x0307, 0x0000, 0x0042, 0x0323, 0x0000, 0x0062,
+    0x0323, 0x0000, 0x0042, 0x0331, 0x0000, 0x0062, 0x0331, 0x0000,
+    0x0043, 0x0327, 0x0301, 0x0000, 0x0063, 0x0327, 0x0301, 0x0000,
+    0x0044, 0x0307, 0x0000, 0x0064, 0x0307, 0x0000, 0x0044, 0x0323,
+    0x0000, 0x0064, 0x0323, 0x0000, 0x0044, 0x0331, 0x0000, 0x0064,
+    0x0331, 0x0000, 0x0044, 0x0327, 0x0000, 0x0064, 0x0327, 0x0000,
+    0x0044, 0x032d, 0x0000, 0x0064, 0x032d, 0x0000, 0x0045, 0x0304,
+    0x0300, 0x0000, 0x0065, 0x0304, 0x0300, 0x0000, 0x0045, 0x0304,
+    0x0301, 0x0000, 0x0065, 0x0304, 0x0301, 0x0000, 0x0045, 0x032d,
+    0x0000, 0x0065, 0x032d, 0x0000, 0x0045, 0x0330, 0x0000, 0x0065,
+    0x0330, 0x0000, 0x0045, 0x0327, 0x0306, 0x0000, 0x0065, 0x0327,
+    0x0306, 0x0000, 0x0046, 0x0307, 0x0000, 0x0066, 0x0307, 0x0000,
+    0x0047, 0x0304, 0x0000, 0x0067, 0x0304, 0x0000, 0x0048, 0x0307,
+    0x0000, 0x0068, 0x0307, 0x0000, 0x0048, 0x0323, 0x0000, 0x0068,
+    0x0323, 0x0000, 0x0048, 0x0308, 0x0000, 0x0068, 0x0308, 0x0000,
+    0x0048, 0x0327, 0x0000, 0x0068, 0x0327, 0x0000, 0x0048, 0x032e,
+    0x0000, 0x0068, 0x032e, 0x0000, 0x0049, 0x0330, 0x0000, 0x0069,
+    0x0330, 0x0000, 0x0049, 0x0308, 0x0301, 0x0000, 0x0069, 0x0308,
+    0x0301, 0x0000, 0x004b, 0x0301, 0x0000, 0x006b, 0x0301, 0x0000,
+    0x004b, 0x0323, 0x0000, 0x006b, 0x0323, 0x0000, 0x004b, 0x0331,
+    0x0000, 0x006b, 0x0331, 0x0000, 0x004c, 0x0323, 0x0000, 0x006c,
+    0x0323, 0x0000, 0x004c, 0x0323, 0x0304, 0x0000, 0x006c, 0x0323,
+    0x0304, 0x0000, 0x004c, 0x0331, 0x0000, 0x006c, 0x0331, 0x0000,
+    0x004c, 0x032d, 0x0000, 0x006c, 0x032d, 0x0000, 0x004d, 0x0301,
+    0x0000, 0x006d, 0x0301, 0x0000, 0x004d, 0x0307, 0x0000, 0x006d,
+    0x0307, 0x0000, 0x004d, 0x0323, 0x0000, 0x006d, 0x0323, 0x0000,
+    0x004e, 0x0307, 0x0000, 0x006e, 0x0307, 0x0000, 0x004e, 0x0323,
+    0x0000, 0x006e, 0x0323, 0x0000, 0x004e, 0x0331, 0x0000, 0x006e,
+    0x0331, 0x0000, 0x004e, 0x032d, 0x0000, 0x006e, 0x032d, 0x0000,
+    0x004f, 0x0303, 0x0301, 0x0000, 0x006f, 0x0303, 0x0301, 0x0000,
+    0x004f, 0x0303, 0x0308, 0x0000, 0x006f, 0x0303, 0x0308, 0x0000,
+    0x004f, 0x0304, 0x0300, 0x0000, 0x006f, 0x0304, 0x0300, 0x0000,
+    0x004f, 0x0304, 0x0301, 0x0000, 0x006f, 0x0304, 0x0301, 0x0000,
+    0x0050, 0x0301, 0x0000, 0x0070, 0x0301, 0x0000, 0x0050, 0x0307,
+    0x0000, 0x0070, 0x0307, 0x0000, 0x0052, 0x0307, 0x0000, 0x0072,
+    0x0307, 0x0000, 0x0052, 0x0323, 0x0000, 0x0072, 0x0323, 0x0000,
+    0x0052, 0x0323, 0x0304, 0x0000, 0x0072, 0x0323, 0x0304, 0x0000,
+    0x0052, 0x0331, 0x0000, 0x0072, 0x0331, 0x0000, 0x0053, 0x0307,
+    0x0000, 0x0073, 0x0307, 0x0000, 0x0053, 0x0323, 0x0000, 0x0073,
+    0x0323, 0x0000, 0x0053, 0x0301, 0x0307, 0x0000, 0x0073, 0x0301,
+    0x0307, 0x0000, 0x0053, 0x030c, 0x0307, 0x0000, 0x0073, 0x030c,
+    0x0307, 0x0000, 0x0053, 0x0323, 0x0307, 0x0000, 0x0073, 0x0323,
+    0x0307, 0x0000, 0x0054, 0x0307, 0x0000, 0x0074, 0x0307, 0x0000,
+    0x0054, 0x0323, 0x0000, 0x0074, 0x0323, 0x0000, 0x0054, 0x0331,
+    0x0000, 0x0074, 0x0331, 0x0000, 0x0054, 0x032d, 0x0000, 0x0074,
+    0x032d, 0x0000, 0x0055, 0x0324, 0x0000, 0x0075, 0x0324, 0x0000,
+    0x0055, 0x0330, 0x0000, 0x0075, 0x0330, 0x0000, 0x0055, 0x032d,
+    0x0000, 0x0075, 0x032d, 0x0000, 0x0055, 0x0303, 0x0301, 0x0000,
+    0x0075, 0x0303, 0x0301, 0x0000, 0x0055, 0x0304, 0x0308, 0x0000,
+    0x0075, 0x0304, 0x0308, 0x0000, 0x0056, 0x0303, 0x0000, 0x0076,
+    0x0303, 0x0000, 0x0056, 0x0323, 0x0000, 0x0076, 0x0323, 0x0000,
+    0x0057, 0x0300, 0x0000, 0x0077, 0x0300, 0x0000, 0x0057, 0x0301,
+    0x0000, 0x0077, 0x0301, 0x0000, 0x0057, 0x0308, 0x0000, 0x0077,
+    0x0308, 0x0000, 0x0057, 0x0307, 0x0000, 0x0077, 0x0307, 0x0000,
+    0x0057, 0x0323, 0x0000, 0x0077, 0x0323, 0x0000, 0x0058, 0x0307,
+    0x0000, 0x0078, 0x0307, 0x0000, 0x0058, 0x0308, 0x0000, 0x0078,
+    0x0308, 0x0000, 0x0059, 0x0307, 0x0000, 0x0079, 0x0307, 0x0000,
+    0x005a, 0x0302, 0x0000, 0x007a, 0x0302, 0x0000, 0x005a, 0x0323,
+    0x0000, 0x007a, 0x0323, 0x0000, 0x005a, 0x0331, 0x0000, 0x007a,
+    0x0331, 0x0000, 0x0068, 0x0331, 0x0000, 0x0074, 0x0308, 0x0000,
+    0x0077, 0x030a, 0x0000, 0x0079, 0x030a, 0x0000, 0x0061, 0x02be,
+    0x0000, 0x017f, 0x0307, 0x0000, 0x0041, 0x0323, 0x0000, 0x0061,
+    0x0323, 0x0000, 0x0041, 0x0309, 0x0000, 0x0061, 0x0309, 0x0000,
+    0x0041, 0x0302, 0x0301, 0x0000, 0x0061, 0x0302, 0x0301, 0x0000,
+    0x0041, 0x0302, 0x0300, 0x0000, 0x0061, 0x0302, 0x0300, 0x0000,
+    0x0041, 0x0302, 0x0309, 0x0000, 0x0061, 0x0302, 0x0309, 0x0000,
+    0x0041, 0x0302, 0x0303, 0x0000, 0x0061, 0x0302, 0x0303, 0x0000,
+    0x0041, 0x0323, 0x0302, 0x0000, 0x0061, 0x0323, 0x0302, 0x0000,
+    0x0041, 0x0306, 0x0301, 0x0000, 0x0061, 0x0306, 0x0301, 0x0000,
+    0x0041, 0x0306, 0x0300, 0x0000, 0x0061, 0x0306, 0x0300, 0x0000,
+    0x0041, 0x0306, 0x0309, 0x0000, 0x0061, 0x0306, 0x0309, 0x0000,
+    0x0041, 0x0306, 0x0303, 0x0000, 0x0061, 0x0306, 0x0303, 0x0000,
+    0x0041, 0x0323, 0x0306, 0x0000, 0x0061, 0x0323, 0x0306, 0x0000,
+    0x0045, 0x0323, 0x0000, 0x0065, 0x0323, 0x0000, 0x0045, 0x0309,
+    0x0000, 0x0065, 0x0309, 0x0000, 0x0045, 0x0303, 0x0000, 0x0065,
+    0x0303, 0x0000, 0x0045, 0x0302, 0x0301, 0x0000, 0x0065, 0x0302,
+    0x0301, 0x0000, 0x0045, 0x0302, 0x0300, 0x0000, 0x0065, 0x0302,
+    0x0300, 0x0000, 0x0045, 0x0302, 0x0309, 0x0000, 0x0065, 0x0302,
+    0x0309, 0x0000, 0x0045, 0x0302, 0x0303, 0x0000, 0x0065, 0x0302,
+    0x0303, 0x0000, 0x0045, 0x0323, 0x0302, 0x0000, 0x0065, 0x0323,
+    0x0302, 0x0000, 0x0049, 0x0309, 0x0000, 0x0069, 0x0309, 0x0000,
+    0x0049, 0x0323, 0x0000, 0x0069, 0x0323, 0x0000, 0x004f, 0x0323,
+    0x0000, 0x006f, 0x0323, 0x0000, 0x004f, 0x0309, 0x0000, 0x006f,
+    0x0309, 0x0000, 0x004f, 0x0302, 0x0301, 0x0000, 0x006f, 0x0302,
+    0x0301, 0x0000, 0x004f, 0x0302, 0x0300, 0x0000, 0x006f, 0x0302,
+    0x0300, 0x0000, 0x004f, 0x0302, 0x0309, 0x0000, 0x006f, 0x0302,
+    0x0309, 0x0000, 0x004f, 0x0302, 0x0303, 0x0000, 0x006f, 0x0302,
+    0x0303, 0x0000, 0x004f, 0x0323, 0x0302, 0x0000, 0x006f, 0x0323,
+    0x0302, 0x0000, 0x004f, 0x031b, 0x0301, 0x0000, 0x006f, 0x031b,
+    0x0301, 0x0000, 0x004f, 0x031b, 0x0300, 0x0000, 0x006f, 0x031b,
+    0x0300, 0x0000, 0x004f, 0x031b, 0x0309, 0x0000, 0x006f, 0x031b,
+    0x0309, 0x0000, 0x004f, 0x031b, 0x0303, 0x0000, 0x006f, 0x031b,
+    0x0303, 0x0000, 0x004f, 0x031b, 0x0323, 0x0000, 0x006f, 0x031b,
+    0x0323, 0x0000, 0x0055, 0x0323, 0x0000, 0x0075, 0x0323, 0x0000,
+    0x0055, 0x0309, 0x0000, 0x0075, 0x0309, 0x0000, 0x0055, 0x031b,
+    0x0301, 0x0000, 0x0075, 0x031b, 0x0301, 0x0000, 0x0055, 0x031b,
+    0x0300, 0x0000, 0x0075, 0x031b, 0x0300, 0x0000, 0x0055, 0x031b,
+    0x0309, 0x0000, 0x0075, 0x031b, 0x0309, 0x0000, 0x0055, 0x031b,
+    0x0303, 0x0000, 0x0075, 0x031b, 0x0303, 0x0000, 0x0055, 0x031b,
+    0x0323, 0x0000, 0x0075, 0x031b, 0x0323, 0x0000, 0x0059, 0x0300,
+    0x0000, 0x0079, 0x0300, 0x0000, 0x0059, 0x0323, 0x0000, 0x0079,
+    0x0323, 0x0000, 0x0059, 0x0309, 0x0000, 0x0079, 0x0309, 0x0000,
+    0x0059, 0x0303, 0x0000, 0x0079, 0x0303, 0x0000, 0x03b1, 0x0313,
+    0x0000, 0x03b1, 0x0314, 0x0000, 0x03b1, 0x0313, 0x0300, 0x0000,
+    0x03b1, 0x0314, 0x0300, 0x0000, 0x03b1, 0x0313, 0x0301, 0x0000,
+    0x03b1, 0x0314, 0x0301, 0x0000, 0x03b1, 0x0313, 0x0342, 0x0000,
+    0x03b1, 0x0314, 0x0342, 0x0000, 0x0391, 0x0313, 0x0000, 0x0391,
+    0x0314, 0x0000, 0x0391, 0x0313, 0x0300, 0x0000, 0x0391, 0x0314,
+    0x0300, 0x0000, 0x0391, 0x0313, 0x0301, 0x0000, 0x0391, 0x0314,
+    0x0301, 0x0000, 0x0391, 0x0313, 0x0342, 0x0000, 0x0391, 0x0314,
+    0x0342, 0x0000, 0x03b5, 0x0313, 0x0000, 0x03b5, 0x0314, 0x0000,
+    0x03b5, 0x0313, 0x0300, 0x0000, 0x03b5, 0x0314, 0x0300, 0x0000,
+    0x03b5, 0x0313, 0x0301, 0x0000, 0x03b5, 0x0314, 0x0301, 0x0000,
+    0x0395, 0x0313, 0x0000, 0x0395, 0x0314, 0x0000, 0x0395, 0x0313,
+    0x0300, 0x0000, 0x0395, 0x0314, 0x0300, 0x0000, 0x0395, 0x0313,
+    0x0301, 0x0000, 0x0395, 0x0314, 0x0301, 0x0000, 0x03b7, 0x0313,
+    0x0000, 0x03b7, 0x0314, 0x0000, 0x03b7, 0x0313, 0x0300, 0x0000,
+    0x03b7, 0x0314, 0x0300, 0x0000, 0x03b7, 0x0313, 0x0301, 0x0000,
+    0x03b7, 0x0314, 0x0301, 0x0000, 0x03b7, 0x0313, 0x0342, 0x0000,
+    0x03b7, 0x0314, 0x0342, 0x0000, 0x0397, 0x0313, 0x0000, 0x0397,
+    0x0314, 0x0000, 0x0397, 0x0313, 0x0300, 0x0000, 0x0397, 0x0314,
+    0x0300, 0x0000, 0x0397, 0x0313, 0x0301, 0x0000, 0x0397, 0x0314,
+    0x0301, 0x0000, 0x0397, 0x0313, 0x0342, 0x0000, 0x0397, 0x0314,
+    0x0342, 0x0000, 0x03b9, 0x0313, 0x0000, 0x03b9, 0x0314, 0x0000,
+    0x03b9, 0x0313, 0x0300, 0x0000, 0x03b9, 0x0314, 0x0300, 0x0000,
+    0x03b9, 0x0313, 0x0301, 0x0000, 0x03b9, 0x0314, 0x0301, 0x0000,
+    0x03b9, 0x0313, 0x0342, 0x0000, 0x03b9, 0x0314, 0x0342, 0x0000,
+    0x0399, 0x0313, 0x0000, 0x0399, 0x0314, 0x0000, 0x0399, 0x0313,
+    0x0300, 0x0000, 0x0399, 0x0314, 0x0300, 0x0000, 0x0399, 0x0313,
+    0x0301, 0x0000, 0x0399, 0x0314, 0x0301, 0x0000, 0x0399, 0x0313,
+    0x0342, 0x0000, 0x0399, 0x0314, 0x0342, 0x0000, 0x03bf, 0x0313,
+    0x0000, 0x03bf, 0x0314, 0x0000, 0x03bf, 0x0313, 0x0300, 0x0000,
+    0x03bf, 0x0314, 0x0300, 0x0000, 0x03bf, 0x0313, 0x0301, 0x0000,
+    0x03bf, 0x0314, 0x0301, 0x0000, 0x039f, 0x0313, 0x0000, 0x039f,
+    0x0314, 0x0000, 0x039f, 0x0313, 0x0300, 0x0000, 0x039f, 0x0314,
+    0x0300, 0x0000, 0x039f, 0x0313, 0x0301, 0x0000, 0x039f, 0x0314,
+    0x0301, 0x0000, 0x03c5, 0x0313, 0x0000, 0x03c5, 0x0314, 0x0000,
+    0x03c5, 0x0313, 0x0300, 0x0000, 0x03c5, 0x0314, 0x0300, 0x0000,
+    0x03c5, 0x0313, 0x0301, 0x0000, 0x03c5, 0x0314, 0x0301, 0x0000,
+    0x03c5, 0x0313, 0x0342, 0x0000, 0x03c5, 0x0314, 0x0342, 0x0000,
+    0x03a5, 0x0314, 0x0000, 0x03a5, 0x0314, 0x0300, 0x0000, 0x03a5,
+    0x0314, 0x0301, 0x0000, 0x03a5, 0x0314, 0x0342, 0x0000, 0x03c9,
+    0x0313, 0x0000, 0x03c9, 0x0314, 0x0000, 0x03c9, 0x0313, 0x0300,
+    0x0000, 0x03c9, 0x0314, 0x0300, 0x0000, 0x03c9, 0x0313, 0x0301,
+    0x0000, 0x03c9, 0x0314, 0x0301, 0x0000, 0x03c9, 0x0313, 0x0342,
+    0x0000, 0x03c9, 0x0314, 0x0342, 0x0000, 0x03a9, 0x0313, 0x0000,
+    0x03a9, 0x0314, 0x0000, 0x03a9, 0x0313, 0x0300, 0x0000, 0x03a9,
+    0x0314, 0x0300, 0x0000, 0x03a9, 0x0313, 0x0301, 0x0000, 0x03a9,
+    0x0314, 0x0301, 0x0000, 0x03a9, 0x0313, 0x0342, 0x0000, 0x03a9,
+    0x0314, 0x0342, 0x0000, 0x03b1, 0x0300, 0x0000, 0x03b5, 0x0300,
+    0x0000, 0x03b7, 0x0300, 0x0000, 0x03b9, 0x0300, 0x0000, 0x03bf,
+    0x0300, 0x0000, 0x03c5, 0x0300, 0x0000, 0x03c9, 0x0300, 0x0000,
+    0x03b1, 0x0313, 0x0345, 0x0000, 0x03b1, 0x0314, 0x0345, 0x0000,
+    0x03b1, 0x0313, 0x0300, 0x0345, 0x0000, 0x03b1, 0x0314, 0x0300,
+    0x0345, 0x0000, 0x03b1, 0x0313, 0x0301, 0x0345, 0x0000, 0x03b1,
+    0x0314, 0x0301, 0x0345, 0x0000, 0x03b1, 0x0313, 0x0342, 0x0345,
+    0x0000, 0x03b1, 0x0314, 0x0342, 0x0345, 0x0000, 0x0391, 0x0313,
+    0x0345, 0x0000, 0x0391, 0x0314, 0x0345, 0x0000, 0x0391, 0x0313,
+    0x0300, 0x0345, 0x0000, 0x0391, 0x0314, 0x0300, 0x0345, 0x0000,
+    0x0391, 0x0313, 0x0301, 0x0345, 0x0000, 0x0391, 0x0314, 0x0301,
+    0x0345, 0x0000, 0x0391, 0x0313, 0x0342, 0x0345, 0x0000, 0x0391,
+    0x0314, 0x0342, 0x0345, 0x0000, 0x03b7, 0x0313, 0x0345, 0x0000,
+    0x03b7, 0x0314, 0x0345, 0x0000, 0x03b7, 0x0313, 0x0300, 0x0345,
+    0x0000, 0x03b7, 0x0314, 0x0300, 0x0345, 0x0000, 0x03b7, 0x0313,
+    0x0301, 0x0345, 0x0000, 0x03b7, 0x0314, 0x0301, 0x0345, 0x0000,
+    0x03b7, 0x0313, 0x0342, 0x0345, 0x0000, 0x03b7, 0x0314, 0x0342,
+    0x0345, 0x0000, 0x0397, 0x0313, 0x0345, 0x0000, 0x0397, 0x0314,
+    0x0345, 0x0000, 0x0397, 0x0313, 0x0300, 0x0345, 0x0000, 0x0397,
+    0x0314, 0x0300, 0x0345, 0x0000, 0x0397, 0x0313, 0x0301, 0x0345,
+    0x0000, 0x0397, 0x0314, 0x0301, 0x0345, 0x0000, 0x0397, 0x0313,
+    0x0342, 0x0345, 0x0000, 0x0397, 0x0314, 0x0342, 0x0345, 0x0000,
+    0x03c9, 0x0313, 0x0345, 0x0000, 0x03c9, 0x0314, 0x0345, 0x0000,
+    0x03c9, 0x0313, 0x0300, 0x0345, 0x0000, 0x03c9, 0x0314, 0x0300,
+    0x0345, 0x0000, 0x03c9, 0x0313, 0x0301, 0x0345, 0x0000, 0x03c9,
+    0x0314, 0x0301, 0x0345, 0x0000, 0x03c9, 0x0313, 0x0342, 0x0345,
+    0x0000, 0x03c9, 0x0314, 0x0342, 0x0345, 0x0000, 0x03a9, 0x0313,
+    0x0345, 0x0000, 0x03a9, 0x0314, 0x0345, 0x0000, 0x03a9, 0x0313,
+    0x0300, 0x0345, 0x0000, 0x03a9, 0x0314, 0x0300, 0x0345, 0x0000,
+    0x03a9, 0x0313, 0x0301, 0x0345, 0x0000, 0x03a9, 0x0314, 0x0301,
+    0x0345, 0x0000, 0x03a9, 0x0313, 0x0342, 0x0345, 0x0000, 0x03a9,
+    0x0314, 0x0342, 0x0345, 0x0000, 0x03b1, 0x0306, 0x0000, 0x03b1,
+    0x0304, 0x0000, 0x03b1, 0x0300, 0x0345, 0x0000, 0x03b1, 0x0345,
+    0x0000, 0x03b1, 0x0301, 0x0345, 0x0000, 0x03b1, 0x0342, 0x0000,
+    0x03b1, 0x0342, 0x0345, 0x0000, 0x0391, 0x0306, 0x0000, 0x0391,
+    0x0304, 0x0000, 0x0391, 0x0300, 0x0000, 0x0391, 0x0345, 0x0000,
+    0x0020, 0x0313, 0x0000, 0x03b9, 0x0000, 0x0020, 0x0342, 0x0000,
+    0x00a8, 0x0342, 0x0000, 0x0020, 0x0308, 0x0342, 0x0000, 0x03b7,
+    0x0300, 0x0345, 0x0000, 0x03b7, 0x0345, 0x0000, 0x03b7, 0x0301,
+    0x0345, 0x0000, 0x03b7, 0x0342, 0x0000, 0x03b7, 0x0342, 0x0345,
+    0x0000, 0x0395, 0x0300, 0x0000, 0x0397, 0x0300, 0x0000, 0x0397,
+    0x0345, 0x0000, 0x1fbf, 0x0300, 0x0000, 0x0020, 0x0313, 0x0300,
+    0x0000, 0x1fbf, 0x0301, 0x0000, 0x0020, 0x0313, 0x0301, 0x0000,
+    0x1fbf, 0x0342, 0x0000, 0x0020, 0x0313, 0x0342, 0x0000, 0x03b9,
+    0x0306, 0x0000, 0x03b9, 0x0304, 0x0000, 0x03b9, 0x0308, 0x0300,
+    0x0000, 0x03b9, 0x0342, 0x0000, 0x03b9, 0x0308, 0x0342, 0x0000,
+    0x0399, 0x0306, 0x0000, 0x0399, 0x0304, 0x0000, 0x0399, 0x0300,
+    0x0000, 0x1ffe, 0x0300, 0x0000, 0x0020, 0x0314, 0x0300, 0x0000,
+    0x1ffe, 0x0301, 0x0000, 0x0020, 0x0314, 0x0301, 0x0000, 0x1ffe,
+    0x0342, 0x0000, 0x0020, 0x0314, 0x0342, 0x0000, 0x03c5, 0x0306,
+    0x0000, 0x03c5, 0x0304, 0x0000, 0x03c5, 0x0308, 0x0300, 0x0000,
+    0x03c1, 0x0313, 0x0000, 0x03c1, 0x0314, 0x0000, 0x03c5, 0x0342,
+    0x0000, 0x03c5, 0x0308, 0x0342, 0x0000, 0x03a5, 0x0306, 0x0000,
+    0x03a5, 0x0304, 0x0000, 0x03a5, 0x0300, 0x0000, 0x03a1, 0x0314,
+    0x0000, 0x00a8, 0x0300, 0x0000, 0x0020, 0x0308, 0x0300, 0x0000,
+    0x0060, 0x0000, 0x03c9, 0x0300, 0x0345, 0x0000, 0x03c9, 0x0345,
+    0x0000, 0x03c9, 0x0301, 0x0345, 0x0000, 0x03c9, 0x0342, 0x0000,
+    0x03c9, 0x0342, 0x0345, 0x0000, 0x039f, 0x0300, 0x0000, 0x03a9,
+    0x0300, 0x0000, 0x03a9, 0x0345, 0x0000, 0x00b4, 0x0000, 0x0020,
+    0x0314, 0x0000, 0x2002, 0x0000, 0x2003, 0x0000, 0x2010, 0x0000,
+    0x0020, 0x0333, 0x0000, 0x002e, 0x0000, 0x002e, 0x002e, 0x0000,
+    0x002e, 0x002e, 0x002e, 0x0000, 0x2032, 0x2032, 0x0000, 0x2032,
+    0x2032, 0x2032, 0x0000, 0x2035, 0x2035, 0x0000, 0x2035, 0x2035,
+    0x2035, 0x0000, 0x0021, 0x0021, 0x0000, 0x0020, 0x0305, 0x0000,
+    0x003f, 0x003f, 0x0000, 0x003f, 0x0021, 0x0000, 0x0021, 0x003f,
+    0x0000, 0x2032, 0x2032, 0x2032, 0x2032, 0x0000, 0x0030, 0x0000,
+    0x0034, 0x0000, 0x0035, 0x0000, 0x0036, 0x0000, 0x0037, 0x0000,
+    0x0038, 0x0000, 0x0039, 0x0000, 0x002b, 0x0000, 0x2212, 0x0000,
+    0x003d, 0x0000, 0x0028, 0x0000, 0x0029, 0x0000, 0x006e, 0x0000,
+    0x0052, 0x0073, 0x0000, 0x0061, 0x002f, 0x0063, 0x0000, 0x0061,
+    0x002f, 0x0073, 0x0000, 0x0043, 0x0000, 0x00b0, 0x0043, 0x0000,
+    0x0063, 0x002f, 0x006f, 0x0000, 0x0063, 0x002f, 0x0075, 0x0000,
+    0x0190, 0x0000, 0x00b0, 0x0046, 0x0000, 0x0127, 0x0000, 0x004e,
+    0x006f, 0x0000, 0x0051, 0x0000, 0x0053, 0x004d, 0x0000, 0x0054,
+    0x0045, 0x004c, 0x0000, 0x0054, 0x004d, 0x0000, 0x005a, 0x0000,
+    0x03a9, 0x0000, 0x0046, 0x0000, 0x05d0, 0x0000, 0x05d1, 0x0000,
+    0x05d2, 0x0000, 0x05d3, 0x0000, 0x0046, 0x0041, 0x0058, 0x0000,
+    0x0393, 0x0000, 0x03a0, 0x0000, 0x2211, 0x0000, 0x0031, 0x2044,
+    0x0037, 0x0000, 0x0031, 0x2044, 0x0039, 0x0000, 0x0031, 0x2044,
+    0x0031, 0x0030, 0x0000, 0x0031, 0x2044, 0x0033, 0x0000, 0x0032,
+    0x2044, 0x0033, 0x0000, 0x0031, 0x2044, 0x0035, 0x0000, 0x0032,
+    0x2044, 0x0035, 0x0000, 0x0033, 0x2044, 0x0035, 0x0000, 0x0034,
+    0x2044, 0x0035, 0x0000, 0x0031, 0x2044, 0x0036, 0x0000, 0x0035,
+    0x2044, 0x0036, 0x0000, 0x0031, 0x2044, 0x0038, 0x0000, 0x0033,
+    0x2044, 0x0038, 0x0000, 0x0035, 0x2044, 0x0038, 0x0000, 0x0037,
+    0x2044, 0x0038, 0x0000, 0x0031, 0x2044, 0x0000, 0x0049, 0x0049,
+    0x0000, 0x0049, 0x0049, 0x0049, 0x0000, 0x0049, 0x0056, 0x0000,
+    0x0056, 0x0000, 0x0056, 0x0049, 0x0000, 0x0056, 0x0049, 0x0049,
+    0x0000, 0x0056, 0x0049, 0x0049, 0x0049, 0x0000, 0x0049, 0x0058,
+    0x0000, 0x0058, 0x0000, 0x0058, 0x0049, 0x0000, 0x0058, 0x0049,
+    0x0049, 0x0000, 0x0069, 0x0069, 0x0000, 0x0069, 0x0069, 0x0069,
+    0x0000, 0x0069, 0x0076, 0x0000, 0x0076, 0x0069, 0x0000, 0x0076,
+    0x0069, 0x0069, 0x0000, 0x0076, 0x0069, 0x0069, 0x0069, 0x0000,
+    0x0069, 0x0078, 0x0000, 0x0078, 0x0069, 0x0000, 0x0078, 0x0069,
+    0x0069, 0x0000, 0x0030, 0x2044, 0x0033, 0x0000, 0x2190, 0x0338,
+    0x0000, 0x2192, 0x0338, 0x0000, 0x2194, 0x0338, 0x0000, 0x21d0,
+    0x0338, 0x0000, 0x21d4, 0x0338, 0x0000, 0x21d2, 0x0338, 0x0000,
+    0x2203, 0x0338, 0x0000, 0x2208, 0x0338, 0x0000, 0x220b, 0x0338,
+    0x0000, 0x2223, 0x0338, 0x0000, 0x2225, 0x0338, 0x0000, 0x222b,
+    0x222b, 0x0000, 0x222b, 0x222b, 0x222b, 0x0000, 0x222e, 0x222e,
+    0x0000, 0x222e, 0x222e, 0x222e, 0x0000, 0x223c, 0x0338, 0x0000,
+    0x2243, 0x0338, 0x0000, 0x2245, 0x0338, 0x0000, 0x2248, 0x0338,
+    0x0000, 0x003d, 0x0338, 0x0000, 0x2261, 0x0338, 0x0000, 0x224d,
+    0x0338, 0x0000, 0x003c, 0x0338, 0x0000, 0x003e, 0x0338, 0x0000,
+    0x2264, 0x0338, 0x0000, 0x2265, 0x0338, 0x0000, 0x2272, 0x0338,
+    0x0000, 0x2273, 0x0338, 0x0000, 0x2276, 0x0338, 0x0000, 0x2277,
+    0x0338, 0x0000, 0x227a, 0x0338, 0x0000, 0x227b, 0x0338, 0x0000,
+    0x2282, 0x0338, 0x0000, 0x2283, 0x0338, 0x0000, 0x2286, 0x0338,
+    0x0000, 0x2287, 0x0338, 0x0000, 0x22a2, 0x0338, 0x0000, 0x22a8,
+    0x0338, 0x0000, 0x22a9, 0x0338, 0x0000, 0x22ab, 0x0338, 0x0000,
+    0x227c, 0x0338, 0x0000, 0x227d, 0x0338, 0x0000, 0x2291, 0x0338,
+    0x0000, 0x2292, 0x0338, 0x0000, 0x22b2, 0x0338, 0x0000, 0x22b3,
+    0x0338, 0x0000, 0x22b4, 0x0338, 0x0000, 0x22b5, 0x0338, 0x0000,
+    0x3008, 0x0000, 0x3009, 0x0000, 0x0031, 0x0030, 0x0000, 0x0031,
+    0x0031, 0x0000, 0x0031, 0x0032, 0x0000, 0x0031, 0x0033, 0x0000,
+    0x0031, 0x0034, 0x0000, 0x0031, 0x0035, 0x0000, 0x0031, 0x0036,
+    0x0000, 0x0031, 0x0037, 0x0000, 0x0031, 0x0038, 0x0000, 0x0031,
+    0x0039, 0x0000, 0x0032, 0x0030, 0x0000, 0x0028, 0x0031, 0x0029,
+    0x0000, 0x0028, 0x0032, 0x0029, 0x0000, 0x0028, 0x0033, 0x0029,
+    0x0000, 0x0028, 0x0034, 0x0029, 0x0000, 0x0028, 0x0035, 0x0029,
+    0x0000, 0x0028, 0x0036, 0x0029, 0x0000, 0x0028, 0x0037, 0x0029,
+    0x0000, 0x0028, 0x0038, 0x0029, 0x0000, 0x0028, 0x0039, 0x0029,
+    0x0000, 0x0028, 0x0031, 0x0030, 0x0029, 0x0000, 0x0028, 0x0031,
+    0x0031, 0x0029, 0x0000, 0x0028, 0x0031, 0x0032, 0x0029, 0x0000,
+    0x0028, 0x0031, 0x0033, 0x0029, 0x0000, 0x0028, 0x0031, 0x0034,
+    0x0029, 0x0000, 0x0028, 0x0031, 0x0035, 0x0029, 0x0000, 0x0028,
+    0x0031, 0x0036, 0x0029, 0x0000, 0x0028, 0x0031, 0x0037, 0x0029,
+    0x0000, 0x0028, 0x0031, 0x0038, 0x0029, 0x0000, 0x0028, 0x0031,
+    0x0039, 0x0029, 0x0000, 0x0028, 0x0032, 0x0030, 0x0029, 0x0000,
+    0x0031, 0x002e, 0x0000, 0x0032, 0x002e, 0x0000, 0x0033, 0x002e,
+    0x0000, 0x0034, 0x002e, 0x0000, 0x0035, 0x002e, 0x0000, 0x0036,
+    0x002e, 0x0000, 0x0037, 0x002e, 0x0000, 0x0038, 0x002e, 0x0000,
+    0x0039, 0x002e, 0x0000, 0x0031, 0x0030, 0x002e, 0x0000, 0x0031,
+    0x0031, 0x002e, 0x0000, 0x0031, 0x0032, 0x002e, 0x0000, 0x0031,
+    0x0033, 0x002e, 0x0000, 0x0031, 0x0034, 0x002e, 0x0000, 0x0031,
+    0x0035, 0x002e, 0x0000, 0x0031, 0x0036, 0x002e, 0x0000, 0x0031,
+    0x0037, 0x002e, 0x0000, 0x0031, 0x0038, 0x002e, 0x0000, 0x0031,
+    0x0039, 0x002e, 0x0000, 0x0032, 0x0030, 0x002e, 0x0000, 0x0028,
+    0x0061, 0x0029, 0x0000, 0x0028, 0x0062, 0x0029, 0x0000, 0x0028,
+    0x0063, 0x0029, 0x0000, 0x0028, 0x0064, 0x0029, 0x0000, 0x0028,
+    0x0065, 0x0029, 0x0000, 0x0028, 0x0066, 0x0029, 0x0000, 0x0028,
+    0x0067, 0x0029, 0x0000, 0x0028, 0x0068, 0x0029, 0x0000, 0x0028,
+    0x0069, 0x0029, 0x0000, 0x0028, 0x006a, 0x0029, 0x0000, 0x0028,
+    0x006b, 0x0029, 0x0000, 0x0028, 0x006c, 0x0029, 0x0000, 0x0028,
+    0x006d, 0x0029, 0x0000, 0x0028, 0x006e, 0x0029, 0x0000, 0x0028,
+    0x006f, 0x0029, 0x0000, 0x0028, 0x0070, 0x0029, 0x0000, 0x0028,
+    0x0071, 0x0029, 0x0000, 0x0028, 0x0072, 0x0029, 0x0000, 0x0028,
+    0x0073, 0x0029, 0x0000, 0x0028, 0x0074, 0x0029, 0x0000, 0x0028,
+    0x0075, 0x0029, 0x0000, 0x0028, 0x0076, 0x0029, 0x0000, 0x0028,
+    0x0077, 0x0029, 0x0000, 0x0028, 0x0078, 0x0029, 0x0000, 0x0028,
+    0x0079, 0x0029, 0x0000, 0x0028, 0x007a, 0x0029, 0x0000, 0x0053,
+    0x0000, 0x0059, 0x0000, 0x0071, 0x0000, 0x222b, 0x222b, 0x222b,
+    0x222b, 0x0000, 0x003a, 0x003a, 0x003d, 0x0000, 0x003d, 0x003d,
+    0x0000, 0x003d, 0x003d, 0x003d, 0x0000, 0x2add, 0x0338, 0x0000,
+    0x2d61, 0x0000, 0x6bcd, 0x0000, 0x9f9f, 0x0000, 0x4e00, 0x0000,
+    0x4e28, 0x0000, 0x4e36, 0x0000, 0x4e3f, 0x0000, 0x4e59, 0x0000,
+    0x4e85, 0x0000, 0x4e8c, 0x0000, 0x4ea0, 0x0000, 0x4eba, 0x0000,
+    0x513f, 0x0000, 0x5165, 0x0000, 0x516b, 0x0000, 0x5182, 0x0000,
+    0x5196, 0x0000, 0x51ab, 0x0000, 0x51e0, 0x0000, 0x51f5, 0x0000,
+    0x5200, 0x0000, 0x529b, 0x0000, 0x52f9, 0x0000, 0x5315, 0x0000,
+    0x531a, 0x0000, 0x5338, 0x0000, 0x5341, 0x0000, 0x535c, 0x0000,
+    0x5369, 0x0000, 0x5382, 0x0000, 0x53b6, 0x0000, 0x53c8, 0x0000,
+    0x53e3, 0x0000, 0x56d7, 0x0000, 0x571f, 0x0000, 0x58eb, 0x0000,
+    0x5902, 0x0000, 0x590a, 0x0000, 0x5915, 0x0000, 0x5927, 0x0000,
+    0x5973, 0x0000, 0x5b50, 0x0000, 0x5b80, 0x0000, 0x5bf8, 0x0000,
+    0x5c0f, 0x0000, 0x5c22, 0x0000, 0x5c38, 0x0000, 0x5c6e, 0x0000,
+    0x5c71, 0x0000, 0x5ddb, 0x0000, 0x5de5, 0x0000, 0x5df1, 0x0000,
+    0x5dfe, 0x0000, 0x5e72, 0x0000, 0x5e7a, 0x0000, 0x5e7f, 0x0000,
+    0x5ef4, 0x0000, 0x5efe, 0x0000, 0x5f0b, 0x0000, 0x5f13, 0x0000,
+    0x5f50, 0x0000, 0x5f61, 0x0000, 0x5f73, 0x0000, 0x5fc3, 0x0000,
+    0x6208, 0x0000, 0x6236, 0x0000, 0x624b, 0x0000, 0x652f, 0x0000,
+    0x6534, 0x0000, 0x6587, 0x0000, 0x6597, 0x0000, 0x65a4, 0x0000,
+    0x65b9, 0x0000, 0x65e0, 0x0000, 0x65e5, 0x0000, 0x66f0, 0x0000,
+    0x6708, 0x0000, 0x6728, 0x0000, 0x6b20, 0x0000, 0x6b62, 0x0000,
+    0x6b79, 0x0000, 0x6bb3, 0x0000, 0x6bcb, 0x0000, 0x6bd4, 0x0000,
+    0x6bdb, 0x0000, 0x6c0f, 0x0000, 0x6c14, 0x0000, 0x6c34, 0x0000,
+    0x706b, 0x0000, 0x722a, 0x0000, 0x7236, 0x0000, 0x723b, 0x0000,
+    0x723f, 0x0000, 0x7247, 0x0000, 0x7259, 0x0000, 0x725b, 0x0000,
+    0x72ac, 0x0000, 0x7384, 0x0000, 0x7389, 0x0000, 0x74dc, 0x0000,
+    0x74e6, 0x0000, 0x7518, 0x0000, 0x751f, 0x0000, 0x7528, 0x0000,
+    0x7530, 0x0000, 0x758b, 0x0000, 0x7592, 0x0000, 0x7676, 0x0000,
+    0x767d, 0x0000, 0x76ae, 0x0000, 0x76bf, 0x0000, 0x76ee, 0x0000,
+    0x77db, 0x0000, 0x77e2, 0x0000, 0x77f3, 0x0000, 0x793a, 0x0000,
+    0x79b8, 0x0000, 0x79be, 0x0000, 0x7a74, 0x0000, 0x7acb, 0x0000,
+    0x7af9, 0x0000, 0x7c73, 0x0000, 0x7cf8, 0x0000, 0x7f36, 0x0000,
+    0x7f51, 0x0000, 0x7f8a, 0x0000, 0x7fbd, 0x0000, 0x8001, 0x0000,
+    0x800c, 0x0000, 0x8012, 0x0000, 0x8033, 0x0000, 0x807f, 0x0000,
+    0x8089, 0x0000, 0x81e3, 0x0000, 0x81ea, 0x0000, 0x81f3, 0x0000,
+    0x81fc, 0x0000, 0x820c, 0x0000, 0x821b, 0x0000, 0x821f, 0x0000,
+    0x826e, 0x0000, 0x8272, 0x0000, 0x8278, 0x0000, 0x864d, 0x0000,
+    0x866b, 0x0000, 0x8840, 0x0000, 0x884c, 0x0000, 0x8863, 0x0000,
+    0x897e, 0x0000, 0x898b, 0x0000, 0x89d2, 0x0000, 0x8a00, 0x0000,
+    0x8c37, 0x0000, 0x8c46, 0x0000, 0x8c55, 0x0000, 0x8c78, 0x0000,
+    0x8c9d, 0x0000, 0x8d64, 0x0000, 0x8d70, 0x0000, 0x8db3, 0x0000,
+    0x8eab, 0x0000, 0x8eca, 0x0000, 0x8f9b, 0x0000, 0x8fb0, 0x0000,
+    0x8fb5, 0x0000, 0x9091, 0x0000, 0x9149, 0x0000, 0x91c6, 0x0000,
+    0x91cc, 0x0000, 0x91d1, 0x0000, 0x9577, 0x0000, 0x9580, 0x0000,
+    0x961c, 0x0000, 0x96b6, 0x0000, 0x96b9, 0x0000, 0x96e8, 0x0000,
+    0x9751, 0x0000, 0x975e, 0x0000, 0x9762, 0x0000, 0x9769, 0x0000,
+    0x97cb, 0x0000, 0x97ed, 0x0000, 0x97f3, 0x0000, 0x9801, 0x0000,
+    0x98a8, 0x0000, 0x98db, 0x0000, 0x98df, 0x0000, 0x9996, 0x0000,
+    0x9999, 0x0000, 0x99ac, 0x0000, 0x9aa8, 0x0000, 0x9ad8, 0x0000,
+    0x9adf, 0x0000, 0x9b25, 0x0000, 0x9b2f, 0x0000, 0x9b32, 0x0000,
+    0x9b3c, 0x0000, 0x9b5a, 0x0000, 0x9ce5, 0x0000, 0x9e75, 0x0000,
+    0x9e7f, 0x0000, 0x9ea5, 0x0000, 0x9ebb, 0x0000, 0x9ec3, 0x0000,
+    0x9ecd, 0x0000, 0x9ed1, 0x0000, 0x9ef9, 0x0000, 0x9efd, 0x0000,
+    0x9f0e, 0x0000, 0x9f13, 0x0000, 0x9f20, 0x0000, 0x9f3b, 0x0000,
+    0x9f4a, 0x0000, 0x9f52, 0x0000, 0x9f8d, 0x0000, 0x9f9c, 0x0000,
+    0x9fa0, 0x0000, 0x3012, 0x0000, 0x5344, 0x0000, 0x5345, 0x0000,
+    0x304b, 0x3099, 0x0000, 0x304d, 0x3099, 0x0000, 0x304f, 0x3099,
+    0x0000, 0x3051, 0x3099, 0x0000, 0x3053, 0x3099, 0x0000, 0x3055,
+    0x3099, 0x0000, 0x3057, 0x3099, 0x0000, 0x3059, 0x3099, 0x0000,
+    0x305b, 0x3099, 0x0000, 0x305d, 0x3099, 0x0000, 0x305f, 0x3099,
+    0x0000, 0x3061, 0x3099, 0x0000, 0x3064, 0x3099, 0x0000, 0x3066,
+    0x3099, 0x0000, 0x3068, 0x3099, 0x0000, 0x306f, 0x3099, 0x0000,
+    0x306f, 0x309a, 0x0000, 0x3072, 0x3099, 0x0000, 0x3072, 0x309a,
+    0x0000, 0x3075, 0x3099, 0x0000, 0x3075, 0x309a, 0x0000, 0x3078,
+    0x3099, 0x0000, 0x3078, 0x309a, 0x0000, 0x307b, 0x3099, 0x0000,
+    0x307b, 0x309a, 0x0000, 0x3046, 0x3099, 0x0000, 0x0020, 0x3099,
+    0x0000, 0x0020, 0x309a, 0x0000, 0x309d, 0x3099, 0x0000, 0x3088,
+    0x308a, 0x0000, 0x30ab, 0x3099, 0x0000, 0x30ad, 0x3099, 0x0000,
+    0x30af, 0x3099, 0x0000, 0x30b1, 0x3099, 0x0000, 0x30b3, 0x3099,
+    0x0000, 0x30b5, 0x3099, 0x0000, 0x30b7, 0x3099, 0x0000, 0x30b9,
+    0x3099, 0x0000, 0x30bb, 0x3099, 0x0000, 0x30bd, 0x3099, 0x0000,
+    0x30bf, 0x3099, 0x0000, 0x30c1, 0x3099, 0x0000, 0x30c4, 0x3099,
+    0x0000, 0x30c6, 0x3099, 0x0000, 0x30c8, 0x3099, 0x0000, 0x30cf,
+    0x3099, 0x0000, 0x30cf, 0x309a, 0x0000, 0x30d2, 0x3099, 0x0000,
+    0x30d2, 0x309a, 0x0000, 0x30d5, 0x3099, 0x0000, 0x30d5, 0x309a,
+    0x0000, 0x30d8, 0x3099, 0x0000, 0x30d8, 0x309a, 0x0000, 0x30db,
+    0x3099, 0x0000, 0x30db, 0x309a, 0x0000, 0x30a6, 0x3099, 0x0000,
+    0x30ef, 0x3099, 0x0000, 0x30f0, 0x3099, 0x0000, 0x30f1, 0x3099,
+    0x0000, 0x30f2, 0x3099, 0x0000, 0x30fd, 0x3099, 0x0000, 0x30b3,
+    0x30c8, 0x0000, 0x1100, 0x0000, 0x1101, 0x0000, 0x11aa, 0x0000,
+    0x1102, 0x0000, 0x11ac, 0x0000, 0x11ad, 0x0000, 0x1103, 0x0000,
+    0x1104, 0x0000, 0x1105, 0x0000, 0x11b0, 0x0000, 0x11b1, 0x0000,
+    0x11b2, 0x0000, 0x11b3, 0x0000, 0x11b4, 0x0000, 0x11b5, 0x0000,
+    0x111a, 0x0000, 0x1106, 0x0000, 0x1107, 0x0000, 0x1108, 0x0000,
+    0x1121, 0x0000, 0x1109, 0x0000, 0x110a, 0x0000, 0x110b, 0x0000,
+    0x110c, 0x0000, 0x110d, 0x0000, 0x110e, 0x0000, 0x110f, 0x0000,
+    0x1110, 0x0000, 0x1111, 0x0000, 0x1112, 0x0000, 0x1161, 0x0000,
+    0x1162, 0x0000, 0x1163, 0x0000, 0x1164, 0x0000, 0x1165, 0x0000,
+    0x1166, 0x0000, 0x1167, 0x0000, 0x1168, 0x0000, 0x1169, 0x0000,
+    0x116a, 0x0000, 0x116b, 0x0000, 0x116c, 0x0000, 0x116d, 0x0000,
+    0x116e, 0x0000, 0x116f, 0x0000, 0x1170, 0x0000, 0x1171, 0x0000,
+    0x1172, 0x0000, 0x1173, 0x0000, 0x1174, 0x0000, 0x1175, 0x0000,
+    0x1160, 0x0000, 0x1114, 0x0000, 0x1115, 0x0000, 0x11c7, 0x0000,
+    0x11c8, 0x0000, 0x11cc, 0x0000, 0x11ce, 0x0000, 0x11d3, 0x0000,
+    0x11d7, 0x0000, 0x11d9, 0x0000, 0x111c, 0x0000, 0x11dd, 0x0000,
+    0x11df, 0x0000, 0x111d, 0x0000, 0x111e, 0x0000, 0x1120, 0x0000,
+    0x1122, 0x0000, 0x1123, 0x0000, 0x1127, 0x0000, 0x1129, 0x0000,
+    0x112b, 0x0000, 0x112c, 0x0000, 0x112d, 0x0000, 0x112e, 0x0000,
+    0x112f, 0x0000, 0x1132, 0x0000, 0x1136, 0x0000, 0x1140, 0x0000,
+    0x1147, 0x0000, 0x114c, 0x0000, 0x11f1, 0x0000, 0x11f2, 0x0000,
+    0x1157, 0x0000, 0x1158, 0x0000, 0x1159, 0x0000, 0x1184, 0x0000,
+    0x1185, 0x0000, 0x1188, 0x0000, 0x1191, 0x0000, 0x1192, 0x0000,
+    0x1194, 0x0000, 0x119e, 0x0000, 0x11a1, 0x0000, 0x4e09, 0x0000,
+    0x56db, 0x0000, 0x4e0a, 0x0000, 0x4e2d, 0x0000, 0x4e0b, 0x0000,
+    0x7532, 0x0000, 0x4e19, 0x0000, 0x4e01, 0x0000, 0x5929, 0x0000,
+    0x5730, 0x0000, 0x0028, 0x1100, 0x0029, 0x0000, 0x0028, 0x1102,
+    0x0029, 0x0000, 0x0028, 0x1103, 0x0029, 0x0000, 0x0028, 0x1105,
+    0x0029, 0x0000, 0x0028, 0x1106, 0x0029, 0x0000, 0x0028, 0x1107,
+    0x0029, 0x0000, 0x0028, 0x1109, 0x0029, 0x0000, 0x0028, 0x110b,
+    0x0029, 0x0000, 0x0028, 0x110c, 0x0029, 0x0000, 0x0028, 0x110e,
+    0x0029, 0x0000, 0x0028, 0x110f, 0x0029, 0x0000, 0x0028, 0x1110,
+    0x0029, 0x0000, 0x0028, 0x1111, 0x0029, 0x0000, 0x0028, 0x1112,
+    0x0029, 0x0000, 0x0028, 0x1100, 0x1161, 0x0029, 0x0000, 0x0028,
+    0x1102, 0x1161, 0x0029, 0x0000, 0x0028, 0x1103, 0x1161, 0x0029,
+    0x0000, 0x0028, 0x1105, 0x1161, 0x0029, 0x0000, 0x0028, 0x1106,
+    0x1161, 0x0029, 0x0000, 0x0028, 0x1107, 0x1161, 0x0029, 0x0000,
+    0x0028, 0x1109, 0x1161, 0x0029, 0x0000, 0x0028, 0x110b, 0x1161,
+    0x0029, 0x0000, 0x0028, 0x110c, 0x1161, 0x0029, 0x0000, 0x0028,
+    0x110e, 0x1161, 0x0029, 0x0000, 0x0028, 0x110f, 0x1161, 0x0029,
+    0x0000, 0x0028, 0x1110, 0x1161, 0x0029, 0x0000, 0x0028, 0x1111,
+    0x1161, 0x0029, 0x0000, 0x0028, 0x1112, 0x1161, 0x0029, 0x0000,
+    0x0028, 0x110c, 0x116e, 0x0029, 0x0000, 0x0028, 0x110b, 0x1169,
+    0x110c, 0x1165, 0x11ab, 0x0029, 0x0000, 0x0028, 0x110b, 0x1169,
+    0x1112, 0x116e, 0x0029, 0x0000, 0x0028, 0x4e00, 0x0029, 0x0000,
+    0x0028, 0x4e8c, 0x0029, 0x0000, 0x0028, 0x4e09, 0x0029, 0x0000,
+    0x0028, 0x56db, 0x0029, 0x0000, 0x0028, 0x4e94, 0x0029, 0x0000,
+    0x0028, 0x516d, 0x0029, 0x0000, 0x0028, 0x4e03, 0x0029, 0x0000,
+    0x0028, 0x516b, 0x0029, 0x0000, 0x0028, 0x4e5d, 0x0029, 0x0000,
+    0x0028, 0x5341, 0x0029, 0x0000, 0x0028, 0x6708, 0x0029, 0x0000,
+    0x0028, 0x706b, 0x0029, 0x0000, 0x0028, 0x6c34, 0x0029, 0x0000,
+    0x0028, 0x6728, 0x0029, 0x0000, 0x0028, 0x91d1, 0x0029, 0x0000,
+    0x0028, 0x571f, 0x0029, 0x0000, 0x0028, 0x65e5, 0x0029, 0x0000,
+    0x0028, 0x682a, 0x0029, 0x0000, 0x0028, 0x6709, 0x0029, 0x0000,
+    0x0028, 0x793e, 0x0029, 0x0000, 0x0028, 0x540d, 0x0029, 0x0000,
+    0x0028, 0x7279, 0x0029, 0x0000, 0x0028, 0x8ca1, 0x0029, 0x0000,
+    0x0028, 0x795d, 0x0029, 0x0000, 0x0028, 0x52b4, 0x0029, 0x0000,
+    0x0028, 0x4ee3, 0x0029, 0x0000, 0x0028, 0x547c, 0x0029, 0x0000,
+    0x0028, 0x5b66, 0x0029, 0x0000, 0x0028, 0x76e3, 0x0029, 0x0000,
+    0x0028, 0x4f01, 0x0029, 0x0000, 0x0028, 0x8cc7, 0x0029, 0x0000,
+    0x0028, 0x5354, 0x0029, 0x0000, 0x0028, 0x796d, 0x0029, 0x0000,
+    0x0028, 0x4f11, 0x0029, 0x0000, 0x0028, 0x81ea, 0x0029, 0x0000,
+    0x0028, 0x81f3, 0x0029, 0x0000, 0x554f, 0x0000, 0x5e7c, 0x0000,
+    0x7b8f, 0x0000, 0x0050, 0x0054, 0x0045, 0x0000, 0x0032, 0x0031,
+    0x0000, 0x0032, 0x0032, 0x0000, 0x0032, 0x0033, 0x0000, 0x0032,
+    0x0034, 0x0000, 0x0032, 0x0035, 0x0000, 0x0032, 0x0036, 0x0000,
+    0x0032, 0x0037, 0x0000, 0x0032, 0x0038, 0x0000, 0x0032, 0x0039,
+    0x0000, 0x0033, 0x0030, 0x0000, 0x0033, 0x0031, 0x0000, 0x0033,
+    0x0032, 0x0000, 0x0033, 0x0033, 0x0000, 0x0033, 0x0034, 0x0000,
+    0x0033, 0x0035, 0x0000, 0x1100, 0x1161, 0x0000, 0x1102, 0x1161,
+    0x0000, 0x1103, 0x1161, 0x0000, 0x1105, 0x1161, 0x0000, 0x1106,
+    0x1161, 0x0000, 0x1107, 0x1161, 0x0000, 0x1109, 0x1161, 0x0000,
+    0x110b, 0x1161, 0x0000, 0x110c, 0x1161, 0x0000, 0x110e, 0x1161,
+    0x0000, 0x110f, 0x1161, 0x0000, 0x1110, 0x1161, 0x0000, 0x1111,
+    0x1161, 0x0000, 0x1112, 0x1161, 0x0000, 0x110e, 0x1161, 0x11b7,
+    0x1100, 0x1169, 0x0000, 0x110c, 0x116e, 0x110b, 0x1174, 0x0000,
+    0x110b, 0x116e, 0x0000, 0x4e94, 0x0000, 0x516d, 0x0000, 0x4e03,
+    0x0000, 0x4e5d, 0x0000, 0x682a, 0x0000, 0x6709, 0x0000, 0x793e,
+    0x0000, 0x540d, 0x0000, 0x7279, 0x0000, 0x8ca1, 0x0000, 0x795d,
+    0x0000, 0x52b4, 0x0000, 0x79d8, 0x0000, 0x7537, 0x0000, 0x9069,
+    0x0000, 0x512a, 0x0000, 0x5370, 0x0000, 0x6ce8, 0x0000, 0x9805,
+    0x0000, 0x4f11, 0x0000, 0x5199, 0x0000, 0x6b63, 0x0000, 0x5de6,
+    0x0000, 0x53f3, 0x0000, 0x533b, 0x0000, 0x5b97, 0x0000, 0x5b66,
+    0x0000, 0x76e3, 0x0000, 0x4f01, 0x0000, 0x8cc7, 0x0000, 0x5354,
+    0x0000, 0x591c, 0x0000, 0x0033, 0x0036, 0x0000, 0x0033, 0x0037,
+    0x0000, 0x0033, 0x0038, 0x0000, 0x0033, 0x0039, 0x0000, 0x0034,
+    0x0030, 0x0000, 0x0034, 0x0031, 0x0000, 0x0034, 0x0032, 0x0000,
+    0x0034, 0x0033, 0x0000, 0x0034, 0x0034, 0x0000, 0x0034, 0x0035,
+    0x0000, 0x0034, 0x0036, 0x0000, 0x0034, 0x0037, 0x0000, 0x0034,
+    0x0038, 0x0000, 0x0034, 0x0039, 0x0000, 0x0035, 0x0030, 0x0000,
+    0x0031, 0x6708, 0x0000, 0x0032, 0x6708, 0x0000, 0x0033, 0x6708,
+    0x0000, 0x0034, 0x6708, 0x0000, 0x0035, 0x6708, 0x0000, 0x0036,
+    0x6708, 0x0000, 0x0037, 0x6708, 0x0000, 0x0038, 0x6708, 0x0000,
+    0x0039, 0x6708, 0x0000, 0x0031, 0x0030, 0x6708, 0x0000, 0x0031,
+    0x0031, 0x6708, 0x0000, 0x0031, 0x0032, 0x6708, 0x0000, 0x0048,
+    0x0067, 0x0000, 0x0065, 0x0072, 0x0067, 0x0000, 0x0065, 0x0056,
+    0x0000, 0x004c, 0x0054, 0x0044, 0x0000, 0x30a2, 0x0000, 0x30a4,
+    0x0000, 0x30a6, 0x0000, 0x30a8, 0x0000, 0x30aa, 0x0000, 0x30ab,
+    0x0000, 0x30ad, 0x0000, 0x30af, 0x0000, 0x30b1, 0x0000, 0x30b3,
+    0x0000, 0x30b5, 0x0000, 0x30b7, 0x0000, 0x30b9, 0x0000, 0x30bb,
+    0x0000, 0x30bd, 0x0000, 0x30bf, 0x0000, 0x30c1, 0x0000, 0x30c4,
+    0x0000, 0x30c6, 0x0000, 0x30c8, 0x0000, 0x30ca, 0x0000, 0x30cb,
+    0x0000, 0x30cc, 0x0000, 0x30cd, 0x0000, 0x30ce, 0x0000, 0x30cf,
+    0x0000, 0x30d2, 0x0000, 0x30d5, 0x0000, 0x30d8, 0x0000, 0x30db,
+    0x0000, 0x30de, 0x0000, 0x30df, 0x0000, 0x30e0, 0x0000, 0x30e1,
+    0x0000, 0x30e2, 0x0000, 0x30e4, 0x0000, 0x30e6, 0x0000, 0x30e8,
+    0x0000, 0x30e9, 0x0000, 0x30ea, 0x0000, 0x30eb, 0x0000, 0x30ec,
+    0x0000, 0x30ed, 0x0000, 0x30ef, 0x0000, 0x30f0, 0x0000, 0x30f1,
+    0x0000, 0x30f2, 0x0000, 0x30a2, 0x30cf, 0x309a, 0x30fc, 0x30c8,
+    0x0000, 0x30a2, 0x30eb, 0x30d5, 0x30a1, 0x0000, 0x30a2, 0x30f3,
+    0x30d8, 0x309a, 0x30a2, 0x0000, 0x30a2, 0x30fc, 0x30eb, 0x0000,
+    0x30a4, 0x30cb, 0x30f3, 0x30af, 0x3099, 0x0000, 0x30a4, 0x30f3,
+    0x30c1, 0x0000, 0x30a6, 0x30a9, 0x30f3, 0x0000, 0x30a8, 0x30b9,
+    0x30af, 0x30fc, 0x30c8, 0x3099, 0x0000, 0x30a8, 0x30fc, 0x30ab,
+    0x30fc, 0x0000, 0x30aa, 0x30f3, 0x30b9, 0x0000, 0x30aa, 0x30fc,
+    0x30e0, 0x0000, 0x30ab, 0x30a4, 0x30ea, 0x0000, 0x30ab, 0x30e9,
+    0x30c3, 0x30c8, 0x0000, 0x30ab, 0x30ed, 0x30ea, 0x30fc, 0x0000,
+    0x30ab, 0x3099, 0x30ed, 0x30f3, 0x0000, 0x30ab, 0x3099, 0x30f3,
+    0x30de, 0x0000, 0x30ad, 0x3099, 0x30ab, 0x3099, 0x0000, 0x30ad,
+    0x3099, 0x30cb, 0x30fc, 0x0000, 0x30ad, 0x30e5, 0x30ea, 0x30fc,
+    0x0000, 0x30ad, 0x3099, 0x30eb, 0x30bf, 0x3099, 0x30fc, 0x0000,
+    0x30ad, 0x30ed, 0x0000, 0x30ad, 0x30ed, 0x30af, 0x3099, 0x30e9,
+    0x30e0, 0x0000, 0x30ad, 0x30ed, 0x30e1, 0x30fc, 0x30c8, 0x30eb,
+    0x0000, 0x30ad, 0x30ed, 0x30ef, 0x30c3, 0x30c8, 0x0000, 0x30af,
+    0x3099, 0x30e9, 0x30e0, 0x0000, 0x30af, 0x3099, 0x30e9, 0x30e0,
+    0x30c8, 0x30f3, 0x0000, 0x30af, 0x30eb, 0x30bb, 0x3099, 0x30a4,
+    0x30ed, 0x0000, 0x30af, 0x30ed, 0x30fc, 0x30cd, 0x0000, 0x30b1,
+    0x30fc, 0x30b9, 0x0000, 0x30b3, 0x30eb, 0x30ca, 0x0000, 0x30b3,
+    0x30fc, 0x30db, 0x309a, 0x0000, 0x30b5, 0x30a4, 0x30af, 0x30eb,
+    0x0000, 0x30b5, 0x30f3, 0x30c1, 0x30fc, 0x30e0, 0x0000, 0x30b7,
+    0x30ea, 0x30f3, 0x30af, 0x3099, 0x0000, 0x30bb, 0x30f3, 0x30c1,
+    0x0000, 0x30bb, 0x30f3, 0x30c8, 0x0000, 0x30bf, 0x3099, 0x30fc,
+    0x30b9, 0x0000, 0x30c6, 0x3099, 0x30b7, 0x0000, 0x30c8, 0x3099,
+    0x30eb, 0x0000, 0x30c8, 0x30f3, 0x0000, 0x30ca, 0x30ce, 0x0000,
+    0x30ce, 0x30c3, 0x30c8, 0x0000, 0x30cf, 0x30a4, 0x30c4, 0x0000,
+    0x30cf, 0x309a, 0x30fc, 0x30bb, 0x30f3, 0x30c8, 0x0000, 0x30cf,
+    0x309a, 0x30fc, 0x30c4, 0x0000, 0x30cf, 0x3099, 0x30fc, 0x30ec,
+    0x30eb, 0x0000, 0x30d2, 0x309a, 0x30a2, 0x30b9, 0x30c8, 0x30eb,
+    0x0000, 0x30d2, 0x309a, 0x30af, 0x30eb, 0x0000, 0x30d2, 0x309a,
+    0x30b3, 0x0000, 0x30d2, 0x3099, 0x30eb, 0x0000, 0x30d5, 0x30a1,
+    0x30e9, 0x30c3, 0x30c8, 0x3099, 0x0000, 0x30d5, 0x30a3, 0x30fc,
+    0x30c8, 0x0000, 0x30d5, 0x3099, 0x30c3, 0x30b7, 0x30a7, 0x30eb,
+    0x0000, 0x30d5, 0x30e9, 0x30f3, 0x0000, 0x30d8, 0x30af, 0x30bf,
+    0x30fc, 0x30eb, 0x0000, 0x30d8, 0x309a, 0x30bd, 0x0000, 0x30d8,
+    0x309a, 0x30cb, 0x30d2, 0x0000, 0x30d8, 0x30eb, 0x30c4, 0x0000,
+    0x30d8, 0x309a, 0x30f3, 0x30b9, 0x0000, 0x30d8, 0x309a, 0x30fc,
+    0x30b7, 0x3099, 0x0000, 0x30d8, 0x3099, 0x30fc, 0x30bf, 0x0000,
+    0x30db, 0x309a, 0x30a4, 0x30f3, 0x30c8, 0x0000, 0x30db, 0x3099,
+    0x30eb, 0x30c8, 0x0000, 0x30db, 0x30f3, 0x0000, 0x30db, 0x309a,
+    0x30f3, 0x30c8, 0x3099, 0x0000, 0x30db, 0x30fc, 0x30eb, 0x0000,
+    0x30db, 0x30fc, 0x30f3, 0x0000, 0x30de, 0x30a4, 0x30af, 0x30ed,
+    0x0000, 0x30de, 0x30a4, 0x30eb, 0x0000, 0x30de, 0x30c3, 0x30cf,
+    0x0000, 0x30de, 0x30eb, 0x30af, 0x0000, 0x30de, 0x30f3, 0x30b7,
+    0x30e7, 0x30f3, 0x0000, 0x30df, 0x30af, 0x30ed, 0x30f3, 0x0000,
+    0x30df, 0x30ea, 0x0000, 0x30df, 0x30ea, 0x30cf, 0x3099, 0x30fc,
+    0x30eb, 0x0000, 0x30e1, 0x30ab, 0x3099, 0x0000, 0x30e1, 0x30ab,
+    0x3099, 0x30c8, 0x30f3, 0x0000, 0x30e1, 0x30fc, 0x30c8, 0x30eb,
+    0x0000, 0x30e4, 0x30fc, 0x30c8, 0x3099, 0x0000, 0x30e4, 0x30fc,
+    0x30eb, 0x0000, 0x30e6, 0x30a2, 0x30f3, 0x0000, 0x30ea, 0x30c3,
+    0x30c8, 0x30eb, 0x0000, 0x30ea, 0x30e9, 0x0000, 0x30eb, 0x30d2,
+    0x309a, 0x30fc, 0x0000, 0x30eb, 0x30fc, 0x30d5, 0x3099, 0x30eb,
+    0x0000, 0x30ec, 0x30e0, 0x0000, 0x30ec, 0x30f3, 0x30c8, 0x30b1,
+    0x3099, 0x30f3, 0x0000, 0x30ef, 0x30c3, 0x30c8, 0x0000, 0x0030,
+    0x70b9, 0x0000, 0x0031, 0x70b9, 0x0000, 0x0032, 0x70b9, 0x0000,
+    0x0033, 0x70b9, 0x0000, 0x0034, 0x70b9, 0x0000, 0x0035, 0x70b9,
+    0x0000, 0x0036, 0x70b9, 0x0000, 0x0037, 0x70b9, 0x0000, 0x0038,
+    0x70b9, 0x0000, 0x0039, 0x70b9, 0x0000, 0x0031, 0x0030, 0x70b9,
+    0x0000, 0x0031, 0x0031, 0x70b9, 0x0000, 0x0031, 0x0032, 0x70b9,
+    0x0000, 0x0031, 0x0033, 0x70b9, 0x0000, 0x0031, 0x0034, 0x70b9,
+    0x0000, 0x0031, 0x0035, 0x70b9, 0x0000, 0x0031, 0x0036, 0x70b9,
+    0x0000, 0x0031, 0x0037, 0x70b9, 0x0000, 0x0031, 0x0038, 0x70b9,
+    0x0000, 0x0031, 0x0039, 0x70b9, 0x0000, 0x0032, 0x0030, 0x70b9,
+    0x0000, 0x0032, 0x0031, 0x70b9, 0x0000, 0x0032, 0x0032, 0x70b9,
+    0x0000, 0x0032, 0x0033, 0x70b9, 0x0000, 0x0032, 0x0034, 0x70b9,
+    0x0000, 0x0068, 0x0050, 0x0061, 0x0000, 0x0064, 0x0061, 0x0000,
+    0x0041, 0x0055, 0x0000, 0x0062, 0x0061, 0x0072, 0x0000, 0x006f,
+    0x0056, 0x0000, 0x0070, 0x0063, 0x0000, 0x0064, 0x006d, 0x0000,
+    0x0064, 0x006d, 0x0032, 0x0000, 0x0064, 0x006d, 0x0033, 0x0000,
+    0x0049, 0x0055, 0x0000, 0x5e73, 0x6210, 0x0000, 0x662d, 0x548c,
+    0x0000, 0x5927, 0x6b63, 0x0000, 0x660e, 0x6cbb, 0x0000, 0x682a,
+    0x5f0f, 0x4f1a, 0x793e, 0x0000, 0x0070, 0x0041, 0x0000, 0x006e,
+    0x0041, 0x0000, 0x03bc, 0x0041, 0x0000, 0x006d, 0x0041, 0x0000,
+    0x006b, 0x0041, 0x0000, 0x004b, 0x0042, 0x0000, 0x004d, 0x0042,
+    0x0000, 0x0047, 0x0042, 0x0000, 0x0063, 0x0061, 0x006c, 0x0000,
+    0x006b, 0x0063, 0x0061, 0x006c, 0x0000, 0x0070, 0x0046, 0x0000,
+    0x006e, 0x0046, 0x0000, 0x03bc, 0x0046, 0x0000, 0x03bc, 0x0067,
+    0x0000, 0x006d, 0x0067, 0x0000, 0x006b, 0x0067, 0x0000, 0x0048,
+    0x007a, 0x0000, 0x006b, 0x0048, 0x007a, 0x0000, 0x004d, 0x0048,
+    0x007a, 0x0000, 0x0047, 0x0048, 0x007a, 0x0000, 0x0054, 0x0048,
+    0x007a, 0x0000, 0x03bc, 0x006c, 0x0000, 0x006d, 0x006c, 0x0000,
+    0x0064, 0x006c, 0x0000, 0x006b, 0x006c, 0x0000, 0x0066, 0x006d,
+    0x0000, 0x006e, 0x006d, 0x0000, 0x03bc, 0x006d, 0x0000, 0x006d,
+    0x006d, 0x0000, 0x0063, 0x006d, 0x0000, 0x006b, 0x006d, 0x0000,
+    0x006d, 0x006d, 0x0032, 0x0000, 0x0063, 0x006d, 0x0032, 0x0000,
+    0x006d, 0x0032, 0x0000, 0x006b, 0x006d, 0x0032, 0x0000, 0x006d,
+    0x006d, 0x0033, 0x0000, 0x0063, 0x006d, 0x0033, 0x0000, 0x006d,
+    0x0033, 0x0000, 0x006b, 0x006d, 0x0033, 0x0000, 0x006d, 0x2215,
+    0x0073, 0x0000, 0x006d, 0x2215, 0x0073, 0x0032, 0x0000, 0x0050,
+    0x0061, 0x0000, 0x006b, 0x0050, 0x0061, 0x0000, 0x004d, 0x0050,
+    0x0061, 0x0000, 0x0047, 0x0050, 0x0061, 0x0000, 0x0072, 0x0061,
+    0x0064, 0x0000, 0x0072, 0x0061, 0x0064, 0x2215, 0x0073, 0x0000,
+    0x0072, 0x0061, 0x0064, 0x2215, 0x0073, 0x0032, 0x0000, 0x0070,
+    0x0073, 0x0000, 0x006e, 0x0073, 0x0000, 0x03bc, 0x0073, 0x0000,
+    0x006d, 0x0073, 0x0000, 0x0070, 0x0056, 0x0000, 0x006e, 0x0056,
+    0x0000, 0x03bc, 0x0056, 0x0000, 0x006d, 0x0056, 0x0000, 0x006b,
+    0x0056, 0x0000, 0x004d, 0x0056, 0x0000, 0x0070, 0x0057, 0x0000,
+    0x006e, 0x0057, 0x0000, 0x03bc, 0x0057, 0x0000, 0x006d, 0x0057,
+    0x0000, 0x006b, 0x0057, 0x0000, 0x004d, 0x0057, 0x0000, 0x006b,
+    0x03a9, 0x0000, 0x004d, 0x03a9, 0x0000, 0x0061, 0x002e, 0x006d,
+    0x002e, 0x0000, 0x0042, 0x0071, 0x0000, 0x0063, 0x0063, 0x0000,
+    0x0063, 0x0064, 0x0000, 0x0043, 0x2215, 0x006b, 0x0067, 0x0000,
+    0x0043, 0x006f, 0x002e, 0x0000, 0x0064, 0x0042, 0x0000, 0x0047,
+    0x0079, 0x0000, 0x0068, 0x0061, 0x0000, 0x0048, 0x0050, 0x0000,
+    0x0069, 0x006e, 0x0000, 0x004b, 0x004b, 0x0000, 0x004b, 0x004d,
+    0x0000, 0x006b, 0x0074, 0x0000, 0x006c, 0x006d, 0x0000, 0x006c,
+    0x006e, 0x0000, 0x006c, 0x006f, 0x0067, 0x0000, 0x006c, 0x0078,
+    0x0000, 0x006d, 0x0062, 0x0000, 0x006d, 0x0069, 0x006c, 0x0000,
+    0x006d, 0x006f, 0x006c, 0x0000, 0x0050, 0x0048, 0x0000, 0x0070,
+    0x002e, 0x006d, 0x002e, 0x0000, 0x0050, 0x0050, 0x004d, 0x0000,
+    0x0050, 0x0052, 0x0000, 0x0073, 0x0072, 0x0000, 0x0053, 0x0076,
+    0x0000, 0x0057, 0x0062, 0x0000, 0x0056, 0x2215, 0x006d, 0x0000,
+    0x0041, 0x2215, 0x006d, 0x0000, 0x0031, 0x65e5, 0x0000, 0x0032,
+    0x65e5, 0x0000, 0x0033, 0x65e5, 0x0000, 0x0034, 0x65e5, 0x0000,
+    0x0035, 0x65e5, 0x0000, 0x0036, 0x65e5, 0x0000, 0x0037, 0x65e5,
+    0x0000, 0x0038, 0x65e5, 0x0000, 0x0039, 0x65e5, 0x0000, 0x0031,
+    0x0030, 0x65e5, 0x0000, 0x0031, 0x0031, 0x65e5, 0x0000, 0x0031,
+    0x0032, 0x65e5, 0x0000, 0x0031, 0x0033, 0x65e5, 0x0000, 0x0031,
+    0x0034, 0x65e5, 0x0000, 0x0031, 0x0035, 0x65e5, 0x0000, 0x0031,
+    0x0036, 0x65e5, 0x0000, 0x0031, 0x0037, 0x65e5, 0x0000, 0x0031,
+    0x0038, 0x65e5, 0x0000, 0x0031, 0x0039, 0x65e5, 0x0000, 0x0032,
+    0x0030, 0x65e5, 0x0000, 0x0032, 0x0031, 0x65e5, 0x0000, 0x0032,
+    0x0032, 0x65e5, 0x0000, 0x0032, 0x0033, 0x65e5, 0x0000, 0x0032,
+    0x0034, 0x65e5, 0x0000, 0x0032, 0x0035, 0x65e5, 0x0000, 0x0032,
+    0x0036, 0x65e5, 0x0000, 0x0032, 0x0037, 0x65e5, 0x0000, 0x0032,
+    0x0038, 0x65e5, 0x0000, 0x0032, 0x0039, 0x65e5, 0x0000, 0x0033,
+    0x0030, 0x65e5, 0x0000, 0x0033, 0x0031, 0x65e5, 0x0000, 0x0067,
+    0x0061, 0x006c, 0x0000, 0x044a, 0x0000, 0x044c, 0x0000, 0xa76f,
+    0x0000, 0x0126, 0x0000, 0x0153, 0x0000, 0xa727, 0x0000, 0xab37,
+    0x0000, 0x026b, 0x0000, 0xab52, 0x0000, 0x8c48, 0x0000, 0x66f4,
+    0x0000, 0x8cc8, 0x0000, 0x6ed1, 0x0000, 0x4e32, 0x0000, 0x53e5,
+    0x0000, 0x5951, 0x0000, 0x5587, 0x0000, 0x5948, 0x0000, 0x61f6,
+    0x0000, 0x7669, 0x0000, 0x7f85, 0x0000, 0x863f, 0x0000, 0x87ba,
+    0x0000, 0x88f8, 0x0000, 0x908f, 0x0000, 0x6a02, 0x0000, 0x6d1b,
+    0x0000, 0x70d9, 0x0000, 0x73de, 0x0000, 0x843d, 0x0000, 0x916a,
+    0x0000, 0x99f1, 0x0000, 0x4e82, 0x0000, 0x5375, 0x0000, 0x6b04,
+    0x0000, 0x721b, 0x0000, 0x862d, 0x0000, 0x9e1e, 0x0000, 0x5d50,
+    0x0000, 0x6feb, 0x0000, 0x85cd, 0x0000, 0x8964, 0x0000, 0x62c9,
+    0x0000, 0x81d8, 0x0000, 0x881f, 0x0000, 0x5eca, 0x0000, 0x6717,
+    0x0000, 0x6d6a, 0x0000, 0x72fc, 0x0000, 0x90ce, 0x0000, 0x4f86,
+    0x0000, 0x51b7, 0x0000, 0x52de, 0x0000, 0x64c4, 0x0000, 0x6ad3,
+    0x0000, 0x7210, 0x0000, 0x76e7, 0x0000, 0x8606, 0x0000, 0x865c,
+    0x0000, 0x8def, 0x0000, 0x9732, 0x0000, 0x9b6f, 0x0000, 0x9dfa,
+    0x0000, 0x788c, 0x0000, 0x797f, 0x0000, 0x7da0, 0x0000, 0x83c9,
+    0x0000, 0x9304, 0x0000, 0x8ad6, 0x0000, 0x58df, 0x0000, 0x5f04,
+    0x0000, 0x7c60, 0x0000, 0x807e, 0x0000, 0x7262, 0x0000, 0x78ca,
+    0x0000, 0x8cc2, 0x0000, 0x96f7, 0x0000, 0x58d8, 0x0000, 0x5c62,
+    0x0000, 0x6a13, 0x0000, 0x6dda, 0x0000, 0x6f0f, 0x0000, 0x7d2f,
+    0x0000, 0x7e37, 0x0000, 0x964b, 0x0000, 0x52d2, 0x0000, 0x808b,
+    0x0000, 0x51dc, 0x0000, 0x51cc, 0x0000, 0x7a1c, 0x0000, 0x7dbe,
+    0x0000, 0x83f1, 0x0000, 0x9675, 0x0000, 0x8b80, 0x0000, 0x62cf,
+    0x0000, 0x8afe, 0x0000, 0x4e39, 0x0000, 0x5be7, 0x0000, 0x6012,
+    0x0000, 0x7387, 0x0000, 0x7570, 0x0000, 0x5317, 0x0000, 0x78fb,
+    0x0000, 0x4fbf, 0x0000, 0x5fa9, 0x0000, 0x4e0d, 0x0000, 0x6ccc,
+    0x0000, 0x6578, 0x0000, 0x7d22, 0x0000, 0x53c3, 0x0000, 0x585e,
+    0x0000, 0x7701, 0x0000, 0x8449, 0x0000, 0x8aaa, 0x0000, 0x6bba,
+    0x0000, 0x6c88, 0x0000, 0x62fe, 0x0000, 0x82e5, 0x0000, 0x63a0,
+    0x0000, 0x7565, 0x0000, 0x4eae, 0x0000, 0x5169, 0x0000, 0x51c9,
+    0x0000, 0x6881, 0x0000, 0x7ce7, 0x0000, 0x826f, 0x0000, 0x8ad2,
+    0x0000, 0x91cf, 0x0000, 0x52f5, 0x0000, 0x5442, 0x0000, 0x5eec,
+    0x0000, 0x65c5, 0x0000, 0x6ffe, 0x0000, 0x792a, 0x0000, 0x95ad,
+    0x0000, 0x9a6a, 0x0000, 0x9e97, 0x0000, 0x9ece, 0x0000, 0x66c6,
+    0x0000, 0x6b77, 0x0000, 0x8f62, 0x0000, 0x5e74, 0x0000, 0x6190,
+    0x0000, 0x6200, 0x0000, 0x649a, 0x0000, 0x6f23, 0x0000, 0x7149,
+    0x0000, 0x7489, 0x0000, 0x79ca, 0x0000, 0x7df4, 0x0000, 0x806f,
+    0x0000, 0x8f26, 0x0000, 0x84ee, 0x0000, 0x9023, 0x0000, 0x934a,
+    0x0000, 0x5217, 0x0000, 0x52a3, 0x0000, 0x54bd, 0x0000, 0x70c8,
+    0x0000, 0x88c2, 0x0000, 0x5ec9, 0x0000, 0x5ff5, 0x0000, 0x637b,
+    0x0000, 0x6bae, 0x0000, 0x7c3e, 0x0000, 0x7375, 0x0000, 0x4ee4,
+    0x0000, 0x56f9, 0x0000, 0x5dba, 0x0000, 0x601c, 0x0000, 0x73b2,
+    0x0000, 0x7469, 0x0000, 0x7f9a, 0x0000, 0x8046, 0x0000, 0x9234,
+    0x0000, 0x96f6, 0x0000, 0x9748, 0x0000, 0x9818, 0x0000, 0x4f8b,
+    0x0000, 0x79ae, 0x0000, 0x91b4, 0x0000, 0x96b8, 0x0000, 0x60e1,
+    0x0000, 0x4e86, 0x0000, 0x50da, 0x0000, 0x5bee, 0x0000, 0x5c3f,
+    0x0000, 0x6599, 0x0000, 0x71ce, 0x0000, 0x7642, 0x0000, 0x84fc,
+    0x0000, 0x907c, 0x0000, 0x6688, 0x0000, 0x962e, 0x0000, 0x5289,
+    0x0000, 0x677b, 0x0000, 0x67f3, 0x0000, 0x6d41, 0x0000, 0x6e9c,
+    0x0000, 0x7409, 0x0000, 0x7559, 0x0000, 0x786b, 0x0000, 0x7d10,
+    0x0000, 0x985e, 0x0000, 0x622e, 0x0000, 0x9678, 0x0000, 0x502b,
+    0x0000, 0x5d19, 0x0000, 0x6dea, 0x0000, 0x8f2a, 0x0000, 0x5f8b,
+    0x0000, 0x6144, 0x0000, 0x6817, 0x0000, 0x9686, 0x0000, 0x5229,
+    0x0000, 0x540f, 0x0000, 0x5c65, 0x0000, 0x6613, 0x0000, 0x674e,
+    0x0000, 0x68a8, 0x0000, 0x6ce5, 0x0000, 0x7406, 0x0000, 0x75e2,
+    0x0000, 0x7f79, 0x0000, 0x88cf, 0x0000, 0x88e1, 0x0000, 0x96e2,
+    0x0000, 0x533f, 0x0000, 0x6eba, 0x0000, 0x541d, 0x0000, 0x71d0,
+    0x0000, 0x7498, 0x0000, 0x85fa, 0x0000, 0x96a3, 0x0000, 0x9c57,
+    0x0000, 0x9e9f, 0x0000, 0x6797, 0x0000, 0x6dcb, 0x0000, 0x81e8,
+    0x0000, 0x7b20, 0x0000, 0x7c92, 0x0000, 0x72c0, 0x0000, 0x7099,
+    0x0000, 0x8b58, 0x0000, 0x4ec0, 0x0000, 0x8336, 0x0000, 0x523a,
+    0x0000, 0x5207, 0x0000, 0x5ea6, 0x0000, 0x62d3, 0x0000, 0x7cd6,
+    0x0000, 0x5b85, 0x0000, 0x6d1e, 0x0000, 0x66b4, 0x0000, 0x8f3b,
+    0x0000, 0x964d, 0x0000, 0x5ed3, 0x0000, 0x5140, 0x0000, 0x55c0,
+    0x0000, 0x585a, 0x0000, 0x6674, 0x0000, 0x51de, 0x0000, 0x732a,
+    0x0000, 0x76ca, 0x0000, 0x793c, 0x0000, 0x795e, 0x0000, 0x7965,
+    0x0000, 0x798f, 0x0000, 0x9756, 0x0000, 0x7cbe, 0x0000, 0x8612,
+    0x0000, 0x8af8, 0x0000, 0x9038, 0x0000, 0x90fd, 0x0000, 0x98ef,
+    0x0000, 0x98fc, 0x0000, 0x9928, 0x0000, 0x9db4, 0x0000, 0x90de,
+    0x0000, 0x96b7, 0x0000, 0x4fae, 0x0000, 0x50e7, 0x0000, 0x514d,
+    0x0000, 0x52c9, 0x0000, 0x52e4, 0x0000, 0x5351, 0x0000, 0x559d,
+    0x0000, 0x5606, 0x0000, 0x5668, 0x0000, 0x5840, 0x0000, 0x58a8,
+    0x0000, 0x5c64, 0x0000, 0x6094, 0x0000, 0x6168, 0x0000, 0x618e,
+    0x0000, 0x61f2, 0x0000, 0x654f, 0x0000, 0x65e2, 0x0000, 0x6691,
+    0x0000, 0x6885, 0x0000, 0x6d77, 0x0000, 0x6e1a, 0x0000, 0x6f22,
+    0x0000, 0x716e, 0x0000, 0x722b, 0x0000, 0x7422, 0x0000, 0x7891,
+    0x0000, 0x7949, 0x0000, 0x7948, 0x0000, 0x7950, 0x0000, 0x7956,
+    0x0000, 0x798d, 0x0000, 0x798e, 0x0000, 0x7a40, 0x0000, 0x7a81,
+    0x0000, 0x7bc0, 0x0000, 0x7e09, 0x0000, 0x7e41, 0x0000, 0x7f72,
+    0x0000, 0x8005, 0x0000, 0x81ed, 0x0000, 0x8279, 0x0000, 0x8457,
+    0x0000, 0x8910, 0x0000, 0x8996, 0x0000, 0x8b01, 0x0000, 0x8b39,
+    0x0000, 0x8cd3, 0x0000, 0x8d08, 0x0000, 0x8fb6, 0x0000, 0x96e3,
+    0x0000, 0x97ff, 0x0000, 0x983b, 0x0000, 0x6075, 0x0000, 0xd850,
+    0xdeee, 0x0000, 0x8218, 0x0000, 0x4e26, 0x0000, 0x51b5, 0x0000,
+    0x5168, 0x0000, 0x4f80, 0x0000, 0x5145, 0x0000, 0x5180, 0x0000,
+    0x52c7, 0x0000, 0x52fa, 0x0000, 0x5555, 0x0000, 0x5599, 0x0000,
+    0x55e2, 0x0000, 0x58b3, 0x0000, 0x5944, 0x0000, 0x5954, 0x0000,
+    0x5a62, 0x0000, 0x5b28, 0x0000, 0x5ed2, 0x0000, 0x5ed9, 0x0000,
+    0x5f69, 0x0000, 0x5fad, 0x0000, 0x60d8, 0x0000, 0x614e, 0x0000,
+    0x6108, 0x0000, 0x6160, 0x0000, 0x6234, 0x0000, 0x63c4, 0x0000,
+    0x641c, 0x0000, 0x6452, 0x0000, 0x6556, 0x0000, 0x671b, 0x0000,
+    0x6756, 0x0000, 0x6edb, 0x0000, 0x6ecb, 0x0000, 0x701e, 0x0000,
+    0x77a7, 0x0000, 0x7235, 0x0000, 0x72af, 0x0000, 0x7471, 0x0000,
+    0x7506, 0x0000, 0x753b, 0x0000, 0x761d, 0x0000, 0x761f, 0x0000,
+    0x76db, 0x0000, 0x76f4, 0x0000, 0x774a, 0x0000, 0x7740, 0x0000,
+    0x78cc, 0x0000, 0x7ab1, 0x0000, 0x7c7b, 0x0000, 0x7d5b, 0x0000,
+    0x7f3e, 0x0000, 0x8352, 0x0000, 0x83ef, 0x0000, 0x8779, 0x0000,
+    0x8941, 0x0000, 0x8986, 0x0000, 0x8abf, 0x0000, 0x8acb, 0x0000,
+    0x8aed, 0x0000, 0x8b8a, 0x0000, 0x8f38, 0x0000, 0x9072, 0x0000,
+    0x9199, 0x0000, 0x9276, 0x0000, 0x967c, 0x0000, 0x97db, 0x0000,
+    0x980b, 0x0000, 0x9b12, 0x0000, 0xd84a, 0xdc4a, 0x0000, 0xd84a,
+    0xdc44, 0x0000, 0xd84c, 0xdfd5, 0x0000, 0x3b9d, 0x0000, 0x4018,
+    0x0000, 0x4039, 0x0000, 0xd854, 0xde49, 0x0000, 0xd857, 0xdcd0,
+    0x0000, 0xd85f, 0xded3, 0x0000, 0x9f43, 0x0000, 0x9f8e, 0x0000,
+    0x0066, 0x0066, 0x0000, 0x0066, 0x0069, 0x0000, 0x0066, 0x006c,
+    0x0000, 0x0066, 0x0066, 0x0069, 0x0000, 0x0066, 0x0066, 0x006c,
+    0x0000, 0x0073, 0x0074, 0x0000, 0x0574, 0x0576, 0x0000, 0x0574,
+    0x0565, 0x0000, 0x0574, 0x056b, 0x0000, 0x057e, 0x0576, 0x0000,
+    0x0574, 0x056d, 0x0000, 0x05d9, 0x05b4, 0x0000, 0x05f2, 0x05b7,
+    0x0000, 0x05e2, 0x0000, 0x05d4, 0x0000, 0x05db, 0x0000, 0x05dc,
+    0x0000, 0x05dd, 0x0000, 0x05e8, 0x0000, 0x05ea, 0x0000, 0x05e9,
+    0x05c1, 0x0000, 0x05e9, 0x05c2, 0x0000, 0x05e9, 0x05bc, 0x05c1,
+    0x0000, 0x05e9, 0x05bc, 0x05c2, 0x0000, 0x05d0, 0x05b7, 0x0000,
+    0x05d0, 0x05b8, 0x0000, 0x05d0, 0x05bc, 0x0000, 0x05d1, 0x05bc,
+    0x0000, 0x05d2, 0x05bc, 0x0000, 0x05d3, 0x05bc, 0x0000, 0x05d4,
+    0x05bc, 0x0000, 0x05d5, 0x05bc, 0x0000, 0x05d6, 0x05bc, 0x0000,
+    0x05d8, 0x05bc, 0x0000, 0x05d9, 0x05bc, 0x0000, 0x05da, 0x05bc,
+    0x0000, 0x05db, 0x05bc, 0x0000, 0x05dc, 0x05bc, 0x0000, 0x05de,
+    0x05bc, 0x0000, 0x05e0, 0x05bc, 0x0000, 0x05e1, 0x05bc, 0x0000,
+    0x05e3, 0x05bc, 0x0000, 0x05e4, 0x05bc, 0x0000, 0x05e6, 0x05bc,
+    0x0000, 0x05e7, 0x05bc, 0x0000, 0x05e8, 0x05bc, 0x0000, 0x05e9,
+    0x05bc, 0x0000, 0x05ea, 0x05bc, 0x0000, 0x05d5, 0x05b9, 0x0000,
+    0x05d1, 0x05bf, 0x0000, 0x05db, 0x05bf, 0x0000, 0x05e4, 0x05bf,
+    0x0000, 0x05d0, 0x05dc, 0x0000, 0x0671, 0x0000, 0x067b, 0x0000,
+    0x067e, 0x0000, 0x0680, 0x0000, 0x067a, 0x0000, 0x067f, 0x0000,
+    0x0679, 0x0000, 0x06a4, 0x0000, 0x06a6, 0x0000, 0x0684, 0x0000,
+    0x0683, 0x0000, 0x0686, 0x0000, 0x0687, 0x0000, 0x068d, 0x0000,
+    0x068c, 0x0000, 0x068e, 0x0000, 0x0688, 0x0000, 0x0698, 0x0000,
+    0x0691, 0x0000, 0x06a9, 0x0000, 0x06af, 0x0000, 0x06b3, 0x0000,
+    0x06b1, 0x0000, 0x06ba, 0x0000, 0x06bb, 0x0000, 0x06c1, 0x0000,
+    0x06be, 0x0000, 0x06d2, 0x0000, 0x06ad, 0x0000, 0x06c7, 0x0000,
+    0x06c6, 0x0000, 0x06c8, 0x0000, 0x06cb, 0x0000, 0x06c5, 0x0000,
+    0x06c9, 0x0000, 0x06d0, 0x0000, 0x0649, 0x0000, 0x064a, 0x0654,
+    0x0627, 0x0000, 0x064a, 0x0654, 0x06d5, 0x0000, 0x064a, 0x0654,
+    0x0648, 0x0000, 0x064a, 0x0654, 0x06c7, 0x0000, 0x064a, 0x0654,
+    0x06c6, 0x0000, 0x064a, 0x0654, 0x06c8, 0x0000, 0x064a, 0x0654,
+    0x06d0, 0x0000, 0x064a, 0x0654, 0x0649, 0x0000, 0x06cc, 0x0000,
+    0x064a, 0x0654, 0x062c, 0x0000, 0x064a, 0x0654, 0x062d, 0x0000,
+    0x064a, 0x0654, 0x0645, 0x0000, 0x064a, 0x0654, 0x064a, 0x0000,
+    0x0628, 0x062c, 0x0000, 0x0628, 0x062d, 0x0000, 0x0628, 0x062e,
+    0x0000, 0x0628, 0x0645, 0x0000, 0x0628, 0x0649, 0x0000, 0x0628,
+    0x064a, 0x0000, 0x062a, 0x062c, 0x0000, 0x062a, 0x062d, 0x0000,
+    0x062a, 0x062e, 0x0000, 0x062a, 0x0645, 0x0000, 0x062a, 0x0649,
+    0x0000, 0x062a, 0x064a, 0x0000, 0x062b, 0x062c, 0x0000, 0x062b,
+    0x0645, 0x0000, 0x062b, 0x0649, 0x0000, 0x062b, 0x064a, 0x0000,
+    0x062c, 0x062d, 0x0000, 0x062c, 0x0645, 0x0000, 0x062d, 0x062c,
+    0x0000, 0x062d, 0x0645, 0x0000, 0x062e, 0x062c, 0x0000, 0x062e,
+    0x062d, 0x0000, 0x062e, 0x0645, 0x0000, 0x0633, 0x062c, 0x0000,
+    0x0633, 0x062d, 0x0000, 0x0633, 0x062e, 0x0000, 0x0633, 0x0645,
+    0x0000, 0x0635, 0x062d, 0x0000, 0x0635, 0x0645, 0x0000, 0x0636,
+    0x062c, 0x0000, 0x0636, 0x062d, 0x0000, 0x0636, 0x062e, 0x0000,
+    0x0636, 0x0645, 0x0000, 0x0637, 0x062d, 0x0000, 0x0637, 0x0645,
+    0x0000, 0x0638, 0x0645, 0x0000, 0x0639, 0x062c, 0x0000, 0x0639,
+    0x0645, 0x0000, 0x063a, 0x062c, 0x0000, 0x063a, 0x0645, 0x0000,
+    0x0641, 0x062c, 0x0000, 0x0641, 0x062d, 0x0000, 0x0641, 0x062e,
+    0x0000, 0x0641, 0x0645, 0x0000, 0x0641, 0x0649, 0x0000, 0x0641,
+    0x064a, 0x0000, 0x0642, 0x062d, 0x0000, 0x0642, 0x0645, 0x0000,
+    0x0642, 0x0649, 0x0000, 0x0642, 0x064a, 0x0000, 0x0643, 0x0627,
+    0x0000, 0x0643, 0x062c, 0x0000, 0x0643, 0x062d, 0x0000, 0x0643,
+    0x062e, 0x0000, 0x0643, 0x0644, 0x0000, 0x0643, 0x0645, 0x0000,
+    0x0643, 0x0649, 0x0000, 0x0643, 0x064a, 0x0000, 0x0644, 0x062c,
+    0x0000, 0x0644, 0x062d, 0x0000, 0x0644, 0x062e, 0x0000, 0x0644,
+    0x0645, 0x0000, 0x0644, 0x0649, 0x0000, 0x0644, 0x064a, 0x0000,
+    0x0645, 0x062c, 0x0000, 0x0645, 0x062d, 0x0000, 0x0645, 0x062e,
+    0x0000, 0x0645, 0x0645, 0x0000, 0x0645, 0x0649, 0x0000, 0x0645,
+    0x064a, 0x0000, 0x0646, 0x062c, 0x0000, 0x0646, 0x062d, 0x0000,
+    0x0646, 0x062e, 0x0000, 0x0646, 0x0645, 0x0000, 0x0646, 0x0649,
+    0x0000, 0x0646, 0x064a, 0x0000, 0x0647, 0x062c, 0x0000, 0x0647,
+    0x0645, 0x0000, 0x0647, 0x0649, 0x0000, 0x0647, 0x064a, 0x0000,
+    0x064a, 0x062c, 0x0000, 0x064a, 0x062d, 0x0000, 0x064a, 0x062e,
+    0x0000, 0x064a, 0x0645, 0x0000, 0x064a, 0x0649, 0x0000, 0x064a,
+    0x064a, 0x0000, 0x0630, 0x0670, 0x0000, 0x0631, 0x0670, 0x0000,
+    0x0649, 0x0670, 0x0000, 0x0020, 0x064c, 0x0651, 0x0000, 0x0020,
+    0x064d, 0x0651, 0x0000, 0x0020, 0x064e, 0x0651, 0x0000, 0x0020,
+    0x064f, 0x0651, 0x0000, 0x0020, 0x0650, 0x0651, 0x0000, 0x0020,
+    0x0651, 0x0670, 0x0000, 0x064a, 0x0654, 0x0631, 0x0000, 0x064a,
+    0x0654, 0x0632, 0x0000, 0x064a, 0x0654, 0x0646, 0x0000, 0x0628,
+    0x0631, 0x0000, 0x0628, 0x0632, 0x0000, 0x0628, 0x0646, 0x0000,
+    0x062a, 0x0631, 0x0000, 0x062a, 0x0632, 0x0000, 0x062a, 0x0646,
+    0x0000, 0x062b, 0x0631, 0x0000, 0x062b, 0x0632, 0x0000, 0x062b,
+    0x0646, 0x0000, 0x0645, 0x0627, 0x0000, 0x0646, 0x0631, 0x0000,
+    0x0646, 0x0632, 0x0000, 0x0646, 0x0646, 0x0000, 0x064a, 0x0631,
+    0x0000, 0x064a, 0x0632, 0x0000, 0x064a, 0x0646, 0x0000, 0x064a,
+    0x0654, 0x062e, 0x0000, 0x064a, 0x0654, 0x0647, 0x0000, 0x0628,
+    0x0647, 0x0000, 0x062a, 0x0647, 0x0000, 0x0635, 0x062e, 0x0000,
+    0x0644, 0x0647, 0x0000, 0x0646, 0x0647, 0x0000, 0x0647, 0x0670,
+    0x0000, 0x064a, 0x0647, 0x0000, 0x062b, 0x0647, 0x0000, 0x0633,
+    0x0647, 0x0000, 0x0634, 0x0645, 0x0000, 0x0634, 0x0647, 0x0000,
+    0x0640, 0x064e, 0x0651, 0x0000, 0x0640, 0x064f, 0x0651, 0x0000,
+    0x0640, 0x0650, 0x0651, 0x0000, 0x0637, 0x0649, 0x0000, 0x0637,
+    0x064a, 0x0000, 0x0639, 0x0649, 0x0000, 0x0639, 0x064a, 0x0000,
+    0x063a, 0x0649, 0x0000, 0x063a, 0x064a, 0x0000, 0x0633, 0x0649,
+    0x0000, 0x0633, 0x064a, 0x0000, 0x0634, 0x0649, 0x0000, 0x0634,
+    0x064a, 0x0000, 0x062d, 0x0649, 0x0000, 0x062d, 0x064a, 0x0000,
+    0x062c, 0x0649, 0x0000, 0x062c, 0x064a, 0x0000, 0x062e, 0x0649,
+    0x0000, 0x062e, 0x064a, 0x0000, 0x0635, 0x0649, 0x0000, 0x0635,
+    0x064a, 0x0000, 0x0636, 0x0649, 0x0000, 0x0636, 0x064a, 0x0000,
+    0x0634, 0x062c, 0x0000, 0x0634, 0x062d, 0x0000, 0x0634, 0x062e,
+    0x0000, 0x0634, 0x0631, 0x0000, 0x0633, 0x0631, 0x0000, 0x0635,
+    0x0631, 0x0000, 0x0636, 0x0631, 0x0000, 0x0627, 0x064b, 0x0000,
+    0x062a, 0x062c, 0x0645, 0x0000, 0x062a, 0x062d, 0x062c, 0x0000,
+    0x062a, 0x062d, 0x0645, 0x0000, 0x062a, 0x062e, 0x0645, 0x0000,
+    0x062a, 0x0645, 0x062c, 0x0000, 0x062a, 0x0645, 0x062d, 0x0000,
+    0x062a, 0x0645, 0x062e, 0x0000, 0x062c, 0x0645, 0x062d, 0x0000,
+    0x062d, 0x0645, 0x064a, 0x0000, 0x062d, 0x0645, 0x0649, 0x0000,
+    0x0633, 0x062d, 0x062c, 0x0000, 0x0633, 0x062c, 0x062d, 0x0000,
+    0x0633, 0x062c, 0x0649, 0x0000, 0x0633, 0x0645, 0x062d, 0x0000,
+    0x0633, 0x0645, 0x062c, 0x0000, 0x0633, 0x0645, 0x0645, 0x0000,
+    0x0635, 0x062d, 0x062d, 0x0000, 0x0635, 0x0645, 0x0645, 0x0000,
+    0x0634, 0x062d, 0x0645, 0x0000, 0x0634, 0x062c, 0x064a, 0x0000,
+    0x0634, 0x0645, 0x062e, 0x0000, 0x0634, 0x0645, 0x0645, 0x0000,
+    0x0636, 0x062d, 0x0649, 0x0000, 0x0636, 0x062e, 0x0645, 0x0000,
+    0x0637, 0x0645, 0x062d, 0x0000, 0x0637, 0x0645, 0x0645, 0x0000,
+    0x0637, 0x0645, 0x064a, 0x0000, 0x0639, 0x062c, 0x0645, 0x0000,
+    0x0639, 0x0645, 0x0645, 0x0000, 0x0639, 0x0645, 0x0649, 0x0000,
+    0x063a, 0x0645, 0x0645, 0x0000, 0x063a, 0x0645, 0x064a, 0x0000,
+    0x063a, 0x0645, 0x0649, 0x0000, 0x0641, 0x062e, 0x0645, 0x0000,
+    0x0642, 0x0645, 0x062d, 0x0000, 0x0642, 0x0645, 0x0645, 0x0000,
+    0x0644, 0x062d, 0x0645, 0x0000, 0x0644, 0x062d, 0x064a, 0x0000,
+    0x0644, 0x062d, 0x0649, 0x0000, 0x0644, 0x062c, 0x062c, 0x0000,
+    0x0644, 0x062e, 0x0645, 0x0000, 0x0644, 0x0645, 0x062d, 0x0000,
+    0x0645, 0x062d, 0x062c, 0x0000, 0x0645, 0x062d, 0x0645, 0x0000,
+    0x0645, 0x062d, 0x064a, 0x0000, 0x0645, 0x062c, 0x062d, 0x0000,
+    0x0645, 0x062c, 0x0645, 0x0000, 0x0645, 0x062e, 0x062c, 0x0000,
+    0x0645, 0x062e, 0x0645, 0x0000, 0x0645, 0x062c, 0x062e, 0x0000,
+    0x0647, 0x0645, 0x062c, 0x0000, 0x0647, 0x0645, 0x0645, 0x0000,
+    0x0646, 0x062d, 0x0645, 0x0000, 0x0646, 0x062d, 0x0649, 0x0000,
+    0x0646, 0x062c, 0x0645, 0x0000, 0x0646, 0x062c, 0x0649, 0x0000,
+    0x0646, 0x0645, 0x064a, 0x0000, 0x0646, 0x0645, 0x0649, 0x0000,
+    0x064a, 0x0645, 0x0645, 0x0000, 0x0628, 0x062e, 0x064a, 0x0000,
+    0x062a, 0x062c, 0x064a, 0x0000, 0x062a, 0x062c, 0x0649, 0x0000,
+    0x062a, 0x062e, 0x064a, 0x0000, 0x062a, 0x062e, 0x0649, 0x0000,
+    0x062a, 0x0645, 0x064a, 0x0000, 0x062a, 0x0645, 0x0649, 0x0000,
+    0x062c, 0x0645, 0x064a, 0x0000, 0x062c, 0x062d, 0x0649, 0x0000,
+    0x062c, 0x0645, 0x0649, 0x0000, 0x0633, 0x062e, 0x0649, 0x0000,
+    0x0635, 0x062d, 0x064a, 0x0000, 0x0634, 0x062d, 0x064a, 0x0000,
+    0x0636, 0x062d, 0x064a, 0x0000, 0x0644, 0x062c, 0x064a, 0x0000,
+    0x0644, 0x0645, 0x064a, 0x0000, 0x064a, 0x062d, 0x064a, 0x0000,
+    0x064a, 0x062c, 0x064a, 0x0000, 0x064a, 0x0645, 0x064a, 0x0000,
+    0x0645, 0x0645, 0x064a, 0x0000, 0x0642, 0x0645, 0x064a, 0x0000,
+    0x0646, 0x062d, 0x064a, 0x0000, 0x0639, 0x0645, 0x064a, 0x0000,
+    0x0643, 0x0645, 0x064a, 0x0000, 0x0646, 0x062c, 0x062d, 0x0000,
+    0x0645, 0x062e, 0x064a, 0x0000, 0x0644, 0x062c, 0x0645, 0x0000,
+    0x0643, 0x0645, 0x0645, 0x0000, 0x062c, 0x062d, 0x064a, 0x0000,
+    0x062d, 0x062c, 0x064a, 0x0000, 0x0645, 0x062c, 0x064a, 0x0000,
+    0x0641, 0x0645, 0x064a, 0x0000, 0x0628, 0x062d, 0x064a, 0x0000,
+    0x0633, 0x062e, 0x064a, 0x0000, 0x0646, 0x062c, 0x064a, 0x0000,
+    0x0635, 0x0644, 0x06d2, 0x0000, 0x0642, 0x0644, 0x06d2, 0x0000,
+    0x0627, 0x0644, 0x0644, 0x0647, 0x0000, 0x0627, 0x0643, 0x0628,
+    0x0631, 0x0000, 0x0645, 0x062d, 0x0645, 0x062f, 0x0000, 0x0635,
+    0x0644, 0x0639, 0x0645, 0x0000, 0x0631, 0x0633, 0x0648, 0x0644,
+    0x0000, 0x0639, 0x0644, 0x064a, 0x0647, 0x0000, 0x0648, 0x0633,
+    0x0644, 0x0645, 0x0000, 0x0635, 0x0644, 0x0649, 0x0000, 0x0635,
+    0x0644, 0x0649, 0x0020, 0x0627, 0x0644, 0x0644, 0x0647, 0x0020,
+    0x0639, 0x0644, 0x064a, 0x0647, 0x0020, 0x0648, 0x0633, 0x0644,
+    0x0645, 0x0000, 0x062c, 0x0644, 0x0020, 0x062c, 0x0644, 0x0627,
+    0x0644, 0x0647, 0x0000, 0x0631, 0x06cc, 0x0627, 0x0644, 0x0000,
+    0x002c, 0x0000, 0x3001, 0x0000, 0x3002, 0x0000, 0x003a, 0x0000,
+    0x0021, 0x0000, 0x003f, 0x0000, 0x3016, 0x0000, 0x3017, 0x0000,
+    0x2014, 0x0000, 0x2013, 0x0000, 0x005f, 0x0000, 0x007b, 0x0000,
+    0x007d, 0x0000, 0x3014, 0x0000, 0x3015, 0x0000, 0x3010, 0x0000,
+    0x3011, 0x0000, 0x300a, 0x0000, 0x300b, 0x0000, 0x300c, 0x0000,
+    0x300d, 0x0000, 0x300e, 0x0000, 0x300f, 0x0000, 0x005b, 0x0000,
+    0x005d, 0x0000, 0x0023, 0x0000, 0x0026, 0x0000, 0x002a, 0x0000,
+    0x002d, 0x0000, 0x003c, 0x0000, 0x003e, 0x0000, 0x005c, 0x0000,
+    0x0024, 0x0000, 0x0025, 0x0000, 0x0040, 0x0000, 0x0020, 0x064b,
+    0x0000, 0x0640, 0x064b, 0x0000, 0x0020, 0x064c, 0x0000, 0x0020,
+    0x064d, 0x0000, 0x0020, 0x064e, 0x0000, 0x0640, 0x064e, 0x0000,
+    0x0020, 0x064f, 0x0000, 0x0640, 0x064f, 0x0000, 0x0020, 0x0650,
+    0x0000, 0x0640, 0x0650, 0x0000, 0x0020, 0x0651, 0x0000, 0x0640,
+    0x0651, 0x0000, 0x0020, 0x0652, 0x0000, 0x0640, 0x0652, 0x0000,
+    0x0621, 0x0000, 0x0627, 0x0000, 0x0628, 0x0000, 0x0629, 0x0000,
+    0x062a, 0x0000, 0x062b, 0x0000, 0x062c, 0x0000, 0x062d, 0x0000,
+    0x062e, 0x0000, 0x062f, 0x0000, 0x0630, 0x0000, 0x0631, 0x0000,
+    0x0632, 0x0000, 0x0633, 0x0000, 0x0634, 0x0000, 0x0635, 0x0000,
+    0x0636, 0x0000, 0x0637, 0x0000, 0x0638, 0x0000, 0x0639, 0x0000,
+    0x063a, 0x0000, 0x0641, 0x0000, 0x0642, 0x0000, 0x0643, 0x0000,
+    0x0644, 0x0000, 0x0645, 0x0000, 0x0646, 0x0000, 0x0647, 0x0000,
+    0x0648, 0x0000, 0x064a, 0x0000, 0x0644, 0x0627, 0x0653, 0x0000,
+    0x0644, 0x0627, 0x0654, 0x0000, 0x0644, 0x0627, 0x0655, 0x0000,
+    0x0644, 0x0627, 0x0000, 0x0022, 0x0000, 0x0027, 0x0000, 0x002f,
+    0x0000, 0x005e, 0x0000, 0x007c, 0x0000, 0x007e, 0x0000, 0x2985,
+    0x0000, 0x2986, 0x0000, 0x30fb, 0x0000, 0x30a1, 0x0000, 0x30a3,
+    0x0000, 0x30a5, 0x0000, 0x30a7, 0x0000, 0x30a9, 0x0000, 0x30e3,
+    0x0000, 0x30e5, 0x0000, 0x30e7, 0x0000, 0x30c3, 0x0000, 0x30fc,
+    0x0000, 0x30f3, 0x0000, 0x3099, 0x0000, 0x309a, 0x0000, 0x00a2,
+    0x0000, 0x00a3, 0x0000, 0x00ac, 0x0000, 0x00a6, 0x0000, 0x00a5,
+    0x0000, 0x20a9, 0x0000, 0x2502, 0x0000, 0x2190, 0x0000, 0x2191,
+    0x0000, 0x2192, 0x0000, 0x2193, 0x0000, 0x25a0, 0x0000, 0x25cb,
+    0x0000, 0xd804, 0xdc99, 0xd804, 0xdcba, 0x0000, 0xd804, 0xdc9b,
+    0xd804, 0xdcba, 0x0000, 0xd804, 0xdca5, 0xd804, 0xdcba, 0x0000,
+    0xd804, 0xdd31, 0xd804, 0xdd27, 0x0000, 0xd804, 0xdd32, 0xd804,
+    0xdd27, 0x0000, 0xd804, 0xdf47, 0xd804, 0xdf3e, 0x0000, 0xd804,
+    0xdf47, 0xd804, 0xdf57, 0x0000, 0xd805, 0xdcb9, 0xd805, 0xdcba,
+    0x0000, 0xd805, 0xdcb9, 0xd805, 0xdcb0, 0x0000, 0xd805, 0xdcb9,
+    0xd805, 0xdcbd, 0x0000, 0xd805, 0xddb8, 0xd805, 0xddaf, 0x0000,
+    0xd805, 0xddb9, 0xd805, 0xddaf, 0x0000, 0xd834, 0xdd57, 0xd834,
+    0xdd65, 0x0000, 0xd834, 0xdd58, 0xd834, 0xdd65, 0x0000, 0xd834,
+    0xdd58, 0xd834, 0xdd65, 0xd834, 0xdd6e, 0x0000, 0xd834, 0xdd58,
+    0xd834, 0xdd65, 0xd834, 0xdd6f, 0x0000, 0xd834, 0xdd58, 0xd834,
+    0xdd65, 0xd834, 0xdd70, 0x0000, 0xd834, 0xdd58, 0xd834, 0xdd65,
+    0xd834, 0xdd71, 0x0000, 0xd834, 0xdd58, 0xd834, 0xdd65, 0xd834,
+    0xdd72, 0x0000, 0xd834, 0xddb9, 0xd834, 0xdd65, 0x0000, 0xd834,
+    0xddba, 0xd834, 0xdd65, 0x0000, 0xd834, 0xddb9, 0xd834, 0xdd65,
+    0xd834, 0xdd6e, 0x0000, 0xd834, 0xddba, 0xd834, 0xdd65, 0xd834,
+    0xdd6e, 0x0000, 0xd834, 0xddb9, 0xd834, 0xdd65, 0xd834, 0xdd6f,
+    0x0000, 0xd834, 0xddba, 0xd834, 0xdd65, 0xd834, 0xdd6f, 0x0000,
+    0x0131, 0x0000, 0x0237, 0x0000, 0x0391, 0x0000, 0x0392, 0x0000,
+    0x0394, 0x0000, 0x0395, 0x0000, 0x0396, 0x0000, 0x0397, 0x0000,
+    0x0399, 0x0000, 0x039a, 0x0000, 0x039b, 0x0000, 0x039c, 0x0000,
+    0x039d, 0x0000, 0x039e, 0x0000, 0x039f, 0x0000, 0x03a1, 0x0000,
+    0x03a4, 0x0000, 0x03a6, 0x0000, 0x03a7, 0x0000, 0x03a8, 0x0000,
+    0x2207, 0x0000, 0x03b1, 0x0000, 0x03b6, 0x0000, 0x03b7, 0x0000,
+    0x03bb, 0x0000, 0x03bd, 0x0000, 0x03be, 0x0000, 0x03bf, 0x0000,
+    0x03c3, 0x0000, 0x03c4, 0x0000, 0x03c5, 0x0000, 0x03c8, 0x0000,
+    0x03c9, 0x0000, 0x2202, 0x0000, 0x03dc, 0x0000, 0x03dd, 0x0000,
+    0x066e, 0x0000, 0x06a1, 0x0000, 0x066f, 0x0000, 0x0030, 0x002e,
+    0x0000, 0x0030, 0x002c, 0x0000, 0x0031, 0x002c, 0x0000, 0x0032,
+    0x002c, 0x0000, 0x0033, 0x002c, 0x0000, 0x0034, 0x002c, 0x0000,
+    0x0035, 0x002c, 0x0000, 0x0036, 0x002c, 0x0000, 0x0037, 0x002c,
+    0x0000, 0x0038, 0x002c, 0x0000, 0x0039, 0x002c, 0x0000, 0x0028,
+    0x0041, 0x0029, 0x0000, 0x0028, 0x0042, 0x0029, 0x0000, 0x0028,
+    0x0043, 0x0029, 0x0000, 0x0028, 0x0044, 0x0029, 0x0000, 0x0028,
+    0x0045, 0x0029, 0x0000, 0x0028, 0x0046, 0x0029, 0x0000, 0x0028,
+    0x0047, 0x0029, 0x0000, 0x0028, 0x0048, 0x0029, 0x0000, 0x0028,
+    0x0049, 0x0029, 0x0000, 0x0028, 0x004a, 0x0029, 0x0000, 0x0028,
+    0x004b, 0x0029, 0x0000, 0x0028, 0x004c, 0x0029, 0x0000, 0x0028,
+    0x004d, 0x0029, 0x0000, 0x0028, 0x004e, 0x0029, 0x0000, 0x0028,
+    0x004f, 0x0029, 0x0000, 0x0028, 0x0050, 0x0029, 0x0000, 0x0028,
+    0x0051, 0x0029, 0x0000, 0x0028, 0x0052, 0x0029, 0x0000, 0x0028,
+    0x0053, 0x0029, 0x0000, 0x0028, 0x0054, 0x0029, 0x0000, 0x0028,
+    0x0055, 0x0029, 0x0000, 0x0028, 0x0056, 0x0029, 0x0000, 0x0028,
+    0x0057, 0x0029, 0x0000, 0x0028, 0x0058, 0x0029, 0x0000, 0x0028,
+    0x0059, 0x0029, 0x0000, 0x0028, 0x005a, 0x0029, 0x0000, 0x3014,
+    0x0053, 0x3015, 0x0000, 0x0043, 0x0044, 0x0000, 0x0057, 0x005a,
+    0x0000, 0x0048, 0x0056, 0x0000, 0x0053, 0x0044, 0x0000, 0x0053,
+    0x0053, 0x0000, 0x0050, 0x0050, 0x0056, 0x0000, 0x0057, 0x0043,
+    0x0000, 0x004d, 0x0043, 0x0000, 0x004d, 0x0044, 0x0000, 0x0044,
+    0x004a, 0x0000, 0x307b, 0x304b, 0x0000, 0x30b3, 0x30b3, 0x0000,
+    0x5b57, 0x0000, 0x53cc, 0x0000, 0x591a, 0x0000, 0x89e3, 0x0000,
+    0x4ea4, 0x0000, 0x6620, 0x0000, 0x7121, 0x0000, 0x524d, 0x0000,
+    0x5f8c, 0x0000, 0x518d, 0x0000, 0x65b0, 0x0000, 0x521d, 0x0000,
+    0x7d42, 0x0000, 0x8ca9, 0x0000, 0x58f0, 0x0000, 0x5439, 0x0000,
+    0x6f14, 0x0000, 0x6295, 0x0000, 0x6355, 0x0000, 0x904a, 0x0000,
+    0x6307, 0x0000, 0x6253, 0x0000, 0x7981, 0x0000, 0x7a7a, 0x0000,
+    0x5408, 0x0000, 0x6e80, 0x0000, 0x7533, 0x0000, 0x5272, 0x0000,
+    0x55b6, 0x0000, 0x914d, 0x0000, 0x3014, 0x672c, 0x3015, 0x0000,
+    0x3014, 0x4e09, 0x3015, 0x0000, 0x3014, 0x4e8c, 0x3015, 0x0000,
+    0x3014, 0x5b89, 0x3015, 0x0000, 0x3014, 0x70b9, 0x3015, 0x0000,
+    0x3014, 0x6253, 0x3015, 0x0000, 0x3014, 0x76d7, 0x3015, 0x0000,
+    0x3014, 0x52dd, 0x3015, 0x0000, 0x3014, 0x6557, 0x3015, 0x0000,
+    0x5f97, 0x0000, 0x53ef, 0x0000, 0x4e3d, 0x0000, 0x4e38, 0x0000,
+    0x4e41, 0x0000, 0xd840, 0xdd22, 0x0000, 0x4f60, 0x0000, 0x4fbb,
+    0x0000, 0x5002, 0x0000, 0x507a, 0x0000, 0x5099, 0x0000, 0x50cf,
+    0x0000, 0x349e, 0x0000, 0xd841, 0xde3a, 0x0000, 0x5154, 0x0000,
+    0x5164, 0x0000, 0x5177, 0x0000, 0xd841, 0xdd1c, 0x0000, 0x34b9,
+    0x0000, 0x5167, 0x0000, 0xd841, 0xdd4b, 0x0000, 0x5197, 0x0000,
+    0x51a4, 0x0000, 0x4ecc, 0x0000, 0x51ac, 0x0000, 0xd864, 0xdddf,
+    0x0000, 0x5203, 0x0000, 0x34df, 0x0000, 0x523b, 0x0000, 0x5246,
+    0x0000, 0x5277, 0x0000, 0x3515, 0x0000, 0x5305, 0x0000, 0x5306,
+    0x0000, 0x5349, 0x0000, 0x535a, 0x0000, 0x5373, 0x0000, 0x537d,
+    0x0000, 0x537f, 0x0000, 0xd842, 0xde2c, 0x0000, 0x7070, 0x0000,
+    0x53ca, 0x0000, 0x53df, 0x0000, 0xd842, 0xdf63, 0x0000, 0x53eb,
+    0x0000, 0x53f1, 0x0000, 0x5406, 0x0000, 0x549e, 0x0000, 0x5438,
+    0x0000, 0x5448, 0x0000, 0x5468, 0x0000, 0x54a2, 0x0000, 0x54f6,
+    0x0000, 0x5510, 0x0000, 0x5553, 0x0000, 0x5563, 0x0000, 0x5584,
+    0x0000, 0x55ab, 0x0000, 0x55b3, 0x0000, 0x55c2, 0x0000, 0x5716,
+    0x0000, 0x5717, 0x0000, 0x5651, 0x0000, 0x5674, 0x0000, 0x58ee,
+    0x0000, 0x57ce, 0x0000, 0x57f4, 0x0000, 0x580d, 0x0000, 0x578b,
+    0x0000, 0x5832, 0x0000, 0x5831, 0x0000, 0x58ac, 0x0000, 0xd845,
+    0xdce4, 0x0000, 0x58f2, 0x0000, 0x58f7, 0x0000, 0x5906, 0x0000,
+    0x5922, 0x0000, 0x5962, 0x0000, 0xd845, 0xdea8, 0x0000, 0xd845,
+    0xdeea, 0x0000, 0x59ec, 0x0000, 0x5a1b, 0x0000, 0x5a27, 0x0000,
+    0x59d8, 0x0000, 0x5a66, 0x0000, 0x36ee, 0x0000, 0x36fc, 0x0000,
+    0x5b08, 0x0000, 0x5b3e, 0x0000, 0xd846, 0xddc8, 0x0000, 0x5bc3,
+    0x0000, 0x5bd8, 0x0000, 0x5bf3, 0x0000, 0xd846, 0xdf18, 0x0000,
+    0x5bff, 0x0000, 0x5c06, 0x0000, 0x5f53, 0x0000, 0x3781, 0x0000,
+    0x5c60, 0x0000, 0x5cc0, 0x0000, 0x5c8d, 0x0000, 0xd847, 0xdde4,
+    0x0000, 0x5d43, 0x0000, 0xd847, 0xdde6, 0x0000, 0x5d6e, 0x0000,
+    0x5d6b, 0x0000, 0x5d7c, 0x0000, 0x5de1, 0x0000, 0x5de2, 0x0000,
+    0x382f, 0x0000, 0x5dfd, 0x0000, 0x5e28, 0x0000, 0x5e3d, 0x0000,
+    0x5e69, 0x0000, 0x3862, 0x0000, 0xd848, 0xdd83, 0x0000, 0x387c,
+    0x0000, 0x5eb0, 0x0000, 0x5eb3, 0x0000, 0x5eb6, 0x0000, 0xd868,
+    0xdf92, 0x0000, 0xd848, 0xdf31, 0x0000, 0x8201, 0x0000, 0x5f22,
+    0x0000, 0x38c7, 0x0000, 0xd84c, 0xdeb8, 0x0000, 0xd858, 0xddda,
+    0x0000, 0x5f62, 0x0000, 0x5f6b, 0x0000, 0x38e3, 0x0000, 0x5f9a,
+    0x0000, 0x5fcd, 0x0000, 0x5fd7, 0x0000, 0x5ff9, 0x0000, 0x6081,
+    0x0000, 0x393a, 0x0000, 0x391c, 0x0000, 0xd849, 0xded4, 0x0000,
+    0x60c7, 0x0000, 0x6148, 0x0000, 0x614c, 0x0000, 0x617a, 0x0000,
+    0x61b2, 0x0000, 0x61a4, 0x0000, 0x61af, 0x0000, 0x61de, 0x0000,
+    0x6210, 0x0000, 0x621b, 0x0000, 0x625d, 0x0000, 0x62b1, 0x0000,
+    0x62d4, 0x0000, 0x6350, 0x0000, 0xd84a, 0xdf0c, 0x0000, 0x633d,
+    0x0000, 0x62fc, 0x0000, 0x6368, 0x0000, 0x6383, 0x0000, 0x63e4,
+    0x0000, 0xd84a, 0xdff1, 0x0000, 0x6422, 0x0000, 0x63c5, 0x0000,
+    0x63a9, 0x0000, 0x3a2e, 0x0000, 0x6469, 0x0000, 0x647e, 0x0000,
+    0x649d, 0x0000, 0x6477, 0x0000, 0x3a6c, 0x0000, 0x656c, 0x0000,
+    0xd84c, 0xdc0a, 0x0000, 0x65e3, 0x0000, 0x66f8, 0x0000, 0x6649,
+    0x0000, 0x3b19, 0x0000, 0x3b08, 0x0000, 0x3ae4, 0x0000, 0x5192,
+    0x0000, 0x5195, 0x0000, 0x6700, 0x0000, 0x669c, 0x0000, 0x80ad,
+    0x0000, 0x43d9, 0x0000, 0x6721, 0x0000, 0x675e, 0x0000, 0x6753,
+    0x0000, 0xd84c, 0xdfc3, 0x0000, 0x3b49, 0x0000, 0x67fa, 0x0000,
+    0x6785, 0x0000, 0x6852, 0x0000, 0xd84d, 0xdc6d, 0x0000, 0x688e,
+    0x0000, 0x681f, 0x0000, 0x6914, 0x0000, 0x6942, 0x0000, 0x69a3,
+    0x0000, 0x69ea, 0x0000, 0x6aa8, 0x0000, 0xd84d, 0xdea3, 0x0000,
+    0x6adb, 0x0000, 0x3c18, 0x0000, 0x6b21, 0x0000, 0xd84e, 0xdca7,
+    0x0000, 0x6b54, 0x0000, 0x3c4e, 0x0000, 0x6b72, 0x0000, 0x6b9f,
+    0x0000, 0x6bbb, 0x0000, 0xd84e, 0xde8d, 0x0000, 0xd847, 0xdd0b,
+    0x0000, 0xd84e, 0xdefa, 0x0000, 0x6c4e, 0x0000, 0xd84f, 0xdcbc,
+    0x0000, 0x6cbf, 0x0000, 0x6ccd, 0x0000, 0x6c67, 0x0000, 0x6d16,
+    0x0000, 0x6d3e, 0x0000, 0x6d69, 0x0000, 0x6d78, 0x0000, 0x6d85,
+    0x0000, 0xd84f, 0xdd1e, 0x0000, 0x6d34, 0x0000, 0x6e2f, 0x0000,
+    0x6e6e, 0x0000, 0x3d33, 0x0000, 0x6ec7, 0x0000, 0xd84f, 0xded1,
+    0x0000, 0x6df9, 0x0000, 0x6f6e, 0x0000, 0xd84f, 0xdf5e, 0x0000,
+    0xd84f, 0xdf8e, 0x0000, 0x6fc6, 0x0000, 0x7039, 0x0000, 0x701b,
+    0x0000, 0x3d96, 0x0000, 0x704a, 0x0000, 0x707d, 0x0000, 0x7077,
+    0x0000, 0x70ad, 0x0000, 0xd841, 0xdd25, 0x0000, 0x7145, 0x0000,
+    0xd850, 0xde63, 0x0000, 0x719c, 0x0000, 0xd850, 0xdfab, 0x0000,
+    0x7228, 0x0000, 0x7250, 0x0000, 0xd851, 0xde08, 0x0000, 0x7280,
+    0x0000, 0x7295, 0x0000, 0xd851, 0xdf35, 0x0000, 0xd852, 0xdc14,
+    0x0000, 0x737a, 0x0000, 0x738b, 0x0000, 0x3eac, 0x0000, 0x73a5,
+    0x0000, 0x3eb8, 0x0000, 0x7447, 0x0000, 0x745c, 0x0000, 0x7485,
+    0x0000, 0x74ca, 0x0000, 0x3f1b, 0x0000, 0x7524, 0x0000, 0xd853,
+    0xdc36, 0x0000, 0x753e, 0x0000, 0xd853, 0xdc92, 0x0000, 0xd848,
+    0xdd9f, 0x0000, 0x7610, 0x0000, 0xd853, 0xdfa1, 0x0000, 0xd853,
+    0xdfb8, 0x0000, 0xd854, 0xdc44, 0x0000, 0x3ffc, 0x0000, 0x4008,
+    0x0000, 0xd854, 0xdcf3, 0x0000, 0xd854, 0xdcf2, 0x0000, 0xd854,
+    0xdd19, 0x0000, 0xd854, 0xdd33, 0x0000, 0x771e, 0x0000, 0x771f,
+    0x0000, 0x778b, 0x0000, 0x4046, 0x0000, 0x4096, 0x0000, 0xd855,
+    0xdc1d, 0x0000, 0x784e, 0x0000, 0x40e3, 0x0000, 0xd855, 0xde26,
+    0x0000, 0xd855, 0xde9a, 0x0000, 0xd855, 0xdec5, 0x0000, 0x79eb,
+    0x0000, 0x412f, 0x0000, 0x7a4a, 0x0000, 0x7a4f, 0x0000, 0xd856,
+    0xdd7c, 0x0000, 0xd856, 0xdea7, 0x0000, 0x7aee, 0x0000, 0x4202,
+    0x0000, 0xd856, 0xdfab, 0x0000, 0x7bc6, 0x0000, 0x7bc9, 0x0000,
+    0x4227, 0x0000, 0xd857, 0xdc80, 0x0000, 0x7cd2, 0x0000, 0x42a0,
+    0x0000, 0x7ce8, 0x0000, 0x7ce3, 0x0000, 0x7d00, 0x0000, 0xd857,
+    0xdf86, 0x0000, 0x7d63, 0x0000, 0x4301, 0x0000, 0x7dc7, 0x0000,
+    0x7e02, 0x0000, 0x7e45, 0x0000, 0x4334, 0x0000, 0xd858, 0xde28,
+    0x0000, 0xd858, 0xde47, 0x0000, 0x4359, 0x0000, 0xd858, 0xded9,
+    0x0000, 0x7f7a, 0x0000, 0xd858, 0xdf3e, 0x0000, 0x7f95, 0x0000,
+    0x7ffa, 0x0000, 0xd859, 0xdcda, 0x0000, 0xd859, 0xdd23, 0x0000,
+    0x8060, 0x0000, 0xd859, 0xdda8, 0x0000, 0x8070, 0x0000, 0xd84c,
+    0xdf5f, 0x0000, 0x43d5, 0x0000, 0x80b2, 0x0000, 0x8103, 0x0000,
+    0x440b, 0x0000, 0x813e, 0x0000, 0x5ab5, 0x0000, 0xd859, 0xdfa7,
+    0x0000, 0xd859, 0xdfb5, 0x0000, 0xd84c, 0xdf93, 0x0000, 0xd84c,
+    0xdf9c, 0x0000, 0x8204, 0x0000, 0x8f9e, 0x0000, 0x446b, 0x0000,
+    0x8291, 0x0000, 0x828b, 0x0000, 0x829d, 0x0000, 0x52b3, 0x0000,
+    0x82b1, 0x0000, 0x82b3, 0x0000, 0x82bd, 0x0000, 0x82e6, 0x0000,
+    0xd85a, 0xdf3c, 0x0000, 0x831d, 0x0000, 0x8363, 0x0000, 0x83ad,
+    0x0000, 0x8323, 0x0000, 0x83bd, 0x0000, 0x83e7, 0x0000, 0x8353,
+    0x0000, 0x83ca, 0x0000, 0x83cc, 0x0000, 0x83dc, 0x0000, 0xd85b,
+    0xdc36, 0x0000, 0xd85b, 0xdd6b, 0x0000, 0xd85b, 0xdcd5, 0x0000,
+    0x452b, 0x0000, 0x84f1, 0x0000, 0x84f3, 0x0000, 0x8516, 0x0000,
+    0xd85c, 0xdfca, 0x0000, 0x8564, 0x0000, 0xd85b, 0xdf2c, 0x0000,
+    0x455d, 0x0000, 0x4561, 0x0000, 0xd85b, 0xdfb1, 0x0000, 0xd85c,
+    0xdcd2, 0x0000, 0x456b, 0x0000, 0x8650, 0x0000, 0x8667, 0x0000,
+    0x8669, 0x0000, 0x86a9, 0x0000, 0x8688, 0x0000, 0x870e, 0x0000,
+    0x86e2, 0x0000, 0x8728, 0x0000, 0x876b, 0x0000, 0x8786, 0x0000,
+    0x45d7, 0x0000, 0x87e1, 0x0000, 0x8801, 0x0000, 0x45f9, 0x0000,
+    0x8860, 0x0000, 0xd85d, 0xde67, 0x0000, 0x88d7, 0x0000, 0x88de,
+    0x0000, 0x4635, 0x0000, 0x88fa, 0x0000, 0x34bb, 0x0000, 0xd85e,
+    0xdcae, 0x0000, 0xd85e, 0xdd66, 0x0000, 0x46be, 0x0000, 0x46c7,
+    0x0000, 0x8aa0, 0x0000, 0xd85f, 0xdca8, 0x0000, 0x8cab, 0x0000,
+    0x8cc1, 0x0000, 0x8d1b, 0x0000, 0x8d77, 0x0000, 0xd85f, 0xdf2f,
+    0x0000, 0xd842, 0xdc04, 0x0000, 0x8dcb, 0x0000, 0x8dbc, 0x0000,
+    0x8df0, 0x0000, 0xd842, 0xdcde, 0x0000, 0x8ed4, 0x0000, 0xd861,
+    0xddd2, 0x0000, 0xd861, 0xdded, 0x0000, 0x9094, 0x0000, 0x90f1,
+    0x0000, 0x9111, 0x0000, 0xd861, 0xdf2e, 0x0000, 0x911b, 0x0000,
+    0x9238, 0x0000, 0x92d7, 0x0000, 0x92d8, 0x0000, 0x927c, 0x0000,
+    0x93f9, 0x0000, 0x9415, 0x0000, 0xd862, 0xdffa, 0x0000, 0x958b,
+    0x0000, 0x4995, 0x0000, 0x95b7, 0x0000, 0xd863, 0xdd77, 0x0000,
+    0x49e6, 0x0000, 0x96c3, 0x0000, 0x5db2, 0x0000, 0x9723, 0x0000,
+    0xd864, 0xdd45, 0x0000, 0xd864, 0xde1a, 0x0000, 0x4a6e, 0x0000,
+    0x4a76, 0x0000, 0x97e0, 0x0000, 0xd865, 0xdc0a, 0x0000, 0x4ab2,
+    0x0000, 0xd865, 0xdc96, 0x0000, 0x9829, 0x0000, 0xd865, 0xddb6,
+    0x0000, 0x98e2, 0x0000, 0x4b33, 0x0000, 0x9929, 0x0000, 0x99a7,
+    0x0000, 0x99c2, 0x0000, 0x99fe, 0x0000, 0x4bce, 0x0000, 0xd866,
+    0xdf30, 0x0000, 0x9c40, 0x0000, 0x9cfd, 0x0000, 0x4cce, 0x0000,
+    0x4ced, 0x0000, 0x9d67, 0x0000, 0xd868, 0xdcce, 0x0000, 0x4cf8,
+    0x0000, 0xd868, 0xdd05, 0x0000, 0xd868, 0xde0e, 0x0000, 0xd868,
+    0xde91, 0x0000, 0x4d56, 0x0000, 0x9efe, 0x0000, 0x9f05, 0x0000,
+    0x9f0f, 0x0000, 0x9f16, 0x0000, 0xd869, 0xde00, 0x0000
+};
+
+static const BYTE decomp_index0[763] =
+{
+    0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x00,
+    0x00, 0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e,
+    0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x10, 0x00, 0x11, 0x12, 0x13,
+    0x14, 0x15, 0x16, 0x17, 0x18, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x19, 0x00, 0x1a, 0x1b, 0x1c, 0x1d,
+    0x1e, 0x1f, 0x20, 0x21, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x22, 0x23,
+    0x00, 0x00, 0x00, 0x24, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x25, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x2b,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x2c, 0x2d, 0x00, 0x2e, 0x2f, 0x30, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x31, 0x00, 0x00, 0x32, 0x33, 0x34, 0x35,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x36, 0x00,
+    0x00, 0x37, 0x38, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x39, 0x3a, 0x3b
+};
+
+static const USHORT decomp_index1[960] =
 {
-    /* index */
-    0x0110, 0x0120, 0x0130, 0x0140, 0x0150, 0x0100, 0x0160, 0x0100,
-    0x0100, 0x0170, 0x0180, 0x0190, 0x01a0, 0x01b0, 0x0100, 0x01c0,
-    0x01d0, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x01e0, 0x0100, 0x0100, 0x01f0, 0x0200,
-    0x0100, 0x0210, 0x0220, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0230, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0240, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
-    0x0100, 0x0100, 0x0100, 0x0250, 0x0100, 0x0100, 0x0100, 0x0100,
     /* null sub-index */
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260,
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260,
-    /* sub-index 00 */
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260,
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0280, 0x02a0, 0x02c0, 0x02e0,
-    /* sub-index 01 */
-    0x0300, 0x0320, 0x0340, 0x0360, 0x0380, 0x03a0, 0x03c0, 0x03e0,
-    0x0260, 0x0260, 0x0400, 0x0420, 0x0440, 0x0460, 0x0480, 0x04a0,
-    /* sub-index 02 */
-    0x04c0, 0x04e0, 0x0500, 0x0520, 0x0260, 0x0260, 0x0260, 0x0260,
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260,
-    /* sub-index 03 */
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0540, 0x0260, 0x0260, 0x0260,
-    0x0560, 0x0580, 0x05a0, 0x05c0, 0x05e0, 0x0600, 0x0260, 0x0260,
-    /* sub-index 04 */
-    0x0620, 0x0640, 0x0260, 0x0660, 0x0260, 0x0680, 0x0260, 0x06a0,
-    0x0260, 0x0260, 0x0260, 0x0260, 0x06c0, 0x06e0, 0x0700, 0x0720,
-    /* sub-index 06 */
-    0x0260, 0x0260, 0x0740, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260,
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0760, 0x0780, 0x0260, 0x0260,
-    /* sub-index 09 */
-    0x0260, 0x0260, 0x07a0, 0x07c0, 0x0260, 0x07e0, 0x0260, 0x0260,
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0800, 0x0820, 0x0260, 0x0260,
-    /* sub-index 0a */
-    0x0260, 0x0260, 0x0260, 0x0840, 0x0260, 0x0860, 0x0260, 0x0260,
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260,
-    /* sub-index 0b */
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0880, 0x08a0, 0x0260, 0x0260,
-    0x0260, 0x08c0, 0x0260, 0x0260, 0x08e0, 0x0260, 0x0260, 0x0260,
-    /* sub-index 0c */
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0900, 0x0260, 0x0260, 0x0260,
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0920, 0x0260, 0x0260, 0x0260,
-    /* sub-index 0d */
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0940, 0x0260, 0x0260, 0x0260,
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0960, 0x0260, 0x0260,
-    /* sub-index 0f */
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0980, 0x09a0, 0x09c0, 0x09e0,
-    0x0a00, 0x0a20, 0x0a40, 0x0a60, 0x0260, 0x0260, 0x0260, 0x0260,
-    /* sub-index 10 */
-    0x0260, 0x0260, 0x0a80, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260,
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260,
-    /* sub-index 1b */
-    0x0aa0, 0x0ac0, 0x0260, 0x0ae0, 0x0b00, 0x0260, 0x0260, 0x0260,
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260,
-    /* sub-index 1e */
-    0x0b20, 0x0b40, 0x0b60, 0x0b80, 0x0ba0, 0x0bc0, 0x0be0, 0x0c00,
-    0x0c20, 0x0c40, 0x0c60, 0x0c80, 0x0ca0, 0x0cc0, 0x0ce0, 0x0d00,
-    /* sub-index 1f */
-    0x0d20, 0x0d40, 0x0d60, 0x0d80, 0x0da0, 0x0dc0, 0x0de0, 0x0e00,
-    0x0e20, 0x0e40, 0x0e60, 0x0e80, 0x0ea0, 0x0ec0, 0x0ee0, 0x0f00,
-    /* sub-index 21 */
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260,
-    0x0260, 0x0f20, 0x0f40, 0x0260, 0x0f60, 0x0260, 0x0260, 0x0260,
-    /* sub-index 22 */
-    0x0f80, 0x0260, 0x0fa0, 0x0260, 0x0fc0, 0x0260, 0x0fe0, 0x1000,
-    0x1020, 0x0260, 0x1040, 0x0260, 0x0260, 0x0260, 0x1060, 0x0260,
-    /* sub-index 2a */
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260,
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x1080, 0x0260, 0x0260,
-    /* sub-index 30 */
-    0x0260, 0x0260, 0x0260, 0x0260, 0x10a0, 0x10c0, 0x10e0, 0x1100,
-    0x0260, 0x1120, 0x1140, 0x1160, 0x1180, 0x11a0, 0x0260, 0x11c0,
-    /* sub-index fb */
-    0x0260, 0x11e0, 0x1200, 0x1220, 0x1240, 0x0260, 0x0260, 0x0260,
-    0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260, 0x0260,
-    /* null mapping */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x01 */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0001, 0x0002, 0x0003, 0x0004, 0x0005, 0x0006,
+    /* sub-index 0x02 */
+    0x0007, 0x0008, 0x0009, 0x000a, 0x000b, 0x000c, 0x000d, 0x000e,
+    0x0000, 0x0000, 0x000f, 0x0010, 0x0011, 0x0012, 0x0013, 0x0014,
+    /* sub-index 0x03 */
+    0x0015, 0x0016, 0x0017, 0x0018, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0019, 0x0000, 0x001a, 0x001b, 0x0000,
+    /* sub-index 0x04 */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x001c, 0x0000, 0x0000, 0x001d,
+    0x001e, 0x001f, 0x0020, 0x0021, 0x0022, 0x0023, 0x0000, 0x0024,
+    /* sub-index 0x05 */
+    0x0025, 0x0026, 0x0000, 0x0027, 0x0000, 0x0028, 0x0000, 0x0029,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x002a, 0x002b, 0x002c, 0x002d,
+    /* sub-index 0x06 */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x002e, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x07 */
+    0x0000, 0x0000, 0x002f, 0x0000, 0x0000, 0x0000, 0x0000, 0x0030,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0031, 0x0032, 0x0000, 0x0000,
+    /* sub-index 0x08 */
+    0x0000, 0x0000, 0x0033, 0x0034, 0x0000, 0x0035, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0036, 0x0037, 0x0000, 0x0000,
+    /* sub-index 0x09 */
+    0x0000, 0x0000, 0x0000, 0x0038, 0x0000, 0x0039, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x0a */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x003a, 0x003b, 0x0000, 0x0000,
+    0x0000, 0x003c, 0x0000, 0x0000, 0x003d, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x0b */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x003e, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x003f, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x0c */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0040, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0041, 0x0000, 0x0000,
+    /* sub-index 0x0d */
+    0x0000, 0x0000, 0x0000, 0x0042, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0043, 0x0000, 0x0044, 0x0000, 0x0000,
+    /* sub-index 0x0e */
+    0x0045, 0x0000, 0x0000, 0x0000, 0x0046, 0x0047, 0x0048, 0x0049,
+    0x004a, 0x004b, 0x004c, 0x004d, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x0f */
+    0x0000, 0x0000, 0x004e, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x004f,
+    /* sub-index 0x10 */
+    0x0050, 0x0051, 0x0000, 0x0052, 0x0053, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x11 */
+    0x0000, 0x0000, 0x0054, 0x0055, 0x0056, 0x0057, 0x0058, 0x0059,
+    0x0000, 0x005a, 0x005b, 0x005c, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x12 */
+    0x005d, 0x005e, 0x005f, 0x0060, 0x0061, 0x0062, 0x0063, 0x0064,
+    0x0065, 0x0066, 0x0067, 0x0068, 0x0069, 0x006a, 0x006b, 0x006c,
+    /* sub-index 0x13 */
+    0x006d, 0x006e, 0x006f, 0x0070, 0x0071, 0x0072, 0x0073, 0x0074,
+    0x0075, 0x0076, 0x0077, 0x0078, 0x0079, 0x007a, 0x007b, 0x007c,
+    /* sub-index 0x14 */
+    0x007d, 0x007e, 0x007f, 0x0080, 0x0081, 0x0082, 0x0000, 0x0083,
+    0x0084, 0x0085, 0x0086, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x15 */
+    0x0087, 0x0088, 0x0089, 0x008a, 0x008b, 0x008c, 0x008d, 0x008e,
+    0x008f, 0x0090, 0x0091, 0x0000, 0x0092, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x16 */
+    0x0093, 0x0000, 0x0094, 0x0095, 0x0096, 0x0000, 0x0097, 0x0098,
+    0x0099, 0x0000, 0x009a, 0x0000, 0x0000, 0x0000, 0x009b, 0x0000,
+    /* sub-index 0x17 */
+    0x0000, 0x0000, 0x009c, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x18 */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x009d, 0x009e,
+    0x009f, 0x00a0, 0x00a1, 0x00a2, 0x00a3, 0x00a4, 0x00a5, 0x0000,
+    /* sub-index 0x19 */
+    0x00a6, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x00a7,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x00a8, 0x0000, 0x0000,
+    /* sub-index 0x1a */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x00a9,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x1b */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x00aa, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x1c */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x00ab, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x00ac,
+    /* sub-index 0x1d */
+    0x00ad, 0x00ae, 0x00af, 0x00b0, 0x00b1, 0x00b2, 0x00b3, 0x00b4,
+    0x00b5, 0x00b6, 0x00b7, 0x00b8, 0x00b9, 0x00ba, 0x0000, 0x0000,
+    /* sub-index 0x1e */
+    0x00bb, 0x0000, 0x0000, 0x00bc, 0x00bd, 0x00be, 0x00bf, 0x00c0,
+    0x0000, 0x00c1, 0x00c2, 0x00c3, 0x00c4, 0x00c5, 0x0000, 0x00c6,
+    /* sub-index 0x1f */
+    0x0000, 0x0000, 0x0000, 0x00c7, 0x00c8, 0x00c9, 0x00ca, 0x00cb,
+    0x00cc, 0x00cd, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x20 */
+    0x00ce, 0x00cf, 0x00d0, 0x00d1, 0x00d2, 0x00d3, 0x00d4, 0x00d5,
+    0x00d6, 0x00d7, 0x00d8, 0x00d9, 0x00da, 0x00db, 0x00dc, 0x00dd,
+    /* sub-index 0x21 */
+    0x00de, 0x00df, 0x00e0, 0x00e1, 0x00e2, 0x00e3, 0x00e4, 0x00e5,
+    0x00e6, 0x00e7, 0x00e8, 0x00e9, 0x00ea, 0x00eb, 0x00ec, 0x00ed,
+    /* sub-index 0x22 */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x00ee, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x23 */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x00ef,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x00f0,
+    /* sub-index 0x24 */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x00f1, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x25 */
+    0x00f2, 0x00f3, 0x00f4, 0x00f5, 0x00f6, 0x00f7, 0x00f8, 0x00f9,
+    0x00fa, 0x00fb, 0x00fc, 0x00fd, 0x00fe, 0x00ff, 0x0100, 0x0101,
+    /* sub-index 0x26 */
+    0x0102, 0x0103, 0x0104, 0x0105, 0x0106, 0x0107, 0x0108, 0x0109,
+    0x010a, 0x010b, 0x010c, 0x010d, 0x010e, 0x010f, 0x0000, 0x0000,
+    /* sub-index 0x27 */
+    0x0110, 0x0111, 0x0112, 0x0113, 0x0114, 0x0115, 0x0116, 0x0117,
+    0x0118, 0x0119, 0x011a, 0x011b, 0x0000, 0x011c, 0x011d, 0x011e,
+    /* sub-index 0x28 */
+    0x011f, 0x0120, 0x0121, 0x0122, 0x0123, 0x0124, 0x0125, 0x0126,
+    0x0127, 0x0128, 0x0129, 0x012a, 0x012b, 0x012c, 0x012d, 0x012e,
+    /* sub-index 0x29 */
+    0x012f, 0x0130, 0x0131, 0x0132, 0x0000, 0x0133, 0x0134, 0x0135,
+    0x0136, 0x0137, 0x0138, 0x0139, 0x013a, 0x0000, 0x0000, 0x013b,
+    /* sub-index 0x2a */
+    0x0000, 0x013c, 0x0000, 0x013d, 0x013e, 0x013f, 0x0140, 0x0141,
+    0x0142, 0x0143, 0x0144, 0x0145, 0x0146, 0x0147, 0x0148, 0x0149,
+    /* sub-index 0x2b */
+    0x014a, 0x014b, 0x014c, 0x014d, 0x014e, 0x014f, 0x0150, 0x0151,
+    0x0152, 0x0153, 0x0154, 0x0155, 0x0156, 0x0157, 0x0158, 0x0000,
+    /* sub-index 0x2c */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0159, 0x015a, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x2d */
+    0x0000, 0x0000, 0x015b, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x2e */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x015c, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x2f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x015d, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x30 */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x015e, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x31 */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x015f, 0x0160, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0161, 0x0162, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x32 */
+    0x0163, 0x0164, 0x0165, 0x0166, 0x0167, 0x0168, 0x0169, 0x016a,
+    0x016b, 0x016c, 0x016d, 0x016e, 0x016f, 0x0170, 0x0171, 0x0172,
+    /* sub-index 0x33 */
+    0x0173, 0x0174, 0x0175, 0x0176, 0x0177, 0x0178, 0x0179, 0x017a,
+    0x017b, 0x017c, 0x017d, 0x017e, 0x017f, 0x0180, 0x0181, 0x0182,
+    /* sub-index 0x34 */
+    0x0183, 0x0184, 0x0185, 0x0186, 0x0187, 0x0188, 0x0189, 0x018a,
+    0x018b, 0x018c, 0x018d, 0x018e, 0x018f, 0x0190, 0x0191, 0x0192,
+    /* sub-index 0x35 */
+    0x0193, 0x0194, 0x0195, 0x0196, 0x0197, 0x0198, 0x0199, 0x019a,
+    0x019b, 0x019c, 0x019d, 0x019e, 0x019f, 0x01a0, 0x01a1, 0x01a2,
+    /* sub-index 0x36 */
+    0x01a3, 0x01a4, 0x01a5, 0x01a6, 0x01a7, 0x01a8, 0x01a9, 0x01aa,
+    0x01ab, 0x01ac, 0x01ad, 0x01ae, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x37 */
+    0x01af, 0x01b0, 0x01b1, 0x01b2, 0x01b3, 0x0000, 0x01b4, 0x0000,
+    0x0000, 0x01b5, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x38 */
+    0x01b6, 0x01b7, 0x01b8, 0x01b9, 0x01ba, 0x01bb, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* sub-index 0x39 */
+    0x01bc, 0x01bd, 0x01be, 0x01bf, 0x01c0, 0x01c1, 0x01c2, 0x01c3,
+    0x01c4, 0x01c5, 0x01c6, 0x01c7, 0x01c8, 0x01c9, 0x01ca, 0x01cb,
+    /* sub-index 0x3a */
+    0x01cc, 0x01cd, 0x01ce, 0x01cf, 0x01d0, 0x01d1, 0x01d2, 0x01d3,
+    0x01d4, 0x01d5, 0x01d6, 0x01d7, 0x01d8, 0x01d9, 0x01da, 0x01db,
+    /* sub-index 0x3b */
+    0x01dc, 0x01dd, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000
+};
+
+static const USHORT decomp_offsets[15296] =
+{
+    /* (nfd, nfkd) x 16 */
+    /* no decomposition */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x00a0 .. 0x00af */
+    0x0000, 0x0001, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0003, 0x0000, 0x0000, 0x0000, 0x0006, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0008,
+    /* 0x00b0 .. 0x00bf */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x000b, 0x0000, 0x000d,
+    0x0000, 0x000f, 0x0000, 0x0012, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0014, 0x0000, 0x0017, 0x0000, 0x0019, 0x0000, 0x0000,
+    0x0000, 0x001b, 0x0000, 0x001f, 0x0000, 0x0023, 0x0000, 0x0000,
     /* 0x00c0 .. 0x00cf */
-    0x0041, 0x0300, 0x0041, 0x0301, 0x0041, 0x0302, 0x0041, 0x0303,
-    0x0041, 0x0308, 0x0041, 0x030a, 0x0000, 0x0000, 0x0043, 0x0327,
-    0x0045, 0x0300, 0x0045, 0x0301, 0x0045, 0x0302, 0x0045, 0x0308,
-    0x0049, 0x0300, 0x0049, 0x0301, 0x0049, 0x0302, 0x0049, 0x0308,
+    0x0027, 0x0027, 0x002a, 0x002a, 0x002d, 0x002d, 0x0030, 0x0030,
+    0x0033, 0x0033, 0x0036, 0x0036, 0x0000, 0x0000, 0x0039, 0x0039,
+    0x003c, 0x003c, 0x003f, 0x003f, 0x0042, 0x0042, 0x0045, 0x0045,
+    0x0048, 0x0048, 0x004b, 0x004b, 0x004e, 0x004e, 0x0051, 0x0051,
     /* 0x00d0 .. 0x00df */
-    0x0000, 0x0000, 0x004e, 0x0303, 0x004f, 0x0300, 0x004f, 0x0301,
-    0x004f, 0x0302, 0x004f, 0x0303, 0x004f, 0x0308, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0055, 0x0300, 0x0055, 0x0301, 0x0055, 0x0302,
-    0x0055, 0x0308, 0x0059, 0x0301, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0054, 0x0054, 0x0057, 0x0057, 0x005a, 0x005a,
+    0x005d, 0x005d, 0x0060, 0x0060, 0x0063, 0x0063, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0066, 0x0066, 0x0069, 0x0069, 0x006c, 0x006c,
+    0x006f, 0x006f, 0x0072, 0x0072, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x00e0 .. 0x00ef */
-    0x0061, 0x0300, 0x0061, 0x0301, 0x0061, 0x0302, 0x0061, 0x0303,
-    0x0061, 0x0308, 0x0061, 0x030a, 0x0000, 0x0000, 0x0063, 0x0327,
-    0x0065, 0x0300, 0x0065, 0x0301, 0x0065, 0x0302, 0x0065, 0x0308,
-    0x0069, 0x0300, 0x0069, 0x0301, 0x0069, 0x0302, 0x0069, 0x0308,
+    0x0075, 0x0075, 0x0078, 0x0078, 0x007b, 0x007b, 0x007e, 0x007e,
+    0x0081, 0x0081, 0x0084, 0x0084, 0x0000, 0x0000, 0x0087, 0x0087,
+    0x008a, 0x008a, 0x008d, 0x008d, 0x0090, 0x0090, 0x0093, 0x0093,
+    0x0096, 0x0096, 0x0099, 0x0099, 0x009c, 0x009c, 0x009f, 0x009f,
     /* 0x00f0 .. 0x00ff */
-    0x0000, 0x0000, 0x006e, 0x0303, 0x006f, 0x0300, 0x006f, 0x0301,
-    0x006f, 0x0302, 0x006f, 0x0303, 0x006f, 0x0308, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0075, 0x0300, 0x0075, 0x0301, 0x0075, 0x0302,
-    0x0075, 0x0308, 0x0079, 0x0301, 0x0000, 0x0000, 0x0079, 0x0308,
+    0x0000, 0x0000, 0x00a2, 0x00a2, 0x00a5, 0x00a5, 0x00a8, 0x00a8,
+    0x00ab, 0x00ab, 0x00ae, 0x00ae, 0x00b1, 0x00b1, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x00b4, 0x00b4, 0x00b7, 0x00b7, 0x00ba, 0x00ba,
+    0x00bd, 0x00bd, 0x00c0, 0x00c0, 0x0000, 0x0000, 0x00c3, 0x00c3,
     /* 0x0100 .. 0x010f */
-    0x0041, 0x0304, 0x0061, 0x0304, 0x0041, 0x0306, 0x0061, 0x0306,
-    0x0041, 0x0328, 0x0061, 0x0328, 0x0043, 0x0301, 0x0063, 0x0301,
-    0x0043, 0x0302, 0x0063, 0x0302, 0x0043, 0x0307, 0x0063, 0x0307,
-    0x0043, 0x030c, 0x0063, 0x030c, 0x0044, 0x030c, 0x0064, 0x030c,
+    0x00c6, 0x00c6, 0x00c9, 0x00c9, 0x00cc, 0x00cc, 0x00cf, 0x00cf,
+    0x00d2, 0x00d2, 0x00d5, 0x00d5, 0x00d8, 0x00d8, 0x00db, 0x00db,
+    0x00de, 0x00de, 0x00e1, 0x00e1, 0x00e4, 0x00e4, 0x00e7, 0x00e7,
+    0x00ea, 0x00ea, 0x00ed, 0x00ed, 0x00f0, 0x00f0, 0x00f3, 0x00f3,
     /* 0x0110 .. 0x011f */
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0045, 0x0304, 0x0065, 0x0304,
-    0x0045, 0x0306, 0x0065, 0x0306, 0x0045, 0x0307, 0x0065, 0x0307,
-    0x0045, 0x0328, 0x0065, 0x0328, 0x0045, 0x030c, 0x0065, 0x030c,
-    0x0047, 0x0302, 0x0067, 0x0302, 0x0047, 0x0306, 0x0067, 0x0306,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x00f6, 0x00f6, 0x00f9, 0x00f9,
+    0x00fc, 0x00fc, 0x00ff, 0x00ff, 0x0102, 0x0102, 0x0105, 0x0105,
+    0x0108, 0x0108, 0x010b, 0x010b, 0x010e, 0x010e, 0x0111, 0x0111,
+    0x0114, 0x0114, 0x0117, 0x0117, 0x011a, 0x011a, 0x011d, 0x011d,
     /* 0x0120 .. 0x012f */
-    0x0047, 0x0307, 0x0067, 0x0307, 0x0047, 0x0327, 0x0067, 0x0327,
-    0x0048, 0x0302, 0x0068, 0x0302, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0049, 0x0303, 0x0069, 0x0303, 0x0049, 0x0304, 0x0069, 0x0304,
-    0x0049, 0x0306, 0x0069, 0x0306, 0x0049, 0x0328, 0x0069, 0x0328,
+    0x0120, 0x0120, 0x0123, 0x0123, 0x0126, 0x0126, 0x0129, 0x0129,
+    0x012c, 0x012c, 0x012f, 0x012f, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0132, 0x0132, 0x0135, 0x0135, 0x0138, 0x0138, 0x013b, 0x013b,
+    0x013e, 0x013e, 0x0141, 0x0141, 0x0144, 0x0144, 0x0147, 0x0147,
     /* 0x0130 .. 0x013f */
-    0x0049, 0x0307, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x004a, 0x0302, 0x006a, 0x0302, 0x004b, 0x0327, 0x006b, 0x0327,
-    0x0000, 0x0000, 0x004c, 0x0301, 0x006c, 0x0301, 0x004c, 0x0327,
-    0x006c, 0x0327, 0x004c, 0x030c, 0x006c, 0x030c, 0x0000, 0x0000,
+    0x014a, 0x014a, 0x0000, 0x0000, 0x0000, 0x014d, 0x0000, 0x0150,
+    0x0153, 0x0153, 0x0156, 0x0156, 0x0159, 0x0159, 0x015c, 0x015c,
+    0x0000, 0x0000, 0x015f, 0x015f, 0x0162, 0x0162, 0x0165, 0x0165,
+    0x0168, 0x0168, 0x016b, 0x016b, 0x016e, 0x016e, 0x0000, 0x0171,
     /* 0x0140 .. 0x014f */
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x004e, 0x0301,
-    0x006e, 0x0301, 0x004e, 0x0327, 0x006e, 0x0327, 0x004e, 0x030c,
-    0x006e, 0x030c, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x004f, 0x0304, 0x006f, 0x0304, 0x004f, 0x0306, 0x006f, 0x0306,
+    0x0000, 0x0174, 0x0000, 0x0000, 0x0000, 0x0000, 0x0177, 0x0177,
+    0x017a, 0x017a, 0x017d, 0x017d, 0x0180, 0x0180, 0x0183, 0x0183,
+    0x0186, 0x0186, 0x0000, 0x0189, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x018c, 0x018c, 0x018f, 0x018f, 0x0192, 0x0192, 0x0195, 0x0195,
     /* 0x0150 .. 0x015f */
-    0x004f, 0x030b, 0x006f, 0x030b, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0052, 0x0301, 0x0072, 0x0301, 0x0052, 0x0327, 0x0072, 0x0327,
-    0x0052, 0x030c, 0x0072, 0x030c, 0x0053, 0x0301, 0x0073, 0x0301,
-    0x0053, 0x0302, 0x0073, 0x0302, 0x0053, 0x0327, 0x0073, 0x0327,
+    0x0198, 0x0198, 0x019b, 0x019b, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x019e, 0x019e, 0x01a1, 0x01a1, 0x01a4, 0x01a4, 0x01a7, 0x01a7,
+    0x01aa, 0x01aa, 0x01ad, 0x01ad, 0x01b0, 0x01b0, 0x01b3, 0x01b3,
+    0x01b6, 0x01b6, 0x01b9, 0x01b9, 0x01bc, 0x01bc, 0x01bf, 0x01bf,
     /* 0x0160 .. 0x016f */
-    0x0053, 0x030c, 0x0073, 0x030c, 0x0054, 0x0327, 0x0074, 0x0327,
-    0x0054, 0x030c, 0x0074, 0x030c, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0055, 0x0303, 0x0075, 0x0303, 0x0055, 0x0304, 0x0075, 0x0304,
-    0x0055, 0x0306, 0x0075, 0x0306, 0x0055, 0x030a, 0x0075, 0x030a,
+    0x01c2, 0x01c2, 0x01c5, 0x01c5, 0x01c8, 0x01c8, 0x01cb, 0x01cb,
+    0x01ce, 0x01ce, 0x01d1, 0x01d1, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x01d4, 0x01d4, 0x01d7, 0x01d7, 0x01da, 0x01da, 0x01dd, 0x01dd,
+    0x01e0, 0x01e0, 0x01e3, 0x01e3, 0x01e6, 0x01e6, 0x01e9, 0x01e9,
     /* 0x0170 .. 0x017f */
-    0x0055, 0x030b, 0x0075, 0x030b, 0x0055, 0x0328, 0x0075, 0x0328,
-    0x0057, 0x0302, 0x0077, 0x0302, 0x0059, 0x0302, 0x0079, 0x0302,
-    0x0059, 0x0308, 0x005a, 0x0301, 0x007a, 0x0301, 0x005a, 0x0307,
-    0x007a, 0x0307, 0x005a, 0x030c, 0x007a, 0x030c, 0x0000, 0x0000,
+    0x01ec, 0x01ec, 0x01ef, 0x01ef, 0x01f2, 0x01f2, 0x01f5, 0x01f5,
+    0x01f8, 0x01f8, 0x01fb, 0x01fb, 0x01fe, 0x01fe, 0x0201, 0x0201,
+    0x0204, 0x0204, 0x0207, 0x0207, 0x020a, 0x020a, 0x020d, 0x020d,
+    0x0210, 0x0210, 0x0213, 0x0213, 0x0216, 0x0216, 0x0000, 0x0219,
     /* 0x01a0 .. 0x01af */
-    0x004f, 0x031b, 0x006f, 0x031b, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x021b, 0x021b, 0x021e, 0x021e, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0055, 0x031b,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0221, 0x0221,
     /* 0x01b0 .. 0x01bf */
-    0x0075, 0x031b, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0224, 0x0224, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x01c0 .. 0x01cf */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0041, 0x030c, 0x0061, 0x030c, 0x0049, 0x030c,
+    0x0000, 0x0227, 0x0000, 0x022b, 0x0000, 0x022f, 0x0000, 0x0233,
+    0x0000, 0x0236, 0x0000, 0x0239, 0x0000, 0x023c, 0x0000, 0x023f,
+    0x0000, 0x0242, 0x0245, 0x0245, 0x0248, 0x0248, 0x024b, 0x024b,
     /* 0x01d0 .. 0x01df */
-    0x0069, 0x030c, 0x004f, 0x030c, 0x006f, 0x030c, 0x0055, 0x030c,
-    0x0075, 0x030c, 0x00dc, 0x0304, 0x00fc, 0x0304, 0x00dc, 0x0301,
-    0x00fc, 0x0301, 0x00dc, 0x030c, 0x00fc, 0x030c, 0x00dc, 0x0300,
-    0x00fc, 0x0300, 0x0000, 0x0000, 0x00c4, 0x0304, 0x00e4, 0x0304,
+    0x024e, 0x024e, 0x0251, 0x0251, 0x0254, 0x0254, 0x0257, 0x0257,
+    0x025a, 0x025a, 0x025d, 0x025d, 0x0261, 0x0261, 0x0265, 0x0265,
+    0x0269, 0x0269, 0x026d, 0x026d, 0x0271, 0x0271, 0x0275, 0x0275,
+    0x0279, 0x0279, 0x0000, 0x0000, 0x027d, 0x027d, 0x0281, 0x0281,
     /* 0x01e0 .. 0x01ef */
-    0x0226, 0x0304, 0x0227, 0x0304, 0x00c6, 0x0304, 0x00e6, 0x0304,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0047, 0x030c, 0x0067, 0x030c,
-    0x004b, 0x030c, 0x006b, 0x030c, 0x004f, 0x0328, 0x006f, 0x0328,
-    0x01ea, 0x0304, 0x01eb, 0x0304, 0x01b7, 0x030c, 0x0292, 0x030c,
+    0x0285, 0x0285, 0x0289, 0x0289, 0x028d, 0x028d, 0x0290, 0x0290,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0293, 0x0293, 0x0296, 0x0296,
+    0x0299, 0x0299, 0x029c, 0x029c, 0x029f, 0x029f, 0x02a2, 0x02a2,
+    0x02a5, 0x02a5, 0x02a9, 0x02a9, 0x02ad, 0x02ad, 0x02b0, 0x02b0,
     /* 0x01f0 .. 0x01ff */
-    0x006a, 0x030c, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0047, 0x0301, 0x0067, 0x0301, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x004e, 0x0300, 0x006e, 0x0300, 0x00c5, 0x0301, 0x00e5, 0x0301,
-    0x00c6, 0x0301, 0x00e6, 0x0301, 0x00d8, 0x0301, 0x00f8, 0x0301,
+    0x02b3, 0x02b3, 0x0000, 0x02b6, 0x0000, 0x02b9, 0x0000, 0x02bc,
+    0x02bf, 0x02bf, 0x02c2, 0x02c2, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x02c5, 0x02c5, 0x02c8, 0x02c8, 0x02cb, 0x02cb, 0x02cf, 0x02cf,
+    0x02d3, 0x02d3, 0x02d6, 0x02d6, 0x02d9, 0x02d9, 0x02dc, 0x02dc,
     /* 0x0200 .. 0x020f */
-    0x0041, 0x030f, 0x0061, 0x030f, 0x0041, 0x0311, 0x0061, 0x0311,
-    0x0045, 0x030f, 0x0065, 0x030f, 0x0045, 0x0311, 0x0065, 0x0311,
-    0x0049, 0x030f, 0x0069, 0x030f, 0x0049, 0x0311, 0x0069, 0x0311,
-    0x004f, 0x030f, 0x006f, 0x030f, 0x004f, 0x0311, 0x006f, 0x0311,
+    0x02df, 0x02df, 0x02e2, 0x02e2, 0x02e5, 0x02e5, 0x02e8, 0x02e8,
+    0x02eb, 0x02eb, 0x02ee, 0x02ee, 0x02f1, 0x02f1, 0x02f4, 0x02f4,
+    0x02f7, 0x02f7, 0x02fa, 0x02fa, 0x02fd, 0x02fd, 0x0300, 0x0300,
+    0x0303, 0x0303, 0x0306, 0x0306, 0x0309, 0x0309, 0x030c, 0x030c,
     /* 0x0210 .. 0x021f */
-    0x0052, 0x030f, 0x0072, 0x030f, 0x0052, 0x0311, 0x0072, 0x0311,
-    0x0055, 0x030f, 0x0075, 0x030f, 0x0055, 0x0311, 0x0075, 0x0311,
-    0x0053, 0x0326, 0x0073, 0x0326, 0x0054, 0x0326, 0x0074, 0x0326,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0048, 0x030c, 0x0068, 0x030c,
+    0x030f, 0x030f, 0x0312, 0x0312, 0x0315, 0x0315, 0x0318, 0x0318,
+    0x031b, 0x031b, 0x031e, 0x031e, 0x0321, 0x0321, 0x0324, 0x0324,
+    0x0327, 0x0327, 0x032a, 0x032a, 0x032d, 0x032d, 0x0330, 0x0330,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0333, 0x0333, 0x0336, 0x0336,
     /* 0x0220 .. 0x022f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0041, 0x0307, 0x0061, 0x0307,
-    0x0045, 0x0327, 0x0065, 0x0327, 0x00d6, 0x0304, 0x00f6, 0x0304,
-    0x00d5, 0x0304, 0x00f5, 0x0304, 0x004f, 0x0307, 0x006f, 0x0307,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0339, 0x0339, 0x033c, 0x033c,
+    0x033f, 0x033f, 0x0342, 0x0342, 0x0345, 0x0345, 0x0349, 0x0349,
+    0x034d, 0x034d, 0x0351, 0x0351, 0x0355, 0x0355, 0x0358, 0x0358,
     /* 0x0230 .. 0x023f */
-    0x022e, 0x0304, 0x022f, 0x0304, 0x0059, 0x0304, 0x0079, 0x0304,
+    0x035b, 0x035b, 0x035f, 0x035f, 0x0363, 0x0363, 0x0366, 0x0366,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x02b0 .. 0x02bf */
+    0x0000, 0x0369, 0x0000, 0x036b, 0x0000, 0x036d, 0x0000, 0x036f,
+    0x0000, 0x0371, 0x0000, 0x0373, 0x0000, 0x0375, 0x0000, 0x0377,
+    0x0000, 0x0379, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x02d0 .. 0x02df */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x037b, 0x0000, 0x037e, 0x0000, 0x0381, 0x0000, 0x0384,
+    0x0000, 0x0387, 0x0000, 0x038a, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x02e0 .. 0x02ef */
+    0x0000, 0x038d, 0x0000, 0x038f, 0x0000, 0x0219, 0x0000, 0x0391,
+    0x0000, 0x0393, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0340 .. 0x034f */
+    0x0395, 0x0395, 0x0397, 0x0397, 0x0000, 0x0000, 0x0399, 0x0399,
+    0x039b, 0x039b, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0308, 0x0301, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x0370 .. 0x037f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x039e, 0x039e, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x03a0, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x03a3, 0x03a3, 0x0000, 0x0000,
     /* 0x0380 .. 0x038f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x00a8, 0x0301, 0x0391, 0x0301, 0x0000, 0x0000,
-    0x0395, 0x0301, 0x0397, 0x0301, 0x0399, 0x0301, 0x0000, 0x0000,
-    0x039f, 0x0301, 0x0000, 0x0000, 0x03a5, 0x0301, 0x03a9, 0x0301,
+    0x0000, 0x000f, 0x03a5, 0x03a8, 0x03ac, 0x03ac, 0x03af, 0x03af,
+    0x03b1, 0x03b1, 0x03b4, 0x03b4, 0x03b7, 0x03b7, 0x0000, 0x0000,
+    0x03ba, 0x03ba, 0x0000, 0x0000, 0x03bd, 0x03bd, 0x03c0, 0x03c0,
     /* 0x0390 .. 0x039f */
-    0x03ca, 0x0301, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x03c3, 0x03c3, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x03a0 .. 0x03af */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0399, 0x0308, 0x03a5, 0x0308,
-    0x03b1, 0x0301, 0x03b5, 0x0301, 0x03b7, 0x0301, 0x03b9, 0x0301,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x03c7, 0x03c7, 0x03ca, 0x03ca,
+    0x03cd, 0x03cd, 0x03d0, 0x03d0, 0x03d3, 0x03d3, 0x03d6, 0x03d6,
     /* 0x03b0 .. 0x03bf */
-    0x03cb, 0x0301, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x03d9, 0x03d9, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x03c0 .. 0x03cf */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x03b9, 0x0308, 0x03c5, 0x0308,
-    0x03bf, 0x0301, 0x03c5, 0x0301, 0x03c9, 0x0301, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x03dd, 0x03dd, 0x03e0, 0x03e0,
+    0x03e3, 0x03e3, 0x03e6, 0x03e6, 0x03e9, 0x03e9, 0x0000, 0x0000,
     /* 0x03d0 .. 0x03df */
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x03d2, 0x0301,
-    0x03d2, 0x0308, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x03ec, 0x0000, 0x03ee, 0x0000, 0x03f0, 0x03f2, 0x03bd,
+    0x03f5, 0x03ca, 0x0000, 0x03f8, 0x0000, 0x03fa, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x03f0 .. 0x03ff */
+    0x0000, 0x03fc, 0x0000, 0x03fe, 0x0000, 0x0400, 0x0000, 0x0000,
+    0x0000, 0x0402, 0x0000, 0x0404, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0406, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0400 .. 0x040f */
-    0x0415, 0x0300, 0x0415, 0x0308, 0x0000, 0x0000, 0x0413, 0x0301,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0406, 0x0308,
+    0x0408, 0x0408, 0x040b, 0x040b, 0x0000, 0x0000, 0x040e, 0x040e,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0411, 0x0411,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x041a, 0x0301, 0x0418, 0x0300, 0x0423, 0x0306, 0x0000, 0x0000,
+    0x0414, 0x0414, 0x0417, 0x0417, 0x041a, 0x041a, 0x0000, 0x0000,
     /* 0x0410 .. 0x041f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0418, 0x0306, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x041d, 0x041d, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0430 .. 0x043f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0438, 0x0306, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0420, 0x0420, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0450 .. 0x045f */
-    0x0435, 0x0300, 0x0435, 0x0308, 0x0000, 0x0000, 0x0433, 0x0301,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0456, 0x0308,
+    0x0423, 0x0423, 0x0426, 0x0426, 0x0000, 0x0000, 0x0429, 0x0429,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x042c, 0x042c,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x043a, 0x0301, 0x0438, 0x0300, 0x0443, 0x0306, 0x0000, 0x0000,
+    0x042f, 0x042f, 0x0432, 0x0432, 0x0435, 0x0435, 0x0000, 0x0000,
     /* 0x0470 .. 0x047f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0474, 0x030f, 0x0475, 0x030f,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0438, 0x0438, 0x043b, 0x043b,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x04c0 .. 0x04cf */
-    0x0000, 0x0000, 0x0416, 0x0306, 0x0436, 0x0306, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x043e, 0x043e, 0x0441, 0x0441, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x04d0 .. 0x04df */
-    0x0410, 0x0306, 0x0430, 0x0306, 0x0410, 0x0308, 0x0430, 0x0308,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0415, 0x0306, 0x0435, 0x0306,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x04d8, 0x0308, 0x04d9, 0x0308,
-    0x0416, 0x0308, 0x0436, 0x0308, 0x0417, 0x0308, 0x0437, 0x0308,
+    0x0444, 0x0444, 0x0447, 0x0447, 0x044a, 0x044a, 0x044d, 0x044d,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0450, 0x0450, 0x0453, 0x0453,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0456, 0x0456, 0x0459, 0x0459,
+    0x045c, 0x045c, 0x045f, 0x045f, 0x0462, 0x0462, 0x0465, 0x0465,
     /* 0x04e0 .. 0x04ef */
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0418, 0x0304, 0x0438, 0x0304,
-    0x0418, 0x0308, 0x0438, 0x0308, 0x041e, 0x0308, 0x043e, 0x0308,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x04e8, 0x0308, 0x04e9, 0x0308,
-    0x042d, 0x0308, 0x044d, 0x0308, 0x0423, 0x0304, 0x0443, 0x0304,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0468, 0x0468, 0x046b, 0x046b,
+    0x046e, 0x046e, 0x0471, 0x0471, 0x0474, 0x0474, 0x0477, 0x0477,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x047a, 0x047a, 0x047d, 0x047d,
+    0x0480, 0x0480, 0x0483, 0x0483, 0x0486, 0x0486, 0x0489, 0x0489,
     /* 0x04f0 .. 0x04ff */
-    0x0423, 0x0308, 0x0443, 0x0308, 0x0423, 0x030b, 0x0443, 0x030b,
-    0x0427, 0x0308, 0x0447, 0x0308, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x042b, 0x0308, 0x044b, 0x0308, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x048c, 0x048c, 0x048f, 0x048f, 0x0492, 0x0492, 0x0495, 0x0495,
+    0x0498, 0x0498, 0x049b, 0x049b, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x049e, 0x049e, 0x04a1, 0x04a1, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x0580 .. 0x058f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x04a4,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0620 .. 0x062f */
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0627, 0x0653, 0x0627, 0x0654,
-    0x0648, 0x0654, 0x0627, 0x0655, 0x064a, 0x0654, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x04a7, 0x04a7, 0x04aa, 0x04aa,
+    0x04ad, 0x04ad, 0x04b0, 0x04b0, 0x04b3, 0x04b3, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x0670 .. 0x067f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x04b6, 0x0000, 0x04b9, 0x0000, 0x04bc,
+    0x0000, 0x04bf, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x06c0 .. 0x06cf */
-    0x06d5, 0x0654, 0x0000, 0x0000, 0x06c1, 0x0654, 0x0000, 0x0000,
+    0x04c2, 0x04c2, 0x0000, 0x0000, 0x04c5, 0x04c5, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x06d0 .. 0x06df */
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x06d2, 0x0654,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x04c8, 0x04c8,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0920 .. 0x092f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0928, 0x093c, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x04cb, 0x04cb, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0930 .. 0x093f */
-    0x0000, 0x0000, 0x0930, 0x093c, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0933, 0x093c, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x04ce, 0x04ce, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x04d1, 0x04d1, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0950 .. 0x095f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0915, 0x093c, 0x0916, 0x093c, 0x0917, 0x093c, 0x091c, 0x093c,
-    0x0921, 0x093c, 0x0922, 0x093c, 0x092b, 0x093c, 0x092f, 0x093c,
+    0x04d4, 0x04d4, 0x04d7, 0x04d7, 0x04da, 0x04da, 0x04dd, 0x04dd,
+    0x04e0, 0x04e0, 0x04e3, 0x04e3, 0x04e6, 0x04e6, 0x04e9, 0x04e9,
     /* 0x09c0 .. 0x09cf */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x09c7, 0x09be,
-    0x09c7, 0x09d7, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x04ec, 0x04ec,
+    0x04ef, 0x04ef, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x09d0 .. 0x09df */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x09a1, 0x09bc, 0x09a2, 0x09bc, 0x0000, 0x0000, 0x09af, 0x09bc,
+    0x04f2, 0x04f2, 0x04f5, 0x04f5, 0x0000, 0x0000, 0x04f8, 0x04f8,
     /* 0x0a30 .. 0x0a3f */
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0a32, 0x0a3c,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0a38, 0x0a3c, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x04fb, 0x04fb,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x04fe, 0x04fe, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0a50 .. 0x0a5f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0a16, 0x0a3c, 0x0a17, 0x0a3c, 0x0a1c, 0x0a3c,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0a2b, 0x0a3c, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0501, 0x0501, 0x0504, 0x0504, 0x0507, 0x0507,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x050a, 0x050a, 0x0000, 0x0000,
     /* 0x0b40 .. 0x0b4f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0b47, 0x0b56, 0x0000, 0x0000, 0x0000, 0x0000, 0x0b47, 0x0b3e,
-    0x0b47, 0x0b57, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x050d, 0x050d, 0x0000, 0x0000, 0x0000, 0x0000, 0x0510, 0x0510,
+    0x0513, 0x0513, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0b50 .. 0x0b5f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0b21, 0x0b3c, 0x0b22, 0x0b3c, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0516, 0x0516, 0x0519, 0x0519, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0b90 .. 0x0b9f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0b92, 0x0bd7, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x051c, 0x051c, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0bc0 .. 0x0bcf */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0bc6, 0x0bbe, 0x0bc7, 0x0bbe,
-    0x0bc6, 0x0bd7, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x051f, 0x051f, 0x0522, 0x0522,
+    0x0525, 0x0525, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0c40 .. 0x0c4f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0c46, 0x0c56, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0528, 0x0528, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0cc0 .. 0x0ccf */
-    0x0cbf, 0x0cd5, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0cc6, 0x0cd5,
-    0x0cc6, 0x0cd6, 0x0000, 0x0000, 0x0cc6, 0x0cc2, 0x0cca, 0x0cd5,
+    0x052b, 0x052b, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x052e, 0x052e,
+    0x0531, 0x0531, 0x0000, 0x0000, 0x0534, 0x0534, 0x0537, 0x0537,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0d40 .. 0x0d4f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0d46, 0x0d3e, 0x0d47, 0x0d3e,
-    0x0d46, 0x0d57, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x053b, 0x053b, 0x053e, 0x053e,
+    0x0541, 0x0541, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0dd0 .. 0x0ddf */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0dd9, 0x0dca, 0x0000, 0x0000,
-    0x0dd9, 0x0dcf, 0x0ddc, 0x0dca, 0x0dd9, 0x0ddf, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0544, 0x0544, 0x0000, 0x0000,
+    0x0547, 0x0547, 0x054a, 0x054a, 0x054e, 0x054e, 0x0000, 0x0000,
+    /* 0x0e30 .. 0x0e3f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0551,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x0eb0 .. 0x0ebf */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0554,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x0ed0 .. 0x0edf */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0557, 0x0000, 0x055a, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x0f00 .. 0x0f0f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x055d, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0f40 .. 0x0f4f */
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0f42, 0x0fb7,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x055f, 0x055f,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0f4c, 0x0fb7, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0562, 0x0562, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0f50 .. 0x0f5f */
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0f51, 0x0fb7, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0f56, 0x0fb7,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0565, 0x0565, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0568, 0x0568,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0f5b, 0x0fb7, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x056b, 0x056b, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0f60 .. 0x0f6f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0f40, 0x0fb5, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x056e, 0x056e, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0f70 .. 0x0f7f */
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0f71, 0x0f72,
-    0x0000, 0x0000, 0x0f71, 0x0f74, 0x0fb2, 0x0f80, 0x0000, 0x0000,
-    0x0fb3, 0x0f80, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0571, 0x0571,
+    0x0000, 0x0000, 0x0574, 0x0574, 0x0577, 0x0577, 0x0000, 0x057a,
+    0x057e, 0x057e, 0x0000, 0x0581, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0f80 .. 0x0f8f */
-    0x0000, 0x0000, 0x0f71, 0x0f80, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0585, 0x0585, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0f90 .. 0x0f9f */
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0f92, 0x0fb7,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0588, 0x0588,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0f9c, 0x0fb7, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x058b, 0x058b, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0fa0 .. 0x0faf */
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0fa1, 0x0fb7, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0fa6, 0x0fb7,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x058e, 0x058e, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0591, 0x0591,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0fab, 0x0fb7, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0594, 0x0594, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x0fb0 .. 0x0fbf */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0f90, 0x0fb5, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0597, 0x0597, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x1020 .. 0x102f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x1025, 0x102e, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x059a, 0x059a, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x10f0 .. 0x10ff */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x059d, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x1b00 .. 0x1b0f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x1b05, 0x1b35, 0x0000, 0x0000,
-    0x1b07, 0x1b35, 0x0000, 0x0000, 0x1b09, 0x1b35, 0x0000, 0x0000,
-    0x1b0b, 0x1b35, 0x0000, 0x0000, 0x1b0d, 0x1b35, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x059f, 0x059f, 0x0000, 0x0000,
+    0x05a2, 0x05a2, 0x0000, 0x0000, 0x05a5, 0x05a5, 0x0000, 0x0000,
+    0x05a8, 0x05a8, 0x0000, 0x0000, 0x05ab, 0x05ab, 0x0000, 0x0000,
     /* 0x1b10 .. 0x1b1f */
-    0x0000, 0x0000, 0x0000, 0x0000, 0x1b11, 0x1b35, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x05ae, 0x05ae, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x1b30 .. 0x1b3f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x1b3a, 0x1b35,
-    0x0000, 0x0000, 0x1b3c, 0x1b35, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x05b1, 0x05b1,
+    0x0000, 0x0000, 0x05b4, 0x05b4, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x1b40 .. 0x1b4f */
-    0x1b3e, 0x1b35, 0x1b3f, 0x1b35, 0x0000, 0x0000, 0x1b42, 0x1b35,
+    0x05b7, 0x05b7, 0x05ba, 0x05ba, 0x0000, 0x0000, 0x05bd, 0x05bd,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x1d20 .. 0x1d2f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x05c0, 0x0000, 0x05c2, 0x0000, 0x05c4, 0x0000, 0x0000,
+    /* 0x1d30 .. 0x1d3f */
+    0x0000, 0x05c6, 0x0000, 0x05c8, 0x0000, 0x05ca, 0x0000, 0x05cc,
+    0x0000, 0x05ce, 0x0000, 0x05d0, 0x0000, 0x05d2, 0x0000, 0x05d4,
+    0x0000, 0x05d6, 0x0000, 0x05d8, 0x0000, 0x05da, 0x0000, 0x0000,
+    0x0000, 0x05dc, 0x0000, 0x05de, 0x0000, 0x05e0, 0x0000, 0x05e2,
+    /* 0x1d40 .. 0x1d4f */
+    0x0000, 0x05e4, 0x0000, 0x05e6, 0x0000, 0x05e8, 0x0000, 0x0006,
+    0x0000, 0x05ea, 0x0000, 0x05ec, 0x0000, 0x05ee, 0x0000, 0x05f0,
+    0x0000, 0x05f2, 0x0000, 0x05f4, 0x0000, 0x05f6, 0x0000, 0x05f8,
+    0x0000, 0x05fa, 0x0000, 0x05fc, 0x0000, 0x0000, 0x0000, 0x05fe,
+    /* 0x1d50 .. 0x1d5f */
+    0x0000, 0x0600, 0x0000, 0x0602, 0x0000, 0x0019, 0x0000, 0x0604,
+    0x0000, 0x0606, 0x0000, 0x0608, 0x0000, 0x060a, 0x0000, 0x060c,
+    0x0000, 0x060e, 0x0000, 0x0610, 0x0000, 0x0612, 0x0000, 0x0614,
+    0x0000, 0x0616, 0x0000, 0x03ec, 0x0000, 0x0618, 0x0000, 0x061a,
+    /* 0x1d60 .. 0x1d6f */
+    0x0000, 0x03f8, 0x0000, 0x061c, 0x0000, 0x061e, 0x0000, 0x036f,
+    0x0000, 0x060e, 0x0000, 0x0614, 0x0000, 0x03ec, 0x0000, 0x0618,
+    0x0000, 0x03fe, 0x0000, 0x03f8, 0x0000, 0x061c, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x1d70 .. 0x1d7f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0620, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x1d90 .. 0x1d9f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0622,
+    0x0000, 0x0624, 0x0000, 0x0626, 0x0000, 0x0628, 0x0000, 0x05fa,
+    /* 0x1da0 .. 0x1daf */
+    0x0000, 0x062a, 0x0000, 0x062c, 0x0000, 0x062e, 0x0000, 0x0630,
+    0x0000, 0x0632, 0x0000, 0x0634, 0x0000, 0x0636, 0x0000, 0x0638,
+    0x0000, 0x063a, 0x0000, 0x063c, 0x0000, 0x063e, 0x0000, 0x0640,
+    0x0000, 0x0642, 0x0000, 0x0644, 0x0000, 0x0646, 0x0000, 0x0648,
+    /* 0x1db0 .. 0x1dbf */
+    0x0000, 0x064a, 0x0000, 0x064c, 0x0000, 0x064e, 0x0000, 0x0650,
+    0x0000, 0x0652, 0x0000, 0x0654, 0x0000, 0x0656, 0x0000, 0x0658,
+    0x0000, 0x065a, 0x0000, 0x065c, 0x0000, 0x065e, 0x0000, 0x0660,
+    0x0000, 0x0662, 0x0000, 0x0664, 0x0000, 0x0666, 0x0000, 0x03ee,
     /* 0x1e00 .. 0x1e0f */
-    0x0041, 0x0325, 0x0061, 0x0325, 0x0042, 0x0307, 0x0062, 0x0307,
-    0x0042, 0x0323, 0x0062, 0x0323, 0x0042, 0x0331, 0x0062, 0x0331,
-    0x00c7, 0x0301, 0x00e7, 0x0301, 0x0044, 0x0307, 0x0064, 0x0307,
-    0x0044, 0x0323, 0x0064, 0x0323, 0x0044, 0x0331, 0x0064, 0x0331,
+    0x0668, 0x0668, 0x066b, 0x066b, 0x066e, 0x066e, 0x0671, 0x0671,
+    0x0674, 0x0674, 0x0677, 0x0677, 0x067a, 0x067a, 0x067d, 0x067d,
+    0x0680, 0x0680, 0x0684, 0x0684, 0x0688, 0x0688, 0x068b, 0x068b,
+    0x068e, 0x068e, 0x0691, 0x0691, 0x0694, 0x0694, 0x0697, 0x0697,
     /* 0x1e10 .. 0x1e1f */
-    0x0044, 0x0327, 0x0064, 0x0327, 0x0044, 0x032d, 0x0064, 0x032d,
-    0x0112, 0x0300, 0x0113, 0x0300, 0x0112, 0x0301, 0x0113, 0x0301,
-    0x0045, 0x032d, 0x0065, 0x032d, 0x0045, 0x0330, 0x0065, 0x0330,
-    0x0228, 0x0306, 0x0229, 0x0306, 0x0046, 0x0307, 0x0066, 0x0307,
+    0x069a, 0x069a, 0x069d, 0x069d, 0x06a0, 0x06a0, 0x06a3, 0x06a3,
+    0x06a6, 0x06a6, 0x06aa, 0x06aa, 0x06ae, 0x06ae, 0x06b2, 0x06b2,
+    0x06b6, 0x06b6, 0x06b9, 0x06b9, 0x06bc, 0x06bc, 0x06bf, 0x06bf,
+    0x06c2, 0x06c2, 0x06c6, 0x06c6, 0x06ca, 0x06ca, 0x06cd, 0x06cd,
     /* 0x1e20 .. 0x1e2f */
-    0x0047, 0x0304, 0x0067, 0x0304, 0x0048, 0x0307, 0x0068, 0x0307,
-    0x0048, 0x0323, 0x0068, 0x0323, 0x0048, 0x0308, 0x0068, 0x0308,
-    0x0048, 0x0327, 0x0068, 0x0327, 0x0048, 0x032e, 0x0068, 0x032e,
-    0x0049, 0x0330, 0x0069, 0x0330, 0x00cf, 0x0301, 0x00ef, 0x0301,
+    0x06d0, 0x06d0, 0x06d3, 0x06d3, 0x06d6, 0x06d6, 0x06d9, 0x06d9,
+    0x06dc, 0x06dc, 0x06df, 0x06df, 0x06e2, 0x06e2, 0x06e5, 0x06e5,
+    0x06e8, 0x06e8, 0x06eb, 0x06eb, 0x06ee, 0x06ee, 0x06f1, 0x06f1,
+    0x06f4, 0x06f4, 0x06f7, 0x06f7, 0x06fa, 0x06fa, 0x06fe, 0x06fe,
     /* 0x1e30 .. 0x1e3f */
-    0x004b, 0x0301, 0x006b, 0x0301, 0x004b, 0x0323, 0x006b, 0x0323,
-    0x004b, 0x0331, 0x006b, 0x0331, 0x004c, 0x0323, 0x006c, 0x0323,
-    0x1e36, 0x0304, 0x1e37, 0x0304, 0x004c, 0x0331, 0x006c, 0x0331,
-    0x004c, 0x032d, 0x006c, 0x032d, 0x004d, 0x0301, 0x006d, 0x0301,
+    0x0702, 0x0702, 0x0705, 0x0705, 0x0708, 0x0708, 0x070b, 0x070b,
+    0x070e, 0x070e, 0x0711, 0x0711, 0x0714, 0x0714, 0x0717, 0x0717,
+    0x071a, 0x071a, 0x071e, 0x071e, 0x0722, 0x0722, 0x0725, 0x0725,
+    0x0728, 0x0728, 0x072b, 0x072b, 0x072e, 0x072e, 0x0731, 0x0731,
     /* 0x1e40 .. 0x1e4f */
-    0x004d, 0x0307, 0x006d, 0x0307, 0x004d, 0x0323, 0x006d, 0x0323,
-    0x004e, 0x0307, 0x006e, 0x0307, 0x004e, 0x0323, 0x006e, 0x0323,
-    0x004e, 0x0331, 0x006e, 0x0331, 0x004e, 0x032d, 0x006e, 0x032d,
-    0x00d5, 0x0301, 0x00f5, 0x0301, 0x00d5, 0x0308, 0x00f5, 0x0308,
+    0x0734, 0x0734, 0x0737, 0x0737, 0x073a, 0x073a, 0x073d, 0x073d,
+    0x0740, 0x0740, 0x0743, 0x0743, 0x0746, 0x0746, 0x0749, 0x0749,
+    0x074c, 0x074c, 0x074f, 0x074f, 0x0752, 0x0752, 0x0755, 0x0755,
+    0x0758, 0x0758, 0x075c, 0x075c, 0x0760, 0x0760, 0x0764, 0x0764,
     /* 0x1e50 .. 0x1e5f */
-    0x014c, 0x0300, 0x014d, 0x0300, 0x014c, 0x0301, 0x014d, 0x0301,
-    0x0050, 0x0301, 0x0070, 0x0301, 0x0050, 0x0307, 0x0070, 0x0307,
-    0x0052, 0x0307, 0x0072, 0x0307, 0x0052, 0x0323, 0x0072, 0x0323,
-    0x1e5a, 0x0304, 0x1e5b, 0x0304, 0x0052, 0x0331, 0x0072, 0x0331,
+    0x0768, 0x0768, 0x076c, 0x076c, 0x0770, 0x0770, 0x0774, 0x0774,
+    0x0778, 0x0778, 0x077b, 0x077b, 0x077e, 0x077e, 0x0781, 0x0781,
+    0x0784, 0x0784, 0x0787, 0x0787, 0x078a, 0x078a, 0x078d, 0x078d,
+    0x0790, 0x0790, 0x0794, 0x0794, 0x0798, 0x0798, 0x079b, 0x079b,
     /* 0x1e60 .. 0x1e6f */
-    0x0053, 0x0307, 0x0073, 0x0307, 0x0053, 0x0323, 0x0073, 0x0323,
-    0x015a, 0x0307, 0x015b, 0x0307, 0x0160, 0x0307, 0x0161, 0x0307,
-    0x1e62, 0x0307, 0x1e63, 0x0307, 0x0054, 0x0307, 0x0074, 0x0307,
-    0x0054, 0x0323, 0x0074, 0x0323, 0x0054, 0x0331, 0x0074, 0x0331,
+    0x079e, 0x079e, 0x07a1, 0x07a1, 0x07a4, 0x07a4, 0x07a7, 0x07a7,
+    0x07aa, 0x07aa, 0x07ae, 0x07ae, 0x07b2, 0x07b2, 0x07b6, 0x07b6,
+    0x07ba, 0x07ba, 0x07be, 0x07be, 0x07c2, 0x07c2, 0x07c5, 0x07c5,
+    0x07c8, 0x07c8, 0x07cb, 0x07cb, 0x07ce, 0x07ce, 0x07d1, 0x07d1,
     /* 0x1e70 .. 0x1e7f */
-    0x0054, 0x032d, 0x0074, 0x032d, 0x0055, 0x0324, 0x0075, 0x0324,
-    0x0055, 0x0330, 0x0075, 0x0330, 0x0055, 0x032d, 0x0075, 0x032d,
-    0x0168, 0x0301, 0x0169, 0x0301, 0x016a, 0x0308, 0x016b, 0x0308,
-    0x0056, 0x0303, 0x0076, 0x0303, 0x0056, 0x0323, 0x0076, 0x0323,
+    0x07d4, 0x07d4, 0x07d7, 0x07d7, 0x07da, 0x07da, 0x07dd, 0x07dd,
+    0x07e0, 0x07e0, 0x07e3, 0x07e3, 0x07e6, 0x07e6, 0x07e9, 0x07e9,
+    0x07ec, 0x07ec, 0x07f0, 0x07f0, 0x07f4, 0x07f4, 0x07f8, 0x07f8,
+    0x07fc, 0x07fc, 0x07ff, 0x07ff, 0x0802, 0x0802, 0x0805, 0x0805,
     /* 0x1e80 .. 0x1e8f */
-    0x0057, 0x0300, 0x0077, 0x0300, 0x0057, 0x0301, 0x0077, 0x0301,
-    0x0057, 0x0308, 0x0077, 0x0308, 0x0057, 0x0307, 0x0077, 0x0307,
-    0x0057, 0x0323, 0x0077, 0x0323, 0x0058, 0x0307, 0x0078, 0x0307,
-    0x0058, 0x0308, 0x0078, 0x0308, 0x0059, 0x0307, 0x0079, 0x0307,
+    0x0808, 0x0808, 0x080b, 0x080b, 0x080e, 0x080e, 0x0811, 0x0811,
+    0x0814, 0x0814, 0x0817, 0x0817, 0x081a, 0x081a, 0x081d, 0x081d,
+    0x0820, 0x0820, 0x0823, 0x0823, 0x0826, 0x0826, 0x0829, 0x0829,
+    0x082c, 0x082c, 0x082f, 0x082f, 0x0832, 0x0832, 0x0835, 0x0835,
     /* 0x1e90 .. 0x1e9f */
-    0x005a, 0x0302, 0x007a, 0x0302, 0x005a, 0x0323, 0x007a, 0x0323,
-    0x005a, 0x0331, 0x007a, 0x0331, 0x0068, 0x0331, 0x0074, 0x0308,
-    0x0077, 0x030a, 0x0079, 0x030a, 0x0000, 0x0000, 0x017f, 0x0307,
+    0x0838, 0x0838, 0x083b, 0x083b, 0x083e, 0x083e, 0x0841, 0x0841,
+    0x0844, 0x0844, 0x0847, 0x0847, 0x084a, 0x084a, 0x084d, 0x084d,
+    0x0850, 0x0850, 0x0853, 0x0853, 0x0000, 0x0856, 0x0859, 0x07a1,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x1ea0 .. 0x1eaf */
-    0x0041, 0x0323, 0x0061, 0x0323, 0x0041, 0x0309, 0x0061, 0x0309,
-    0x00c2, 0x0301, 0x00e2, 0x0301, 0x00c2, 0x0300, 0x00e2, 0x0300,
-    0x00c2, 0x0309, 0x00e2, 0x0309, 0x00c2, 0x0303, 0x00e2, 0x0303,
-    0x1ea0, 0x0302, 0x1ea1, 0x0302, 0x0102, 0x0301, 0x0103, 0x0301,
+    0x085c, 0x085c, 0x085f, 0x085f, 0x0862, 0x0862, 0x0865, 0x0865,
+    0x0868, 0x0868, 0x086c, 0x086c, 0x0870, 0x0870, 0x0874, 0x0874,
+    0x0878, 0x0878, 0x087c, 0x087c, 0x0880, 0x0880, 0x0884, 0x0884,
+    0x0888, 0x0888, 0x088c, 0x088c, 0x0890, 0x0890, 0x0894, 0x0894,
     /* 0x1eb0 .. 0x1ebf */
-    0x0102, 0x0300, 0x0103, 0x0300, 0x0102, 0x0309, 0x0103, 0x0309,
-    0x0102, 0x0303, 0x0103, 0x0303, 0x1ea0, 0x0306, 0x1ea1, 0x0306,
-    0x0045, 0x0323, 0x0065, 0x0323, 0x0045, 0x0309, 0x0065, 0x0309,
-    0x0045, 0x0303, 0x0065, 0x0303, 0x00ca, 0x0301, 0x00ea, 0x0301,
+    0x0898, 0x0898, 0x089c, 0x089c, 0x08a0, 0x08a0, 0x08a4, 0x08a4,
+    0x08a8, 0x08a8, 0x08ac, 0x08ac, 0x08b0, 0x08b0, 0x08b4, 0x08b4,
+    0x08b8, 0x08b8, 0x08bb, 0x08bb, 0x08be, 0x08be, 0x08c1, 0x08c1,
+    0x08c4, 0x08c4, 0x08c7, 0x08c7, 0x08ca, 0x08ca, 0x08ce, 0x08ce,
     /* 0x1ec0 .. 0x1ecf */
-    0x00ca, 0x0300, 0x00ea, 0x0300, 0x00ca, 0x0309, 0x00ea, 0x0309,
-    0x00ca, 0x0303, 0x00ea, 0x0303, 0x1eb8, 0x0302, 0x1eb9, 0x0302,
-    0x0049, 0x0309, 0x0069, 0x0309, 0x0049, 0x0323, 0x0069, 0x0323,
-    0x004f, 0x0323, 0x006f, 0x0323, 0x004f, 0x0309, 0x006f, 0x0309,
+    0x08d2, 0x08d2, 0x08d6, 0x08d6, 0x08da, 0x08da, 0x08de, 0x08de,
+    0x08e2, 0x08e2, 0x08e6, 0x08e6, 0x08ea, 0x08ea, 0x08ee, 0x08ee,
+    0x08f2, 0x08f2, 0x08f5, 0x08f5, 0x08f8, 0x08f8, 0x08fb, 0x08fb,
+    0x08fe, 0x08fe, 0x0901, 0x0901, 0x0904, 0x0904, 0x0907, 0x0907,
     /* 0x1ed0 .. 0x1edf */
-    0x00d4, 0x0301, 0x00f4, 0x0301, 0x00d4, 0x0300, 0x00f4, 0x0300,
-    0x00d4, 0x0309, 0x00f4, 0x0309, 0x00d4, 0x0303, 0x00f4, 0x0303,
-    0x1ecc, 0x0302, 0x1ecd, 0x0302, 0x01a0, 0x0301, 0x01a1, 0x0301,
-    0x01a0, 0x0300, 0x01a1, 0x0300, 0x01a0, 0x0309, 0x01a1, 0x0309,
+    0x090a, 0x090a, 0x090e, 0x090e, 0x0912, 0x0912, 0x0916, 0x0916,
+    0x091a, 0x091a, 0x091e, 0x091e, 0x0922, 0x0922, 0x0926, 0x0926,
+    0x092a, 0x092a, 0x092e, 0x092e, 0x0932, 0x0932, 0x0936, 0x0936,
+    0x093a, 0x093a, 0x093e, 0x093e, 0x0942, 0x0942, 0x0946, 0x0946,
     /* 0x1ee0 .. 0x1eef */
-    0x01a0, 0x0303, 0x01a1, 0x0303, 0x01a0, 0x0323, 0x01a1, 0x0323,
-    0x0055, 0x0323, 0x0075, 0x0323, 0x0055, 0x0309, 0x0075, 0x0309,
-    0x01af, 0x0301, 0x01b0, 0x0301, 0x01af, 0x0300, 0x01b0, 0x0300,
-    0x01af, 0x0309, 0x01b0, 0x0309, 0x01af, 0x0303, 0x01b0, 0x0303,
+    0x094a, 0x094a, 0x094e, 0x094e, 0x0952, 0x0952, 0x0956, 0x0956,
+    0x095a, 0x095a, 0x095d, 0x095d, 0x0960, 0x0960, 0x0963, 0x0963,
+    0x0966, 0x0966, 0x096a, 0x096a, 0x096e, 0x096e, 0x0972, 0x0972,
+    0x0976, 0x0976, 0x097a, 0x097a, 0x097e, 0x097e, 0x0982, 0x0982,
     /* 0x1ef0 .. 0x1eff */
-    0x01af, 0x0323, 0x01b0, 0x0323, 0x0059, 0x0300, 0x0079, 0x0300,
-    0x0059, 0x0323, 0x0079, 0x0323, 0x0059, 0x0309, 0x0079, 0x0309,
-    0x0059, 0x0303, 0x0079, 0x0303, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0986, 0x0986, 0x098a, 0x098a, 0x098e, 0x098e, 0x0991, 0x0991,
+    0x0994, 0x0994, 0x0997, 0x0997, 0x099a, 0x099a, 0x099d, 0x099d,
+    0x09a0, 0x09a0, 0x09a3, 0x09a3, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x1f00 .. 0x1f0f */
-    0x03b1, 0x0313, 0x03b1, 0x0314, 0x1f00, 0x0300, 0x1f01, 0x0300,
-    0x1f00, 0x0301, 0x1f01, 0x0301, 0x1f00, 0x0342, 0x1f01, 0x0342,
-    0x0391, 0x0313, 0x0391, 0x0314, 0x1f08, 0x0300, 0x1f09, 0x0300,
-    0x1f08, 0x0301, 0x1f09, 0x0301, 0x1f08, 0x0342, 0x1f09, 0x0342,
+    0x09a6, 0x09a6, 0x09a9, 0x09a9, 0x09ac, 0x09ac, 0x09b0, 0x09b0,
+    0x09b4, 0x09b4, 0x09b8, 0x09b8, 0x09bc, 0x09bc, 0x09c0, 0x09c0,
+    0x09c4, 0x09c4, 0x09c7, 0x09c7, 0x09ca, 0x09ca, 0x09ce, 0x09ce,
+    0x09d2, 0x09d2, 0x09d6, 0x09d6, 0x09da, 0x09da, 0x09de, 0x09de,
     /* 0x1f10 .. 0x1f1f */
-    0x03b5, 0x0313, 0x03b5, 0x0314, 0x1f10, 0x0300, 0x1f11, 0x0300,
-    0x1f10, 0x0301, 0x1f11, 0x0301, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0395, 0x0313, 0x0395, 0x0314, 0x1f18, 0x0300, 0x1f19, 0x0300,
-    0x1f18, 0x0301, 0x1f19, 0x0301, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x09e2, 0x09e2, 0x09e5, 0x09e5, 0x09e8, 0x09e8, 0x09ec, 0x09ec,
+    0x09f0, 0x09f0, 0x09f4, 0x09f4, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x09f8, 0x09f8, 0x09fb, 0x09fb, 0x09fe, 0x09fe, 0x0a02, 0x0a02,
+    0x0a06, 0x0a06, 0x0a0a, 0x0a0a, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x1f20 .. 0x1f2f */
-    0x03b7, 0x0313, 0x03b7, 0x0314, 0x1f20, 0x0300, 0x1f21, 0x0300,
-    0x1f20, 0x0301, 0x1f21, 0x0301, 0x1f20, 0x0342, 0x1f21, 0x0342,
-    0x0397, 0x0313, 0x0397, 0x0314, 0x1f28, 0x0300, 0x1f29, 0x0300,
-    0x1f28, 0x0301, 0x1f29, 0x0301, 0x1f28, 0x0342, 0x1f29, 0x0342,
+    0x0a0e, 0x0a0e, 0x0a11, 0x0a11, 0x0a14, 0x0a14, 0x0a18, 0x0a18,
+    0x0a1c, 0x0a1c, 0x0a20, 0x0a20, 0x0a24, 0x0a24, 0x0a28, 0x0a28,
+    0x0a2c, 0x0a2c, 0x0a2f, 0x0a2f, 0x0a32, 0x0a32, 0x0a36, 0x0a36,
+    0x0a3a, 0x0a3a, 0x0a3e, 0x0a3e, 0x0a42, 0x0a42, 0x0a46, 0x0a46,
     /* 0x1f30 .. 0x1f3f */
-    0x03b9, 0x0313, 0x03b9, 0x0314, 0x1f30, 0x0300, 0x1f31, 0x0300,
-    0x1f30, 0x0301, 0x1f31, 0x0301, 0x1f30, 0x0342, 0x1f31, 0x0342,
-    0x0399, 0x0313, 0x0399, 0x0314, 0x1f38, 0x0300, 0x1f39, 0x0300,
-    0x1f38, 0x0301, 0x1f39, 0x0301, 0x1f38, 0x0342, 0x1f39, 0x0342,
+    0x0a4a, 0x0a4a, 0x0a4d, 0x0a4d, 0x0a50, 0x0a50, 0x0a54, 0x0a54,
+    0x0a58, 0x0a58, 0x0a5c, 0x0a5c, 0x0a60, 0x0a60, 0x0a64, 0x0a64,
+    0x0a68, 0x0a68, 0x0a6b, 0x0a6b, 0x0a6e, 0x0a6e, 0x0a72, 0x0a72,
+    0x0a76, 0x0a76, 0x0a7a, 0x0a7a, 0x0a7e, 0x0a7e, 0x0a82, 0x0a82,
     /* 0x1f40 .. 0x1f4f */
-    0x03bf, 0x0313, 0x03bf, 0x0314, 0x1f40, 0x0300, 0x1f41, 0x0300,
-    0x1f40, 0x0301, 0x1f41, 0x0301, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x039f, 0x0313, 0x039f, 0x0314, 0x1f48, 0x0300, 0x1f49, 0x0300,
-    0x1f48, 0x0301, 0x1f49, 0x0301, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0a86, 0x0a86, 0x0a89, 0x0a89, 0x0a8c, 0x0a8c, 0x0a90, 0x0a90,
+    0x0a94, 0x0a94, 0x0a98, 0x0a98, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0a9c, 0x0a9c, 0x0a9f, 0x0a9f, 0x0aa2, 0x0aa2, 0x0aa6, 0x0aa6,
+    0x0aaa, 0x0aaa, 0x0aae, 0x0aae, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x1f50 .. 0x1f5f */
-    0x03c5, 0x0313, 0x03c5, 0x0314, 0x1f50, 0x0300, 0x1f51, 0x0300,
-    0x1f50, 0x0301, 0x1f51, 0x0301, 0x1f50, 0x0342, 0x1f51, 0x0342,
-    0x0000, 0x0000, 0x03a5, 0x0314, 0x0000, 0x0000, 0x1f59, 0x0300,
-    0x0000, 0x0000, 0x1f59, 0x0301, 0x0000, 0x0000, 0x1f59, 0x0342,
+    0x0ab2, 0x0ab2, 0x0ab5, 0x0ab5, 0x0ab8, 0x0ab8, 0x0abc, 0x0abc,
+    0x0ac0, 0x0ac0, 0x0ac4, 0x0ac4, 0x0ac8, 0x0ac8, 0x0acc, 0x0acc,
+    0x0000, 0x0000, 0x0ad0, 0x0ad0, 0x0000, 0x0000, 0x0ad3, 0x0ad3,
+    0x0000, 0x0000, 0x0ad7, 0x0ad7, 0x0000, 0x0000, 0x0adb, 0x0adb,
     /* 0x1f60 .. 0x1f6f */
-    0x03c9, 0x0313, 0x03c9, 0x0314, 0x1f60, 0x0300, 0x1f61, 0x0300,
-    0x1f60, 0x0301, 0x1f61, 0x0301, 0x1f60, 0x0342, 0x1f61, 0x0342,
-    0x03a9, 0x0313, 0x03a9, 0x0314, 0x1f68, 0x0300, 0x1f69, 0x0300,
-    0x1f68, 0x0301, 0x1f69, 0x0301, 0x1f68, 0x0342, 0x1f69, 0x0342,
+    0x0adf, 0x0adf, 0x0ae2, 0x0ae2, 0x0ae5, 0x0ae5, 0x0ae9, 0x0ae9,
+    0x0aed, 0x0aed, 0x0af1, 0x0af1, 0x0af5, 0x0af5, 0x0af9, 0x0af9,
+    0x0afd, 0x0afd, 0x0b00, 0x0b00, 0x0b03, 0x0b03, 0x0b07, 0x0b07,
+    0x0b0b, 0x0b0b, 0x0b0f, 0x0b0f, 0x0b13, 0x0b13, 0x0b17, 0x0b17,
     /* 0x1f70 .. 0x1f7f */
-    0x03b1, 0x0300, 0x0000, 0x0000, 0x03b5, 0x0300, 0x0000, 0x0000,
-    0x03b7, 0x0300, 0x0000, 0x0000, 0x03b9, 0x0300, 0x0000, 0x0000,
-    0x03bf, 0x0300, 0x0000, 0x0000, 0x03c5, 0x0300, 0x0000, 0x0000,
-    0x03c9, 0x0300, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0b1b, 0x0b1b, 0x03cd, 0x03cd, 0x0b1e, 0x0b1e, 0x03d0, 0x03d0,
+    0x0b21, 0x0b21, 0x03d3, 0x03d3, 0x0b24, 0x0b24, 0x03d6, 0x03d6,
+    0x0b27, 0x0b27, 0x03e3, 0x03e3, 0x0b2a, 0x0b2a, 0x03e6, 0x03e6,
+    0x0b2d, 0x0b2d, 0x03e9, 0x03e9, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x1f80 .. 0x1f8f */
-    0x1f00, 0x0345, 0x1f01, 0x0345, 0x1f02, 0x0345, 0x1f03, 0x0345,
-    0x1f04, 0x0345, 0x1f05, 0x0345, 0x1f06, 0x0345, 0x1f07, 0x0345,
-    0x1f08, 0x0345, 0x1f09, 0x0345, 0x1f0a, 0x0345, 0x1f0b, 0x0345,
-    0x1f0c, 0x0345, 0x1f0d, 0x0345, 0x1f0e, 0x0345, 0x1f0f, 0x0345,
+    0x0b30, 0x0b30, 0x0b34, 0x0b34, 0x0b38, 0x0b38, 0x0b3d, 0x0b3d,
+    0x0b42, 0x0b42, 0x0b47, 0x0b47, 0x0b4c, 0x0b4c, 0x0b51, 0x0b51,
+    0x0b56, 0x0b56, 0x0b5a, 0x0b5a, 0x0b5e, 0x0b5e, 0x0b63, 0x0b63,
+    0x0b68, 0x0b68, 0x0b6d, 0x0b6d, 0x0b72, 0x0b72, 0x0b77, 0x0b77,
     /* 0x1f90 .. 0x1f9f */
-    0x1f20, 0x0345, 0x1f21, 0x0345, 0x1f22, 0x0345, 0x1f23, 0x0345,
-    0x1f24, 0x0345, 0x1f25, 0x0345, 0x1f26, 0x0345, 0x1f27, 0x0345,
-    0x1f28, 0x0345, 0x1f29, 0x0345, 0x1f2a, 0x0345, 0x1f2b, 0x0345,
-    0x1f2c, 0x0345, 0x1f2d, 0x0345, 0x1f2e, 0x0345, 0x1f2f, 0x0345,
+    0x0b7c, 0x0b7c, 0x0b80, 0x0b80, 0x0b84, 0x0b84, 0x0b89, 0x0b89,
+    0x0b8e, 0x0b8e, 0x0b93, 0x0b93, 0x0b98, 0x0b98, 0x0b9d, 0x0b9d,
+    0x0ba2, 0x0ba2, 0x0ba6, 0x0ba6, 0x0baa, 0x0baa, 0x0baf, 0x0baf,
+    0x0bb4, 0x0bb4, 0x0bb9, 0x0bb9, 0x0bbe, 0x0bbe, 0x0bc3, 0x0bc3,
     /* 0x1fa0 .. 0x1faf */
-    0x1f60, 0x0345, 0x1f61, 0x0345, 0x1f62, 0x0345, 0x1f63, 0x0345,
-    0x1f64, 0x0345, 0x1f65, 0x0345, 0x1f66, 0x0345, 0x1f67, 0x0345,
-    0x1f68, 0x0345, 0x1f69, 0x0345, 0x1f6a, 0x0345, 0x1f6b, 0x0345,
-    0x1f6c, 0x0345, 0x1f6d, 0x0345, 0x1f6e, 0x0345, 0x1f6f, 0x0345,
+    0x0bc8, 0x0bc8, 0x0bcc, 0x0bcc, 0x0bd0, 0x0bd0, 0x0bd5, 0x0bd5,
+    0x0bda, 0x0bda, 0x0bdf, 0x0bdf, 0x0be4, 0x0be4, 0x0be9, 0x0be9,
+    0x0bee, 0x0bee, 0x0bf2, 0x0bf2, 0x0bf6, 0x0bf6, 0x0bfb, 0x0bfb,
+    0x0c00, 0x0c00, 0x0c05, 0x0c05, 0x0c0a, 0x0c0a, 0x0c0f, 0x0c0f,
     /* 0x1fb0 .. 0x1fbf */
-    0x03b1, 0x0306, 0x03b1, 0x0304, 0x1f70, 0x0345, 0x03b1, 0x0345,
-    0x03ac, 0x0345, 0x0000, 0x0000, 0x03b1, 0x0342, 0x1fb6, 0x0345,
-    0x0391, 0x0306, 0x0391, 0x0304, 0x0391, 0x0300, 0x0000, 0x0000,
-    0x0391, 0x0345, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0c14, 0x0c14, 0x0c17, 0x0c17, 0x0c1a, 0x0c1a, 0x0c1e, 0x0c1e,
+    0x0c21, 0x0c21, 0x0000, 0x0000, 0x0c25, 0x0c25, 0x0c28, 0x0c28,
+    0x0c2c, 0x0c2c, 0x0c2f, 0x0c2f, 0x0c32, 0x0c32, 0x03ac, 0x03ac,
+    0x0c35, 0x0c35, 0x0000, 0x0c38, 0x0c3b, 0x0c3b, 0x0000, 0x0c38,
     /* 0x1fc0 .. 0x1fcf */
-    0x0000, 0x0000, 0x00a8, 0x0342, 0x1f74, 0x0345, 0x03b7, 0x0345,
-    0x03ae, 0x0345, 0x0000, 0x0000, 0x03b7, 0x0342, 0x1fc6, 0x0345,
-    0x0395, 0x0300, 0x0000, 0x0000, 0x0397, 0x0300, 0x0000, 0x0000,
-    0x0397, 0x0345, 0x1fbf, 0x0300, 0x1fbf, 0x0301, 0x1fbf, 0x0342,
+    0x0000, 0x0c3d, 0x0c40, 0x0c43, 0x0c47, 0x0c47, 0x0c4b, 0x0c4b,
+    0x0c4e, 0x0c4e, 0x0000, 0x0000, 0x0c52, 0x0c52, 0x0c55, 0x0c55,
+    0x0c59, 0x0c59, 0x03b1, 0x03b1, 0x0c5c, 0x0c5c, 0x03b4, 0x03b4,
+    0x0c5f, 0x0c5f, 0x0c62, 0x0c65, 0x0c69, 0x0c6c, 0x0c70, 0x0c73,
     /* 0x1fd0 .. 0x1fdf */
-    0x03b9, 0x0306, 0x03b9, 0x0304, 0x03ca, 0x0300, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x03b9, 0x0342, 0x03ca, 0x0342,
-    0x0399, 0x0306, 0x0399, 0x0304, 0x0399, 0x0300, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x1ffe, 0x0300, 0x1ffe, 0x0301, 0x1ffe, 0x0342,
+    0x0c77, 0x0c77, 0x0c7a, 0x0c7a, 0x0c7d, 0x0c7d, 0x03c3, 0x03c3,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0c81, 0x0c81, 0x0c84, 0x0c84,
+    0x0c88, 0x0c88, 0x0c8b, 0x0c8b, 0x0c8e, 0x0c8e, 0x03b7, 0x03b7,
+    0x0000, 0x0000, 0x0c91, 0x0c94, 0x0c98, 0x0c9b, 0x0c9f, 0x0ca2,
     /* 0x1fe0 .. 0x1fef */
-    0x03c5, 0x0306, 0x03c5, 0x0304, 0x03cb, 0x0300, 0x0000, 0x0000,
-    0x03c1, 0x0313, 0x03c1, 0x0314, 0x03c5, 0x0342, 0x03cb, 0x0342,
-    0x03a5, 0x0306, 0x03a5, 0x0304, 0x03a5, 0x0300, 0x0000, 0x0000,
-    0x03a1, 0x0314, 0x00a8, 0x0300, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0ca6, 0x0ca6, 0x0ca9, 0x0ca9, 0x0cac, 0x0cac, 0x03d9, 0x03d9,
+    0x0cb0, 0x0cb0, 0x0cb3, 0x0cb3, 0x0cb6, 0x0cb6, 0x0cb9, 0x0cb9,
+    0x0cbd, 0x0cbd, 0x0cc0, 0x0cc0, 0x0cc3, 0x0cc3, 0x03bd, 0x03bd,
+    0x0cc6, 0x0cc6, 0x0cc9, 0x0ccc, 0x03a5, 0x03a8, 0x0cd0, 0x0cd0,
     /* 0x1ff0 .. 0x1fff */
-    0x0000, 0x0000, 0x0000, 0x0000, 0x1f7c, 0x0345, 0x03c9, 0x0345,
-    0x03ce, 0x0345, 0x0000, 0x0000, 0x03c9, 0x0342, 0x1ff6, 0x0345,
-    0x039f, 0x0300, 0x0000, 0x0000, 0x03a9, 0x0300, 0x0000, 0x0000,
-    0x03a9, 0x0345, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0cd2, 0x0cd2, 0x0cd6, 0x0cd6,
+    0x0cd9, 0x0cd9, 0x0000, 0x0000, 0x0cdd, 0x0cdd, 0x0ce0, 0x0ce0,
+    0x0ce4, 0x0ce4, 0x03ba, 0x03ba, 0x0ce7, 0x0ce7, 0x03c0, 0x03c0,
+    0x0cea, 0x0cea, 0x0ced, 0x000f, 0x0000, 0x0cef, 0x0000, 0x0000,
+    /* 0x2000 .. 0x200f */
+    0x0cf2, 0x0001, 0x0cf4, 0x0001, 0x0000, 0x0001, 0x0000, 0x0001,
+    0x0000, 0x0001, 0x0000, 0x0001, 0x0000, 0x0001, 0x0000, 0x0001,
+    0x0000, 0x0001, 0x0000, 0x0001, 0x0000, 0x0001, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x2010 .. 0x201f */
+    0x0000, 0x0000, 0x0000, 0x0cf6, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0cf8,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x2020 .. 0x202f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0cfb, 0x0000, 0x0cfd, 0x0000, 0x0d00, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0001,
+    /* 0x2030 .. 0x203f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0d04,
+    0x0000, 0x0d07, 0x0000, 0x0000, 0x0000, 0x0d0b, 0x0000, 0x0d0e,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0d12, 0x0000, 0x0000, 0x0000, 0x0d15, 0x0000, 0x0000,
+    /* 0x2040 .. 0x204f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0d18,
+    0x0000, 0x0d1b, 0x0000, 0x0d1e, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x2050 .. 0x205f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0d21,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0001,
+    /* 0x2070 .. 0x207f */
+    0x0000, 0x0d26, 0x0000, 0x061e, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0d28, 0x0000, 0x0d2a, 0x0000, 0x0d2c, 0x0000, 0x0d2e,
+    0x0000, 0x0d30, 0x0000, 0x0d32, 0x0000, 0x0d34, 0x0000, 0x0d36,
+    0x0000, 0x0d38, 0x0000, 0x0d3a, 0x0000, 0x0d3c, 0x0000, 0x0d3e,
+    /* 0x2080 .. 0x208f */
+    0x0000, 0x0d26, 0x0000, 0x0017, 0x0000, 0x000b, 0x0000, 0x000d,
+    0x0000, 0x0d28, 0x0000, 0x0d2a, 0x0000, 0x0d2c, 0x0000, 0x0d2e,
+    0x0000, 0x0d30, 0x0000, 0x0d32, 0x0000, 0x0d34, 0x0000, 0x0d36,
+    0x0000, 0x0d38, 0x0000, 0x0d3a, 0x0000, 0x0d3c, 0x0000, 0x0000,
+    /* 0x2090 .. 0x209f */
+    0x0000, 0x0006, 0x0000, 0x05f4, 0x0000, 0x0019, 0x0000, 0x0391,
+    0x0000, 0x05f6, 0x0000, 0x0369, 0x0000, 0x05fe, 0x0000, 0x038f,
+    0x0000, 0x0600, 0x0000, 0x0d3e, 0x0000, 0x060a, 0x0000, 0x0219,
+    0x0000, 0x060c, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x20a0 .. 0x20af */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0d40, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x2100 .. 0x210f */
+    0x0000, 0x0d43, 0x0000, 0x0d47, 0x0000, 0x0d4b, 0x0000, 0x0d4d,
+    0x0000, 0x0000, 0x0000, 0x0d50, 0x0000, 0x0d54, 0x0000, 0x0d58,
+    0x0000, 0x0000, 0x0000, 0x0d5a, 0x0000, 0x05fc, 0x0000, 0x05ce,
+    0x0000, 0x05ce, 0x0000, 0x05ce, 0x0000, 0x0369, 0x0000, 0x0d5d,
+    /* 0x2110 .. 0x211f */
+    0x0000, 0x05d0, 0x0000, 0x05d0, 0x0000, 0x05d6, 0x0000, 0x038f,
+    0x0000, 0x0000, 0x0000, 0x05da, 0x0000, 0x0d5f, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x05e0, 0x0000, 0x0d62, 0x0000, 0x05e2,
+    0x0000, 0x05e2, 0x0000, 0x05e2, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x2120 .. 0x212f */
+    0x0000, 0x0d64, 0x0000, 0x0d67, 0x0000, 0x0d6b, 0x0000, 0x0000,
+    0x0000, 0x0d6e, 0x0000, 0x0000, 0x0d70, 0x0d70, 0x0000, 0x0000,
+    0x0000, 0x0d6e, 0x0000, 0x0000, 0x05d4, 0x05d4, 0x0036, 0x0036,
+    0x0000, 0x05c4, 0x0000, 0x0d4b, 0x0000, 0x0000, 0x0000, 0x05f4,
+    /* 0x2130 .. 0x213f */
+    0x0000, 0x05c8, 0x0000, 0x0d72, 0x0000, 0x0000, 0x0000, 0x05d8,
+    0x0000, 0x0019, 0x0000, 0x0d74, 0x0000, 0x0d76, 0x0000, 0x0d78,
+    0x0000, 0x0d7a, 0x0000, 0x061e, 0x0000, 0x0000, 0x0000, 0x0d7c,
+    0x0000, 0x03fa, 0x0000, 0x0618, 0x0000, 0x0d80, 0x0000, 0x0d82,
+    /* 0x2140 .. 0x214f */
+    0x0000, 0x0d84, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x05c6, 0x0000, 0x05f2, 0x0000, 0x05f4,
+    0x0000, 0x061e, 0x0000, 0x036d, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x2150 .. 0x215f */
+    0x0000, 0x0d86, 0x0000, 0x0d8a, 0x0000, 0x0d8e, 0x0000, 0x0d93,
+    0x0000, 0x0d97, 0x0000, 0x0d9b, 0x0000, 0x0d9f, 0x0000, 0x0da3,
+    0x0000, 0x0da7, 0x0000, 0x0dab, 0x0000, 0x0daf, 0x0000, 0x0db3,
+    0x0000, 0x0db7, 0x0000, 0x0dbb, 0x0000, 0x0dbf, 0x0000, 0x0dc3,
+    /* 0x2160 .. 0x216f */
+    0x0000, 0x05d0, 0x0000, 0x0dc6, 0x0000, 0x0dc9, 0x0000, 0x0dcd,
+    0x0000, 0x0dd0, 0x0000, 0x0dd2, 0x0000, 0x0dd5, 0x0000, 0x0dd9,
+    0x0000, 0x0dde, 0x0000, 0x0de1, 0x0000, 0x0de3, 0x0000, 0x0de6,
+    0x0000, 0x05d6, 0x0000, 0x0d4b, 0x0000, 0x05c6, 0x0000, 0x05d8,
+    /* 0x2170 .. 0x217f */
+    0x0000, 0x061e, 0x0000, 0x0dea, 0x0000, 0x0ded, 0x0000, 0x0df1,
+    0x0000, 0x0614, 0x0000, 0x0df4, 0x0000, 0x0df7, 0x0000, 0x0dfb,
+    0x0000, 0x0e00, 0x0000, 0x0391, 0x0000, 0x0e03, 0x0000, 0x0e06,
+    0x0000, 0x038f, 0x0000, 0x0624, 0x0000, 0x05f2, 0x0000, 0x0600,
+    /* 0x2180 .. 0x218f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0e0a, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x2190 .. 0x219f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x2190, 0x0338, 0x2192, 0x0338,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0e0e, 0x0e0e, 0x0e11, 0x0e11,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x21a0 .. 0x21af */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x2194, 0x0338, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0e14, 0x0e14, 0x0000, 0x0000,
     /* 0x21c0 .. 0x21cf */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x21d0, 0x0338, 0x21d4, 0x0338, 0x21d2, 0x0338,
+    0x0000, 0x0000, 0x0e17, 0x0e17, 0x0e1a, 0x0e1a, 0x0e1d, 0x0e1d,
     /* 0x2200 .. 0x220f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x2203, 0x0338, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x2208, 0x0338, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x220b, 0x0338, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0e20, 0x0e20, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0e23, 0x0e23, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0e26, 0x0e26, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x2220 .. 0x222f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x2223, 0x0338, 0x0000, 0x0000, 0x2225, 0x0338, 0x0000, 0x0000,
+    0x0e29, 0x0e29, 0x0000, 0x0000, 0x0e2c, 0x0e2c, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0e2f, 0x0000, 0x0e32, 0x0000, 0x0000, 0x0000, 0x0e36,
+    /* 0x2230 .. 0x223f */
+    0x0000, 0x0e39, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x2240 .. 0x224f */
-    0x0000, 0x0000, 0x223c, 0x0338, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x2243, 0x0338, 0x0000, 0x0000, 0x0000, 0x0000, 0x2245, 0x0338,
-    0x0000, 0x0000, 0x2248, 0x0338, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0e3d, 0x0e3d, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0e40, 0x0e40, 0x0000, 0x0000, 0x0000, 0x0000, 0x0e43, 0x0e43,
+    0x0000, 0x0000, 0x0e46, 0x0e46, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x2260 .. 0x226f */
-    0x003d, 0x0338, 0x0000, 0x0000, 0x2261, 0x0338, 0x0000, 0x0000,
+    0x0e49, 0x0e49, 0x0000, 0x0000, 0x0e4c, 0x0e4c, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x224d, 0x0338, 0x003c, 0x0338, 0x003e, 0x0338,
+    0x0000, 0x0000, 0x0e4f, 0x0e4f, 0x0e52, 0x0e52, 0x0e55, 0x0e55,
     /* 0x2270 .. 0x227f */
-    0x2264, 0x0338, 0x2265, 0x0338, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x2272, 0x0338, 0x2273, 0x0338, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x2276, 0x0338, 0x2277, 0x0338, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0e58, 0x0e58, 0x0e5b, 0x0e5b, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0e5e, 0x0e5e, 0x0e61, 0x0e61, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0e64, 0x0e64, 0x0e67, 0x0e67, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x2280 .. 0x228f */
-    0x227a, 0x0338, 0x227b, 0x0338, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x2282, 0x0338, 0x2283, 0x0338, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x2286, 0x0338, 0x2287, 0x0338, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0e6a, 0x0e6a, 0x0e6d, 0x0e6d, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0e70, 0x0e70, 0x0e73, 0x0e73, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0e76, 0x0e76, 0x0e79, 0x0e79, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x22a0 .. 0x22af */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x22a2, 0x0338, 0x22a8, 0x0338, 0x22a9, 0x0338, 0x22ab, 0x0338,
+    0x0e7c, 0x0e7c, 0x0e7f, 0x0e7f, 0x0e82, 0x0e82, 0x0e85, 0x0e85,
     /* 0x22e0 .. 0x22ef */
-    0x227c, 0x0338, 0x227d, 0x0338, 0x2291, 0x0338, 0x2292, 0x0338,
+    0x0e88, 0x0e88, 0x0e8b, 0x0e8b, 0x0e8e, 0x0e8e, 0x0e91, 0x0e91,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0e94, 0x0e94, 0x0e97, 0x0e97,
+    0x0e9a, 0x0e9a, 0x0e9d, 0x0e9d, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x2320 .. 0x232f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0ea0, 0x0ea0, 0x0ea2, 0x0ea2, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x2460 .. 0x246f */
+    0x0000, 0x0017, 0x0000, 0x000b, 0x0000, 0x000d, 0x0000, 0x0d28,
+    0x0000, 0x0d2a, 0x0000, 0x0d2c, 0x0000, 0x0d2e, 0x0000, 0x0d30,
+    0x0000, 0x0d32, 0x0000, 0x0ea4, 0x0000, 0x0ea7, 0x0000, 0x0eaa,
+    0x0000, 0x0ead, 0x0000, 0x0eb0, 0x0000, 0x0eb3, 0x0000, 0x0eb6,
+    /* 0x2470 .. 0x247f */
+    0x0000, 0x0eb9, 0x0000, 0x0ebc, 0x0000, 0x0ebf, 0x0000, 0x0ec2,
+    0x0000, 0x0ec5, 0x0000, 0x0ec9, 0x0000, 0x0ecd, 0x0000, 0x0ed1,
+    0x0000, 0x0ed5, 0x0000, 0x0ed9, 0x0000, 0x0edd, 0x0000, 0x0ee1,
+    0x0000, 0x0ee5, 0x0000, 0x0ee9, 0x0000, 0x0eee, 0x0000, 0x0ef3,
+    /* 0x2480 .. 0x248f */
+    0x0000, 0x0ef8, 0x0000, 0x0efd, 0x0000, 0x0f02, 0x0000, 0x0f07,
+    0x0000, 0x0f0c, 0x0000, 0x0f11, 0x0000, 0x0f16, 0x0000, 0x0f1b,
+    0x0000, 0x0f20, 0x0000, 0x0f23, 0x0000, 0x0f26, 0x0000, 0x0f29,
+    0x0000, 0x0f2c, 0x0000, 0x0f2f, 0x0000, 0x0f32, 0x0000, 0x0f35,
+    /* 0x2490 .. 0x249f */
+    0x0000, 0x0f38, 0x0000, 0x0f3b, 0x0000, 0x0f3f, 0x0000, 0x0f43,
+    0x0000, 0x0f47, 0x0000, 0x0f4b, 0x0000, 0x0f4f, 0x0000, 0x0f53,
+    0x0000, 0x0f57, 0x0000, 0x0f5b, 0x0000, 0x0f5f, 0x0000, 0x0f63,
+    0x0000, 0x0f67, 0x0000, 0x0f6b, 0x0000, 0x0f6f, 0x0000, 0x0f73,
+    /* 0x24a0 .. 0x24af */
+    0x0000, 0x0f77, 0x0000, 0x0f7b, 0x0000, 0x0f7f, 0x0000, 0x0f83,
+    0x0000, 0x0f87, 0x0000, 0x0f8b, 0x0000, 0x0f8f, 0x0000, 0x0f93,
+    0x0000, 0x0f97, 0x0000, 0x0f9b, 0x0000, 0x0f9f, 0x0000, 0x0fa3,
+    0x0000, 0x0fa7, 0x0000, 0x0fab, 0x0000, 0x0faf, 0x0000, 0x0fb3,
+    /* 0x24b0 .. 0x24bf */
+    0x0000, 0x0fb7, 0x0000, 0x0fbb, 0x0000, 0x0fbf, 0x0000, 0x0fc3,
+    0x0000, 0x0fc7, 0x0000, 0x0fcb, 0x0000, 0x05c0, 0x0000, 0x05c4,
+    0x0000, 0x0d4b, 0x0000, 0x05c6, 0x0000, 0x05c8, 0x0000, 0x0d72,
+    0x0000, 0x05cc, 0x0000, 0x05ce, 0x0000, 0x05d0, 0x0000, 0x05d2,
+    /* 0x24c0 .. 0x24cf */
+    0x0000, 0x05d4, 0x0000, 0x05d6, 0x0000, 0x05d8, 0x0000, 0x05da,
+    0x0000, 0x05dc, 0x0000, 0x05e0, 0x0000, 0x0d62, 0x0000, 0x05e2,
+    0x0000, 0x0fcf, 0x0000, 0x05e4, 0x0000, 0x05e6, 0x0000, 0x0dd0,
+    0x0000, 0x05e8, 0x0000, 0x0de1, 0x0000, 0x0fd1, 0x0000, 0x0d6e,
+    /* 0x24d0 .. 0x24df */
+    0x0000, 0x0006, 0x0000, 0x05f0, 0x0000, 0x0624, 0x0000, 0x05f2,
+    0x0000, 0x05f4, 0x0000, 0x062a, 0x0000, 0x05fc, 0x0000, 0x0369,
+    0x0000, 0x061e, 0x0000, 0x036d, 0x0000, 0x05fe, 0x0000, 0x038f,
+    0x0000, 0x0600, 0x0000, 0x0d3e, 0x0000, 0x0019, 0x0000, 0x060a,
+    /* 0x24e0 .. 0x24ef */
+    0x0000, 0x0fd3, 0x0000, 0x036f, 0x0000, 0x0219, 0x0000, 0x060c,
+    0x0000, 0x060e, 0x0000, 0x0614, 0x0000, 0x0377, 0x0000, 0x0391,
+    0x0000, 0x0379, 0x0000, 0x0660, 0x0000, 0x0d26, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x2a00 .. 0x2a0f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0fd5, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x2a70 .. 0x2a7f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0fda, 0x0000, 0x0fde, 0x0000, 0x0fe1, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x22b2, 0x0338, 0x22b3, 0x0338,
-    0x22b4, 0x0338, 0x22b5, 0x0338, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x2ad0 .. 0x2adf */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x2add, 0x0338, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0fe5, 0x0fe5, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x2c70 .. 0x2c7f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x036d, 0x0000, 0x0dd0, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x2d60 .. 0x2d6f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0fe8,
+    /* 0x2e90 .. 0x2e9f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0fea,
+    /* 0x2ef0 .. 0x2eff */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0fec,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x2f00 .. 0x2f0f */
+    0x0000, 0x0fee, 0x0000, 0x0ff0, 0x0000, 0x0ff2, 0x0000, 0x0ff4,
+    0x0000, 0x0ff6, 0x0000, 0x0ff8, 0x0000, 0x0ffa, 0x0000, 0x0ffc,
+    0x0000, 0x0ffe, 0x0000, 0x1000, 0x0000, 0x1002, 0x0000, 0x1004,
+    0x0000, 0x1006, 0x0000, 0x1008, 0x0000, 0x100a, 0x0000, 0x100c,
+    /* 0x2f10 .. 0x2f1f */
+    0x0000, 0x100e, 0x0000, 0x1010, 0x0000, 0x1012, 0x0000, 0x1014,
+    0x0000, 0x1016, 0x0000, 0x1018, 0x0000, 0x101a, 0x0000, 0x101c,
+    0x0000, 0x101e, 0x0000, 0x1020, 0x0000, 0x1022, 0x0000, 0x1024,
+    0x0000, 0x1026, 0x0000, 0x1028, 0x0000, 0x102a, 0x0000, 0x102c,
+    /* 0x2f20 .. 0x2f2f */
+    0x0000, 0x102e, 0x0000, 0x1030, 0x0000, 0x1032, 0x0000, 0x1034,
+    0x0000, 0x1036, 0x0000, 0x1038, 0x0000, 0x103a, 0x0000, 0x103c,
+    0x0000, 0x103e, 0x0000, 0x1040, 0x0000, 0x1042, 0x0000, 0x1044,
+    0x0000, 0x1046, 0x0000, 0x1048, 0x0000, 0x104a, 0x0000, 0x104c,
+    /* 0x2f30 .. 0x2f3f */
+    0x0000, 0x104e, 0x0000, 0x1050, 0x0000, 0x1052, 0x0000, 0x1054,
+    0x0000, 0x1056, 0x0000, 0x1058, 0x0000, 0x105a, 0x0000, 0x105c,
+    0x0000, 0x105e, 0x0000, 0x1060, 0x0000, 0x1062, 0x0000, 0x1064,
+    0x0000, 0x1066, 0x0000, 0x1068, 0x0000, 0x106a, 0x0000, 0x106c,
+    /* 0x2f40 .. 0x2f4f */
+    0x0000, 0x106e, 0x0000, 0x1070, 0x0000, 0x1072, 0x0000, 0x1074,
+    0x0000, 0x1076, 0x0000, 0x1078, 0x0000, 0x107a, 0x0000, 0x107c,
+    0x0000, 0x107e, 0x0000, 0x1080, 0x0000, 0x1082, 0x0000, 0x1084,
+    0x0000, 0x1086, 0x0000, 0x1088, 0x0000, 0x108a, 0x0000, 0x108c,
+    /* 0x2f50 .. 0x2f5f */
+    0x0000, 0x108e, 0x0000, 0x1090, 0x0000, 0x1092, 0x0000, 0x1094,
+    0x0000, 0x1096, 0x0000, 0x1098, 0x0000, 0x109a, 0x0000, 0x109c,
+    0x0000, 0x109e, 0x0000, 0x10a0, 0x0000, 0x10a2, 0x0000, 0x10a4,
+    0x0000, 0x10a6, 0x0000, 0x10a8, 0x0000, 0x10aa, 0x0000, 0x10ac,
+    /* 0x2f60 .. 0x2f6f */
+    0x0000, 0x10ae, 0x0000, 0x10b0, 0x0000, 0x10b2, 0x0000, 0x10b4,
+    0x0000, 0x10b6, 0x0000, 0x10b8, 0x0000, 0x10ba, 0x0000, 0x10bc,
+    0x0000, 0x10be, 0x0000, 0x10c0, 0x0000, 0x10c2, 0x0000, 0x10c4,
+    0x0000, 0x10c6, 0x0000, 0x10c8, 0x0000, 0x10ca, 0x0000, 0x10cc,
+    /* 0x2f70 .. 0x2f7f */
+    0x0000, 0x10ce, 0x0000, 0x10d0, 0x0000, 0x10d2, 0x0000, 0x10d4,
+    0x0000, 0x10d6, 0x0000, 0x10d8, 0x0000, 0x10da, 0x0000, 0x10dc,
+    0x0000, 0x10de, 0x0000, 0x10e0, 0x0000, 0x10e2, 0x0000, 0x10e4,
+    0x0000, 0x10e6, 0x0000, 0x10e8, 0x0000, 0x10ea, 0x0000, 0x10ec,
+    /* 0x2f80 .. 0x2f8f */
+    0x0000, 0x10ee, 0x0000, 0x10f0, 0x0000, 0x10f2, 0x0000, 0x10f4,
+    0x0000, 0x10f6, 0x0000, 0x10f8, 0x0000, 0x10fa, 0x0000, 0x10fc,
+    0x0000, 0x10fe, 0x0000, 0x1100, 0x0000, 0x1102, 0x0000, 0x1104,
+    0x0000, 0x1106, 0x0000, 0x1108, 0x0000, 0x110a, 0x0000, 0x110c,
+    /* 0x2f90 .. 0x2f9f */
+    0x0000, 0x110e, 0x0000, 0x1110, 0x0000, 0x1112, 0x0000, 0x1114,
+    0x0000, 0x1116, 0x0000, 0x1118, 0x0000, 0x111a, 0x0000, 0x111c,
+    0x0000, 0x111e, 0x0000, 0x1120, 0x0000, 0x1122, 0x0000, 0x1124,
+    0x0000, 0x1126, 0x0000, 0x1128, 0x0000, 0x112a, 0x0000, 0x112c,
+    /* 0x2fa0 .. 0x2faf */
+    0x0000, 0x112e, 0x0000, 0x1130, 0x0000, 0x1132, 0x0000, 0x1134,
+    0x0000, 0x1136, 0x0000, 0x1138, 0x0000, 0x113a, 0x0000, 0x113c,
+    0x0000, 0x113e, 0x0000, 0x1140, 0x0000, 0x1142, 0x0000, 0x1144,
+    0x0000, 0x1146, 0x0000, 0x1148, 0x0000, 0x114a, 0x0000, 0x114c,
+    /* 0x2fb0 .. 0x2fbf */
+    0x0000, 0x114e, 0x0000, 0x1150, 0x0000, 0x1152, 0x0000, 0x1154,
+    0x0000, 0x1156, 0x0000, 0x1158, 0x0000, 0x115a, 0x0000, 0x115c,
+    0x0000, 0x115e, 0x0000, 0x1160, 0x0000, 0x1162, 0x0000, 0x1164,
+    0x0000, 0x1166, 0x0000, 0x1168, 0x0000, 0x116a, 0x0000, 0x116c,
+    /* 0x2fc0 .. 0x2fcf */
+    0x0000, 0x116e, 0x0000, 0x1170, 0x0000, 0x1172, 0x0000, 0x1174,
+    0x0000, 0x1176, 0x0000, 0x1178, 0x0000, 0x117a, 0x0000, 0x117c,
+    0x0000, 0x117e, 0x0000, 0x1180, 0x0000, 0x1182, 0x0000, 0x1184,
+    0x0000, 0x1186, 0x0000, 0x1188, 0x0000, 0x118a, 0x0000, 0x118c,
+    /* 0x2fd0 .. 0x2fdf */
+    0x0000, 0x118e, 0x0000, 0x1190, 0x0000, 0x1192, 0x0000, 0x1194,
+    0x0000, 0x1196, 0x0000, 0x1198, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x3000 .. 0x300f */
+    0x0000, 0x0001, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x3030 .. 0x303f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x119a, 0x0000, 0x0000,
+    0x0000, 0x101c, 0x0000, 0x119c, 0x0000, 0x119e, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x3040 .. 0x304f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x304b, 0x3099, 0x0000, 0x0000, 0x304d, 0x3099, 0x0000, 0x0000,
+    0x11a0, 0x11a0, 0x0000, 0x0000, 0x11a3, 0x11a3, 0x0000, 0x0000,
     /* 0x3050 .. 0x305f */
-    0x304f, 0x3099, 0x0000, 0x0000, 0x3051, 0x3099, 0x0000, 0x0000,
-    0x3053, 0x3099, 0x0000, 0x0000, 0x3055, 0x3099, 0x0000, 0x0000,
-    0x3057, 0x3099, 0x0000, 0x0000, 0x3059, 0x3099, 0x0000, 0x0000,
-    0x305b, 0x3099, 0x0000, 0x0000, 0x305d, 0x3099, 0x0000, 0x0000,
+    0x11a6, 0x11a6, 0x0000, 0x0000, 0x11a9, 0x11a9, 0x0000, 0x0000,
+    0x11ac, 0x11ac, 0x0000, 0x0000, 0x11af, 0x11af, 0x0000, 0x0000,
+    0x11b2, 0x11b2, 0x0000, 0x0000, 0x11b5, 0x11b5, 0x0000, 0x0000,
+    0x11b8, 0x11b8, 0x0000, 0x0000, 0x11bb, 0x11bb, 0x0000, 0x0000,
     /* 0x3060 .. 0x306f */
-    0x305f, 0x3099, 0x0000, 0x0000, 0x3061, 0x3099, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x3064, 0x3099, 0x0000, 0x0000, 0x3066, 0x3099,
-    0x0000, 0x0000, 0x3068, 0x3099, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x11be, 0x11be, 0x0000, 0x0000, 0x11c1, 0x11c1, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x11c4, 0x11c4, 0x0000, 0x0000, 0x11c7, 0x11c7,
+    0x0000, 0x0000, 0x11ca, 0x11ca, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x3070 .. 0x307f */
-    0x306f, 0x3099, 0x306f, 0x309a, 0x0000, 0x0000, 0x3072, 0x3099,
-    0x3072, 0x309a, 0x0000, 0x0000, 0x3075, 0x3099, 0x3075, 0x309a,
-    0x0000, 0x0000, 0x3078, 0x3099, 0x3078, 0x309a, 0x0000, 0x0000,
-    0x307b, 0x3099, 0x307b, 0x309a, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x11cd, 0x11cd, 0x11d0, 0x11d0, 0x0000, 0x0000, 0x11d3, 0x11d3,
+    0x11d6, 0x11d6, 0x0000, 0x0000, 0x11d9, 0x11d9, 0x11dc, 0x11dc,
+    0x0000, 0x0000, 0x11df, 0x11df, 0x11e2, 0x11e2, 0x0000, 0x0000,
+    0x11e5, 0x11e5, 0x11e8, 0x11e8, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x3090 .. 0x309f */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x3046, 0x3099, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x309d, 0x3099, 0x0000, 0x0000,
+    0x11eb, 0x11eb, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x11ee,
+    0x0000, 0x11f1, 0x0000, 0x0000, 0x11f4, 0x11f4, 0x0000, 0x11f7,
     /* 0x30a0 .. 0x30af */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x30ab, 0x3099, 0x0000, 0x0000, 0x30ad, 0x3099, 0x0000, 0x0000,
+    0x11fa, 0x11fa, 0x0000, 0x0000, 0x11fd, 0x11fd, 0x0000, 0x0000,
     /* 0x30b0 .. 0x30bf */
-    0x30af, 0x3099, 0x0000, 0x0000, 0x30b1, 0x3099, 0x0000, 0x0000,
-    0x30b3, 0x3099, 0x0000, 0x0000, 0x30b5, 0x3099, 0x0000, 0x0000,
-    0x30b7, 0x3099, 0x0000, 0x0000, 0x30b9, 0x3099, 0x0000, 0x0000,
-    0x30bb, 0x3099, 0x0000, 0x0000, 0x30bd, 0x3099, 0x0000, 0x0000,
+    0x1200, 0x1200, 0x0000, 0x0000, 0x1203, 0x1203, 0x0000, 0x0000,
+    0x1206, 0x1206, 0x0000, 0x0000, 0x1209, 0x1209, 0x0000, 0x0000,
+    0x120c, 0x120c, 0x0000, 0x0000, 0x120f, 0x120f, 0x0000, 0x0000,
+    0x1212, 0x1212, 0x0000, 0x0000, 0x1215, 0x1215, 0x0000, 0x0000,
     /* 0x30c0 .. 0x30cf */
-    0x30bf, 0x3099, 0x0000, 0x0000, 0x30c1, 0x3099, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x30c4, 0x3099, 0x0000, 0x0000, 0x30c6, 0x3099,
-    0x0000, 0x0000, 0x30c8, 0x3099, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x1218, 0x1218, 0x0000, 0x0000, 0x121b, 0x121b, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x121e, 0x121e, 0x0000, 0x0000, 0x1221, 0x1221,
+    0x0000, 0x0000, 0x1224, 0x1224, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x30d0 .. 0x30df */
-    0x30cf, 0x3099, 0x30cf, 0x309a, 0x0000, 0x0000, 0x30d2, 0x3099,
-    0x30d2, 0x309a, 0x0000, 0x0000, 0x30d5, 0x3099, 0x30d5, 0x309a,
-    0x0000, 0x0000, 0x30d8, 0x3099, 0x30d8, 0x309a, 0x0000, 0x0000,
-    0x30db, 0x3099, 0x30db, 0x309a, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x1227, 0x1227, 0x122a, 0x122a, 0x0000, 0x0000, 0x122d, 0x122d,
+    0x1230, 0x1230, 0x0000, 0x0000, 0x1233, 0x1233, 0x1236, 0x1236,
+    0x0000, 0x0000, 0x1239, 0x1239, 0x123c, 0x123c, 0x0000, 0x0000,
+    0x123f, 0x123f, 0x1242, 0x1242, 0x0000, 0x0000, 0x0000, 0x0000,
     /* 0x30f0 .. 0x30ff */
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x30a6, 0x3099, 0x0000, 0x0000, 0x0000, 0x0000, 0x30ef, 0x3099,
-    0x30f0, 0x3099, 0x30f1, 0x3099, 0x30f2, 0x3099, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x30fd, 0x3099, 0x0000, 0x0000,
-    /* 0xfb10 .. 0xfb1f */
+    0x1245, 0x1245, 0x0000, 0x0000, 0x0000, 0x0000, 0x1248, 0x1248,
+    0x124b, 0x124b, 0x124e, 0x124e, 0x1251, 0x1251, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x1254, 0x1254, 0x0000, 0x1257,
+    /* 0x3130 .. 0x313f */
+    0x0000, 0x0000, 0x0000, 0x125a, 0x0000, 0x125c, 0x0000, 0x125e,
+    0x0000, 0x1260, 0x0000, 0x1262, 0x0000, 0x1264, 0x0000, 0x1266,
+    0x0000, 0x1268, 0x0000, 0x126a, 0x0000, 0x126c, 0x0000, 0x126e,
+    0x0000, 0x1270, 0x0000, 0x1272, 0x0000, 0x1274, 0x0000, 0x1276,
+    /* 0x3140 .. 0x314f */
+    0x0000, 0x1278, 0x0000, 0x127a, 0x0000, 0x127c, 0x0000, 0x127e,
+    0x0000, 0x1280, 0x0000, 0x1282, 0x0000, 0x1284, 0x0000, 0x1286,
+    0x0000, 0x1288, 0x0000, 0x128a, 0x0000, 0x128c, 0x0000, 0x128e,
+    0x0000, 0x1290, 0x0000, 0x1292, 0x0000, 0x1294, 0x0000, 0x1296,
+    /* 0x3150 .. 0x315f */
+    0x0000, 0x1298, 0x0000, 0x129a, 0x0000, 0x129c, 0x0000, 0x129e,
+    0x0000, 0x12a0, 0x0000, 0x12a2, 0x0000, 0x12a4, 0x0000, 0x12a6,
+    0x0000, 0x12a8, 0x0000, 0x12aa, 0x0000, 0x12ac, 0x0000, 0x12ae,
+    0x0000, 0x12b0, 0x0000, 0x12b2, 0x0000, 0x12b4, 0x0000, 0x12b6,
+    /* 0x3160 .. 0x316f */
+    0x0000, 0x12b8, 0x0000, 0x12ba, 0x0000, 0x12bc, 0x0000, 0x12be,
+    0x0000, 0x12c0, 0x0000, 0x12c2, 0x0000, 0x12c4, 0x0000, 0x12c6,
+    0x0000, 0x12c8, 0x0000, 0x12ca, 0x0000, 0x12cc, 0x0000, 0x12ce,
+    0x0000, 0x12d0, 0x0000, 0x12d2, 0x0000, 0x12d4, 0x0000, 0x12d6,
+    /* 0x3170 .. 0x317f */
+    0x0000, 0x12d8, 0x0000, 0x12da, 0x0000, 0x12dc, 0x0000, 0x12de,
+    0x0000, 0x12e0, 0x0000, 0x12e2, 0x0000, 0x12e4, 0x0000, 0x12e6,
+    0x0000, 0x12e8, 0x0000, 0x12ea, 0x0000, 0x12ec, 0x0000, 0x12ee,
+    0x0000, 0x12f0, 0x0000, 0x12f2, 0x0000, 0x12f4, 0x0000, 0x12f6,
+    /* 0x3180 .. 0x318f */
+    0x0000, 0x12f8, 0x0000, 0x12fa, 0x0000, 0x12fc, 0x0000, 0x12fe,
+    0x0000, 0x1300, 0x0000, 0x1302, 0x0000, 0x1304, 0x0000, 0x1306,
+    0x0000, 0x1308, 0x0000, 0x130a, 0x0000, 0x130c, 0x0000, 0x130e,
+    0x0000, 0x1310, 0x0000, 0x1312, 0x0000, 0x1314, 0x0000, 0x0000,
+    /* 0x3190 .. 0x319f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0fee, 0x0000, 0x0ffa,
+    0x0000, 0x1316, 0x0000, 0x1318, 0x0000, 0x131a, 0x0000, 0x131c,
+    0x0000, 0x131e, 0x0000, 0x1320, 0x0000, 0x0ff6, 0x0000, 0x1322,
+    0x0000, 0x1324, 0x0000, 0x1326, 0x0000, 0x1328, 0x0000, 0x0ffe,
+    /* 0x3200 .. 0x320f */
+    0x0000, 0x132a, 0x0000, 0x132e, 0x0000, 0x1332, 0x0000, 0x1336,
+    0x0000, 0x133a, 0x0000, 0x133e, 0x0000, 0x1342, 0x0000, 0x1346,
+    0x0000, 0x134a, 0x0000, 0x134e, 0x0000, 0x1352, 0x0000, 0x1356,
+    0x0000, 0x135a, 0x0000, 0x135e, 0x0000, 0x1362, 0x0000, 0x1367,
+    /* 0x3210 .. 0x321f */
+    0x0000, 0x136c, 0x0000, 0x1371, 0x0000, 0x1376, 0x0000, 0x137b,
+    0x0000, 0x1380, 0x0000, 0x1385, 0x0000, 0x138a, 0x0000, 0x138f,
+    0x0000, 0x1394, 0x0000, 0x1399, 0x0000, 0x139e, 0x0000, 0x13a3,
+    0x0000, 0x13a8, 0x0000, 0x13ad, 0x0000, 0x13b5, 0x0000, 0x0000,
+    /* 0x3220 .. 0x322f */
+    0x0000, 0x13bc, 0x0000, 0x13c0, 0x0000, 0x13c4, 0x0000, 0x13c8,
+    0x0000, 0x13cc, 0x0000, 0x13d0, 0x0000, 0x13d4, 0x0000, 0x13d8,
+    0x0000, 0x13dc, 0x0000, 0x13e0, 0x0000, 0x13e4, 0x0000, 0x13e8,
+    0x0000, 0x13ec, 0x0000, 0x13f0, 0x0000, 0x13f4, 0x0000, 0x13f8,
+    /* 0x3230 .. 0x323f */
+    0x0000, 0x13fc, 0x0000, 0x1400, 0x0000, 0x1404, 0x0000, 0x1408,
+    0x0000, 0x140c, 0x0000, 0x1410, 0x0000, 0x1414, 0x0000, 0x1418,
+    0x0000, 0x141c, 0x0000, 0x1420, 0x0000, 0x1424, 0x0000, 0x1428,
+    0x0000, 0x142c, 0x0000, 0x1430, 0x0000, 0x1434, 0x0000, 0x1438,
+    /* 0x3240 .. 0x324f */
+    0x0000, 0x143c, 0x0000, 0x1440, 0x0000, 0x1444, 0x0000, 0x1448,
+    0x0000, 0x144c, 0x0000, 0x144e, 0x0000, 0x1072, 0x0000, 0x1450,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x3250 .. 0x325f */
+    0x0000, 0x1452, 0x0000, 0x1456, 0x0000, 0x1459, 0x0000, 0x145c,
+    0x0000, 0x145f, 0x0000, 0x1462, 0x0000, 0x1465, 0x0000, 0x1468,
+    0x0000, 0x146b, 0x0000, 0x146e, 0x0000, 0x1471, 0x0000, 0x1474,
+    0x0000, 0x1477, 0x0000, 0x147a, 0x0000, 0x147d, 0x0000, 0x1480,
+    /* 0x3260 .. 0x326f */
+    0x0000, 0x125a, 0x0000, 0x1260, 0x0000, 0x1266, 0x0000, 0x126a,
+    0x0000, 0x127a, 0x0000, 0x127c, 0x0000, 0x1282, 0x0000, 0x1286,
+    0x0000, 0x1288, 0x0000, 0x128c, 0x0000, 0x128e, 0x0000, 0x1290,
+    0x0000, 0x1292, 0x0000, 0x1294, 0x0000, 0x1483, 0x0000, 0x1486,
+    /* 0x3270 .. 0x327f */
+    0x0000, 0x1489, 0x0000, 0x148c, 0x0000, 0x148f, 0x0000, 0x1492,
+    0x0000, 0x1495, 0x0000, 0x1498, 0x0000, 0x149b, 0x0000, 0x149e,
+    0x0000, 0x14a1, 0x0000, 0x14a4, 0x0000, 0x14a7, 0x0000, 0x14aa,
+    0x0000, 0x14ad, 0x0000, 0x14b3, 0x0000, 0x14b8, 0x0000, 0x0000,
+    /* 0x3280 .. 0x328f */
+    0x0000, 0x0fee, 0x0000, 0x0ffa, 0x0000, 0x1316, 0x0000, 0x1318,
+    0x0000, 0x14bb, 0x0000, 0x14bd, 0x0000, 0x14bf, 0x0000, 0x1004,
+    0x0000, 0x14c1, 0x0000, 0x101c, 0x0000, 0x1080, 0x0000, 0x1098,
+    0x0000, 0x1096, 0x0000, 0x1082, 0x0000, 0x113a, 0x0000, 0x102c,
+    /* 0x3290 .. 0x329f */
+    0x0000, 0x107c, 0x0000, 0x14c3, 0x0000, 0x14c5, 0x0000, 0x14c7,
+    0x0000, 0x14c9, 0x0000, 0x14cb, 0x0000, 0x14cd, 0x0000, 0x14cf,
+    0x0000, 0x14d1, 0x0000, 0x14d3, 0x0000, 0x14d5, 0x0000, 0x1038,
+    0x0000, 0x14d7, 0x0000, 0x14d9, 0x0000, 0x14db, 0x0000, 0x14dd,
+    /* 0x32a0 .. 0x32af */
+    0x0000, 0x14df, 0x0000, 0x14e1, 0x0000, 0x14e3, 0x0000, 0x14e5,
+    0x0000, 0x131a, 0x0000, 0x131c, 0x0000, 0x131e, 0x0000, 0x14e7,
+    0x0000, 0x14e9, 0x0000, 0x14eb, 0x0000, 0x14ed, 0x0000, 0x14ef,
+    0x0000, 0x14f1, 0x0000, 0x14f3, 0x0000, 0x14f5, 0x0000, 0x14f7,
+    /* 0x32b0 .. 0x32bf */
+    0x0000, 0x14f9, 0x0000, 0x14fb, 0x0000, 0x14fe, 0x0000, 0x1501,
+    0x0000, 0x1504, 0x0000, 0x1507, 0x0000, 0x150a, 0x0000, 0x150d,
+    0x0000, 0x1510, 0x0000, 0x1513, 0x0000, 0x1516, 0x0000, 0x1519,
+    0x0000, 0x151c, 0x0000, 0x151f, 0x0000, 0x1522, 0x0000, 0x1525,
+    /* 0x32c0 .. 0x32cf */
+    0x0000, 0x1528, 0x0000, 0x152b, 0x0000, 0x152e, 0x0000, 0x1531,
+    0x0000, 0x1534, 0x0000, 0x1537, 0x0000, 0x153a, 0x0000, 0x153d,
+    0x0000, 0x1540, 0x0000, 0x1543, 0x0000, 0x1547, 0x0000, 0x154b,
+    0x0000, 0x154f, 0x0000, 0x1552, 0x0000, 0x1556, 0x0000, 0x1559,
+    /* 0x32d0 .. 0x32df */
+    0x0000, 0x155d, 0x0000, 0x155f, 0x0000, 0x1561, 0x0000, 0x1563,
+    0x0000, 0x1565, 0x0000, 0x1567, 0x0000, 0x1569, 0x0000, 0x156b,
+    0x0000, 0x156d, 0x0000, 0x156f, 0x0000, 0x1571, 0x0000, 0x1573,
+    0x0000, 0x1575, 0x0000, 0x1577, 0x0000, 0x1579, 0x0000, 0x157b,
+    /* 0x32e0 .. 0x32ef */
+    0x0000, 0x157d, 0x0000, 0x157f, 0x0000, 0x1581, 0x0000, 0x1583,
+    0x0000, 0x1585, 0x0000, 0x1587, 0x0000, 0x1589, 0x0000, 0x158b,
+    0x0000, 0x158d, 0x0000, 0x158f, 0x0000, 0x1591, 0x0000, 0x1593,
+    0x0000, 0x1595, 0x0000, 0x1597, 0x0000, 0x1599, 0x0000, 0x159b,
+    /* 0x32f0 .. 0x32ff */
+    0x0000, 0x159d, 0x0000, 0x159f, 0x0000, 0x15a1, 0x0000, 0x15a3,
+    0x0000, 0x15a5, 0x0000, 0x15a7, 0x0000, 0x15a9, 0x0000, 0x15ab,
+    0x0000, 0x15ad, 0x0000, 0x15af, 0x0000, 0x15b1, 0x0000, 0x15b3,
+    0x0000, 0x15b5, 0x0000, 0x15b7, 0x0000, 0x15b9, 0x0000, 0x0000,
+    /* 0x3300 .. 0x330f */
+    0x0000, 0x15bb, 0x0000, 0x15c1, 0x0000, 0x15c6, 0x0000, 0x15cc,
+    0x0000, 0x15d0, 0x0000, 0x15d6, 0x0000, 0x15da, 0x0000, 0x15de,
+    0x0000, 0x15e5, 0x0000, 0x15ea, 0x0000, 0x15ee, 0x0000, 0x15f2,
+    0x0000, 0x15f6, 0x0000, 0x15fb, 0x0000, 0x1600, 0x0000, 0x1605,
+    /* 0x3310 .. 0x331f */
+    0x0000, 0x160a, 0x0000, 0x160f, 0x0000, 0x1614, 0x0000, 0x1619,
+    0x0000, 0x1620, 0x0000, 0x1623, 0x0000, 0x162a, 0x0000, 0x1631,
+    0x0000, 0x1637, 0x0000, 0x163c, 0x0000, 0x1643, 0x0000, 0x164a,
+    0x0000, 0x164f, 0x0000, 0x1653, 0x0000, 0x1657, 0x0000, 0x165c,
+    /* 0x3320 .. 0x332f */
+    0x0000, 0x1661, 0x0000, 0x1667, 0x0000, 0x166d, 0x0000, 0x1671,
+    0x0000, 0x1675, 0x0000, 0x167a, 0x0000, 0x167e, 0x0000, 0x1682,
+    0x0000, 0x1685, 0x0000, 0x1688, 0x0000, 0x168c, 0x0000, 0x1690,
+    0x0000, 0x1697, 0x0000, 0x169c, 0x0000, 0x16a2, 0x0000, 0x16a9,
+    /* 0x3330 .. 0x333f */
+    0x0000, 0x16ae, 0x0000, 0x16b2, 0x0000, 0x16b6, 0x0000, 0x16bd,
+    0x0000, 0x16c2, 0x0000, 0x16c9, 0x0000, 0x16cd, 0x0000, 0x16d3,
+    0x0000, 0x16d7, 0x0000, 0x16dc, 0x0000, 0x16e0, 0x0000, 0x16e5,
+    0x0000, 0x16eb, 0x0000, 0x16f0, 0x0000, 0x16f6, 0x0000, 0x16fb,
+    /* 0x3340 .. 0x334f */
+    0x0000, 0x16fe, 0x0000, 0x1704, 0x0000, 0x1708, 0x0000, 0x170c,
+    0x0000, 0x1711, 0x0000, 0x1715, 0x0000, 0x1719, 0x0000, 0x171d,
+    0x0000, 0x1723, 0x0000, 0x1728, 0x0000, 0x172b, 0x0000, 0x1732,
+    0x0000, 0x1736, 0x0000, 0x173c, 0x0000, 0x1741, 0x0000, 0x1746,
+    /* 0x3350 .. 0x335f */
+    0x0000, 0x174a, 0x0000, 0x174e, 0x0000, 0x1753, 0x0000, 0x1756,
+    0x0000, 0x175b, 0x0000, 0x1761, 0x0000, 0x1764, 0x0000, 0x176b,
+    0x0000, 0x176f, 0x0000, 0x1772, 0x0000, 0x1775, 0x0000, 0x1778,
+    0x0000, 0x177b, 0x0000, 0x177e, 0x0000, 0x1781, 0x0000, 0x1784,
+    /* 0x3360 .. 0x336f */
+    0x0000, 0x1787, 0x0000, 0x178a, 0x0000, 0x178d, 0x0000, 0x1791,
+    0x0000, 0x1795, 0x0000, 0x1799, 0x0000, 0x179d, 0x0000, 0x17a1,
+    0x0000, 0x17a5, 0x0000, 0x17a9, 0x0000, 0x17ad, 0x0000, 0x17b1,
+    0x0000, 0x17b5, 0x0000, 0x17b9, 0x0000, 0x17bd, 0x0000, 0x17c1,
+    /* 0x3370 .. 0x337f */
+    0x0000, 0x17c5, 0x0000, 0x17c9, 0x0000, 0x17cd, 0x0000, 0x17d0,
+    0x0000, 0x17d3, 0x0000, 0x17d7, 0x0000, 0x17da, 0x0000, 0x17dd,
+    0x0000, 0x17e0, 0x0000, 0x17e4, 0x0000, 0x17e8, 0x0000, 0x17eb,
+    0x0000, 0x17ee, 0x0000, 0x17f1, 0x0000, 0x17f4, 0x0000, 0x17f7,
+    /* 0x3380 .. 0x338f */
+    0x0000, 0x17fc, 0x0000, 0x17ff, 0x0000, 0x1802, 0x0000, 0x1805,
+    0x0000, 0x1808, 0x0000, 0x180b, 0x0000, 0x180e, 0x0000, 0x1811,
+    0x0000, 0x1814, 0x0000, 0x1818, 0x0000, 0x181d, 0x0000, 0x1820,
+    0x0000, 0x1823, 0x0000, 0x1826, 0x0000, 0x1829, 0x0000, 0x182c,
+    /* 0x3390 .. 0x339f */
+    0x0000, 0x182f, 0x0000, 0x1832, 0x0000, 0x1836, 0x0000, 0x183a,
+    0x0000, 0x183e, 0x0000, 0x1842, 0x0000, 0x1845, 0x0000, 0x1848,
+    0x0000, 0x184b, 0x0000, 0x184e, 0x0000, 0x1851, 0x0000, 0x1854,
+    0x0000, 0x1857, 0x0000, 0x185a, 0x0000, 0x185d, 0x0000, 0x1860,
+    /* 0x33a0 .. 0x33af */
+    0x0000, 0x1864, 0x0000, 0x1868, 0x0000, 0x186b, 0x0000, 0x186f,
+    0x0000, 0x1873, 0x0000, 0x1877, 0x0000, 0x187a, 0x0000, 0x187e,
+    0x0000, 0x1882, 0x0000, 0x1887, 0x0000, 0x188a, 0x0000, 0x188e,
+    0x0000, 0x1892, 0x0000, 0x1896, 0x0000, 0x189a, 0x0000, 0x18a0,
+    /* 0x33b0 .. 0x33bf */
+    0x0000, 0x18a7, 0x0000, 0x18aa, 0x0000, 0x18ad, 0x0000, 0x18b0,
+    0x0000, 0x18b3, 0x0000, 0x18b6, 0x0000, 0x18b9, 0x0000, 0x18bc,
+    0x0000, 0x18bf, 0x0000, 0x18c2, 0x0000, 0x18c5, 0x0000, 0x18c8,
+    0x0000, 0x18cb, 0x0000, 0x18ce, 0x0000, 0x18d1, 0x0000, 0x18d4,
+    /* 0x33c0 .. 0x33cf */
+    0x0000, 0x18d7, 0x0000, 0x18da, 0x0000, 0x18dd, 0x0000, 0x18e2,
+    0x0000, 0x18e5, 0x0000, 0x18e8, 0x0000, 0x18eb, 0x0000, 0x18f0,
+    0x0000, 0x18f4, 0x0000, 0x18f7, 0x0000, 0x18fa, 0x0000, 0x18fd,
+    0x0000, 0x1900, 0x0000, 0x1903, 0x0000, 0x1906, 0x0000, 0x1909,
+    /* 0x33d0 .. 0x33df */
+    0x0000, 0x190c, 0x0000, 0x190f, 0x0000, 0x1912, 0x0000, 0x1916,
+    0x0000, 0x1919, 0x0000, 0x191c, 0x0000, 0x1920, 0x0000, 0x1924,
+    0x0000, 0x1927, 0x0000, 0x192c, 0x0000, 0x1930, 0x0000, 0x1933,
+    0x0000, 0x1936, 0x0000, 0x1939, 0x0000, 0x193c, 0x0000, 0x1940,
+    /* 0x33e0 .. 0x33ef */
+    0x0000, 0x1944, 0x0000, 0x1947, 0x0000, 0x194a, 0x0000, 0x194d,
+    0x0000, 0x1950, 0x0000, 0x1953, 0x0000, 0x1956, 0x0000, 0x1959,
+    0x0000, 0x195c, 0x0000, 0x195f, 0x0000, 0x1963, 0x0000, 0x1967,
+    0x0000, 0x196b, 0x0000, 0x196f, 0x0000, 0x1973, 0x0000, 0x1977,
+    /* 0x33f0 .. 0x33ff */
+    0x0000, 0x197b, 0x0000, 0x197f, 0x0000, 0x1983, 0x0000, 0x1987,
+    0x0000, 0x198b, 0x0000, 0x198f, 0x0000, 0x1993, 0x0000, 0x1997,
+    0x0000, 0x199b, 0x0000, 0x199f, 0x0000, 0x19a3, 0x0000, 0x19a7,
+    0x0000, 0x19ab, 0x0000, 0x19af, 0x0000, 0x19b3, 0x0000, 0x19b7,
+    /* 0xa690 .. 0xa69f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x19bb, 0x0000, 0x19bd, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0xa770 .. 0xa77f */
+    0x0000, 0x19bf, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0xa7f0 .. 0xa7ff */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x19c1, 0x0000, 0x19c3, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0xab50 .. 0xab5f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x19c5, 0x0000, 0x19c7, 0x0000, 0x19c9, 0x0000, 0x19cb,
+    /* 0xf900 .. 0xf90f */
+    0x19cd, 0x19cd, 0x19cf, 0x19cf, 0x112a, 0x112a, 0x19d1, 0x19d1,
+    0x19d3, 0x19d3, 0x19d5, 0x19d5, 0x19d7, 0x19d7, 0x1196, 0x1196,
+    0x1196, 0x1196, 0x19d9, 0x19d9, 0x113a, 0x113a, 0x19db, 0x19db,
+    0x19dd, 0x19dd, 0x19df, 0x19df, 0x19e1, 0x19e1, 0x19e3, 0x19e3,
+    /* 0xf910 .. 0xf91f */
+    0x19e5, 0x19e5, 0x19e7, 0x19e7, 0x19e9, 0x19e9, 0x19eb, 0x19eb,
+    0x19ed, 0x19ed, 0x19ef, 0x19ef, 0x19f1, 0x19f1, 0x19f3, 0x19f3,
+    0x19f5, 0x19f5, 0x19f7, 0x19f7, 0x19f9, 0x19f9, 0x19fb, 0x19fb,
+    0x19fd, 0x19fd, 0x19ff, 0x19ff, 0x1a01, 0x1a01, 0x1a03, 0x1a03,
+    /* 0xf920 .. 0xf92f */
+    0x1a05, 0x1a05, 0x1a07, 0x1a07, 0x1a09, 0x1a09, 0x1a0b, 0x1a0b,
+    0x1a0d, 0x1a0d, 0x1a0f, 0x1a0f, 0x1a11, 0x1a11, 0x1a13, 0x1a13,
+    0x1a15, 0x1a15, 0x1a17, 0x1a17, 0x1a19, 0x1a19, 0x1a1b, 0x1a1b,
+    0x1a1d, 0x1a1d, 0x1a1f, 0x1a1f, 0x1a21, 0x1a21, 0x1a23, 0x1a23,
+    /* 0xf930 .. 0xf93f */
+    0x1a25, 0x1a25, 0x1a27, 0x1a27, 0x1a29, 0x1a29, 0x1a2b, 0x1a2b,
+    0x10e6, 0x10e6, 0x1a2d, 0x1a2d, 0x1a2f, 0x1a2f, 0x1a31, 0x1a31,
+    0x1a33, 0x1a33, 0x1a35, 0x1a35, 0x1a37, 0x1a37, 0x1a39, 0x1a39,
+    0x1a3b, 0x1a3b, 0x1a3d, 0x1a3d, 0x1a3f, 0x1a3f, 0x1a41, 0x1a41,
+    /* 0xf940 .. 0xf94f */
+    0x1178, 0x1178, 0x1a43, 0x1a43, 0x1a45, 0x1a45, 0x1a47, 0x1a47,
+    0x1a49, 0x1a49, 0x1a4b, 0x1a4b, 0x1a4d, 0x1a4d, 0x1a4f, 0x1a4f,
+    0x1a51, 0x1a51, 0x1a53, 0x1a53, 0x1a55, 0x1a55, 0x1a57, 0x1a57,
+    0x1a59, 0x1a59, 0x1a5b, 0x1a5b, 0x1a5d, 0x1a5d, 0x1a5f, 0x1a5f,
+    /* 0xf950 .. 0xf95f */
+    0x1a61, 0x1a61, 0x1a63, 0x1a63, 0x1a65, 0x1a65, 0x1a67, 0x1a67,
+    0x1a69, 0x1a69, 0x1a6b, 0x1a6b, 0x1a6d, 0x1a6d, 0x1a6f, 0x1a6f,
+    0x1a71, 0x1a71, 0x1a73, 0x1a73, 0x1a75, 0x1a75, 0x1a77, 0x1a77,
+    0x19ed, 0x19ed, 0x1a79, 0x1a79, 0x1a7b, 0x1a7b, 0x1a7d, 0x1a7d,
+    /* 0xf960 .. 0xf96f */
+    0x1a7f, 0x1a7f, 0x1a81, 0x1a81, 0x1a83, 0x1a83, 0x1a85, 0x1a85,
+    0x1a87, 0x1a87, 0x1a89, 0x1a89, 0x1a8b, 0x1a8b, 0x1a8d, 0x1a8d,
+    0x1a8f, 0x1a8f, 0x1a91, 0x1a91, 0x1a93, 0x1a93, 0x1a95, 0x1a95,
+    0x1a97, 0x1a97, 0x1a99, 0x1a99, 0x1a9b, 0x1a9b, 0x1a9d, 0x1a9d,
+    /* 0xf970 .. 0xf97f */
+    0x1a9f, 0x1a9f, 0x112e, 0x112e, 0x1aa1, 0x1aa1, 0x1aa3, 0x1aa3,
+    0x1aa5, 0x1aa5, 0x1aa7, 0x1aa7, 0x1aa9, 0x1aa9, 0x1aab, 0x1aab,
+    0x1aad, 0x1aad, 0x1aaf, 0x1aaf, 0x1ab1, 0x1ab1, 0x1ab3, 0x1ab3,
+    0x1ab5, 0x1ab5, 0x1ab7, 0x1ab7, 0x1ab9, 0x1ab9, 0x1abb, 0x1abb,
+    /* 0xf980 .. 0xf98f */
+    0x1abd, 0x1abd, 0x1038, 0x1038, 0x1abf, 0x1abf, 0x1ac1, 0x1ac1,
+    0x1ac3, 0x1ac3, 0x1ac5, 0x1ac5, 0x1ac7, 0x1ac7, 0x1ac9, 0x1ac9,
+    0x1acb, 0x1acb, 0x1acd, 0x1acd, 0x1012, 0x1012, 0x1acf, 0x1acf,
+    0x1ad1, 0x1ad1, 0x1ad3, 0x1ad3, 0x1ad5, 0x1ad5, 0x1ad7, 0x1ad7,
+    /* 0xf990 .. 0xf99f */
+    0x1ad9, 0x1ad9, 0x1adb, 0x1adb, 0x1add, 0x1add, 0x1adf, 0x1adf,
+    0x1ae1, 0x1ae1, 0x1ae3, 0x1ae3, 0x1ae5, 0x1ae5, 0x1ae7, 0x1ae7,
+    0x1ae9, 0x1ae9, 0x1aeb, 0x1aeb, 0x1aed, 0x1aed, 0x1aef, 0x1aef,
+    0x1af1, 0x1af1, 0x1af3, 0x1af3, 0x1af5, 0x1af5, 0x1af7, 0x1af7,
+    /* 0xf9a0 .. 0xf9af */
+    0x1af9, 0x1af9, 0x1a9d, 0x1a9d, 0x1afb, 0x1afb, 0x1afd, 0x1afd,
+    0x1aff, 0x1aff, 0x1b01, 0x1b01, 0x1b03, 0x1b03, 0x1b05, 0x1b05,
+    0x1b07, 0x1b07, 0x1b09, 0x1b09, 0x1a7d, 0x1a7d, 0x1b0b, 0x1b0b,
+    0x1b0d, 0x1b0d, 0x1b0f, 0x1b0f, 0x1b11, 0x1b11, 0x1b13, 0x1b13,
+    /* 0xf9b0 .. 0xf9bf */
+    0x1b15, 0x1b15, 0x1b17, 0x1b17, 0x1b19, 0x1b19, 0x1b1b, 0x1b1b,
+    0x1b1d, 0x1b1d, 0x1b1f, 0x1b1f, 0x1b21, 0x1b21, 0x1b23, 0x1b23,
+    0x1b25, 0x1b25, 0x1b27, 0x1b27, 0x1b29, 0x1b29, 0x1b2b, 0x1b2b,
+    0x1b2d, 0x1b2d, 0x1b2f, 0x1b2f, 0x1b31, 0x1b31, 0x19ed, 0x19ed,
+    /* 0xf9c0 .. 0xf9cf */
+    0x1b33, 0x1b33, 0x1b35, 0x1b35, 0x1b37, 0x1b37, 0x1b39, 0x1b39,
+    0x1194, 0x1194, 0x1b3b, 0x1b3b, 0x1b3d, 0x1b3d, 0x1b3f, 0x1b3f,
+    0x1b41, 0x1b41, 0x1b43, 0x1b43, 0x1b45, 0x1b45, 0x1b47, 0x1b47,
+    0x1b49, 0x1b49, 0x1b4b, 0x1b4b, 0x1b4d, 0x1b4d, 0x1b4f, 0x1b4f,
+    /* 0xf9d0 .. 0xf9df */
+    0x1b51, 0x1b51, 0x14bd, 0x14bd, 0x1b53, 0x1b53, 0x1b55, 0x1b55,
+    0x1b57, 0x1b57, 0x1b59, 0x1b59, 0x1b5b, 0x1b5b, 0x1b5d, 0x1b5d,
+    0x1b5f, 0x1b5f, 0x1b61, 0x1b61, 0x1b63, 0x1b63, 0x1a81, 0x1a81,
+    0x1b65, 0x1b65, 0x1b67, 0x1b67, 0x1b69, 0x1b69, 0x1b6b, 0x1b6b,
+    /* 0xf9e0 .. 0xf9ef */
+    0x1b6d, 0x1b6d, 0x1b6f, 0x1b6f, 0x1b71, 0x1b71, 0x1b73, 0x1b73,
+    0x1b75, 0x1b75, 0x1b77, 0x1b77, 0x1b79, 0x1b79, 0x1b7b, 0x1b7b,
+    0x1b7d, 0x1b7d, 0x1138, 0x1138, 0x1b7f, 0x1b7f, 0x1b81, 0x1b81,
+    0x1b83, 0x1b83, 0x1b85, 0x1b85, 0x1b87, 0x1b87, 0x1b89, 0x1b89,
+    /* 0xf9f0 .. 0xf9ff */
+    0x1b8b, 0x1b8b, 0x1b8d, 0x1b8d, 0x1b8f, 0x1b8f, 0x1b91, 0x1b91,
+    0x1b93, 0x1b93, 0x1b95, 0x1b95, 0x1b97, 0x1b97, 0x10d6, 0x10d6,
+    0x1b99, 0x1b99, 0x1b9b, 0x1b9b, 0x1b9d, 0x1b9d, 0x1b9f, 0x1b9f,
+    0x1ba1, 0x1ba1, 0x1ba3, 0x1ba3, 0x1ba5, 0x1ba5, 0x1ba7, 0x1ba7,
+    /* 0xfa00 .. 0xfa0f */
+    0x1ba9, 0x1ba9, 0x1bab, 0x1bab, 0x1bad, 0x1bad, 0x1baf, 0x1baf,
+    0x1bb1, 0x1bb1, 0x1bb3, 0x1bb3, 0x1bb5, 0x1bb5, 0x1bb7, 0x1bb7,
+    0x110c, 0x110c, 0x1bb9, 0x1bb9, 0x1112, 0x1112, 0x1bbb, 0x1bbb,
+    0x1bbd, 0x1bbd, 0x1bbf, 0x1bbf, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0xfa10 .. 0xfa1f */
+    0x1bc1, 0x1bc1, 0x0000, 0x0000, 0x1bc3, 0x1bc3, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x1bc5, 0x1bc5, 0x1bc7, 0x1bc7, 0x1bc9, 0x1bc9,
+    0x1bcb, 0x1bcb, 0x1bcd, 0x1bcd, 0x1bcf, 0x1bcf, 0x1bd1, 0x1bd1,
+    0x1bd3, 0x1bd3, 0x1bd5, 0x1bd5, 0x10e4, 0x10e4, 0x0000, 0x0000,
+    /* 0xfa20 .. 0xfa2f */
+    0x1bd7, 0x1bd7, 0x0000, 0x0000, 0x1bd9, 0x1bd9, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x1bdb, 0x1bdb, 0x1bdd, 0x1bdd, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x1bdf, 0x1bdf, 0x1be1, 0x1be1,
+    0x1be3, 0x1be3, 0x1be5, 0x1be5, 0x1be7, 0x1be7, 0x1be9, 0x1be9,
+    /* 0xfa30 .. 0xfa3f */
+    0x1beb, 0x1beb, 0x1bed, 0x1bed, 0x1bef, 0x1bef, 0x1bf1, 0x1bf1,
+    0x1bf3, 0x1bf3, 0x1bf5, 0x1bf5, 0x1bf7, 0x1bf7, 0x1bf9, 0x1bf9,
+    0x1bfb, 0x1bfb, 0x1bfd, 0x1bfd, 0x1bff, 0x1bff, 0x1c01, 0x1c01,
+    0x1046, 0x1046, 0x1c03, 0x1c03, 0x1c05, 0x1c05, 0x1c07, 0x1c07,
+    /* 0xfa40 .. 0xfa4f */
+    0x1c09, 0x1c09, 0x1c0b, 0x1c0b, 0x1c0d, 0x1c0d, 0x1c0f, 0x1c0f,
+    0x1c11, 0x1c11, 0x1c13, 0x1c13, 0x1c15, 0x1c15, 0x1c17, 0x1c17,
+    0x1c19, 0x1c19, 0x1c1b, 0x1c1b, 0x1c1d, 0x1c1d, 0x1c1f, 0x1c1f,
+    0x14c7, 0x14c7, 0x1c21, 0x1c21, 0x1c23, 0x1c23, 0x1c25, 0x1c25,
+    /* 0xfa50 .. 0xfa5f */
+    0x1c27, 0x1c27, 0x14cf, 0x14cf, 0x1c29, 0x1c29, 0x1c2b, 0x1c2b,
+    0x1c2d, 0x1c2d, 0x1c2f, 0x1c2f, 0x1c31, 0x1c31, 0x1ae5, 0x1ae5,
+    0x1c33, 0x1c33, 0x1c35, 0x1c35, 0x1c37, 0x1c37, 0x1c39, 0x1c39,
+    0x1c3b, 0x1c3b, 0x1c3d, 0x1c3d, 0x1c3d, 0x1c3d, 0x1c3f, 0x1c3f,
+    /* 0xfa60 .. 0xfa6f */
+    0x1c41, 0x1c41, 0x1c43, 0x1c43, 0x1c45, 0x1c45, 0x1c47, 0x1c47,
+    0x1c49, 0x1c49, 0x1c4b, 0x1c4b, 0x1c4d, 0x1c4d, 0x1bdb, 0x1bdb,
+    0x1c4f, 0x1c4f, 0x1c51, 0x1c51, 0x1c53, 0x1c53, 0x1c55, 0x1c55,
+    0x1c57, 0x1c57, 0x1c5a, 0x1c5a, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0xfa70 .. 0xfa7f */
+    0x1c5c, 0x1c5c, 0x1c5e, 0x1c5e, 0x1c60, 0x1c60, 0x1c62, 0x1c62,
+    0x1c64, 0x1c64, 0x1c66, 0x1c66, 0x1c68, 0x1c68, 0x1c6a, 0x1c6a,
+    0x1bf7, 0x1bf7, 0x1c6c, 0x1c6c, 0x1c6e, 0x1c6e, 0x1c70, 0x1c70,
+    0x1bc1, 0x1bc1, 0x1c72, 0x1c72, 0x1c74, 0x1c74, 0x1c76, 0x1c76,
+    /* 0xfa80 .. 0xfa8f */
+    0x1c78, 0x1c78, 0x1c7a, 0x1c7a, 0x1c7c, 0x1c7c, 0x1c7e, 0x1c7e,
+    0x1c80, 0x1c80, 0x1c82, 0x1c82, 0x1c84, 0x1c84, 0x1c86, 0x1c86,
+    0x1c88, 0x1c88, 0x1c07, 0x1c07, 0x1c8a, 0x1c8a, 0x1c09, 0x1c09,
+    0x1c8c, 0x1c8c, 0x1c8e, 0x1c8e, 0x1c90, 0x1c90, 0x1c92, 0x1c92,
+    /* 0xfa90 .. 0xfa9f */
+    0x1c94, 0x1c94, 0x1bc3, 0x1bc3, 0x1a17, 0x1a17, 0x1c96, 0x1c96,
+    0x1c98, 0x1c98, 0x1088, 0x1088, 0x1a9f, 0x1a9f, 0x1b45, 0x1b45,
+    0x1c9a, 0x1c9a, 0x1c9c, 0x1c9c, 0x1c17, 0x1c17, 0x1c9e, 0x1c9e,
+    0x1c19, 0x1c19, 0x1ca0, 0x1ca0, 0x1ca2, 0x1ca2, 0x1ca4, 0x1ca4,
+    /* 0xfaa0 .. 0xfaaf */
+    0x1bc7, 0x1bc7, 0x1ca6, 0x1ca6, 0x1ca8, 0x1ca8, 0x1caa, 0x1caa,
+    0x1cac, 0x1cac, 0x1cae, 0x1cae, 0x1bc9, 0x1bc9, 0x1cb0, 0x1cb0,
+    0x1cb2, 0x1cb2, 0x1cb4, 0x1cb4, 0x1cb6, 0x1cb6, 0x1cb8, 0x1cb8,
+    0x1cba, 0x1cba, 0x1c31, 0x1c31, 0x1cbc, 0x1cbc, 0x1cbe, 0x1cbe,
+    /* 0xfab0 .. 0xfabf */
+    0x1ae5, 0x1ae5, 0x1cc0, 0x1cc0, 0x1c39, 0x1c39, 0x1cc2, 0x1cc2,
+    0x1cc4, 0x1cc4, 0x1cc6, 0x1cc6, 0x1cc8, 0x1cc8, 0x1cca, 0x1cca,
+    0x1c43, 0x1c43, 0x1ccc, 0x1ccc, 0x1bd9, 0x1bd9, 0x1cce, 0x1cce,
+    0x1c45, 0x1c45, 0x1a79, 0x1a79, 0x1cd0, 0x1cd0, 0x1c47, 0x1c47,
+    /* 0xfac0 .. 0xfacf */
+    0x1cd2, 0x1cd2, 0x1c4b, 0x1c4b, 0x1cd4, 0x1cd4, 0x1cd6, 0x1cd6,
+    0x1cd8, 0x1cd8, 0x1cda, 0x1cda, 0x1cdc, 0x1cdc, 0x1c4f, 0x1c4f,
+    0x1bd3, 0x1bd3, 0x1cde, 0x1cde, 0x1c51, 0x1c51, 0x1ce0, 0x1ce0,
+    0x1c53, 0x1c53, 0x1ce2, 0x1ce2, 0x1196, 0x1196, 0x1ce4, 0x1ce4,
+    /* 0xfad0 .. 0xfadf */
+    0x1ce7, 0x1ce7, 0x1cea, 0x1cea, 0x1ced, 0x1ced, 0x1cef, 0x1cef,
+    0x1cf1, 0x1cf1, 0x1cf3, 0x1cf3, 0x1cf6, 0x1cf6, 0x1cf9, 0x1cf9,
+    0x1cfc, 0x1cfc, 0x1cfe, 0x1cfe, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0xfb00 .. 0xfb0f */
+    0x0000, 0x1d00, 0x0000, 0x1d03, 0x0000, 0x1d06, 0x0000, 0x1d09,
+    0x0000, 0x1d0d, 0x0000, 0x1d11, 0x0000, 0x1d11, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0xfb10 .. 0xfb1f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x1d14,
+    0x0000, 0x1d17, 0x0000, 0x1d1a, 0x0000, 0x1d1d, 0x0000, 0x1d20,
     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x05d9, 0x05b4, 0x0000, 0x0000, 0x05f2, 0x05b7,
+    0x0000, 0x0000, 0x1d23, 0x1d23, 0x0000, 0x0000, 0x1d26, 0x1d26,
     /* 0xfb20 .. 0xfb2f */
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
-    0x0000, 0x0000, 0x0000, 0x0000, 0x05e9, 0x05c1, 0x05e9, 0x05c2,
-    0xfb49, 0x05c1, 0xfb49, 0x05c2, 0x05d0, 0x05b7, 0x05d0, 0x05b8,
+    0x0000, 0x1d29, 0x0000, 0x0d74, 0x0000, 0x0d7a, 0x0000, 0x1d2b,
+    0x0000, 0x1d2d, 0x0000, 0x1d2f, 0x0000, 0x1d31, 0x0000, 0x1d33,
+    0x0000, 0x1d35, 0x0000, 0x0d34, 0x1d37, 0x1d37, 0x1d3a, 0x1d3a,
+    0x1d3d, 0x1d3d, 0x1d41, 0x1d41, 0x1d45, 0x1d45, 0x1d48, 0x1d48,
     /* 0xfb30 .. 0xfb3f */
-    0x05d0, 0x05bc, 0x05d1, 0x05bc, 0x05d2, 0x05bc, 0x05d3, 0x05bc,
-    0x05d4, 0x05bc, 0x05d5, 0x05bc, 0x05d6, 0x05bc, 0x0000, 0x0000,
-    0x05d8, 0x05bc, 0x05d9, 0x05bc, 0x05da, 0x05bc, 0x05db, 0x05bc,
-    0x05dc, 0x05bc, 0x0000, 0x0000, 0x05de, 0x05bc, 0x0000, 0x0000,
+    0x1d4b, 0x1d4b, 0x1d4e, 0x1d4e, 0x1d51, 0x1d51, 0x1d54, 0x1d54,
+    0x1d57, 0x1d57, 0x1d5a, 0x1d5a, 0x1d5d, 0x1d5d, 0x0000, 0x0000,
+    0x1d60, 0x1d60, 0x1d63, 0x1d63, 0x1d66, 0x1d66, 0x1d69, 0x1d69,
+    0x1d6c, 0x1d6c, 0x0000, 0x0000, 0x1d6f, 0x1d6f, 0x0000, 0x0000,
     /* 0xfb40 .. 0xfb4f */
-    0x05e0, 0x05bc, 0x05e1, 0x05bc, 0x0000, 0x0000, 0x05e3, 0x05bc,
-    0x05e4, 0x05bc, 0x0000, 0x0000, 0x05e6, 0x05bc, 0x05e7, 0x05bc,
-    0x05e8, 0x05bc, 0x05e9, 0x05bc, 0x05ea, 0x05bc, 0x05d5, 0x05b9,
-    0x05d1, 0x05bf, 0x05db, 0x05bf, 0x05e4, 0x05bf, 0x0000, 0x0000
+    0x1d72, 0x1d72, 0x1d75, 0x1d75, 0x0000, 0x0000, 0x1d78, 0x1d78,
+    0x1d7b, 0x1d7b, 0x0000, 0x0000, 0x1d7e, 0x1d7e, 0x1d81, 0x1d81,
+    0x1d84, 0x1d84, 0x1d87, 0x1d87, 0x1d8a, 0x1d8a, 0x1d8d, 0x1d8d,
+    0x1d90, 0x1d90, 0x1d93, 0x1d93, 0x1d96, 0x1d96, 0x0000, 0x1d99,
+    /* 0xfb50 .. 0xfb5f */
+    0x0000, 0x1d9c, 0x0000, 0x1d9c, 0x0000, 0x1d9e, 0x0000, 0x1d9e,
+    0x0000, 0x1d9e, 0x0000, 0x1d9e, 0x0000, 0x1da0, 0x0000, 0x1da0,
+    0x0000, 0x1da0, 0x0000, 0x1da0, 0x0000, 0x1da2, 0x0000, 0x1da2,
+    0x0000, 0x1da2, 0x0000, 0x1da2, 0x0000, 0x1da4, 0x0000, 0x1da4,
+    /* 0xfb60 .. 0xfb6f */
+    0x0000, 0x1da4, 0x0000, 0x1da4, 0x0000, 0x1da6, 0x0000, 0x1da6,
+    0x0000, 0x1da6, 0x0000, 0x1da6, 0x0000, 0x1da8, 0x0000, 0x1da8,
+    0x0000, 0x1da8, 0x0000, 0x1da8, 0x0000, 0x1daa, 0x0000, 0x1daa,
+    0x0000, 0x1daa, 0x0000, 0x1daa, 0x0000, 0x1dac, 0x0000, 0x1dac,
+    /* 0xfb70 .. 0xfb7f */
+    0x0000, 0x1dac, 0x0000, 0x1dac, 0x0000, 0x1dae, 0x0000, 0x1dae,
+    0x0000, 0x1dae, 0x0000, 0x1dae, 0x0000, 0x1db0, 0x0000, 0x1db0,
+    0x0000, 0x1db0, 0x0000, 0x1db0, 0x0000, 0x1db2, 0x0000, 0x1db2,
+    0x0000, 0x1db2, 0x0000, 0x1db2, 0x0000, 0x1db4, 0x0000, 0x1db4,
+    /* 0xfb80 .. 0xfb8f */
+    0x0000, 0x1db4, 0x0000, 0x1db4, 0x0000, 0x1db6, 0x0000, 0x1db6,
+    0x0000, 0x1db8, 0x0000, 0x1db8, 0x0000, 0x1dba, 0x0000, 0x1dba,
+    0x0000, 0x1dbc, 0x0000, 0x1dbc, 0x0000, 0x1dbe, 0x0000, 0x1dbe,
+    0x0000, 0x1dc0, 0x0000, 0x1dc0, 0x0000, 0x1dc2, 0x0000, 0x1dc2,
+    /* 0xfb90 .. 0xfb9f */
+    0x0000, 0x1dc2, 0x0000, 0x1dc2, 0x0000, 0x1dc4, 0x0000, 0x1dc4,
+    0x0000, 0x1dc4, 0x0000, 0x1dc4, 0x0000, 0x1dc6, 0x0000, 0x1dc6,
+    0x0000, 0x1dc6, 0x0000, 0x1dc6, 0x0000, 0x1dc8, 0x0000, 0x1dc8,
+    0x0000, 0x1dc8, 0x0000, 0x1dc8, 0x0000, 0x1dca, 0x0000, 0x1dca,
+    /* 0xfba0 .. 0xfbaf */
+    0x0000, 0x1dcc, 0x0000, 0x1dcc, 0x0000, 0x1dcc, 0x0000, 0x1dcc,
+    0x0000, 0x04c2, 0x0000, 0x04c2, 0x0000, 0x1dce, 0x0000, 0x1dce,
+    0x0000, 0x1dce, 0x0000, 0x1dce, 0x0000, 0x1dd0, 0x0000, 0x1dd0,
+    0x0000, 0x1dd0, 0x0000, 0x1dd0, 0x0000, 0x1dd2, 0x0000, 0x1dd2,
+    /* 0xfbb0 .. 0xfbbf */
+    0x0000, 0x04c8, 0x0000, 0x04c8, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0xfbd0 .. 0xfbdf */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x1dd4,
+    0x0000, 0x1dd4, 0x0000, 0x1dd4, 0x0000, 0x1dd4, 0x0000, 0x1dd6,
+    0x0000, 0x1dd6, 0x0000, 0x1dd8, 0x0000, 0x1dd8, 0x0000, 0x1dda,
+    0x0000, 0x1dda, 0x0000, 0x04bc, 0x0000, 0x1ddc, 0x0000, 0x1ddc,
+    /* 0xfbe0 .. 0xfbef */
+    0x0000, 0x1dde, 0x0000, 0x1dde, 0x0000, 0x1de0, 0x0000, 0x1de0,
+    0x0000, 0x1de2, 0x0000, 0x1de2, 0x0000, 0x1de2, 0x0000, 0x1de2,
+    0x0000, 0x1de4, 0x0000, 0x1de4, 0x0000, 0x1de6, 0x0000, 0x1de6,
+    0x0000, 0x1dea, 0x0000, 0x1dea, 0x0000, 0x1dee, 0x0000, 0x1dee,
+    /* 0xfbf0 .. 0xfbff */
+    0x0000, 0x1df2, 0x0000, 0x1df2, 0x0000, 0x1df6, 0x0000, 0x1df6,
+    0x0000, 0x1dfa, 0x0000, 0x1dfa, 0x0000, 0x1dfe, 0x0000, 0x1dfe,
+    0x0000, 0x1dfe, 0x0000, 0x1e02, 0x0000, 0x1e02, 0x0000, 0x1e02,
+    0x0000, 0x1e06, 0x0000, 0x1e06, 0x0000, 0x1e06, 0x0000, 0x1e06,
+    /* 0xfc00 .. 0xfc0f */
+    0x0000, 0x1e08, 0x0000, 0x1e0c, 0x0000, 0x1e10, 0x0000, 0x1e02,
+    0x0000, 0x1e14, 0x0000, 0x1e18, 0x0000, 0x1e1b, 0x0000, 0x1e1e,
+    0x0000, 0x1e21, 0x0000, 0x1e24, 0x0000, 0x1e27, 0x0000, 0x1e2a,
+    0x0000, 0x1e2d, 0x0000, 0x1e30, 0x0000, 0x1e33, 0x0000, 0x1e36,
+    /* 0xfc10 .. 0xfc1f */
+    0x0000, 0x1e39, 0x0000, 0x1e3c, 0x0000, 0x1e3f, 0x0000, 0x1e42,
+    0x0000, 0x1e45, 0x0000, 0x1e48, 0x0000, 0x1e4b, 0x0000, 0x1e4e,
+    0x0000, 0x1e51, 0x0000, 0x1e54, 0x0000, 0x1e57, 0x0000, 0x1e5a,
+    0x0000, 0x1e5d, 0x0000, 0x1e60, 0x0000, 0x1e63, 0x0000, 0x1e66,
+    /* 0xfc20 .. 0xfc2f */
+    0x0000, 0x1e69, 0x0000, 0x1e6c, 0x0000, 0x1e6f, 0x0000, 0x1e72,
+    0x0000, 0x1e75, 0x0000, 0x1e78, 0x0000, 0x1e7b, 0x0000, 0x1e7e,
+    0x0000, 0x1e81, 0x0000, 0x1e84, 0x0000, 0x1e87, 0x0000, 0x1e8a,
+    0x0000, 0x1e8d, 0x0000, 0x1e90, 0x0000, 0x1e93, 0x0000, 0x1e96,
+    /* 0xfc30 .. 0xfc3f */
+    0x0000, 0x1e99, 0x0000, 0x1e9c, 0x0000, 0x1e9f, 0x0000, 0x1ea2,
+    0x0000, 0x1ea5, 0x0000, 0x1ea8, 0x0000, 0x1eab, 0x0000, 0x1eae,
+    0x0000, 0x1eb1, 0x0000, 0x1eb4, 0x0000, 0x1eb7, 0x0000, 0x1eba,
+    0x0000, 0x1ebd, 0x0000, 0x1ec0, 0x0000, 0x1ec3, 0x0000, 0x1ec6,
+    /* 0xfc40 .. 0xfc4f */
+    0x0000, 0x1ec9, 0x0000, 0x1ecc, 0x0000, 0x1ecf, 0x0000, 0x1ed2,
+    0x0000, 0x1ed5, 0x0000, 0x1ed8, 0x0000, 0x1edb, 0x0000, 0x1ede,
+    0x0000, 0x1ee1, 0x0000, 0x1ee4, 0x0000, 0x1ee7, 0x0000, 0x1eea,
+    0x0000, 0x1eed, 0x0000, 0x1ef0, 0x0000, 0x1ef3, 0x0000, 0x1ef6,
+    /* 0xfc50 .. 0xfc5f */
+    0x0000, 0x1ef9, 0x0000, 0x1efc, 0x0000, 0x1eff, 0x0000, 0x1f02,
+    0x0000, 0x1f05, 0x0000, 0x1f08, 0x0000, 0x1f0b, 0x0000, 0x1f0e,
+    0x0000, 0x1f11, 0x0000, 0x1f14, 0x0000, 0x1f17, 0x0000, 0x1f1a,
+    0x0000, 0x1f1d, 0x0000, 0x1f20, 0x0000, 0x1f23, 0x0000, 0x1f27,
+    /* 0xfc60 .. 0xfc6f */
+    0x0000, 0x1f2b, 0x0000, 0x1f2f, 0x0000, 0x1f33, 0x0000, 0x1f37,
+    0x0000, 0x1f3b, 0x0000, 0x1f3f, 0x0000, 0x1e10, 0x0000, 0x1f43,
+    0x0000, 0x1e02, 0x0000, 0x1e14, 0x0000, 0x1f47, 0x0000, 0x1f4a,
+    0x0000, 0x1e21, 0x0000, 0x1f4d, 0x0000, 0x1e24, 0x0000, 0x1e27,
+    /* 0xfc70 .. 0xfc7f */
+    0x0000, 0x1f50, 0x0000, 0x1f53, 0x0000, 0x1e33, 0x0000, 0x1f56,
+    0x0000, 0x1e36, 0x0000, 0x1e39, 0x0000, 0x1f59, 0x0000, 0x1f5c,
+    0x0000, 0x1e3f, 0x0000, 0x1f5f, 0x0000, 0x1e42, 0x0000, 0x1e45,
+    0x0000, 0x1e9c, 0x0000, 0x1e9f, 0x0000, 0x1ea8, 0x0000, 0x1eab,
+    /* 0xfc80 .. 0xfc8f */
+    0x0000, 0x1eae, 0x0000, 0x1eba, 0x0000, 0x1ebd, 0x0000, 0x1ec0,
+    0x0000, 0x1ec3, 0x0000, 0x1ecf, 0x0000, 0x1ed2, 0x0000, 0x1ed5,
+    0x0000, 0x1f62, 0x0000, 0x1ee1, 0x0000, 0x1f65, 0x0000, 0x1f68,
+    0x0000, 0x1ef3, 0x0000, 0x1f6b, 0x0000, 0x1ef6, 0x0000, 0x1ef9,
+    /* 0xfc90 .. 0xfc9f */
+    0x0000, 0x1f20, 0x0000, 0x1f6e, 0x0000, 0x1f71, 0x0000, 0x1f11,
+    0x0000, 0x1f74, 0x0000, 0x1f14, 0x0000, 0x1f17, 0x0000, 0x1e08,
+    0x0000, 0x1e0c, 0x0000, 0x1f77, 0x0000, 0x1e10, 0x0000, 0x1f7b,
+    0x0000, 0x1e18, 0x0000, 0x1e1b, 0x0000, 0x1e1e, 0x0000, 0x1e21,
+    /* 0xfca0 .. 0xfcaf */
+    0x0000, 0x1f7f, 0x0000, 0x1e2a, 0x0000, 0x1e2d, 0x0000, 0x1e30,
+    0x0000, 0x1e33, 0x0000, 0x1f82, 0x0000, 0x1e3f, 0x0000, 0x1e48,
+    0x0000, 0x1e4b, 0x0000, 0x1e4e, 0x0000, 0x1e51, 0x0000, 0x1e54,
+    0x0000, 0x1e5a, 0x0000, 0x1e5d, 0x0000, 0x1e60, 0x0000, 0x1e63,
+    /* 0xfcb0 .. 0xfcbf */
+    0x0000, 0x1e66, 0x0000, 0x1e69, 0x0000, 0x1f85, 0x0000, 0x1e6c,
+    0x0000, 0x1e6f, 0x0000, 0x1e72, 0x0000, 0x1e75, 0x0000, 0x1e78,
+    0x0000, 0x1e7b, 0x0000, 0x1e81, 0x0000, 0x1e84, 0x0000, 0x1e87,
+    0x0000, 0x1e8a, 0x0000, 0x1e8d, 0x0000, 0x1e90, 0x0000, 0x1e93,
+    /* 0xfcc0 .. 0xfccf */
+    0x0000, 0x1e96, 0x0000, 0x1e99, 0x0000, 0x1ea2, 0x0000, 0x1ea5,
+    0x0000, 0x1eb1, 0x0000, 0x1eb4, 0x0000, 0x1eb7, 0x0000, 0x1eba,
+    0x0000, 0x1ebd, 0x0000, 0x1ec6, 0x0000, 0x1ec9, 0x0000, 0x1ecc,
+    0x0000, 0x1ecf, 0x0000, 0x1f88, 0x0000, 0x1ed8, 0x0000, 0x1edb,
+    /* 0xfcd0 .. 0xfcdf */
+    0x0000, 0x1ede, 0x0000, 0x1ee1, 0x0000, 0x1eea, 0x0000, 0x1eed,
+    0x0000, 0x1ef0, 0x0000, 0x1ef3, 0x0000, 0x1f8b, 0x0000, 0x1efc,
+    0x0000, 0x1eff, 0x0000, 0x1f8e, 0x0000, 0x1f08, 0x0000, 0x1f0b,
+    0x0000, 0x1f0e, 0x0000, 0x1f11, 0x0000, 0x1f91, 0x0000, 0x1e10,
+    /* 0xfce0 .. 0xfcef */
+    0x0000, 0x1f7b, 0x0000, 0x1e21, 0x0000, 0x1f7f, 0x0000, 0x1e33,
+    0x0000, 0x1f82, 0x0000, 0x1e3f, 0x0000, 0x1f94, 0x0000, 0x1e66,
+    0x0000, 0x1f97, 0x0000, 0x1f9a, 0x0000, 0x1f9d, 0x0000, 0x1eba,
+    0x0000, 0x1ebd, 0x0000, 0x1ecf, 0x0000, 0x1ef3, 0x0000, 0x1f8b,
+    /* 0xfcf0 .. 0xfcff */
+    0x0000, 0x1f11, 0x0000, 0x1f91, 0x0000, 0x1fa0, 0x0000, 0x1fa4,
+    0x0000, 0x1fa8, 0x0000, 0x1fac, 0x0000, 0x1faf, 0x0000, 0x1fb2,
+    0x0000, 0x1fb5, 0x0000, 0x1fb8, 0x0000, 0x1fbb, 0x0000, 0x1fbe,
+    0x0000, 0x1fc1, 0x0000, 0x1fc4, 0x0000, 0x1fc7, 0x0000, 0x1fca,
+    /* 0xfd00 .. 0xfd0f */
+    0x0000, 0x1fcd, 0x0000, 0x1fd0, 0x0000, 0x1fd3, 0x0000, 0x1fd6,
+    0x0000, 0x1fd9, 0x0000, 0x1fdc, 0x0000, 0x1fdf, 0x0000, 0x1fe2,
+    0x0000, 0x1fe5, 0x0000, 0x1fe8, 0x0000, 0x1feb, 0x0000, 0x1fee,
+    0x0000, 0x1f9a, 0x0000, 0x1ff1, 0x0000, 0x1ff4, 0x0000, 0x1ff7,
+    /* 0xfd10 .. 0xfd1f */
+    0x0000, 0x1ffa, 0x0000, 0x1fac, 0x0000, 0x1faf, 0x0000, 0x1fb2,
+    0x0000, 0x1fb5, 0x0000, 0x1fb8, 0x0000, 0x1fbb, 0x0000, 0x1fbe,
+    0x0000, 0x1fc1, 0x0000, 0x1fc4, 0x0000, 0x1fc7, 0x0000, 0x1fca,
+    0x0000, 0x1fcd, 0x0000, 0x1fd0, 0x0000, 0x1fd3, 0x0000, 0x1fd6,
+    /* 0xfd20 .. 0xfd2f */
+    0x0000, 0x1fd9, 0x0000, 0x1fdc, 0x0000, 0x1fdf, 0x0000, 0x1fe2,
+    0x0000, 0x1fe5, 0x0000, 0x1fe8, 0x0000, 0x1feb, 0x0000, 0x1fee,
+    0x0000, 0x1f9a, 0x0000, 0x1ff1, 0x0000, 0x1ff4, 0x0000, 0x1ff7,
+    0x0000, 0x1ffa, 0x0000, 0x1fe8, 0x0000, 0x1feb, 0x0000, 0x1fee,
+    /* 0xfd30 .. 0xfd3f */
+    0x0000, 0x1f9a, 0x0000, 0x1f97, 0x0000, 0x1f9d, 0x0000, 0x1e7e,
+    0x0000, 0x1e5d, 0x0000, 0x1e60, 0x0000, 0x1e63, 0x0000, 0x1fe8,
+    0x0000, 0x1feb, 0x0000, 0x1fee, 0x0000, 0x1e7e, 0x0000, 0x1e81,
+    0x0000, 0x1ffd, 0x0000, 0x1ffd, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0xfd50 .. 0xfd5f */
+    0x0000, 0x2000, 0x0000, 0x2004, 0x0000, 0x2004, 0x0000, 0x2008,
+    0x0000, 0x200c, 0x0000, 0x2010, 0x0000, 0x2014, 0x0000, 0x2018,
+    0x0000, 0x201c, 0x0000, 0x201c, 0x0000, 0x2020, 0x0000, 0x2024,
+    0x0000, 0x2028, 0x0000, 0x202c, 0x0000, 0x2030, 0x0000, 0x2034,
+    /* 0xfd60 .. 0xfd6f */
+    0x0000, 0x2034, 0x0000, 0x2038, 0x0000, 0x203c, 0x0000, 0x203c,
+    0x0000, 0x2040, 0x0000, 0x2040, 0x0000, 0x2044, 0x0000, 0x2048,
+    0x0000, 0x2048, 0x0000, 0x204c, 0x0000, 0x2050, 0x0000, 0x2050,
+    0x0000, 0x2054, 0x0000, 0x2054, 0x0000, 0x2058, 0x0000, 0x205c,
+    /* 0xfd70 .. 0xfd7f */
+    0x0000, 0x205c, 0x0000, 0x2060, 0x0000, 0x2060, 0x0000, 0x2064,
+    0x0000, 0x2068, 0x0000, 0x206c, 0x0000, 0x2070, 0x0000, 0x2070,
+    0x0000, 0x2074, 0x0000, 0x2078, 0x0000, 0x207c, 0x0000, 0x2080,
+    0x0000, 0x2084, 0x0000, 0x2084, 0x0000, 0x2088, 0x0000, 0x208c,
+    /* 0xfd80 .. 0xfd8f */
+    0x0000, 0x2090, 0x0000, 0x2094, 0x0000, 0x2098, 0x0000, 0x209c,
+    0x0000, 0x209c, 0x0000, 0x20a0, 0x0000, 0x20a0, 0x0000, 0x20a4,
+    0x0000, 0x20a4, 0x0000, 0x20a8, 0x0000, 0x20ac, 0x0000, 0x20b0,
+    0x0000, 0x20b4, 0x0000, 0x20b8, 0x0000, 0x20bc, 0x0000, 0x20c0,
+    /* 0xfd90 .. 0xfd9f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x20c4, 0x0000, 0x20c8,
+    0x0000, 0x20cc, 0x0000, 0x20d0, 0x0000, 0x20d4, 0x0000, 0x20d8,
+    0x0000, 0x20d8, 0x0000, 0x20dc, 0x0000, 0x20e0, 0x0000, 0x20e4,
+    0x0000, 0x20e8, 0x0000, 0x20e8, 0x0000, 0x20ec, 0x0000, 0x20f0,
+    /* 0xfda0 .. 0xfdaf */
+    0x0000, 0x20f4, 0x0000, 0x20f8, 0x0000, 0x20fc, 0x0000, 0x2100,
+    0x0000, 0x2104, 0x0000, 0x2108, 0x0000, 0x210c, 0x0000, 0x2110,
+    0x0000, 0x2114, 0x0000, 0x2118, 0x0000, 0x211c, 0x0000, 0x2120,
+    0x0000, 0x2124, 0x0000, 0x2128, 0x0000, 0x212c, 0x0000, 0x2130,
+    /* 0xfdb0 .. 0xfdbf */
+    0x0000, 0x2134, 0x0000, 0x2138, 0x0000, 0x213c, 0x0000, 0x2140,
+    0x0000, 0x2088, 0x0000, 0x2090, 0x0000, 0x2144, 0x0000, 0x2148,
+    0x0000, 0x214c, 0x0000, 0x2150, 0x0000, 0x2154, 0x0000, 0x2158,
+    0x0000, 0x2154, 0x0000, 0x214c, 0x0000, 0x215c, 0x0000, 0x2160,
+    /* 0xfdc0 .. 0xfdcf */
+    0x0000, 0x2164, 0x0000, 0x2168, 0x0000, 0x216c, 0x0000, 0x2158,
+    0x0000, 0x206c, 0x0000, 0x2044, 0x0000, 0x2170, 0x0000, 0x2174,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0xfdf0 .. 0xfdff */
+    0x0000, 0x2178, 0x0000, 0x217c, 0x0000, 0x2180, 0x0000, 0x2185,
+    0x0000, 0x218a, 0x0000, 0x218f, 0x0000, 0x2194, 0x0000, 0x2199,
+    0x0000, 0x219e, 0x0000, 0x21a3, 0x0000, 0x21a7, 0x0000, 0x21ba,
+    0x0000, 0x21c3, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0xfe10 .. 0xfe1f */
+    0x0000, 0x21c8, 0x0000, 0x21ca, 0x0000, 0x21cc, 0x0000, 0x21ce,
+    0x0000, 0x03a3, 0x0000, 0x21d0, 0x0000, 0x21d2, 0x0000, 0x21d4,
+    0x0000, 0x21d6, 0x0000, 0x0d00, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0xfe30 .. 0xfe3f */
+    0x0000, 0x0cfd, 0x0000, 0x21d8, 0x0000, 0x21da, 0x0000, 0x21dc,
+    0x0000, 0x21dc, 0x0000, 0x0d3a, 0x0000, 0x0d3c, 0x0000, 0x21de,
+    0x0000, 0x21e0, 0x0000, 0x21e2, 0x0000, 0x21e4, 0x0000, 0x21e6,
+    0x0000, 0x21e8, 0x0000, 0x21ea, 0x0000, 0x21ec, 0x0000, 0x0ea0,
+    /* 0xfe40 .. 0xfe4f */
+    0x0000, 0x0ea2, 0x0000, 0x21ee, 0x0000, 0x21f0, 0x0000, 0x21f2,
+    0x0000, 0x21f4, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x21f6,
+    0x0000, 0x21f8, 0x0000, 0x0d15, 0x0000, 0x0d15, 0x0000, 0x0d15,
+    0x0000, 0x0d15, 0x0000, 0x21dc, 0x0000, 0x21dc, 0x0000, 0x21dc,
+    /* 0xfe50 .. 0xfe5f */
+    0x0000, 0x21c8, 0x0000, 0x21ca, 0x0000, 0x0cfb, 0x0000, 0x0000,
+    0x0000, 0x03a3, 0x0000, 0x21ce, 0x0000, 0x21d2, 0x0000, 0x21d0,
+    0x0000, 0x21d8, 0x0000, 0x0d3a, 0x0000, 0x0d3c, 0x0000, 0x21de,
+    0x0000, 0x21e0, 0x0000, 0x21e2, 0x0000, 0x21e4, 0x0000, 0x21fa,
+    /* 0xfe60 .. 0xfe6f */
+    0x0000, 0x21fc, 0x0000, 0x21fe, 0x0000, 0x0d34, 0x0000, 0x2200,
+    0x0000, 0x2202, 0x0000, 0x2204, 0x0000, 0x0d38, 0x0000, 0x0000,
+    0x0000, 0x2206, 0x0000, 0x2208, 0x0000, 0x220a, 0x0000, 0x220c,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0xfe70 .. 0xfe7f */
+    0x0000, 0x220e, 0x0000, 0x2211, 0x0000, 0x2214, 0x0000, 0x0000,
+    0x0000, 0x2217, 0x0000, 0x0000, 0x0000, 0x221a, 0x0000, 0x221d,
+    0x0000, 0x2220, 0x0000, 0x2223, 0x0000, 0x2226, 0x0000, 0x2229,
+    0x0000, 0x222c, 0x0000, 0x222f, 0x0000, 0x2232, 0x0000, 0x2235,
+    /* 0xfe80 .. 0xfe8f */
+    0x0000, 0x2238, 0x0000, 0x04a7, 0x0000, 0x04a7, 0x0000, 0x04aa,
+    0x0000, 0x04aa, 0x0000, 0x04ad, 0x0000, 0x04ad, 0x0000, 0x04b0,
+    0x0000, 0x04b0, 0x0000, 0x04b3, 0x0000, 0x04b3, 0x0000, 0x04b3,
+    0x0000, 0x04b3, 0x0000, 0x223a, 0x0000, 0x223a, 0x0000, 0x223c,
+    /* 0xfe90 .. 0xfe9f */
+    0x0000, 0x223c, 0x0000, 0x223c, 0x0000, 0x223c, 0x0000, 0x223e,
+    0x0000, 0x223e, 0x0000, 0x2240, 0x0000, 0x2240, 0x0000, 0x2240,
+    0x0000, 0x2240, 0x0000, 0x2242, 0x0000, 0x2242, 0x0000, 0x2242,
+    0x0000, 0x2242, 0x0000, 0x2244, 0x0000, 0x2244, 0x0000, 0x2244,
+    /* 0xfea0 .. 0xfeaf */
+    0x0000, 0x2244, 0x0000, 0x2246, 0x0000, 0x2246, 0x0000, 0x2246,
+    0x0000, 0x2246, 0x0000, 0x2248, 0x0000, 0x2248, 0x0000, 0x2248,
+    0x0000, 0x2248, 0x0000, 0x224a, 0x0000, 0x224a, 0x0000, 0x224c,
+    0x0000, 0x224c, 0x0000, 0x224e, 0x0000, 0x224e, 0x0000, 0x2250,
+    /* 0xfeb0 .. 0xfebf */
+    0x0000, 0x2250, 0x0000, 0x2252, 0x0000, 0x2252, 0x0000, 0x2252,
+    0x0000, 0x2252, 0x0000, 0x2254, 0x0000, 0x2254, 0x0000, 0x2254,
+    0x0000, 0x2254, 0x0000, 0x2256, 0x0000, 0x2256, 0x0000, 0x2256,
+    0x0000, 0x2256, 0x0000, 0x2258, 0x0000, 0x2258, 0x0000, 0x2258,
+    /* 0xfec0 .. 0xfecf */
+    0x0000, 0x2258, 0x0000, 0x225a, 0x0000, 0x225a, 0x0000, 0x225a,
+    0x0000, 0x225a, 0x0000, 0x225c, 0x0000, 0x225c, 0x0000, 0x225c,
+    0x0000, 0x225c, 0x0000, 0x225e, 0x0000, 0x225e, 0x0000, 0x225e,
+    0x0000, 0x225e, 0x0000, 0x2260, 0x0000, 0x2260, 0x0000, 0x2260,
+    /* 0xfed0 .. 0xfedf */
+    0x0000, 0x2260, 0x0000, 0x2262, 0x0000, 0x2262, 0x0000, 0x2262,
+    0x0000, 0x2262, 0x0000, 0x2264, 0x0000, 0x2264, 0x0000, 0x2264,
+    0x0000, 0x2264, 0x0000, 0x2266, 0x0000, 0x2266, 0x0000, 0x2266,
+    0x0000, 0x2266, 0x0000, 0x2268, 0x0000, 0x2268, 0x0000, 0x2268,
+    /* 0xfee0 .. 0xfeef */
+    0x0000, 0x2268, 0x0000, 0x226a, 0x0000, 0x226a, 0x0000, 0x226a,
+    0x0000, 0x226a, 0x0000, 0x226c, 0x0000, 0x226c, 0x0000, 0x226c,
+    0x0000, 0x226c, 0x0000, 0x226e, 0x0000, 0x226e, 0x0000, 0x226e,
+    0x0000, 0x226e, 0x0000, 0x2270, 0x0000, 0x2270, 0x0000, 0x1de4,
+    /* 0xfef0 .. 0xfeff */
+    0x0000, 0x1de4, 0x0000, 0x2272, 0x0000, 0x2272, 0x0000, 0x2272,
+    0x0000, 0x2272, 0x0000, 0x2274, 0x0000, 0x2274, 0x0000, 0x2278,
+    0x0000, 0x2278, 0x0000, 0x227c, 0x0000, 0x227c, 0x0000, 0x2280,
+    0x0000, 0x2280, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0xff00 .. 0xff0f */
+    0x0000, 0x0000, 0x0000, 0x21d0, 0x0000, 0x2283, 0x0000, 0x21fa,
+    0x0000, 0x2208, 0x0000, 0x220a, 0x0000, 0x21fc, 0x0000, 0x2285,
+    0x0000, 0x0d3a, 0x0000, 0x0d3c, 0x0000, 0x21fe, 0x0000, 0x0d34,
+    0x0000, 0x21c8, 0x0000, 0x2200, 0x0000, 0x0cfb, 0x0000, 0x2287,
+    /* 0xff10 .. 0xff1f */
+    0x0000, 0x0d26, 0x0000, 0x0017, 0x0000, 0x000b, 0x0000, 0x000d,
+    0x0000, 0x0d28, 0x0000, 0x0d2a, 0x0000, 0x0d2c, 0x0000, 0x0d2e,
+    0x0000, 0x0d30, 0x0000, 0x0d32, 0x0000, 0x21ce, 0x0000, 0x03a3,
+    0x0000, 0x2202, 0x0000, 0x0d38, 0x0000, 0x2204, 0x0000, 0x21d2,
+    /* 0xff20 .. 0xff2f */
+    0x0000, 0x220c, 0x0000, 0x05c0, 0x0000, 0x05c4, 0x0000, 0x0d4b,
+    0x0000, 0x05c6, 0x0000, 0x05c8, 0x0000, 0x0d72, 0x0000, 0x05cc,
+    0x0000, 0x05ce, 0x0000, 0x05d0, 0x0000, 0x05d2, 0x0000, 0x05d4,
+    0x0000, 0x05d6, 0x0000, 0x05d8, 0x0000, 0x05da, 0x0000, 0x05dc,
+    /* 0xff30 .. 0xff3f */
+    0x0000, 0x05e0, 0x0000, 0x0d62, 0x0000, 0x05e2, 0x0000, 0x0fcf,
+    0x0000, 0x05e4, 0x0000, 0x05e6, 0x0000, 0x0dd0, 0x0000, 0x05e8,
+    0x0000, 0x0de1, 0x0000, 0x0fd1, 0x0000, 0x0d6e, 0x0000, 0x21f6,
+    0x0000, 0x2206, 0x0000, 0x21f8, 0x0000, 0x2289, 0x0000, 0x21dc,
+    /* 0xff40 .. 0xff4f */
+    0x0000, 0x0cd0, 0x0000, 0x0006, 0x0000, 0x05f0, 0x0000, 0x0624,
+    0x0000, 0x05f2, 0x0000, 0x05f4, 0x0000, 0x062a, 0x0000, 0x05fc,
+    0x0000, 0x0369, 0x0000, 0x061e, 0x0000, 0x036d, 0x0000, 0x05fe,
+    0x0000, 0x038f, 0x0000, 0x0600, 0x0000, 0x0d3e, 0x0000, 0x0019,
+    /* 0xff50 .. 0xff5f */
+    0x0000, 0x060a, 0x0000, 0x0fd3, 0x0000, 0x036f, 0x0000, 0x0219,
+    0x0000, 0x060c, 0x0000, 0x060e, 0x0000, 0x0614, 0x0000, 0x0377,
+    0x0000, 0x0391, 0x0000, 0x0379, 0x0000, 0x0660, 0x0000, 0x21de,
+    0x0000, 0x228b, 0x0000, 0x21e0, 0x0000, 0x228d, 0x0000, 0x228f,
+    /* 0xff60 .. 0xff6f */
+    0x0000, 0x2291, 0x0000, 0x21cc, 0x0000, 0x21ee, 0x0000, 0x21f0,
+    0x0000, 0x21ca, 0x0000, 0x2293, 0x0000, 0x15b9, 0x0000, 0x2295,
+    0x0000, 0x2297, 0x0000, 0x2299, 0x0000, 0x229b, 0x0000, 0x229d,
+    0x0000, 0x229f, 0x0000, 0x22a1, 0x0000, 0x22a3, 0x0000, 0x22a5,
+    /* 0xff70 .. 0xff7f */
+    0x0000, 0x22a7, 0x0000, 0x155d, 0x0000, 0x155f, 0x0000, 0x1561,
+    0x0000, 0x1563, 0x0000, 0x1565, 0x0000, 0x1567, 0x0000, 0x1569,
+    0x0000, 0x156b, 0x0000, 0x156d, 0x0000, 0x156f, 0x0000, 0x1571,
+    0x0000, 0x1573, 0x0000, 0x1575, 0x0000, 0x1577, 0x0000, 0x1579,
+    /* 0xff80 .. 0xff8f */
+    0x0000, 0x157b, 0x0000, 0x157d, 0x0000, 0x157f, 0x0000, 0x1581,
+    0x0000, 0x1583, 0x0000, 0x1585, 0x0000, 0x1587, 0x0000, 0x1589,
+    0x0000, 0x158b, 0x0000, 0x158d, 0x0000, 0x158f, 0x0000, 0x1591,
+    0x0000, 0x1593, 0x0000, 0x1595, 0x0000, 0x1597, 0x0000, 0x1599,
+    /* 0xff90 .. 0xff9f */
+    0x0000, 0x159b, 0x0000, 0x159d, 0x0000, 0x159f, 0x0000, 0x15a1,
+    0x0000, 0x15a3, 0x0000, 0x15a5, 0x0000, 0x15a7, 0x0000, 0x15a9,
+    0x0000, 0x15ab, 0x0000, 0x15ad, 0x0000, 0x15af, 0x0000, 0x15b1,
+    0x0000, 0x15b3, 0x0000, 0x22a9, 0x0000, 0x22ab, 0x0000, 0x22ad,
+    /* 0xffa0 .. 0xffaf */
+    0x0000, 0x12c0, 0x0000, 0x125a, 0x0000, 0x125c, 0x0000, 0x125e,
+    0x0000, 0x1260, 0x0000, 0x1262, 0x0000, 0x1264, 0x0000, 0x1266,
+    0x0000, 0x1268, 0x0000, 0x126a, 0x0000, 0x126c, 0x0000, 0x126e,
+    0x0000, 0x1270, 0x0000, 0x1272, 0x0000, 0x1274, 0x0000, 0x1276,
+    /* 0xffb0 .. 0xffbf */
+    0x0000, 0x1278, 0x0000, 0x127a, 0x0000, 0x127c, 0x0000, 0x127e,
+    0x0000, 0x1280, 0x0000, 0x1282, 0x0000, 0x1284, 0x0000, 0x1286,
+    0x0000, 0x1288, 0x0000, 0x128a, 0x0000, 0x128c, 0x0000, 0x128e,
+    0x0000, 0x1290, 0x0000, 0x1292, 0x0000, 0x1294, 0x0000, 0x0000,
+    /* 0xffc0 .. 0xffcf */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x1296, 0x0000, 0x1298,
+    0x0000, 0x129a, 0x0000, 0x129c, 0x0000, 0x129e, 0x0000, 0x12a0,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x12a2, 0x0000, 0x12a4,
+    0x0000, 0x12a6, 0x0000, 0x12a8, 0x0000, 0x12aa, 0x0000, 0x12ac,
+    /* 0xffd0 .. 0xffdf */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x12ae, 0x0000, 0x12b0,
+    0x0000, 0x12b2, 0x0000, 0x12b4, 0x0000, 0x12b6, 0x0000, 0x12b8,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x12ba, 0x0000, 0x12bc,
+    0x0000, 0x12be, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0xffe0 .. 0xffef */
+    0x0000, 0x22af, 0x0000, 0x22b1, 0x0000, 0x22b3, 0x0000, 0x0008,
+    0x0000, 0x22b5, 0x0000, 0x22b7, 0x0000, 0x22b9, 0x0000, 0x0000,
+    0x0000, 0x22bb, 0x0000, 0x22bd, 0x0000, 0x22bf, 0x0000, 0x22c1,
+    0x0000, 0x22c3, 0x0000, 0x22c5, 0x0000, 0x22c7, 0x0000, 0x0000,
+    /* 0x11090 .. 0x1109f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x22c9, 0x22c9, 0x0000, 0x0000,
+    0x22ce, 0x22ce, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x110a0 .. 0x110af */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x22d3, 0x22d3,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x11120 .. 0x1112f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x22d8, 0x22d8, 0x22dd, 0x22dd,
+    /* 0x11340 .. 0x1134f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x22e2, 0x22e2,
+    0x22e7, 0x22e7, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x114b0 .. 0x114bf */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x22ec, 0x22ec,
+    0x22f1, 0x22f1, 0x0000, 0x0000, 0x22f6, 0x22f6, 0x0000, 0x0000,
+    /* 0x115b0 .. 0x115bf */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x22fb, 0x22fb, 0x2300, 0x2300,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x1d150 .. 0x1d15f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x2305, 0x2305, 0x230a, 0x230a,
+    /* 0x1d160 .. 0x1d16f */
+    0x230f, 0x230f, 0x2316, 0x2316, 0x231d, 0x231d, 0x2324, 0x2324,
+    0x232b, 0x232b, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x1d1b0 .. 0x1d1bf */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x2332, 0x2332,
+    0x2337, 0x2337, 0x233c, 0x233c, 0x2343, 0x2343, 0x234a, 0x234a,
+    /* 0x1d1c0 .. 0x1d1cf */
+    0x2351, 0x2351, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x1d400 .. 0x1d40f */
+    0x0000, 0x05c0, 0x0000, 0x05c4, 0x0000, 0x0d4b, 0x0000, 0x05c6,
+    0x0000, 0x05c8, 0x0000, 0x0d72, 0x0000, 0x05cc, 0x0000, 0x05ce,
+    0x0000, 0x05d0, 0x0000, 0x05d2, 0x0000, 0x05d4, 0x0000, 0x05d6,
+    0x0000, 0x05d8, 0x0000, 0x05da, 0x0000, 0x05dc, 0x0000, 0x05e0,
+    /* 0x1d410 .. 0x1d41f */
+    0x0000, 0x0d62, 0x0000, 0x05e2, 0x0000, 0x0fcf, 0x0000, 0x05e4,
+    0x0000, 0x05e6, 0x0000, 0x0dd0, 0x0000, 0x05e8, 0x0000, 0x0de1,
+    0x0000, 0x0fd1, 0x0000, 0x0d6e, 0x0000, 0x0006, 0x0000, 0x05f0,
+    0x0000, 0x0624, 0x0000, 0x05f2, 0x0000, 0x05f4, 0x0000, 0x062a,
+    /* 0x1d420 .. 0x1d42f */
+    0x0000, 0x05fc, 0x0000, 0x0369, 0x0000, 0x061e, 0x0000, 0x036d,
+    0x0000, 0x05fe, 0x0000, 0x038f, 0x0000, 0x0600, 0x0000, 0x0d3e,
+    0x0000, 0x0019, 0x0000, 0x060a, 0x0000, 0x0fd3, 0x0000, 0x036f,
+    0x0000, 0x0219, 0x0000, 0x060c, 0x0000, 0x060e, 0x0000, 0x0614,
+    /* 0x1d430 .. 0x1d43f */
+    0x0000, 0x0377, 0x0000, 0x0391, 0x0000, 0x0379, 0x0000, 0x0660,
+    0x0000, 0x05c0, 0x0000, 0x05c4, 0x0000, 0x0d4b, 0x0000, 0x05c6,
+    0x0000, 0x05c8, 0x0000, 0x0d72, 0x0000, 0x05cc, 0x0000, 0x05ce,
+    0x0000, 0x05d0, 0x0000, 0x05d2, 0x0000, 0x05d4, 0x0000, 0x05d6,
+    /* 0x1d440 .. 0x1d44f */
+    0x0000, 0x05d8, 0x0000, 0x05da, 0x0000, 0x05dc, 0x0000, 0x05e0,
+    0x0000, 0x0d62, 0x0000, 0x05e2, 0x0000, 0x0fcf, 0x0000, 0x05e4,
+    0x0000, 0x05e6, 0x0000, 0x0dd0, 0x0000, 0x05e8, 0x0000, 0x0de1,
+    0x0000, 0x0fd1, 0x0000, 0x0d6e, 0x0000, 0x0006, 0x0000, 0x05f0,
+    /* 0x1d450 .. 0x1d45f */
+    0x0000, 0x0624, 0x0000, 0x05f2, 0x0000, 0x05f4, 0x0000, 0x062a,
+    0x0000, 0x05fc, 0x0000, 0x0000, 0x0000, 0x061e, 0x0000, 0x036d,
+    0x0000, 0x05fe, 0x0000, 0x038f, 0x0000, 0x0600, 0x0000, 0x0d3e,
+    0x0000, 0x0019, 0x0000, 0x060a, 0x0000, 0x0fd3, 0x0000, 0x036f,
+    /* 0x1d460 .. 0x1d46f */
+    0x0000, 0x0219, 0x0000, 0x060c, 0x0000, 0x060e, 0x0000, 0x0614,
+    0x0000, 0x0377, 0x0000, 0x0391, 0x0000, 0x0379, 0x0000, 0x0660,
+    0x0000, 0x05c0, 0x0000, 0x05c4, 0x0000, 0x0d4b, 0x0000, 0x05c6,
+    0x0000, 0x05c8, 0x0000, 0x0d72, 0x0000, 0x05cc, 0x0000, 0x05ce,
+    /* 0x1d470 .. 0x1d47f */
+    0x0000, 0x05d0, 0x0000, 0x05d2, 0x0000, 0x05d4, 0x0000, 0x05d6,
+    0x0000, 0x05d8, 0x0000, 0x05da, 0x0000, 0x05dc, 0x0000, 0x05e0,
+    0x0000, 0x0d62, 0x0000, 0x05e2, 0x0000, 0x0fcf, 0x0000, 0x05e4,
+    0x0000, 0x05e6, 0x0000, 0x0dd0, 0x0000, 0x05e8, 0x0000, 0x0de1,
+    /* 0x1d480 .. 0x1d48f */
+    0x0000, 0x0fd1, 0x0000, 0x0d6e, 0x0000, 0x0006, 0x0000, 0x05f0,
+    0x0000, 0x0624, 0x0000, 0x05f2, 0x0000, 0x05f4, 0x0000, 0x062a,
+    0x0000, 0x05fc, 0x0000, 0x0369, 0x0000, 0x061e, 0x0000, 0x036d,
+    0x0000, 0x05fe, 0x0000, 0x038f, 0x0000, 0x0600, 0x0000, 0x0d3e,
+    /* 0x1d490 .. 0x1d49f */
+    0x0000, 0x0019, 0x0000, 0x060a, 0x0000, 0x0fd3, 0x0000, 0x036f,
+    0x0000, 0x0219, 0x0000, 0x060c, 0x0000, 0x060e, 0x0000, 0x0614,
+    0x0000, 0x0377, 0x0000, 0x0391, 0x0000, 0x0379, 0x0000, 0x0660,
+    0x0000, 0x05c0, 0x0000, 0x0000, 0x0000, 0x0d4b, 0x0000, 0x05c6,
+    /* 0x1d4a0 .. 0x1d4af */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x05cc, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x05d2, 0x0000, 0x05d4, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x05da, 0x0000, 0x05dc, 0x0000, 0x05e0,
+    0x0000, 0x0d62, 0x0000, 0x0000, 0x0000, 0x0fcf, 0x0000, 0x05e4,
+    /* 0x1d4b0 .. 0x1d4bf */
+    0x0000, 0x05e6, 0x0000, 0x0dd0, 0x0000, 0x05e8, 0x0000, 0x0de1,
+    0x0000, 0x0fd1, 0x0000, 0x0d6e, 0x0000, 0x0006, 0x0000, 0x05f0,
+    0x0000, 0x0624, 0x0000, 0x05f2, 0x0000, 0x0000, 0x0000, 0x062a,
+    0x0000, 0x0000, 0x0000, 0x0369, 0x0000, 0x061e, 0x0000, 0x036d,
+    /* 0x1d4c0 .. 0x1d4cf */
+    0x0000, 0x05fe, 0x0000, 0x038f, 0x0000, 0x0600, 0x0000, 0x0d3e,
+    0x0000, 0x0000, 0x0000, 0x060a, 0x0000, 0x0fd3, 0x0000, 0x036f,
+    0x0000, 0x0219, 0x0000, 0x060c, 0x0000, 0x060e, 0x0000, 0x0614,
+    0x0000, 0x0377, 0x0000, 0x0391, 0x0000, 0x0379, 0x0000, 0x0660,
+    /* 0x1d4d0 .. 0x1d4df */
+    0x0000, 0x05c0, 0x0000, 0x05c4, 0x0000, 0x0d4b, 0x0000, 0x05c6,
+    0x0000, 0x05c8, 0x0000, 0x0d72, 0x0000, 0x05cc, 0x0000, 0x05ce,
+    0x0000, 0x05d0, 0x0000, 0x05d2, 0x0000, 0x05d4, 0x0000, 0x05d6,
+    0x0000, 0x05d8, 0x0000, 0x05da, 0x0000, 0x05dc, 0x0000, 0x05e0,
+    /* 0x1d4e0 .. 0x1d4ef */
+    0x0000, 0x0d62, 0x0000, 0x05e2, 0x0000, 0x0fcf, 0x0000, 0x05e4,
+    0x0000, 0x05e6, 0x0000, 0x0dd0, 0x0000, 0x05e8, 0x0000, 0x0de1,
+    0x0000, 0x0fd1, 0x0000, 0x0d6e, 0x0000, 0x0006, 0x0000, 0x05f0,
+    0x0000, 0x0624, 0x0000, 0x05f2, 0x0000, 0x05f4, 0x0000, 0x062a,
+    /* 0x1d4f0 .. 0x1d4ff */
+    0x0000, 0x05fc, 0x0000, 0x0369, 0x0000, 0x061e, 0x0000, 0x036d,
+    0x0000, 0x05fe, 0x0000, 0x038f, 0x0000, 0x0600, 0x0000, 0x0d3e,
+    0x0000, 0x0019, 0x0000, 0x060a, 0x0000, 0x0fd3, 0x0000, 0x036f,
+    0x0000, 0x0219, 0x0000, 0x060c, 0x0000, 0x060e, 0x0000, 0x0614,
+    /* 0x1d500 .. 0x1d50f */
+    0x0000, 0x0377, 0x0000, 0x0391, 0x0000, 0x0379, 0x0000, 0x0660,
+    0x0000, 0x05c0, 0x0000, 0x05c4, 0x0000, 0x0000, 0x0000, 0x05c6,
+    0x0000, 0x05c8, 0x0000, 0x0d72, 0x0000, 0x05cc, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x05d2, 0x0000, 0x05d4, 0x0000, 0x05d6,
+    /* 0x1d510 .. 0x1d51f */
+    0x0000, 0x05d8, 0x0000, 0x05da, 0x0000, 0x05dc, 0x0000, 0x05e0,
+    0x0000, 0x0d62, 0x0000, 0x0000, 0x0000, 0x0fcf, 0x0000, 0x05e4,
+    0x0000, 0x05e6, 0x0000, 0x0dd0, 0x0000, 0x05e8, 0x0000, 0x0de1,
+    0x0000, 0x0fd1, 0x0000, 0x0000, 0x0000, 0x0006, 0x0000, 0x05f0,
+    /* 0x1d520 .. 0x1d52f */
+    0x0000, 0x0624, 0x0000, 0x05f2, 0x0000, 0x05f4, 0x0000, 0x062a,
+    0x0000, 0x05fc, 0x0000, 0x0369, 0x0000, 0x061e, 0x0000, 0x036d,
+    0x0000, 0x05fe, 0x0000, 0x038f, 0x0000, 0x0600, 0x0000, 0x0d3e,
+    0x0000, 0x0019, 0x0000, 0x060a, 0x0000, 0x0fd3, 0x0000, 0x036f,
+    /* 0x1d530 .. 0x1d53f */
+    0x0000, 0x0219, 0x0000, 0x060c, 0x0000, 0x060e, 0x0000, 0x0614,
+    0x0000, 0x0377, 0x0000, 0x0391, 0x0000, 0x0379, 0x0000, 0x0660,
+    0x0000, 0x05c0, 0x0000, 0x05c4, 0x0000, 0x0000, 0x0000, 0x05c6,
+    0x0000, 0x05c8, 0x0000, 0x0d72, 0x0000, 0x05cc, 0x0000, 0x0000,
+    /* 0x1d540 .. 0x1d54f */
+    0x0000, 0x05d0, 0x0000, 0x05d2, 0x0000, 0x05d4, 0x0000, 0x05d6,
+    0x0000, 0x05d8, 0x0000, 0x0000, 0x0000, 0x05dc, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0fcf, 0x0000, 0x05e4,
+    0x0000, 0x05e6, 0x0000, 0x0dd0, 0x0000, 0x05e8, 0x0000, 0x0de1,
+    /* 0x1d550 .. 0x1d55f */
+    0x0000, 0x0fd1, 0x0000, 0x0000, 0x0000, 0x0006, 0x0000, 0x05f0,
+    0x0000, 0x0624, 0x0000, 0x05f2, 0x0000, 0x05f4, 0x0000, 0x062a,
+    0x0000, 0x05fc, 0x0000, 0x0369, 0x0000, 0x061e, 0x0000, 0x036d,
+    0x0000, 0x05fe, 0x0000, 0x038f, 0x0000, 0x0600, 0x0000, 0x0d3e,
+    /* 0x1d560 .. 0x1d56f */
+    0x0000, 0x0019, 0x0000, 0x060a, 0x0000, 0x0fd3, 0x0000, 0x036f,
+    0x0000, 0x0219, 0x0000, 0x060c, 0x0000, 0x060e, 0x0000, 0x0614,
+    0x0000, 0x0377, 0x0000, 0x0391, 0x0000, 0x0379, 0x0000, 0x0660,
+    0x0000, 0x05c0, 0x0000, 0x05c4, 0x0000, 0x0d4b, 0x0000, 0x05c6,
+    /* 0x1d570 .. 0x1d57f */
+    0x0000, 0x05c8, 0x0000, 0x0d72, 0x0000, 0x05cc, 0x0000, 0x05ce,
+    0x0000, 0x05d0, 0x0000, 0x05d2, 0x0000, 0x05d4, 0x0000, 0x05d6,
+    0x0000, 0x05d8, 0x0000, 0x05da, 0x0000, 0x05dc, 0x0000, 0x05e0,
+    0x0000, 0x0d62, 0x0000, 0x05e2, 0x0000, 0x0fcf, 0x0000, 0x05e4,
+    /* 0x1d580 .. 0x1d58f */
+    0x0000, 0x05e6, 0x0000, 0x0dd0, 0x0000, 0x05e8, 0x0000, 0x0de1,
+    0x0000, 0x0fd1, 0x0000, 0x0d6e, 0x0000, 0x0006, 0x0000, 0x05f0,
+    0x0000, 0x0624, 0x0000, 0x05f2, 0x0000, 0x05f4, 0x0000, 0x062a,
+    0x0000, 0x05fc, 0x0000, 0x0369, 0x0000, 0x061e, 0x0000, 0x036d,
+    /* 0x1d590 .. 0x1d59f */
+    0x0000, 0x05fe, 0x0000, 0x038f, 0x0000, 0x0600, 0x0000, 0x0d3e,
+    0x0000, 0x0019, 0x0000, 0x060a, 0x0000, 0x0fd3, 0x0000, 0x036f,
+    0x0000, 0x0219, 0x0000, 0x060c, 0x0000, 0x060e, 0x0000, 0x0614,
+    0x0000, 0x0377, 0x0000, 0x0391, 0x0000, 0x0379, 0x0000, 0x0660,
+    /* 0x1d5a0 .. 0x1d5af */
+    0x0000, 0x05c0, 0x0000, 0x05c4, 0x0000, 0x0d4b, 0x0000, 0x05c6,
+    0x0000, 0x05c8, 0x0000, 0x0d72, 0x0000, 0x05cc, 0x0000, 0x05ce,
+    0x0000, 0x05d0, 0x0000, 0x05d2, 0x0000, 0x05d4, 0x0000, 0x05d6,
+    0x0000, 0x05d8, 0x0000, 0x05da, 0x0000, 0x05dc, 0x0000, 0x05e0,
+    /* 0x1d5b0 .. 0x1d5bf */
+    0x0000, 0x0d62, 0x0000, 0x05e2, 0x0000, 0x0fcf, 0x0000, 0x05e4,
+    0x0000, 0x05e6, 0x0000, 0x0dd0, 0x0000, 0x05e8, 0x0000, 0x0de1,
+    0x0000, 0x0fd1, 0x0000, 0x0d6e, 0x0000, 0x0006, 0x0000, 0x05f0,
+    0x0000, 0x0624, 0x0000, 0x05f2, 0x0000, 0x05f4, 0x0000, 0x062a,
+    /* 0x1d5c0 .. 0x1d5cf */
+    0x0000, 0x05fc, 0x0000, 0x0369, 0x0000, 0x061e, 0x0000, 0x036d,
+    0x0000, 0x05fe, 0x0000, 0x038f, 0x0000, 0x0600, 0x0000, 0x0d3e,
+    0x0000, 0x0019, 0x0000, 0x060a, 0x0000, 0x0fd3, 0x0000, 0x036f,
+    0x0000, 0x0219, 0x0000, 0x060c, 0x0000, 0x060e, 0x0000, 0x0614,
+    /* 0x1d5d0 .. 0x1d5df */
+    0x0000, 0x0377, 0x0000, 0x0391, 0x0000, 0x0379, 0x0000, 0x0660,
+    0x0000, 0x05c0, 0x0000, 0x05c4, 0x0000, 0x0d4b, 0x0000, 0x05c6,
+    0x0000, 0x05c8, 0x0000, 0x0d72, 0x0000, 0x05cc, 0x0000, 0x05ce,
+    0x0000, 0x05d0, 0x0000, 0x05d2, 0x0000, 0x05d4, 0x0000, 0x05d6,
+    /* 0x1d5e0 .. 0x1d5ef */
+    0x0000, 0x05d8, 0x0000, 0x05da, 0x0000, 0x05dc, 0x0000, 0x05e0,
+    0x0000, 0x0d62, 0x0000, 0x05e2, 0x0000, 0x0fcf, 0x0000, 0x05e4,
+    0x0000, 0x05e6, 0x0000, 0x0dd0, 0x0000, 0x05e8, 0x0000, 0x0de1,
+    0x0000, 0x0fd1, 0x0000, 0x0d6e, 0x0000, 0x0006, 0x0000, 0x05f0,
+    /* 0x1d5f0 .. 0x1d5ff */
+    0x0000, 0x0624, 0x0000, 0x05f2, 0x0000, 0x05f4, 0x0000, 0x062a,
+    0x0000, 0x05fc, 0x0000, 0x0369, 0x0000, 0x061e, 0x0000, 0x036d,
+    0x0000, 0x05fe, 0x0000, 0x038f, 0x0000, 0x0600, 0x0000, 0x0d3e,
+    0x0000, 0x0019, 0x0000, 0x060a, 0x0000, 0x0fd3, 0x0000, 0x036f,
+    /* 0x1d600 .. 0x1d60f */
+    0x0000, 0x0219, 0x0000, 0x060c, 0x0000, 0x060e, 0x0000, 0x0614,
+    0x0000, 0x0377, 0x0000, 0x0391, 0x0000, 0x0379, 0x0000, 0x0660,
+    0x0000, 0x05c0, 0x0000, 0x05c4, 0x0000, 0x0d4b, 0x0000, 0x05c6,
+    0x0000, 0x05c8, 0x0000, 0x0d72, 0x0000, 0x05cc, 0x0000, 0x05ce,
+    /* 0x1d610 .. 0x1d61f */
+    0x0000, 0x05d0, 0x0000, 0x05d2, 0x0000, 0x05d4, 0x0000, 0x05d6,
+    0x0000, 0x05d8, 0x0000, 0x05da, 0x0000, 0x05dc, 0x0000, 0x05e0,
+    0x0000, 0x0d62, 0x0000, 0x05e2, 0x0000, 0x0fcf, 0x0000, 0x05e4,
+    0x0000, 0x05e6, 0x0000, 0x0dd0, 0x0000, 0x05e8, 0x0000, 0x0de1,
+    /* 0x1d620 .. 0x1d62f */
+    0x0000, 0x0fd1, 0x0000, 0x0d6e, 0x0000, 0x0006, 0x0000, 0x05f0,
+    0x0000, 0x0624, 0x0000, 0x05f2, 0x0000, 0x05f4, 0x0000, 0x062a,
+    0x0000, 0x05fc, 0x0000, 0x0369, 0x0000, 0x061e, 0x0000, 0x036d,
+    0x0000, 0x05fe, 0x0000, 0x038f, 0x0000, 0x0600, 0x0000, 0x0d3e,
+    /* 0x1d630 .. 0x1d63f */
+    0x0000, 0x0019, 0x0000, 0x060a, 0x0000, 0x0fd3, 0x0000, 0x036f,
+    0x0000, 0x0219, 0x0000, 0x060c, 0x0000, 0x060e, 0x0000, 0x0614,
+    0x0000, 0x0377, 0x0000, 0x0391, 0x0000, 0x0379, 0x0000, 0x0660,
+    0x0000, 0x05c0, 0x0000, 0x05c4, 0x0000, 0x0d4b, 0x0000, 0x05c6,
+    /* 0x1d640 .. 0x1d64f */
+    0x0000, 0x05c8, 0x0000, 0x0d72, 0x0000, 0x05cc, 0x0000, 0x05ce,
+    0x0000, 0x05d0, 0x0000, 0x05d2, 0x0000, 0x05d4, 0x0000, 0x05d6,
+    0x0000, 0x05d8, 0x0000, 0x05da, 0x0000, 0x05dc, 0x0000, 0x05e0,
+    0x0000, 0x0d62, 0x0000, 0x05e2, 0x0000, 0x0fcf, 0x0000, 0x05e4,
+    /* 0x1d650 .. 0x1d65f */
+    0x0000, 0x05e6, 0x0000, 0x0dd0, 0x0000, 0x05e8, 0x0000, 0x0de1,
+    0x0000, 0x0fd1, 0x0000, 0x0d6e, 0x0000, 0x0006, 0x0000, 0x05f0,
+    0x0000, 0x0624, 0x0000, 0x05f2, 0x0000, 0x05f4, 0x0000, 0x062a,
+    0x0000, 0x05fc, 0x0000, 0x0369, 0x0000, 0x061e, 0x0000, 0x036d,
+    /* 0x1d660 .. 0x1d66f */
+    0x0000, 0x05fe, 0x0000, 0x038f, 0x0000, 0x0600, 0x0000, 0x0d3e,
+    0x0000, 0x0019, 0x0000, 0x060a, 0x0000, 0x0fd3, 0x0000, 0x036f,
+    0x0000, 0x0219, 0x0000, 0x060c, 0x0000, 0x060e, 0x0000, 0x0614,
+    0x0000, 0x0377, 0x0000, 0x0391, 0x0000, 0x0379, 0x0000, 0x0660,
+    /* 0x1d670 .. 0x1d67f */
+    0x0000, 0x05c0, 0x0000, 0x05c4, 0x0000, 0x0d4b, 0x0000, 0x05c6,
+    0x0000, 0x05c8, 0x0000, 0x0d72, 0x0000, 0x05cc, 0x0000, 0x05ce,
+    0x0000, 0x05d0, 0x0000, 0x05d2, 0x0000, 0x05d4, 0x0000, 0x05d6,
+    0x0000, 0x05d8, 0x0000, 0x05da, 0x0000, 0x05dc, 0x0000, 0x05e0,
+    /* 0x1d680 .. 0x1d68f */
+    0x0000, 0x0d62, 0x0000, 0x05e2, 0x0000, 0x0fcf, 0x0000, 0x05e4,
+    0x0000, 0x05e6, 0x0000, 0x0dd0, 0x0000, 0x05e8, 0x0000, 0x0de1,
+    0x0000, 0x0fd1, 0x0000, 0x0d6e, 0x0000, 0x0006, 0x0000, 0x05f0,
+    0x0000, 0x0624, 0x0000, 0x05f2, 0x0000, 0x05f4, 0x0000, 0x062a,
+    /* 0x1d690 .. 0x1d69f */
+    0x0000, 0x05fc, 0x0000, 0x0369, 0x0000, 0x061e, 0x0000, 0x036d,
+    0x0000, 0x05fe, 0x0000, 0x038f, 0x0000, 0x0600, 0x0000, 0x0d3e,
+    0x0000, 0x0019, 0x0000, 0x060a, 0x0000, 0x0fd3, 0x0000, 0x036f,
+    0x0000, 0x0219, 0x0000, 0x060c, 0x0000, 0x060e, 0x0000, 0x0614,
+    /* 0x1d6a0 .. 0x1d6af */
+    0x0000, 0x0377, 0x0000, 0x0391, 0x0000, 0x0379, 0x0000, 0x0660,
+    0x0000, 0x2358, 0x0000, 0x235a, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x235c, 0x0000, 0x235e, 0x0000, 0x0d80, 0x0000, 0x2360,
+    0x0000, 0x2362, 0x0000, 0x2364, 0x0000, 0x2366, 0x0000, 0x0402,
+    /* 0x1d6b0 .. 0x1d6bf */
+    0x0000, 0x2368, 0x0000, 0x236a, 0x0000, 0x236c, 0x0000, 0x236e,
+    0x0000, 0x2370, 0x0000, 0x2372, 0x0000, 0x2374, 0x0000, 0x0d82,
+    0x0000, 0x2376, 0x0000, 0x0402, 0x0000, 0x0406, 0x0000, 0x2378,
+    0x0000, 0x03f0, 0x0000, 0x237a, 0x0000, 0x237c, 0x0000, 0x237e,
+    /* 0x1d6c0 .. 0x1d6cf */
+    0x0000, 0x0d70, 0x0000, 0x2380, 0x0000, 0x2382, 0x0000, 0x03ec,
+    0x0000, 0x0618, 0x0000, 0x061a, 0x0000, 0x0404, 0x0000, 0x2384,
+    0x0000, 0x2386, 0x0000, 0x03ee, 0x0000, 0x0c3b, 0x0000, 0x03fc,
+    0x0000, 0x2388, 0x0000, 0x0012, 0x0000, 0x238a, 0x0000, 0x238c,
+    /* 0x1d6d0 .. 0x1d6df */
+    0x0000, 0x238e, 0x0000, 0x03fa, 0x0000, 0x03fe, 0x0000, 0x0400,
+    0x0000, 0x2390, 0x0000, 0x2392, 0x0000, 0x2394, 0x0000, 0x03f8,
+    0x0000, 0x061c, 0x0000, 0x2396, 0x0000, 0x2398, 0x0000, 0x239a,
+    0x0000, 0x0404, 0x0000, 0x03ee, 0x0000, 0x03fc, 0x0000, 0x03f8,
+    /* 0x1d6e0 .. 0x1d6ef */
+    0x0000, 0x03fe, 0x0000, 0x03fa, 0x0000, 0x235c, 0x0000, 0x235e,
+    0x0000, 0x0d80, 0x0000, 0x2360, 0x0000, 0x2362, 0x0000, 0x2364,
+    0x0000, 0x2366, 0x0000, 0x0402, 0x0000, 0x2368, 0x0000, 0x236a,
+    0x0000, 0x236c, 0x0000, 0x236e, 0x0000, 0x2370, 0x0000, 0x2372,
+    /* 0x1d6f0 .. 0x1d6ff */
+    0x0000, 0x2374, 0x0000, 0x0d82, 0x0000, 0x2376, 0x0000, 0x0402,
+    0x0000, 0x0406, 0x0000, 0x2378, 0x0000, 0x03f0, 0x0000, 0x237a,
+    0x0000, 0x237c, 0x0000, 0x237e, 0x0000, 0x0d70, 0x0000, 0x2380,
+    0x0000, 0x2382, 0x0000, 0x03ec, 0x0000, 0x0618, 0x0000, 0x061a,
+    /* 0x1d700 .. 0x1d70f */
+    0x0000, 0x0404, 0x0000, 0x2384, 0x0000, 0x2386, 0x0000, 0x03ee,
+    0x0000, 0x0c3b, 0x0000, 0x03fc, 0x0000, 0x2388, 0x0000, 0x0012,
+    0x0000, 0x238a, 0x0000, 0x238c, 0x0000, 0x238e, 0x0000, 0x03fa,
+    0x0000, 0x03fe, 0x0000, 0x0400, 0x0000, 0x2390, 0x0000, 0x2392,
+    /* 0x1d710 .. 0x1d71f */
+    0x0000, 0x2394, 0x0000, 0x03f8, 0x0000, 0x061c, 0x0000, 0x2396,
+    0x0000, 0x2398, 0x0000, 0x239a, 0x0000, 0x0404, 0x0000, 0x03ee,
+    0x0000, 0x03fc, 0x0000, 0x03f8, 0x0000, 0x03fe, 0x0000, 0x03fa,
+    0x0000, 0x235c, 0x0000, 0x235e, 0x0000, 0x0d80, 0x0000, 0x2360,
+    /* 0x1d720 .. 0x1d72f */
+    0x0000, 0x2362, 0x0000, 0x2364, 0x0000, 0x2366, 0x0000, 0x0402,
+    0x0000, 0x2368, 0x0000, 0x236a, 0x0000, 0x236c, 0x0000, 0x236e,
+    0x0000, 0x2370, 0x0000, 0x2372, 0x0000, 0x2374, 0x0000, 0x0d82,
+    0x0000, 0x2376, 0x0000, 0x0402, 0x0000, 0x0406, 0x0000, 0x2378,
+    /* 0x1d730 .. 0x1d73f */
+    0x0000, 0x03f0, 0x0000, 0x237a, 0x0000, 0x237c, 0x0000, 0x237e,
+    0x0000, 0x0d70, 0x0000, 0x2380, 0x0000, 0x2382, 0x0000, 0x03ec,
+    0x0000, 0x0618, 0x0000, 0x061a, 0x0000, 0x0404, 0x0000, 0x2384,
+    0x0000, 0x2386, 0x0000, 0x03ee, 0x0000, 0x0c3b, 0x0000, 0x03fc,
+    /* 0x1d740 .. 0x1d74f */
+    0x0000, 0x2388, 0x0000, 0x0012, 0x0000, 0x238a, 0x0000, 0x238c,
+    0x0000, 0x238e, 0x0000, 0x03fa, 0x0000, 0x03fe, 0x0000, 0x0400,
+    0x0000, 0x2390, 0x0000, 0x2392, 0x0000, 0x2394, 0x0000, 0x03f8,
+    0x0000, 0x061c, 0x0000, 0x2396, 0x0000, 0x2398, 0x0000, 0x239a,
+    /* 0x1d750 .. 0x1d75f */
+    0x0000, 0x0404, 0x0000, 0x03ee, 0x0000, 0x03fc, 0x0000, 0x03f8,
+    0x0000, 0x03fe, 0x0000, 0x03fa, 0x0000, 0x235c, 0x0000, 0x235e,
+    0x0000, 0x0d80, 0x0000, 0x2360, 0x0000, 0x2362, 0x0000, 0x2364,
+    0x0000, 0x2366, 0x0000, 0x0402, 0x0000, 0x2368, 0x0000, 0x236a,
+    /* 0x1d760 .. 0x1d76f */
+    0x0000, 0x236c, 0x0000, 0x236e, 0x0000, 0x2370, 0x0000, 0x2372,
+    0x0000, 0x2374, 0x0000, 0x0d82, 0x0000, 0x2376, 0x0000, 0x0402,
+    0x0000, 0x0406, 0x0000, 0x2378, 0x0000, 0x03f0, 0x0000, 0x237a,
+    0x0000, 0x237c, 0x0000, 0x237e, 0x0000, 0x0d70, 0x0000, 0x2380,
+    /* 0x1d770 .. 0x1d77f */
+    0x0000, 0x2382, 0x0000, 0x03ec, 0x0000, 0x0618, 0x0000, 0x061a,
+    0x0000, 0x0404, 0x0000, 0x2384, 0x0000, 0x2386, 0x0000, 0x03ee,
+    0x0000, 0x0c3b, 0x0000, 0x03fc, 0x0000, 0x2388, 0x0000, 0x0012,
+    0x0000, 0x238a, 0x0000, 0x238c, 0x0000, 0x238e, 0x0000, 0x03fa,
+    /* 0x1d780 .. 0x1d78f */
+    0x0000, 0x03fe, 0x0000, 0x0400, 0x0000, 0x2390, 0x0000, 0x2392,
+    0x0000, 0x2394, 0x0000, 0x03f8, 0x0000, 0x061c, 0x0000, 0x2396,
+    0x0000, 0x2398, 0x0000, 0x239a, 0x0000, 0x0404, 0x0000, 0x03ee,
+    0x0000, 0x03fc, 0x0000, 0x03f8, 0x0000, 0x03fe, 0x0000, 0x03fa,
+    /* 0x1d790 .. 0x1d79f */
+    0x0000, 0x235c, 0x0000, 0x235e, 0x0000, 0x0d80, 0x0000, 0x2360,
+    0x0000, 0x2362, 0x0000, 0x2364, 0x0000, 0x2366, 0x0000, 0x0402,
+    0x0000, 0x2368, 0x0000, 0x236a, 0x0000, 0x236c, 0x0000, 0x236e,
+    0x0000, 0x2370, 0x0000, 0x2372, 0x0000, 0x2374, 0x0000, 0x0d82,
+    /* 0x1d7a0 .. 0x1d7af */
+    0x0000, 0x2376, 0x0000, 0x0402, 0x0000, 0x0406, 0x0000, 0x2378,
+    0x0000, 0x03f0, 0x0000, 0x237a, 0x0000, 0x237c, 0x0000, 0x237e,
+    0x0000, 0x0d70, 0x0000, 0x2380, 0x0000, 0x2382, 0x0000, 0x03ec,
+    0x0000, 0x0618, 0x0000, 0x061a, 0x0000, 0x0404, 0x0000, 0x2384,
+    /* 0x1d7b0 .. 0x1d7bf */
+    0x0000, 0x2386, 0x0000, 0x03ee, 0x0000, 0x0c3b, 0x0000, 0x03fc,
+    0x0000, 0x2388, 0x0000, 0x0012, 0x0000, 0x238a, 0x0000, 0x238c,
+    0x0000, 0x238e, 0x0000, 0x03fa, 0x0000, 0x03fe, 0x0000, 0x0400,
+    0x0000, 0x2390, 0x0000, 0x2392, 0x0000, 0x2394, 0x0000, 0x03f8,
+    /* 0x1d7c0 .. 0x1d7cf */
+    0x0000, 0x061c, 0x0000, 0x2396, 0x0000, 0x2398, 0x0000, 0x239a,
+    0x0000, 0x0404, 0x0000, 0x03ee, 0x0000, 0x03fc, 0x0000, 0x03f8,
+    0x0000, 0x03fe, 0x0000, 0x03fa, 0x0000, 0x239c, 0x0000, 0x239e,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0d26, 0x0000, 0x0017,
+    /* 0x1d7d0 .. 0x1d7df */
+    0x0000, 0x000b, 0x0000, 0x000d, 0x0000, 0x0d28, 0x0000, 0x0d2a,
+    0x0000, 0x0d2c, 0x0000, 0x0d2e, 0x0000, 0x0d30, 0x0000, 0x0d32,
+    0x0000, 0x0d26, 0x0000, 0x0017, 0x0000, 0x000b, 0x0000, 0x000d,
+    0x0000, 0x0d28, 0x0000, 0x0d2a, 0x0000, 0x0d2c, 0x0000, 0x0d2e,
+    /* 0x1d7e0 .. 0x1d7ef */
+    0x0000, 0x0d30, 0x0000, 0x0d32, 0x0000, 0x0d26, 0x0000, 0x0017,
+    0x0000, 0x000b, 0x0000, 0x000d, 0x0000, 0x0d28, 0x0000, 0x0d2a,
+    0x0000, 0x0d2c, 0x0000, 0x0d2e, 0x0000, 0x0d30, 0x0000, 0x0d32,
+    0x0000, 0x0d26, 0x0000, 0x0017, 0x0000, 0x000b, 0x0000, 0x000d,
+    /* 0x1d7f0 .. 0x1d7ff */
+    0x0000, 0x0d28, 0x0000, 0x0d2a, 0x0000, 0x0d2c, 0x0000, 0x0d2e,
+    0x0000, 0x0d30, 0x0000, 0x0d32, 0x0000, 0x0d26, 0x0000, 0x0017,
+    0x0000, 0x000b, 0x0000, 0x000d, 0x0000, 0x0d28, 0x0000, 0x0d2a,
+    0x0000, 0x0d2c, 0x0000, 0x0d2e, 0x0000, 0x0d30, 0x0000, 0x0d32,
+    /* 0x1ee00 .. 0x1ee0f */
+    0x0000, 0x223a, 0x0000, 0x223c, 0x0000, 0x2244, 0x0000, 0x224a,
+    0x0000, 0x0000, 0x0000, 0x2270, 0x0000, 0x2250, 0x0000, 0x2246,
+    0x0000, 0x225a, 0x0000, 0x2272, 0x0000, 0x2266, 0x0000, 0x2268,
+    0x0000, 0x226a, 0x0000, 0x226c, 0x0000, 0x2252, 0x0000, 0x225e,
+    /* 0x1ee10 .. 0x1ee1f */
+    0x0000, 0x2262, 0x0000, 0x2256, 0x0000, 0x2264, 0x0000, 0x224e,
+    0x0000, 0x2254, 0x0000, 0x2240, 0x0000, 0x2242, 0x0000, 0x2248,
+    0x0000, 0x224c, 0x0000, 0x2258, 0x0000, 0x225c, 0x0000, 0x2260,
+    0x0000, 0x23a0, 0x0000, 0x1dca, 0x0000, 0x23a2, 0x0000, 0x23a4,
+    /* 0x1ee20 .. 0x1ee2f */
+    0x0000, 0x0000, 0x0000, 0x223c, 0x0000, 0x2244, 0x0000, 0x0000,
+    0x0000, 0x226e, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x2246,
+    0x0000, 0x0000, 0x0000, 0x2272, 0x0000, 0x2266, 0x0000, 0x2268,
+    0x0000, 0x226a, 0x0000, 0x226c, 0x0000, 0x2252, 0x0000, 0x225e,
+    /* 0x1ee30 .. 0x1ee3f */
+    0x0000, 0x2262, 0x0000, 0x2256, 0x0000, 0x2264, 0x0000, 0x0000,
+    0x0000, 0x2254, 0x0000, 0x2240, 0x0000, 0x2242, 0x0000, 0x2248,
+    0x0000, 0x0000, 0x0000, 0x2258, 0x0000, 0x0000, 0x0000, 0x2260,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x1ee40 .. 0x1ee4f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x2244, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x2246,
+    0x0000, 0x0000, 0x0000, 0x2272, 0x0000, 0x0000, 0x0000, 0x2268,
+    0x0000, 0x0000, 0x0000, 0x226c, 0x0000, 0x2252, 0x0000, 0x225e,
+    /* 0x1ee50 .. 0x1ee5f */
+    0x0000, 0x0000, 0x0000, 0x2256, 0x0000, 0x2264, 0x0000, 0x0000,
+    0x0000, 0x2254, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x2248,
+    0x0000, 0x0000, 0x0000, 0x2258, 0x0000, 0x0000, 0x0000, 0x2260,
+    0x0000, 0x0000, 0x0000, 0x1dca, 0x0000, 0x0000, 0x0000, 0x23a4,
+    /* 0x1ee60 .. 0x1ee6f */
+    0x0000, 0x0000, 0x0000, 0x223c, 0x0000, 0x2244, 0x0000, 0x0000,
+    0x0000, 0x226e, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x2246,
+    0x0000, 0x225a, 0x0000, 0x2272, 0x0000, 0x2266, 0x0000, 0x0000,
+    0x0000, 0x226a, 0x0000, 0x226c, 0x0000, 0x2252, 0x0000, 0x225e,
+    /* 0x1ee70 .. 0x1ee7f */
+    0x0000, 0x2262, 0x0000, 0x2256, 0x0000, 0x2264, 0x0000, 0x0000,
+    0x0000, 0x2254, 0x0000, 0x2240, 0x0000, 0x2242, 0x0000, 0x2248,
+    0x0000, 0x0000, 0x0000, 0x2258, 0x0000, 0x225c, 0x0000, 0x2260,
+    0x0000, 0x23a0, 0x0000, 0x0000, 0x0000, 0x23a2, 0x0000, 0x0000,
+    /* 0x1ee80 .. 0x1ee8f */
+    0x0000, 0x223a, 0x0000, 0x223c, 0x0000, 0x2244, 0x0000, 0x224a,
+    0x0000, 0x226e, 0x0000, 0x2270, 0x0000, 0x2250, 0x0000, 0x2246,
+    0x0000, 0x225a, 0x0000, 0x2272, 0x0000, 0x0000, 0x0000, 0x2268,
+    0x0000, 0x226a, 0x0000, 0x226c, 0x0000, 0x2252, 0x0000, 0x225e,
+    /* 0x1ee90 .. 0x1ee9f */
+    0x0000, 0x2262, 0x0000, 0x2256, 0x0000, 0x2264, 0x0000, 0x224e,
+    0x0000, 0x2254, 0x0000, 0x2240, 0x0000, 0x2242, 0x0000, 0x2248,
+    0x0000, 0x224c, 0x0000, 0x2258, 0x0000, 0x225c, 0x0000, 0x2260,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x1eea0 .. 0x1eeaf */
+    0x0000, 0x0000, 0x0000, 0x223c, 0x0000, 0x2244, 0x0000, 0x224a,
+    0x0000, 0x0000, 0x0000, 0x2270, 0x0000, 0x2250, 0x0000, 0x2246,
+    0x0000, 0x225a, 0x0000, 0x2272, 0x0000, 0x0000, 0x0000, 0x2268,
+    0x0000, 0x226a, 0x0000, 0x226c, 0x0000, 0x2252, 0x0000, 0x225e,
+    /* 0x1eeb0 .. 0x1eebf */
+    0x0000, 0x2262, 0x0000, 0x2256, 0x0000, 0x2264, 0x0000, 0x224e,
+    0x0000, 0x2254, 0x0000, 0x2240, 0x0000, 0x2242, 0x0000, 0x2248,
+    0x0000, 0x224c, 0x0000, 0x2258, 0x0000, 0x225c, 0x0000, 0x2260,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x1f100 .. 0x1f10f */
+    0x0000, 0x23a6, 0x0000, 0x23a9, 0x0000, 0x23ac, 0x0000, 0x23af,
+    0x0000, 0x23b2, 0x0000, 0x23b5, 0x0000, 0x23b8, 0x0000, 0x23bb,
+    0x0000, 0x23be, 0x0000, 0x23c1, 0x0000, 0x23c4, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x1f110 .. 0x1f11f */
+    0x0000, 0x23c7, 0x0000, 0x23cb, 0x0000, 0x23cf, 0x0000, 0x23d3,
+    0x0000, 0x23d7, 0x0000, 0x23db, 0x0000, 0x23df, 0x0000, 0x23e3,
+    0x0000, 0x23e7, 0x0000, 0x23eb, 0x0000, 0x23ef, 0x0000, 0x23f3,
+    0x0000, 0x23f7, 0x0000, 0x23fb, 0x0000, 0x23ff, 0x0000, 0x2403,
+    /* 0x1f120 .. 0x1f12f */
+    0x0000, 0x2407, 0x0000, 0x240b, 0x0000, 0x240f, 0x0000, 0x2413,
+    0x0000, 0x2417, 0x0000, 0x241b, 0x0000, 0x241f, 0x0000, 0x2423,
+    0x0000, 0x2427, 0x0000, 0x242b, 0x0000, 0x242f, 0x0000, 0x0d4b,
+    0x0000, 0x05e2, 0x0000, 0x2433, 0x0000, 0x2436, 0x0000, 0x0000,
+    /* 0x1f130 .. 0x1f13f */
+    0x0000, 0x05c0, 0x0000, 0x05c4, 0x0000, 0x0d4b, 0x0000, 0x05c6,
+    0x0000, 0x05c8, 0x0000, 0x0d72, 0x0000, 0x05cc, 0x0000, 0x05ce,
+    0x0000, 0x05d0, 0x0000, 0x05d2, 0x0000, 0x05d4, 0x0000, 0x05d6,
+    0x0000, 0x05d8, 0x0000, 0x05da, 0x0000, 0x05dc, 0x0000, 0x05e0,
+    /* 0x1f140 .. 0x1f14f */
+    0x0000, 0x0d62, 0x0000, 0x05e2, 0x0000, 0x0fcf, 0x0000, 0x05e4,
+    0x0000, 0x05e6, 0x0000, 0x0dd0, 0x0000, 0x05e8, 0x0000, 0x0de1,
+    0x0000, 0x0fd1, 0x0000, 0x0d6e, 0x0000, 0x2439, 0x0000, 0x18c2,
+    0x0000, 0x243c, 0x0000, 0x243f, 0x0000, 0x2442, 0x0000, 0x2446,
+    /* 0x1f160 .. 0x1f16f */
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x2449, 0x0000, 0x244c,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x1f190 .. 0x1f19f */
+    0x0000, 0x244f, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x1f200 .. 0x1f20f */
+    0x0000, 0x2452, 0x0000, 0x2455, 0x0000, 0x1571, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x1f210 .. 0x1f21f */
+    0x0000, 0x106c, 0x0000, 0x2458, 0x0000, 0x245a, 0x0000, 0x1221,
+    0x0000, 0x0ffa, 0x0000, 0x245c, 0x0000, 0x245e, 0x0000, 0x1326,
+    0x0000, 0x2460, 0x0000, 0x2462, 0x0000, 0x2464, 0x0000, 0x1b31,
+    0x0000, 0x2466, 0x0000, 0x2468, 0x0000, 0x246a, 0x0000, 0x246c,
+    /* 0x1f220 .. 0x1f22f */
+    0x0000, 0x246e, 0x0000, 0x2470, 0x0000, 0x10b4, 0x0000, 0x2472,
+    0x0000, 0x2474, 0x0000, 0x2476, 0x0000, 0x2478, 0x0000, 0x247a,
+    0x0000, 0x247c, 0x0000, 0x0fee, 0x0000, 0x1316, 0x0000, 0x247e,
+    0x0000, 0x14e7, 0x0000, 0x131c, 0x0000, 0x14e9, 0x0000, 0x2480,
+    /* 0x1f230 .. 0x1f23f */
+    0x0000, 0x1124, 0x0000, 0x2482, 0x0000, 0x2484, 0x0000, 0x2486,
+    0x0000, 0x2488, 0x0000, 0x248a, 0x0000, 0x14c5, 0x0000, 0x1080,
+    0x0000, 0x248c, 0x0000, 0x248e, 0x0000, 0x2490, 0x0000, 0x2492,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x1f240 .. 0x1f24f */
+    0x0000, 0x2494, 0x0000, 0x2498, 0x0000, 0x249c, 0x0000, 0x24a0,
+    0x0000, 0x24a4, 0x0000, 0x24a8, 0x0000, 0x24ac, 0x0000, 0x24b0,
+    0x0000, 0x24b4, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x1f250 .. 0x1f25f */
+    0x0000, 0x24b8, 0x0000, 0x24ba, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
+    /* 0x2f800 .. 0x2f80f */
+    0x24bc, 0x24bc, 0x24be, 0x24be, 0x24c0, 0x24c0, 0x24c2, 0x24c2,
+    0x24c5, 0x24c5, 0x1beb, 0x1beb, 0x24c7, 0x24c7, 0x24c9, 0x24c9,
+    0x24cb, 0x24cb, 0x24cd, 0x24cd, 0x1bed, 0x1bed, 0x24cf, 0x24cf,
+    0x24d1, 0x24d1, 0x24d3, 0x24d3, 0x1bef, 0x1bef, 0x24d6, 0x24d6,
+    /* 0x2f810 .. 0x2f81f */
+    0x24d8, 0x24d8, 0x24da, 0x24da, 0x24dc, 0x24dc, 0x24df, 0x24df,
+    0x24e1, 0x24e1, 0x246a, 0x246a, 0x24e3, 0x24e3, 0x24e6, 0x24e6,
+    0x24e8, 0x24e8, 0x24ea, 0x24ea, 0x24ec, 0x24ec, 0x1c5e, 0x1c5e,
+    0x24ee, 0x24ee, 0x100e, 0x100e, 0x24f1, 0x24f1, 0x24f3, 0x24f3,
+    /* 0x2f820 .. 0x2f82f */
+    0x24f5, 0x24f5, 0x24f7, 0x24f7, 0x248e, 0x248e, 0x24f9, 0x24f9,
+    0x24fb, 0x24fb, 0x1c68, 0x1c68, 0x1bf1, 0x1bf1, 0x1bf3, 0x1bf3,
+    0x1c6a, 0x1c6a, 0x24fd, 0x24fd, 0x24ff, 0x24ff, 0x1a85, 0x1a85,
+    0x2501, 0x2501, 0x1bf5, 0x1bf5, 0x2503, 0x2503, 0x2505, 0x2505,
+    /* 0x2f830 .. 0x2f83f */
+    0x2507, 0x2507, 0x2509, 0x2509, 0x2509, 0x2509, 0x2509, 0x2509,
+    0x250b, 0x250b, 0x250e, 0x250e, 0x2510, 0x2510, 0x2512, 0x2512,
+    0x2514, 0x2514, 0x2517, 0x2517, 0x2519, 0x2519, 0x251b, 0x251b,
+    0x251d, 0x251d, 0x251f, 0x251f, 0x2521, 0x2521, 0x2523, 0x2523,
+    /* 0x2f840 .. 0x2f84f */
+    0x2525, 0x2525, 0x2527, 0x2527, 0x2529, 0x2529, 0x252b, 0x252b,
+    0x252d, 0x252d, 0x252f, 0x252f, 0x252f, 0x252f, 0x1c6e, 0x1c6e,
+    0x2531, 0x2531, 0x2533, 0x2533, 0x2535, 0x2535, 0x2537, 0x2537,
+    0x1bf9, 0x1bf9, 0x2539, 0x2539, 0x253b, 0x253b, 0x253d, 0x253d,
+    /* 0x2f850 .. 0x2f85f */
+    0x1ba9, 0x1ba9, 0x253f, 0x253f, 0x2541, 0x2541, 0x2543, 0x2543,
+    0x2545, 0x2545, 0x2547, 0x2547, 0x2549, 0x2549, 0x254b, 0x254b,
+    0x254d, 0x254d, 0x254f, 0x254f, 0x2552, 0x2552, 0x2554, 0x2554,
+    0x2556, 0x2556, 0x245c, 0x245c, 0x2558, 0x2558, 0x255a, 0x255a,
+    /* 0x2f860 .. 0x2f86f */
+    0x255c, 0x255c, 0x255f, 0x255f, 0x2562, 0x2562, 0x2564, 0x2564,
+    0x2566, 0x2566, 0x2568, 0x2568, 0x256a, 0x256a, 0x256c, 0x256c,
+    0x256e, 0x256e, 0x2570, 0x2570, 0x2572, 0x2572, 0x2572, 0x2572,
+    0x2574, 0x2574, 0x2577, 0x2577, 0x2579, 0x2579, 0x1a7d, 0x1a7d,
+    /* 0x2f870 .. 0x2f87f */
+    0x257b, 0x257b, 0x257d, 0x257d, 0x2580, 0x2580, 0x2582, 0x2582,
+    0x2584, 0x2584, 0x1042, 0x1042, 0x2586, 0x2586, 0x2588, 0x2588,
+    0x1046, 0x1046, 0x258a, 0x258a, 0x258c, 0x258c, 0x258e, 0x258e,
+    0x2591, 0x2591, 0x2593, 0x2593, 0x2596, 0x2596, 0x2598, 0x2598,
+    /* 0x2f880 .. 0x2f88f */
+    0x259a, 0x259a, 0x259c, 0x259c, 0x259e, 0x259e, 0x25a0, 0x25a0,
+    0x25a2, 0x25a2, 0x25a4, 0x25a4, 0x25a6, 0x25a6, 0x25a8, 0x25a8,
+    0x25aa, 0x25aa, 0x25ac, 0x25ac, 0x25af, 0x25af, 0x25b1, 0x25b1,
+    0x25b3, 0x25b3, 0x25b5, 0x25b5, 0x1a15, 0x1a15, 0x25b7, 0x25b7,
+    /* 0x2f890 .. 0x2f89f */
+    0x105a, 0x105a, 0x25ba, 0x25ba, 0x25ba, 0x25ba, 0x25bd, 0x25bd,
+    0x25bf, 0x25bf, 0x25bf, 0x25bf, 0x25c1, 0x25c1, 0x25c3, 0x25c3,
+    0x25c6, 0x25c6, 0x25c9, 0x25c9, 0x25cb, 0x25cb, 0x25cd, 0x25cd,
+    0x25cf, 0x25cf, 0x25d1, 0x25d1, 0x25d3, 0x25d3, 0x25d5, 0x25d5,
+    /* 0x2f8a0 .. 0x2f8af */
+    0x25d7, 0x25d7, 0x25d9, 0x25d9, 0x25db, 0x25db, 0x1c03, 0x1c03,
+    0x25dd, 0x25dd, 0x25e0, 0x25e0, 0x25e2, 0x25e2, 0x25e4, 0x25e4,
+    0x1c86, 0x1c86, 0x25e4, 0x25e4, 0x25e6, 0x25e6, 0x1c07, 0x1c07,
+    0x25e8, 0x25e8, 0x25ea, 0x25ea, 0x25ec, 0x25ec, 0x25ee, 0x25ee,
+    /* 0x2f8b0 .. 0x2f8bf */
+    0x1c09, 0x1c09, 0x19df, 0x19df, 0x25f0, 0x25f0, 0x25f2, 0x25f2,
+    0x25f4, 0x25f4, 0x25f6, 0x25f6, 0x25f8, 0x25f8, 0x25fa, 0x25fa,
+    0x25fc, 0x25fc, 0x25ff, 0x25ff, 0x2601, 0x2601, 0x2603, 0x2603,
+    0x2605, 0x2605, 0x2607, 0x2607, 0x2609, 0x2609, 0x260c, 0x260c,
+    /* 0x2f8c0 .. 0x2f8cf */
+    0x260e, 0x260e, 0x2610, 0x2610, 0x2612, 0x2612, 0x2614, 0x2614,
+    0x2616, 0x2616, 0x2618, 0x2618, 0x261a, 0x261a, 0x261c, 0x261c,
+    0x1c0b, 0x1c0b, 0x261e, 0x261e, 0x2620, 0x2620, 0x2623, 0x2623,
+    0x2625, 0x2625, 0x2627, 0x2627, 0x2629, 0x2629, 0x1c0f, 0x1c0f,
+    /* 0x2f8d0 .. 0x2f8df */
+    0x262b, 0x262b, 0x262d, 0x262d, 0x262f, 0x262f, 0x2631, 0x2631,
+    0x2633, 0x2633, 0x2635, 0x2635, 0x2637, 0x2637, 0x2639, 0x2639,
+    0x1a17, 0x1a17, 0x1c96, 0x1c96, 0x263b, 0x263b, 0x263d, 0x263d,
+    0x263f, 0x263f, 0x2641, 0x2641, 0x2644, 0x2644, 0x2646, 0x2646,
+    /* 0x2f8e0 .. 0x2f8ef */
+    0x2648, 0x2648, 0x264a, 0x264a, 0x1c11, 0x1c11, 0x264c, 0x264c,
+    0x264f, 0x264f, 0x2651, 0x2651, 0x2653, 0x2653, 0x1ced, 0x1ced,
+    0x2655, 0x2655, 0x2657, 0x2657, 0x2659, 0x2659, 0x265b, 0x265b,
+    0x265d, 0x265d, 0x2660, 0x2660, 0x2662, 0x2662, 0x2664, 0x2664,
+    /* 0x2f8f0 .. 0x2f8ff */
+    0x2666, 0x2666, 0x2669, 0x2669, 0x266b, 0x266b, 0x266d, 0x266d,
+    0x266f, 0x266f, 0x1a9f, 0x1a9f, 0x2671, 0x2671, 0x2673, 0x2673,
+    0x2676, 0x2676, 0x2679, 0x2679, 0x267c, 0x267c, 0x267e, 0x267e,
+    0x2681, 0x2681, 0x2683, 0x2683, 0x2685, 0x2685, 0x2687, 0x2687,
+    /* 0x2f900 .. 0x2f90f */
+    0x2689, 0x2689, 0x1c13, 0x1c13, 0x1b45, 0x1b45, 0x268b, 0x268b,
+    0x268d, 0x268d, 0x268f, 0x268f, 0x2691, 0x2691, 0x2694, 0x2694,
+    0x2696, 0x2696, 0x2698, 0x2698, 0x269a, 0x269a, 0x1c9c, 0x1c9c,
+    0x269c, 0x269c, 0x269e, 0x269e, 0x26a1, 0x26a1, 0x26a3, 0x26a3,
+    /* 0x2f910 .. 0x2f91f */
+    0x26a5, 0x26a5, 0x26a8, 0x26a8, 0x26ab, 0x26ab, 0x26ad, 0x26ad,
+    0x1c9e, 0x1c9e, 0x26af, 0x26af, 0x26b1, 0x26b1, 0x26b3, 0x26b3,
+    0x26b5, 0x26b5, 0x26b7, 0x26b7, 0x26b9, 0x26b9, 0x26bb, 0x26bb,
+    0x26be, 0x26be, 0x26c0, 0x26c0, 0x26c3, 0x26c3, 0x26c5, 0x26c5,
+    /* 0x2f920 .. 0x2f92f */
+    0x26c8, 0x26c8, 0x1ca2, 0x1ca2, 0x26ca, 0x26ca, 0x26cc, 0x26cc,
+    0x26cf, 0x26cf, 0x26d1, 0x26d1, 0x26d3, 0x26d3, 0x26d6, 0x26d6,
+    0x26d9, 0x26d9, 0x26db, 0x26db, 0x26dd, 0x26dd, 0x26df, 0x26df,
+    0x26e1, 0x26e1, 0x26e1, 0x26e1, 0x26e3, 0x26e3, 0x26e5, 0x26e5,
+    /* 0x2f930 .. 0x2f93f */
+    0x1ca6, 0x1ca6, 0x26e7, 0x26e7, 0x26e9, 0x26e9, 0x26eb, 0x26eb,
+    0x26ed, 0x26ed, 0x26ef, 0x26ef, 0x26f2, 0x26f2, 0x26f4, 0x26f4,
+    0x1a83, 0x1a83, 0x26f7, 0x26f7, 0x26fa, 0x26fa, 0x26fc, 0x26fc,
+    0x26ff, 0x26ff, 0x2702, 0x2702, 0x2705, 0x2705, 0x2707, 0x2707,
+    /* 0x2f940 .. 0x2f94f */
+    0x1cb2, 0x1cb2, 0x2709, 0x2709, 0x270c, 0x270c, 0x270f, 0x270f,
+    0x2712, 0x2712, 0x2715, 0x2715, 0x2717, 0x2717, 0x2717, 0x2717,
+    0x1cb4, 0x1cb4, 0x1cf1, 0x1cf1, 0x2719, 0x2719, 0x271b, 0x271b,
+    0x271d, 0x271d, 0x271f, 0x271f, 0x2722, 0x2722, 0x1a39, 0x1a39,
+    /* 0x2f950 .. 0x2f95f */
+    0x1cb8, 0x1cb8, 0x2724, 0x2724, 0x2726, 0x2726, 0x1c27, 0x1c27,
+    0x2729, 0x2729, 0x272c, 0x272c, 0x1bd1, 0x1bd1, 0x272f, 0x272f,
+    0x2731, 0x2731, 0x1c2d, 0x1c2d, 0x2733, 0x2733, 0x2735, 0x2735,
+    0x2737, 0x2737, 0x273a, 0x273a, 0x273a, 0x273a, 0x273d, 0x273d,
+    /* 0x2f960 .. 0x2f96f */
+    0x273f, 0x273f, 0x2741, 0x2741, 0x2744, 0x2744, 0x2746, 0x2746,
+    0x2748, 0x2748, 0x274a, 0x274a, 0x274d, 0x274d, 0x274f, 0x274f,
+    0x2751, 0x2751, 0x2753, 0x2753, 0x2755, 0x2755, 0x2757, 0x2757,
+    0x275a, 0x275a, 0x275c, 0x275c, 0x275e, 0x275e, 0x2760, 0x2760,
+    /* 0x2f970 .. 0x2f97f */
+    0x2762, 0x2762, 0x2764, 0x2764, 0x2766, 0x2766, 0x2769, 0x2769,
+    0x276c, 0x276c, 0x276e, 0x276e, 0x2771, 0x2771, 0x2773, 0x2773,
+    0x2776, 0x2776, 0x2778, 0x2778, 0x1c39, 0x1c39, 0x277a, 0x277a,
+    0x277d, 0x277d, 0x2780, 0x2780, 0x2782, 0x2782, 0x2785, 0x2785,
+    /* 0x2f980 .. 0x2f98f */
+    0x2787, 0x2787, 0x278a, 0x278a, 0x278c, 0x278c, 0x278e, 0x278e,
+    0x2790, 0x2790, 0x2792, 0x2792, 0x2794, 0x2794, 0x2796, 0x2796,
+    0x2799, 0x2799, 0x279c, 0x279c, 0x279f, 0x279f, 0x25bd, 0x25bd,
+    0x27a2, 0x27a2, 0x27a4, 0x27a4, 0x27a6, 0x27a6, 0x27a8, 0x27a8,
+    /* 0x2f990 .. 0x2f99f */
+    0x27aa, 0x27aa, 0x27ac, 0x27ac, 0x27ae, 0x27ae, 0x27b0, 0x27b0,
+    0x27b2, 0x27b2, 0x27b4, 0x27b4, 0x27b6, 0x27b6, 0x27b8, 0x27b8,
+    0x1aa5, 0x1aa5, 0x27bb, 0x27bb, 0x27bd, 0x27bd, 0x27bf, 0x27bf,
+    0x27c1, 0x27c1, 0x27c3, 0x27c3, 0x27c5, 0x27c5, 0x1c3f, 0x1c3f,
+    /* 0x2f9a0 .. 0x2f9af */
+    0x27c7, 0x27c7, 0x27c9, 0x27c9, 0x27cb, 0x27cb, 0x27cd, 0x27cd,
+    0x27cf, 0x27cf, 0x27d2, 0x27d2, 0x27d5, 0x27d5, 0x27d8, 0x27d8,
+    0x27da, 0x27da, 0x27dc, 0x27dc, 0x27de, 0x27de, 0x27e0, 0x27e0,
+    0x27e3, 0x27e3, 0x27e5, 0x27e5, 0x27e8, 0x27e8, 0x27ea, 0x27ea,
+    /* 0x2f9b0 .. 0x2f9bf */
+    0x27ec, 0x27ec, 0x27ef, 0x27ef, 0x27f2, 0x27f2, 0x27f4, 0x27f4,
+    0x1a2f, 0x1a2f, 0x27f6, 0x27f6, 0x27f8, 0x27f8, 0x27fa, 0x27fa,
+    0x27fc, 0x27fc, 0x27fe, 0x27fe, 0x2800, 0x2800, 0x1cc6, 0x1cc6,
+    0x2802, 0x2802, 0x2804, 0x2804, 0x2806, 0x2806, 0x2808, 0x2808,
+    /* 0x2f9c0 .. 0x2f9cf */
+    0x280a, 0x280a, 0x280c, 0x280c, 0x280e, 0x280e, 0x2810, 0x2810,
+    0x110e, 0x110e, 0x2812, 0x2812, 0x2815, 0x2815, 0x2817, 0x2817,
+    0x2819, 0x2819, 0x281b, 0x281b, 0x281d, 0x281d, 0x281f, 0x281f,
+    0x2822, 0x2822, 0x2825, 0x2825, 0x2827, 0x2827, 0x2829, 0x2829,
+    /* 0x2f9d0 .. 0x2f9df */
+    0x1cd0, 0x1cd0, 0x1cd2, 0x1cd2, 0x111c, 0x111c, 0x282b, 0x282b,
+    0x282e, 0x282e, 0x2830, 0x2830, 0x2832, 0x2832, 0x2834, 0x2834,
+    0x2836, 0x2836, 0x2839, 0x2839, 0x283c, 0x283c, 0x283e, 0x283e,
+    0x2840, 0x2840, 0x2842, 0x2842, 0x2845, 0x2845, 0x1cd4, 0x1cd4,
+    /* 0x2f9e0 .. 0x2f9ef */
+    0x2847, 0x2847, 0x284a, 0x284a, 0x284d, 0x284d, 0x284f, 0x284f,
+    0x2851, 0x2851, 0x2853, 0x2853, 0x2856, 0x2856, 0x2858, 0x2858,
+    0x285a, 0x285a, 0x285c, 0x285c, 0x285e, 0x285e, 0x2860, 0x2860,
+    0x2862, 0x2862, 0x2864, 0x2864, 0x2867, 0x2867, 0x2869, 0x2869,
+    /* 0x2f9f0 .. 0x2f9ff */
+    0x286b, 0x286b, 0x286d, 0x286d, 0x2870, 0x2870, 0x2872, 0x2872,
+    0x2874, 0x2874, 0x2876, 0x2876, 0x2878, 0x2878, 0x287b, 0x287b,
+    0x287e, 0x287e, 0x2880, 0x2880, 0x2882, 0x2882, 0x2884, 0x2884,
+    0x2887, 0x2887, 0x2889, 0x2889, 0x1ce0, 0x1ce0, 0x1ce0, 0x1ce0,
+    /* 0x2fa00 .. 0x2fa0f */
+    0x288c, 0x288c, 0x288e, 0x288e, 0x2891, 0x2891, 0x2893, 0x2893,
+    0x2895, 0x2895, 0x2897, 0x2897, 0x2899, 0x2899, 0x289b, 0x289b,
+    0x289d, 0x289d, 0x289f, 0x289f, 0x1ce2, 0x1ce2, 0x28a2, 0x28a2,
+    0x28a4, 0x28a4, 0x28a6, 0x28a6, 0x28a8, 0x28a8, 0x28aa, 0x28aa,
+    /* 0x2fa10 .. 0x2fa1f */
+    0x28ac, 0x28ac, 0x28af, 0x28af, 0x28b1, 0x28b1, 0x28b4, 0x28b4,
+    0x28b7, 0x28b7, 0x117c, 0x117c, 0x28ba, 0x28ba, 0x1184, 0x1184,
+    0x28bc, 0x28bc, 0x28be, 0x28be, 0x28c0, 0x28c0, 0x28c2, 0x28c2,
+    0x118e, 0x118e, 0x28c4, 0x28c4, 0x0000, 0x0000, 0x0000, 0x0000
+};
+
+static const BYTE class_index0[490] =
+{
+    0x00, 0x00, 0x00, 0x01, 0x02, 0x03, 0x04, 0x05,
+    0x06, 0x07, 0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d,
+    0x0e, 0x00, 0x00, 0x0f, 0x00, 0x00, 0x00, 0x10,
+    0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x00, 0x00,
+    0x17, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x18, 0x19, 0x00, 0x00,
+    0x1a, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1b, 0x00,
+    0x1c, 0x1d, 0x1e, 0x1f, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x21, 0x00,
+    0x00, 0x22, 0x23, 0x24, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x25, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x26, 0x27, 0x28, 0x29, 0x2a, 0x2b, 0x2c, 0x2d,
+    0x00, 0x00, 0x2e, 0x00, 0x2f, 0x30, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x31, 0x32, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x33, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x34, 0x35, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x36, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x37, 0x38
 };
 
-unsigned int DECLSPEC_HIDDEN wine_decompose( WCHAR ch, WCHAR *dst, unsigned int dstlen )
+static const BYTE class_index1[912] =
 {
-    const WCHAR *ptr = table + table[table[ch >> 8] + ((ch >> 4) & 0x0f)] + 2 * (ch & 0xf);
-    unsigned int res;
-
-    *dst = ch;
-    if (!*ptr) return 1;
-    if (dstlen <= 1) return 0;
-    /* apply the decomposition recursively to the first char */
-    if ((res = wine_decompose( *ptr, dst, dstlen-1 ))) dst[res++] = ptr[1];
-    return res;
+    /* null sub-index */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x01 */
+    0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x02 */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x03 */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x09, 0x0a, 0x0b, 0x0c, 0x00, 0x00, 0x00,
+    /* sub-index 0x04 */
+    0x00, 0x0d, 0x00, 0x00, 0x0e, 0x0f, 0x00, 0x10,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x11, 0x12, 0x00,
+    /* sub-index 0x05 */
+    0x00, 0x13, 0x00, 0x14, 0x15, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x16, 0x17,
+    /* sub-index 0x06 */
+    0x00, 0x18, 0x19, 0x00, 0x00, 0x1a, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x1b, 0x1c, 0x1d,
+    /* sub-index 0x07 */
+    0x00, 0x00, 0x00, 0x1e, 0x1f, 0x20, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x21, 0x22, 0x00, 0x00, 0x00,
+    /* sub-index 0x08 */
+    0x00, 0x00, 0x00, 0x23, 0x24, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x25, 0x26, 0x00, 0x00, 0x00,
+    /* sub-index 0x09 */
+    0x00, 0x00, 0x00, 0x27, 0x28, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x29, 0x00, 0x00, 0x00,
+    /* sub-index 0x0a */
+    0x00, 0x00, 0x00, 0x00, 0x2a, 0x2b, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x2c, 0x2d, 0x00, 0x00, 0x00,
+    /* sub-index 0x0b */
+    0x00, 0x00, 0x00, 0x2e, 0x2f, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0x00, 0x00,
+    /* sub-index 0x0c */
+    0x00, 0x00, 0x00, 0x31, 0x32, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x33, 0x34, 0x00, 0x00, 0x00,
+    /* sub-index 0x0d */
+    0x00, 0x35, 0x00, 0x36, 0x00, 0x00, 0x00, 0x37,
+    0x38, 0x00, 0x00, 0x00, 0x39, 0x00, 0x00, 0x00,
+    /* sub-index 0x0e */
+    0x00, 0x00, 0x00, 0x3a, 0x00, 0x00, 0x00, 0x00,
+    0x3b, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x0f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x3c, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x10 */
+    0x00, 0x3d, 0x00, 0x3e, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0x00, 0x00,
+    /* sub-index 0x11 */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x12 */
+    0x00, 0x00, 0x00, 0x41, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x13 */
+    0x00, 0x42, 0x00, 0x00, 0x00, 0x00, 0x43, 0x44,
+    0x00, 0x00, 0x00, 0x45, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x14 */
+    0x00, 0x00, 0x00, 0x46, 0x47, 0x00, 0x48, 0x49,
+    0x00, 0x00, 0x4a, 0x00, 0x00, 0x00, 0x4b, 0x4c,
+    /* sub-index 0x15 */
+    0x00, 0x00, 0x00, 0x4d, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x4e, 0x4f, 0x50,
+    /* sub-index 0x16 */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x51, 0x52, 0x53, 0x54,
+    /* sub-index 0x17 */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x55, 0x56, 0x57,
+    /* sub-index 0x18 */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x58, 0x59,
+    /* sub-index 0x19 */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x5a,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x5b, 0x5c,
+    /* sub-index 0x1a */
+    0x00, 0x00, 0x5d, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x5e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x1b */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x5f, 0x60,
+    0x00, 0x61, 0x00, 0x00, 0x00, 0x00, 0x00, 0x62,
+    /* sub-index 0x1c */
+    0x63, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x64, 0x00, 0x65, 0x66,
+    /* sub-index 0x1d */
+    0x00, 0x00, 0x67, 0x00, 0x00, 0x68, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x69, 0x6a, 0x00, 0x00, 0x00,
+    /* sub-index 0x1e */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x6b, 0x6c, 0x00, 0x00, 0x6d,
+    /* sub-index 0x1f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x6e, 0x00,
+    /* sub-index 0x20 */
+    0x00, 0x6f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x21 */
+    0x00, 0x00, 0x70, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x22 */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x71,
+    /* sub-index 0x23 */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x72, 0x00,
+    /* sub-index 0x24 */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x73,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x25 */
+    0x74, 0x00, 0x00, 0x75, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x76, 0x00,
+    /* sub-index 0x26 */
+    0x00, 0x00, 0x00, 0x00, 0x77, 0x00, 0x00, 0x78,
+    0x00, 0x00, 0x00, 0x79, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x27 */
+    0x7a, 0x00, 0x00, 0x7b, 0x00, 0x00, 0x00, 0x7c,
+    0x00, 0x00, 0x00, 0x00, 0x7d, 0x00, 0x00, 0x00,
+    /* sub-index 0x28 */
+    0x00, 0x00, 0x00, 0x7e, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7f, 0x00,
+    /* sub-index 0x29 */
+    0x00, 0x00, 0x00, 0x80, 0x81, 0x00, 0x82, 0x83,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x2a */
+    0x00, 0x00, 0x00, 0x00, 0x84, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x85, 0x00, 0x00, 0x00,
+    /* sub-index 0x2b */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x86, 0x87, 0x00, 0x00, 0x00,
+    /* sub-index 0x2c */
+    0x00, 0x00, 0x00, 0x88, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x89, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x2d */
+    0x00, 0x00, 0x8a, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x2e */
+    0x00, 0x00, 0x00, 0x8b, 0x8c, 0x00, 0x00, 0x00,
+    0x00, 0x8d, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x2f */
+    0x00, 0x00, 0x00, 0x8e, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x30 */
+    0x00, 0x00, 0x00, 0x00, 0x8f, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x31 */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x90,
+    /* sub-index 0x32 */
+    0x00, 0x00, 0x00, 0x91, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x33 */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x92, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x34 */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x93, 0x94,
+    0x95, 0x00, 0x96, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x35 */
+    0x00, 0x00, 0x00, 0x00, 0x97, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x36 */
+    0x98, 0x99, 0x9a, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* sub-index 0x37 */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x9b, 0x00, 0x00,
+    /* sub-index 0x38 */
+    0x00, 0x00, 0x00, 0x00, 0x9c, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
+};
+
+static const BYTE class_data[2512] =
+{
+    /* zero */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x0300 .. 0x030f */
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    /* 0x0310 .. 0x031f */
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe8, 0xdc, 0xdc,
+    0xdc, 0xdc, 0xe8, 0xd8, 0xdc, 0xdc, 0xdc, 0xdc,
+    /* 0x0320 .. 0x032f */
+    0xdc, 0xca, 0xca, 0xdc, 0xdc, 0xdc, 0xdc, 0xca,
+    0xca, 0xdc, 0xdc, 0xdc, 0xdc, 0xdc, 0xdc, 0xdc,
+    /* 0x0330 .. 0x033f */
+    0xdc, 0xdc, 0xdc, 0xdc, 0x01, 0x01, 0x01, 0x01,
+    0x01, 0xdc, 0xdc, 0xdc, 0xdc, 0xe6, 0xe6, 0xe6,
+    /* 0x0340 .. 0x034f */
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xf0, 0xe6, 0xdc,
+    0xdc, 0xdc, 0xe6, 0xe6, 0xe6, 0xdc, 0xdc, 0x00,
+    /* 0x0350 .. 0x035f */
+    0xe6, 0xe6, 0xe6, 0xdc, 0xdc, 0xdc, 0xdc, 0xe6,
+    0xe8, 0xdc, 0xdc, 0xe6, 0xe9, 0xea, 0xea, 0xe9,
+    /* 0x0360 .. 0x036f */
+    0xea, 0xea, 0xe9, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    /* 0x0480 .. 0x048f */
+    0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x0590 .. 0x059f */
+    0x00, 0xdc, 0xe6, 0xe6, 0xe6, 0xe6, 0xdc, 0xe6,
+    0xe6, 0xe6, 0xde, 0xdc, 0xe6, 0xe6, 0xe6, 0xe6,
+    /* 0x05a0 .. 0x05af */
+    0xe6, 0xe6, 0xdc, 0xdc, 0xdc, 0xdc, 0xdc, 0xdc,
+    0xe6, 0xe6, 0xdc, 0xe6, 0xe6, 0xde, 0xe4, 0xe6,
+    /* 0x05b0 .. 0x05bf */
+    0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f, 0x10, 0x11,
+    0x12, 0x13, 0x13, 0x14, 0x15, 0x16, 0x00, 0x17,
+    /* 0x05c0 .. 0x05cf */
+    0x00, 0x18, 0x19, 0x00, 0xe6, 0xdc, 0x00, 0x12,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x0610 .. 0x061f */
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    0x1e, 0x1f, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x0640 .. 0x064f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x1b, 0x1c, 0x1d, 0x1e, 0x1f,
+    /* 0x0650 .. 0x065f */
+    0x20, 0x21, 0x22, 0xe6, 0xe6, 0xdc, 0xdc, 0xe6,
+    0xe6, 0xe6, 0xe6, 0xe6, 0xdc, 0xe6, 0xe6, 0xdc,
+    /* 0x0670 .. 0x067f */
+    0x23, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x06d0 .. 0x06df */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6,
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x00, 0x00, 0xe6,
+    /* 0x06e0 .. 0x06ef */
+    0xe6, 0xe6, 0xe6, 0xdc, 0xe6, 0x00, 0x00, 0xe6,
+    0xe6, 0x00, 0xdc, 0xe6, 0xe6, 0xdc, 0x00, 0x00,
+    /* 0x0710 .. 0x071f */
+    0x00, 0x24, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x0730 .. 0x073f */
+    0xe6, 0xdc, 0xe6, 0xe6, 0xdc, 0xe6, 0xe6, 0xdc,
+    0xdc, 0xdc, 0xe6, 0xdc, 0xdc, 0xe6, 0xdc, 0xe6,
+    /* 0x0740 .. 0x074f */
+    0xe6, 0xe6, 0xdc, 0xe6, 0xdc, 0xe6, 0xdc, 0xe6,
+    0xdc, 0xe6, 0xe6, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x07e0 .. 0x07ef */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    /* 0x07f0 .. 0x07ff */
+    0xe6, 0xe6, 0xdc, 0xe6, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x0810 .. 0x081f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6,
+    0xe6, 0xe6, 0x00, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    /* 0x0820 .. 0x082f */
+    0xe6, 0xe6, 0xe6, 0xe6, 0x00, 0xe6, 0xe6, 0xe6,
+    0x00, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x00, 0x00,
+    /* 0x0850 .. 0x085f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0xdc, 0xdc, 0xdc, 0x00, 0x00, 0x00, 0x00,
+    /* 0x08d0 .. 0x08df */
+    0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6, 0xe6,
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    /* 0x08e0 .. 0x08ef */
+    0xe6, 0xe6, 0x00, 0xdc, 0xe6, 0xe6, 0xdc, 0xe6,
+    0xe6, 0xdc, 0xe6, 0xe6, 0xe6, 0xdc, 0xdc, 0xdc,
+    /* 0x08f0 .. 0x08ff */
+    0x1b, 0x1c, 0x1d, 0xe6, 0xe6, 0xe6, 0xdc, 0xe6,
+    0xe6, 0xdc, 0xdc, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    /* 0x0930 .. 0x093f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00,
+    /* 0x0940 .. 0x094f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00,
+    /* 0x0950 .. 0x095f */
+    0x00, 0xe6, 0xdc, 0xe6, 0xe6, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x09b0 .. 0x09bf */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00,
+    /* 0x09c0 .. 0x09cf */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00,
+    /* 0x0a30 .. 0x0a3f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00,
+    /* 0x0a40 .. 0x0a4f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00,
+    /* 0x0ab0 .. 0x0abf */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00,
+    /* 0x0ac0 .. 0x0acf */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00,
+    /* 0x0b30 .. 0x0b3f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00,
+    /* 0x0b40 .. 0x0b4f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00,
+    /* 0x0bc0 .. 0x0bcf */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00,
+    /* 0x0c40 .. 0x0c4f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00,
+    /* 0x0c50 .. 0x0c5f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x54, 0x5b, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x0cb0 .. 0x0cbf */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00,
+    /* 0x0cc0 .. 0x0ccf */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00,
+    /* 0x0d30 .. 0x0d3f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x09, 0x09, 0x00, 0x00, 0x00,
+    /* 0x0d40 .. 0x0d4f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00,
+    /* 0x0dc0 .. 0x0dcf */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x09, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x0e30 .. 0x0e3f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x67, 0x67, 0x09, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x0e40 .. 0x0e4f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x6b, 0x6b, 0x6b, 0x6b, 0x00, 0x00, 0x00, 0x00,
+    /* 0x0eb0 .. 0x0ebf */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x76, 0x76, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x0ec0 .. 0x0ecf */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x7a, 0x7a, 0x7a, 0x7a, 0x00, 0x00, 0x00, 0x00,
+    /* 0x0f10 .. 0x0f1f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0xdc, 0xdc, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x0f30 .. 0x0f3f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0xdc, 0x00, 0xdc,
+    0x00, 0xd8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x0f70 .. 0x0f7f */
+    0x00, 0x81, 0x82, 0x00, 0x84, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x82, 0x82, 0x82, 0x82, 0x00, 0x00,
+    /* 0x0f80 .. 0x0f8f */
+    0x82, 0x00, 0xe6, 0xe6, 0x09, 0x00, 0xe6, 0xe6,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x0fc0 .. 0x0fcf */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xdc, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1030 .. 0x103f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
+    0x00, 0x09, 0x09, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1080 .. 0x108f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0xdc, 0x00, 0x00,
+    /* 0x1350 .. 0x135f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6,
+    /* 0x1710 .. 0x171f */
+    0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1730 .. 0x173f */
+    0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x17d0 .. 0x17df */
+    0x00, 0x00, 0x09, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0x00, 0x00,
+    /* 0x18a0 .. 0x18af */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0xe4, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1930 .. 0x193f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0xde, 0xe6, 0xdc, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1a10 .. 0x1a1f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe6,
+    0xdc, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1a60 .. 0x1a6f */
+    0x09, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1a70 .. 0x1a7f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6,
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x00, 0x00, 0xdc,
+    /* 0x1ab0 .. 0x1abf */
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xdc, 0xdc, 0xdc,
+    0xdc, 0xdc, 0xdc, 0xe6, 0xe6, 0xdc, 0x00, 0x00,
+    /* 0x1b30 .. 0x1b3f */
+    0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1b40 .. 0x1b4f */
+    0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1b60 .. 0x1b6f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0xe6, 0xdc, 0xe6, 0xe6, 0xe6,
+    /* 0x1b70 .. 0x1b7f */
+    0xe6, 0xe6, 0xe6, 0xe6, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1ba0 .. 0x1baf */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x09, 0x09, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1be0 .. 0x1bef */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1bf0 .. 0x1bff */
+    0x00, 0x00, 0x09, 0x09, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1c30 .. 0x1c3f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1cd0 .. 0x1cdf */
+    0xe6, 0xe6, 0xe6, 0x00, 0x01, 0xdc, 0xdc, 0xdc,
+    0xdc, 0xdc, 0xe6, 0xe6, 0xdc, 0xdc, 0xdc, 0xdc,
+    /* 0x1ce0 .. 0x1cef */
+    0xe6, 0x00, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
+    0x01, 0x00, 0x00, 0x00, 0x00, 0xdc, 0x00, 0x00,
+    /* 0x1cf0 .. 0x1cff */
+    0x00, 0x00, 0x00, 0x00, 0xe6, 0x00, 0x00, 0x00,
+    0xe6, 0xe6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1dc0 .. 0x1dcf */
+    0xe6, 0xe6, 0xdc, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    0xe6, 0xe6, 0xdc, 0xe6, 0xe6, 0xea, 0xd6, 0xdc,
+    /* 0x1dd0 .. 0x1ddf */
+    0xca, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    /* 0x1de0 .. 0x1def */
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    /* 0x1df0 .. 0x1dff */
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe8, 0xe4,
+    0xe4, 0xdc, 0x00, 0xe6, 0xe9, 0xdc, 0xe6, 0xdc,
+    /* 0x20d0 .. 0x20df */
+    0xe6, 0xe6, 0x01, 0x01, 0xe6, 0xe6, 0xe6, 0xe6,
+    0x01, 0x01, 0x01, 0xe6, 0xe6, 0x00, 0x00, 0x00,
+    /* 0x20e0 .. 0x20ef */
+    0x00, 0xe6, 0x00, 0x00, 0x00, 0x01, 0x01, 0xe6,
+    0xdc, 0xe6, 0x01, 0x01, 0xdc, 0xdc, 0xdc, 0xdc,
+    /* 0x20f0 .. 0x20ff */
+    0xe6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x2ce0 .. 0x2cef */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe6,
+    /* 0x2cf0 .. 0x2cff */
+    0xe6, 0xe6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x2d70 .. 0x2d7f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x09,
+    /* 0x2de0 .. 0x2def */
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    /* 0x2df0 .. 0x2dff */
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    /* 0x3020 .. 0x302f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0xda, 0xe4, 0xe8, 0xde, 0xe0, 0xe0,
+    /* 0x3090 .. 0x309f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x08, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0xa660 .. 0xa66f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe6,
+    /* 0xa670 .. 0xa67f */
+    0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6, 0xe6,
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x00, 0x00,
+    /* 0xa690 .. 0xa69f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6,
+    /* 0xa6f0 .. 0xa6ff */
+    0xe6, 0xe6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0xa800 .. 0xa80f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0xa8c0 .. 0xa8cf */
+    0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0xa8e0 .. 0xa8ef */
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    /* 0xa8f0 .. 0xa8ff */
+    0xe6, 0xe6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0xa920 .. 0xa92f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0xdc, 0xdc, 0xdc, 0x00, 0x00,
+    /* 0xa950 .. 0xa95f */
+    0x00, 0x00, 0x00, 0x09, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0xa9b0 .. 0xa9bf */
+    0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0xa9c0 .. 0xa9cf */
+    0x09, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0xaab0 .. 0xaabf */
+    0xe6, 0x00, 0xe6, 0xe6, 0xdc, 0x00, 0x00, 0xe6,
+    0xe6, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6,
+    /* 0xaac0 .. 0xaacf */
+    0x00, 0xe6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0xaaf0 .. 0xaaff */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0xabe0 .. 0xabef */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00,
+    /* 0xfb10 .. 0xfb1f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1a, 0x00,
+    /* 0xfe20 .. 0xfe2f */
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xdc,
+    0xdc, 0xdc, 0xdc, 0xdc, 0xdc, 0xdc, 0xe6, 0xe6,
+    /* 0x101f0 .. 0x101ff */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0xdc, 0x00, 0x00,
+    /* 0x102e0 .. 0x102ef */
+    0xdc, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x10370 .. 0x1037f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6,
+    0xe6, 0xe6, 0xe6, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x10a00 .. 0x10a0f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0xdc, 0x00, 0xe6,
+    /* 0x10a30 .. 0x10a3f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0xe6, 0x01, 0xdc, 0x00, 0x00, 0x00, 0x00, 0x09,
+    /* 0x10ae0 .. 0x10aef */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xdc, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x11040 .. 0x1104f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x11070 .. 0x1107f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x09,
+    /* 0x110b0 .. 0x110bf */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x09, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x11100 .. 0x1110f */
+    0xe6, 0xe6, 0xe6, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x11130 .. 0x1113f */
+    0x00, 0x00, 0x00, 0x09, 0x09, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x11170 .. 0x1117f */
+    0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x111c0 .. 0x111cf */
+    0x09, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x11230 .. 0x1123f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x07, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x112e0 .. 0x112ef */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x07, 0x09, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x11330 .. 0x1133f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00,
+    /* 0x11340 .. 0x1134f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00,
+    /* 0x11360 .. 0x1136f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6,
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x00, 0x00, 0x00,
+    /* 0x11370 .. 0x1137f */
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x11440 .. 0x1144f */
+    0x00, 0x00, 0x09, 0x00, 0x00, 0x00, 0x07, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x114c0 .. 0x114cf */
+    0x00, 0x00, 0x09, 0x07, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x115b0 .. 0x115bf */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x09,
+    /* 0x115c0 .. 0x115cf */
+    0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x11630 .. 0x1163f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x09,
+    /* 0x116b0 .. 0x116bf */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x07,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x11720 .. 0x1172f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x09, 0x00, 0x00, 0x00, 0x00,
+    /* 0x11a30 .. 0x11a3f */
+    0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x11a40 .. 0x11a4f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x09,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x11a90 .. 0x11a9f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x09, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x11c30 .. 0x11c3f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x09,
+    /* 0x11d40 .. 0x11d4f */
+    0x00, 0x00, 0x07, 0x00, 0x09, 0x09, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x16af0 .. 0x16aff */
+    0x01, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x16b30 .. 0x16b3f */
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1bc90 .. 0x1bc9f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00,
+    /* 0x1d160 .. 0x1d16f */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0xd8, 0xd8, 0x01,
+    0x01, 0x01, 0x00, 0x00, 0x00, 0xe2, 0xd8, 0xd8,
+    /* 0x1d170 .. 0x1d17f */
+    0xd8, 0xd8, 0xd8, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0xdc, 0xdc, 0xdc, 0xdc, 0xdc,
+    /* 0x1d180 .. 0x1d18f */
+    0xdc, 0xdc, 0xdc, 0x00, 0x00, 0xe6, 0xe6, 0xe6,
+    0xe6, 0xe6, 0xdc, 0xdc, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1d1a0 .. 0x1d1af */
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0xe6, 0xe6, 0xe6, 0xe6, 0x00, 0x00,
+    /* 0x1d240 .. 0x1d24f */
+    0x00, 0x00, 0xe6, 0xe6, 0xe6, 0x00, 0x00, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1e000 .. 0x1e00f */
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x00,
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    /* 0x1e010 .. 0x1e01f */
+    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    0xe6, 0x00, 0x00, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,
+    /* 0x1e020 .. 0x1e02f */
+    0xe6, 0xe6, 0x00, 0xe6, 0xe6, 0x00, 0xe6, 0xe6,
+    0xe6, 0xe6, 0xe6, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1e8d0 .. 0x1e8df */
+    0xdc, 0xdc, 0xdc, 0xdc, 0xdc, 0xdc, 0xdc, 0x00,
+    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+    /* 0x1e940 .. 0x1e94f */
+    0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6, 0xe6,
+    0xe6, 0xe6, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00
+};
+
+static inline const WCHAR *decomp_lookup( UINT x, int k )
+{
+    if (x <= decomp_last)
+    {
+        USHORT a, b, c, d;
+        a = decomp_index0[x >> 8];
+        b = decomp_index1[(a << 4) | ((x >> 4) & 0xf)];
+        c = (b << 5) | ((x & 0xf) << 1);
+        if (k) ++c;
+        d = decomp_offsets[c];
+        return &decomp_data[d];
+    }
+    else
+    {
+        return NULL;
+    }
+}
+
+static inline BYTE class_lookup( UINT x )
+{
+    if (x <= class_last)
+    {
+        BYTE a, b;
+        a = class_index0[x >> 8];
+        b = class_index1[(a << 4) | ((x >> 4) & 0xf)];
+        return class_data[(b << 4) | (x & 0xf)];
+    }
+    else
+    {
+        return 0;
+    }
+}
+
+static inline int decompose_hangul( WCHAR ch, WCHAR *l, WCHAR *v, WCHAR *t )
+{
+    static const WCHAR sbase = 0xac00, lbase = 0x1100, vbase = 0x1161, tbase = 0x11a7;
+    static const WCHAR /*lcount = 19, vcount = 21,*/ tcount = 28, ncount = 588/*, scount = 11172*/;
+    WCHAR sindex, lindex, vindex, tindex;
+    sindex = ch - sbase;
+    lindex = sindex / ncount;
+    vindex = (sindex % ncount) / tcount;
+    tindex = sindex % tcount;
+    *l = lbase + lindex;
+    *v = vbase + vindex;
+    *t = (tindex > 0) ? (tbase + tindex) : 0;
+    return 0;
+}
+
+static inline int decompose_pair( UINT ch, WCHAR *hi, WCHAR *lo )
+{
+    if (ch <= 0xffff)
+    {
+        *hi = ch;
+        *lo = 0;
+    }
+    else
+    {
+        WCHAR hx, hw, lx;
+        UINT hu;
+        hx = (WCHAR)ch;
+        hu = (ch >> 16) & ((1 << 5) - 1);
+        hw = (WCHAR)hu - 1;
+        lx = (WCHAR)ch;
+        *hi = 0xD800 | (hw << 6) | (hx >> 10);
+        *lo = (WCHAR)(0xDC00 | (lx & ((1 << 10) - 1)));
+    }
+    return 0;
+}
+
+static inline UINT compose_pair( WCHAR hi, WCHAR lo )
+{
+    UINT x, w, u, c;
+    x = ((hi & ((1 << 6) - 1)) << 10) | (lo & ((1 << 10) - 1));
+    w = (hi >> 6) & ((1 << 5) - 1);
+    u = w + 1;
+    c = (u << 16) | x;
+    return c;
+}
+
+static int decompose( int compat, UINT ch, WCHAR *dst, unsigned int dstlen )
+{
+    const WCHAR *mapping = NULL;
+    WCHAR buffer[4] = {0, 0, 0, 0};
+    int i = 0;
+    int write = 1;
+    if (dstlen == 0 || dst == NULL) write = 0;
+
+    if (ch < 0xa0) /* fast path */
+    {
+        buffer[0] = ch;
+        mapping = buffer;
+    }
+    else if (ch >= 0xac00 && ch <= 0xd7af) /* Hangul */
+    {
+        decompose_hangul(ch, &buffer[0], &buffer[1], &buffer[2]);
+        mapping = buffer;
+    }
+    else
+    {
+        mapping = decomp_lookup(ch, compat);
+    }
+
+    if (!mapping || !*mapping)
+    {
+        decompose_pair(ch, &buffer[0], &buffer[1]);
+        mapping = buffer;
+    }
+
+    do
+    {
+        if (i >= dstlen) write = 0;
+        if (write) dst[i] = mapping[i];
+    }
+    while (mapping[++i] != 0);
+    return i;
+}
+
+static int reorder( WCHAR *str, int len )
+{
+    int i = 0, j, m, p, seqlen;
+    UINT ch1, ch2;
+    BYTE k1, k2;
+
+    while (i < len)
+    {
+        /* Seek to first non-starter */
+        while (i < len)
+        {
+            UINT c;
+            c = str[i];
+            if (c >= 0xd800 && c <= 0xdbff)
+                c = compose_pair(c, str[++i]);
+            if (class_lookup(c)) break;
+            ++i;
+        }
+
+        /* Seek to next starter or end */
+        j = i + 1;
+        while (j < len)
+        {
+            UINT c;
+            c = str[j];
+            if (c >= 0xd800 && c <= 0xdbff)
+                c = compose_pair(c, str[++j]);
+            if (!class_lookup(c)) break;
+            ++j;
+        }
+
+        seqlen = j - i;
+
+        /* Bubble sort */
+        while (seqlen-- > 1)
+        {
+            for (m = 0; m < seqlen; ++m)
+            {
+                p = i + m;
+
+                ch1 = str[i + m];
+                if (ch1 >= 0xd800 && ch1 <= 0xdbff)
+                    ch1 = compose_pair(ch1, str[i + ++m]);
+                k1 = class_lookup(ch1);
+
+                ch2 = str[i + m + 1];
+                if (ch2 >= 0xd800 && ch2 <= 0xdbff)
+                    ch2 = compose_pair(ch2, str[i + ++m + 1]);
+                k2 = class_lookup(ch2);
+
+                /* Swap */
+                if (k1 > k2)
+                {
+                    if (ch2 <= 0xffff)
+                    {
+                        str[p++] = ch2;
+                    }
+                    else
+                    {
+                        WCHAR *hi, *lo;
+                        hi = &str[p++];
+                        lo = &str[p++];
+                        decompose_pair(ch2, hi, lo);
+                    }
+
+                    if (ch1 <= 0xffff)
+                    {
+                        str[p++] = ch1;
+                    }
+                    else
+                    {
+                        WCHAR *hi, *lo;
+                        hi = &str[p++];
+                        lo = &str[p++];
+                        decompose_pair(ch1, hi, lo);
+                    }
+                }
+            }
+        }
+        i = j;
+    }
+    return 0;
+}
+
+unsigned int wine_decompose ( WCHAR ch, WCHAR *dst, unsigned int dstlen )
+{
+    int r;
+    r = decompose(0, ch, dst, dstlen);
+    if (r <= dstlen) return r;
+    else return 0;
+}
+
+int wine_decompose_string( int compat, const WCHAR *src, int srclen, WCHAR *dst, int dstlen )
+{
+    UINT ch;
+    int srcpos = 0, dstpos = 0, r;
+    if (srclen <= 0 || src == NULL) return 0;
+    if (dstlen < 0) dstlen = 0;
+
+    while (srcpos < srclen)
+    {
+        ch = src[srcpos];
+        if (ch >= 0xd800 && ch <= 0xdbff) /* high surrogate */
+        {
+            WCHAR hi, lo;
+            if (srcpos+1 == srclen) return (-srcpos);
+            hi = (WCHAR)ch;
+            lo = src[++srcpos];
+            if (lo < 0xdc00 || lo > 0xdfff) return (-srcpos);
+            ch = compose_pair(hi, lo);
+        }
+        else if (ch >= 0xdc00 && ch <= 0xdfff) /* low surrogate */
+        {
+            return (-srcpos);
+        }
+
+        r = decompose(compat, ch, dst+dstpos, dstlen);
+        dstpos += r;
+
+        if (dstlen > 0)
+        {
+            dstlen -= r;
+            if (dstlen < 0) dstlen = 0;
+        }
+
+        ++srcpos;
+    }
+
+    if (dstlen) reorder(dst, dstpos+1);
+    return dstpos+1;
 }
diff --git a/tools/make_unicode b/tools/make_unicode
index 92b0b64a94..c795e268e6 100755
--- a/tools/make_unicode
+++ b/tools/make_unicode
@@ -357,7 +357,9 @@ my @compatmap_table = ();
 my @category_table = ();
 my @joining_table = ();
 my @direction_table = ();
+my @combining_table = ();
 my @decomp_table = ();
+my @decomp_table_full = ();
 my @compose_table = ();
 my $default_char;
 my $default_wchar;
@@ -469,8 +471,31 @@ sub READ_DEFAULTS($)
             }
         }
 
+        # store combining class information
+        if ($comb ne "" && $comb != 0) { $combining_table[$src] = $comb; }
+
         next if $decomp eq "";  # no decomposition, skip it
 
+        # store all decompositions (and not just <compat> for NFKD)
+        if ($decomp =~ /^<([a-zA-Z]+)>(\s+[0-9a-fA-F]+)+$/)
+        {
+            my @seq = ();
+            for my $ch (split /\s+/, (split /\s+/, $decomp, 2)[1])
+            {
+                push @seq, (hex $ch);
+            }
+            $decomp_table_full[$src] = [1, \@seq];
+        }
+        elsif ($decomp =~ /^([0-9a-fA-F]+)(\s+([0-9a-fA-F]+))*$/)
+        {
+            my @seq = ();
+            for my $ch (split /\s+/, $decomp)
+            {
+                push @seq, (hex $ch);
+            }
+            $decomp_table_full[$src] = [0, \@seq];
+        }
+
         if ($decomp =~ /^<([a-zA-Z]+)>\s+([0-9a-fA-F]+)$/)
         {
             # decomposition of the form "<foo> 1234" -> use char if type is known
@@ -760,7 +785,7 @@ sub READ_SORTKEYS_FILE()
     # compress the keys to 32 bit:
     # key 1 to 16 bits, key 2 to 8 bits, key 3 to 4 bits, key 4 to 1 bit
 
-    @sortkeys = sort { ${$a}[1] <=> ${$b}[1] or 
+    @sortkeys = sort { ${$a}[1] <=> ${$b}[1] or
                        ${$a}[2] <=> ${$b}[2] or
                        ${$a}[3] <=> ${$b}[3] or
                        ${$a}[4] <=> ${$b}[4] or
@@ -1894,7 +1919,7 @@ sub dump_binary_case_table(@)
     my @difftables;
     my %offtables2_hash = ();
     my @offtables2 = ();
-    
+
     my @offtable = ();
     for (my $i = 0; $i < 256; $i++)
     {
@@ -2242,7 +2267,7 @@ static inline int binary_search( WCHAR ch, int low, int high )
     return -1;
 }
 
-WCHAR DECLSPEC_HIDDEN wine_compose( const WCHAR *str )
+WCHAR wine_compose( const WCHAR *str )
 {
     int pos, idx = 1, start = 0, count = $count;
     for (;;)
@@ -2253,11 +2278,62 @@ WCHAR DECLSPEC_HIDDEN wine_compose( const WCHAR *str )
         count = table[2 * pos + 3];
     }
 }
+
+int wine_compose_string( int compat, const WCHAR *src, int srclen, WCHAR *dst, int dstlen )
+{
+    /* FIXME: Implement */
+    return 0;
+}
 EOF
     close OUTPUT;
     save_file($filename);
 }
 
+sub recursive_decomp
+{
+    my ($char, $table_ref, $compat) = @_;
+
+    return ($char) unless defined $table_ref->[$char];
+    my $data = $table_ref->[$char];
+    return ($char) if $data->[0] && !$compat;
+    my @mapping = ();
+    for my $ch (@{$data->[1]})
+    {
+        push @mapping, recursive_decomp( $ch, $table_ref, $compat );
+    }
+    return @mapping;
+}
+
+sub expand_pairs
+{
+    my @data = @_;
+    my @result = ();
+
+    for my $ch (@data)
+    {
+        if ($ch <= 0xFFFF)
+        {
+            push @result, $ch;
+        }
+        elsif ($ch >= 2097152) # 2**21
+        {
+            die sprintf "Invalid Unicode character %04x\n", $ch;
+        }
+        else
+        {
+            my $hx = $ch & 0xFFFF;
+            my $hu = ($ch >> 16) & ((1 << 5) - 1);
+            my $hw = ($hu - 1) & 0xFFFF;
+            my $hi = 0xD800 | ($hw << 6) | ($hx >> 10);
+            my $lx = $ch & 0xFFFF;
+            my $lo = (0xDC00 | ($lx & ((1 << 10) - 1))) & 0xFFFF;
+            push @result, $hi;
+            push @result, $lo;
+        }
+    }
+    return @result;
+}
+
 ################################################################
 # dump the char decomposition table
 sub dump_decompose_table($)
@@ -2266,98 +2342,494 @@ sub dump_decompose_table($)
 
     open OUTPUT,">$filename.new" or die "Cannot create $filename";
     print "Building $filename\n";
-    print OUTPUT "/* Unicode char composition */\n";
+    print OUTPUT "/* Unicode char decomposition */\n";
     print OUTPUT "/* generated from $UNIDATA/UnicodeData.txt */\n";
     print OUTPUT "/* DO NOT EDIT!! */\n\n";
     print OUTPUT "#include \"wine/unicode.h\"\n\n";
 
-    # first determine all the 16-char subsets that contain something
+    # set to 65536 (2^16) to disable surrogate pairs
+    my $utflim = 1114112; # 2^20 + 2^16
+    my %nfd_lookup = ();
+    my %nfkd_lookup = ();
+    my %decomp_lookup = ();
+    my @decomp_data = (0);
+    my $pos = 1;
+    my $lastchar;
+    my $lastclass;
 
-    my @filled = (0) x 4096;
-    my $pos = 16*2;  # for the null subset
-    for (my $i = 0; $i < 65536; $i++)
+    for (my $i = 0; $i < $utflim; $i++)
     {
-        next unless defined $decomp_table[$i];
-        $filled[$i >> 4] = $pos;
-        $pos += 16*2;
-        $i |= 15;
+        $lastclass = $i if defined $combining_table[$i];
+        next unless defined $decomp_table_full[$i];
+        $lastchar = $i;
+
+        # fully expand input and mappings
+
+        my @char = expand_pairs( ($i) );
+        push @char, 0;
+        my $char = pack "n*", @char;
+
+        my @nfd = recursive_decomp( $i, \@decomp_table_full, 0 );
+        @nfd = expand_pairs( @nfd );
+        push @nfd, 0;
+        my $nfd = pack "n*", @nfd;
+
+        my @nfkd = recursive_decomp( $i, \@decomp_table_full, 1 );
+        @nfkd = expand_pairs( @nfkd );
+        push @nfkd, 0;
+        my $nfkd = pack "n*", @nfkd;
+
+        # lookup or add mappings
+
+        if ($nfd eq $char)
+        {
+            $nfd = undef;
+        }
+        elsif (exists $decomp_lookup{$nfd})
+        {
+            $nfd_lookup{$i} = $decomp_lookup{$nfd};
+        }
+        else
+        {
+            push @decomp_data, @nfd;
+            $decomp_lookup{$nfd} = $pos;
+            $nfd_lookup{$i} = $pos;
+            $pos += @nfd;
+        }
+
+        if ($nfkd eq $char)
+        {
+            $nfkd = undef;
+        }
+        elsif (exists $decomp_lookup{$nfkd})
+        {
+            $nfkd_lookup{$i} = $decomp_lookup{$nfkd};
+        }
+        else
+        {
+            push @decomp_data, @nfkd;
+            $decomp_lookup{$nfkd} = $pos;
+            $nfkd_lookup{$i} = $pos;
+            $pos += @nfkd;
+        }
     }
-    my $total = $pos;
 
-    # now count the 256-char subsets that contain something
+    printf OUTPUT "static const UINT decomp_last = 0x%04x;\n\n", $lastchar;
+    printf OUTPUT "static const UINT class_last = 0x%04x;\n\n", $lastclass;
 
-    my @filled_idx = (256) x 256;
-    $pos = 256 + 16;
-    for (my $i = 0; $i < 4096; $i++)
+    # dump decomposition data
+
+    printf OUTPUT "static const WCHAR decomp_data[%d] =\n", $pos;
+    print OUTPUT "{\n";
+    printf OUTPUT "%s", DUMP_ARRAY( "0x%04x", 0, @decomp_data );
+    print OUTPUT "\n};\n\n";
+
+    # decomp: find 256-char subsets that contain something
+
+    my $filled_pos = 1;
+    my $filled_lim = ($lastchar >> 8) + 1;
+    my @filled = (0) x $filled_lim;
+    for (my $i = 0; $i < $utflim; $i++)
+    {
+        last if $i > $lastchar;
+        next unless exists $nfd_lookup{$i} || exists $nfkd_lookup{$i};
+        $filled[$i >> 8] = $filled_pos++;
+        $i |= 255;
+    }
+
+    # decomp: dump index of 256-char subsets
+
+    printf OUTPUT "static const BYTE decomp_index0[%d] =\n", $filled_lim;
+    print OUTPUT "{\n";
+    printf OUTPUT "%s", DUMP_ARRAY( "0x%02x", 0, @filled );
+    print OUTPUT "\n};\n\n";
+
+    # decomp: for 256-char subsets, find non-empty 16-char subsets
+
+    my $sub_filled_pos = 1;
+    my %sub_filled = ();
+    for (my $i = 0; $i < $filled_lim; $i++)
     {
         next unless $filled[$i];
-        $filled_idx[$i >> 4] = $pos;
-        $pos += 16;
-        $i |= 15;
+        for (my $j = 0; $j < 256; $j++)
+        {
+            my $idx = ($i << 8) | $j;
+            next unless exists $nfd_lookup{$idx} || exists $nfkd_lookup{$idx};
+            $sub_filled{$idx >> 4} = $sub_filled_pos++;
+            $j |= 15;
+        }
     }
-    my $null_offset = $pos;  # null mapping
-    $total += $pos;
 
-    # add the index offsets to the subsets positions
+    # decomp: dump index of 16-char subsets
 
-    for (my $i = 0; $i < 4096; $i++)
+    printf OUTPUT "static const USHORT decomp_index1[%d] =\n", $filled_pos * 16;
+    print OUTPUT "{\n";
+    my @null_idx = (0) x 16;
+    print OUTPUT "    /* null sub-index */\n";
+    printf OUTPUT "%s", DUMP_ARRAY( "0x%04x", 0, @null_idx );
+    for (my $i = 0; $i < $filled_lim; $i++)
     {
         next unless $filled[$i];
-        $filled[$i] += $null_offset;
+        printf OUTPUT ",\n    /* sub-index 0x%02x */\n", $filled[$i];
+
+        my @sub_idx;
+        for (my $j = 0; $j < 16; $j++)
+        {
+            my $idx = ($i << 4) | $j;
+            $sub_idx[$j] = $sub_filled{$idx} || 0;
+        }
+        printf OUTPUT "%s", DUMP_ARRAY( "0x%04x", 0, @sub_idx );
     }
+    print OUTPUT "\n};\n\n";
 
-    # dump the main index
+    # decomp: dump the 16-char subsets
 
-    printf OUTPUT "static const WCHAR table[%d] =\n", $total;
-    printf OUTPUT "{\n    /* index */\n";
-    printf OUTPUT "%s", DUMP_ARRAY( "0x%04x", 0, @filled_idx );
-    printf OUTPUT ",\n    /* null sub-index */\n%s", DUMP_ARRAY( "0x%04x", 0, ($null_offset) x 16 );
+    printf OUTPUT "static const USHORT decomp_offsets[%d] =\n", 32 * $sub_filled_pos;
+    print OUTPUT "{\n";
+    print OUTPUT "    /* (nfd, nfkd) x 16 */\n";
+    my @null_table = (0) x 32;
+    print OUTPUT "    /* no decomposition */\n";
+    printf OUTPUT "%s", DUMP_ARRAY( "0x%04x", 0, @null_table );
+    for my $key (sort {$a <=> $b} keys %sub_filled)
+    {
+        printf OUTPUT ",\n    /* 0x%03x0 .. 0x%03xf */\n", $key, $key;
+        my @sub_table;
+        for (my $j = 0; $j < 16; $j++)
+        {
+            my $idx = ($key << 4) | $j;
+            $sub_table[2 * $j] = $nfd_lookup{$idx} || 0;
+            $sub_table[2 * $j + 1] = $nfkd_lookup{$idx} || 0;
+        }
+        printf OUTPUT "%s", DUMP_ARRAY( "0x%04x", 0, @sub_table );
+    }
+    print OUTPUT "\n};\n\n";
 
-    # dump the second-level indexes
+    # class: find 256-char subsets that contain something
 
-    for (my $i = 0; $i < 256; $i++)
+    my $class_pos = 1;
+    my $class_lim = ($lastclass >> 8) + 1;
+    my @class = (0) x $class_lim;
+    for (my $i = 0; $i < $utflim; $i++)
     {
-        next unless ($filled_idx[$i] > 256);
-        my @table = @filled[($i<<4)..($i<<4)+15];
-        for (my $j = 0; $j < 16; $j++) { $table[$j] ||= $null_offset; }
-        printf OUTPUT ",\n    /* sub-index %02x */\n", $i;
-        printf OUTPUT "%s", DUMP_ARRAY( "0x%04x", 0, @table );
+        last if $i > $lastclass;
+        next unless defined $combining_table[$i];
+        $class[$i >> 8] = $class_pos++;
+        $i |= 255;
     }
 
-    # dump the 16-char subsets
+    # class: dump index of 256-char subsets
 
-    printf OUTPUT ",\n    /* null mapping */\n";
-    printf OUTPUT "%s", DUMP_ARRAY( "0x%04x", 0, (0) x 32 );
+    printf OUTPUT "static const BYTE class_index0[%d] =\n", $class_lim;
+    print OUTPUT "{\n";
+    printf OUTPUT "%s", DUMP_ARRAY( "0x%02x", 0, @class );
+    print OUTPUT "\n};\n\n";
 
-    for (my $i = 0; $i < 4096; $i++)
+    # class: for 256-char subsets, find non-empty 16-char subsets
+
+    my $sub_class_pos = 1;
+    my %sub_class = ();
+    for (my $i = 0; $i < $class_lim; $i++)
     {
-        next unless $filled[$i];
-        my @table = (0) x 32;
+        next unless $class[$i];
+        for (my $j = 0; $j < 256; $j++)
+        {
+            my $idx = ($i << 8) | $j;
+            next unless defined $combining_table[$idx];
+            $sub_class{$idx >> 4} = $sub_class_pos++;
+            $j |= 15;
+        }
+    }
+
+    # class: dump index of 16-char subsets
+
+    @null_idx = (0) x 16;
+    printf OUTPUT "static const BYTE class_index1[%d] =\n", $class_pos * 16;
+    print OUTPUT "{\n";
+    print OUTPUT "    /* null sub-index */\n";
+    printf OUTPUT "%s", DUMP_ARRAY( "0x%02x", 0, @null_idx );
+    for (my $i = 0; $i < $class_lim; $i++)
+    {
+        next unless $class[$i];
+        printf OUTPUT ",\n    /* sub-index 0x%02x */\n", $class[$i];
+
+        my @sub_idx;
+        for (my $j = 0; $j < 16; $j++)
+        {
+            my $idx = ($i << 4) | $j;
+            $sub_idx[$j] = $sub_class{$idx} || 0;
+        }
+        printf OUTPUT "%s", DUMP_ARRAY( "0x%02x", 0, @sub_idx );
+    }
+    print OUTPUT "\n};\n\n";
+
+    # class: dump the 16-char subsets
+
+    @null_table = (0) x 16;
+    printf OUTPUT "static const BYTE class_data[%d] =\n", 16 * $sub_class_pos;
+    print OUTPUT "{\n";
+    print OUTPUT "    /* zero */\n";
+    printf OUTPUT "%s", DUMP_ARRAY( "0x%02x", 0, @null_table );
+    for my $key (sort {$a <=> $b} keys %sub_class)
+    {
+        printf OUTPUT ",\n    /* 0x%03x0 .. 0x%03xf */\n", $key, $key;
+        my @sub_table;
         for (my $j = 0; $j < 16; $j++)
         {
-            if (defined $decomp_table[($i<<4) + $j])
+            my $idx = ($key << 4) | $j;
+            $sub_table[$j] = $combining_table[$idx] || 0;
+        }
+        printf OUTPUT "%s", DUMP_ARRAY( "0x%02x", 0, @sub_table );
+    }
+    print OUTPUT "\n};\n\n";
+
+    print OUTPUT <<"EOF";
+static inline const WCHAR *decomp_lookup( UINT x, int k )
+{
+    if (x <= decomp_last)
+    {
+        USHORT a, b, c, d;
+        a = decomp_index0[x >> 8];
+        b = decomp_index1[(a << 4) | ((x >> 4) & 0xf)];
+        c = (b << 5) | ((x & 0xf) << 1);
+        if (k) ++c;
+        d = decomp_offsets[c];
+        return &decomp_data[d];
+    }
+    else
+    {
+        return NULL;
+    }
+}
+
+static inline BYTE class_lookup( UINT x )
+{
+    if (x <= class_last)
+    {
+        BYTE a, b;
+        a = class_index0[x >> 8];
+        b = class_index1[(a << 4) | ((x >> 4) & 0xf)];
+        return class_data[(b << 4) | (x & 0xf)];
+    }
+    else
+    {
+        return 0;
+    }
+}
+
+static inline int decompose_hangul( WCHAR ch, WCHAR *l, WCHAR *v, WCHAR *t )
+{
+    static const WCHAR sbase = 0xac00, lbase = 0x1100, vbase = 0x1161, tbase = 0x11a7;
+    static const WCHAR /*lcount = 19, vcount = 21,*/ tcount = 28, ncount = 588/*, scount = 11172*/;
+    WCHAR sindex, lindex, vindex, tindex;
+    sindex = ch - sbase;
+    lindex = sindex / ncount;
+    vindex = (sindex % ncount) / tcount;
+    tindex = sindex % tcount;
+    *l = lbase + lindex;
+    *v = vbase + vindex;
+    *t = (tindex > 0) ? (tbase + tindex) : 0;
+    return 0;
+}
+
+static inline int decompose_pair( UINT ch, WCHAR *hi, WCHAR *lo )
+{
+    if (ch <= 0xffff)
+    {
+        *hi = ch;
+        *lo = 0;
+    }
+    else
+    {
+        WCHAR hx, hw, lx;
+        UINT hu;
+        hx = (WCHAR)ch;
+        hu = (ch >> 16) & ((1 << 5) - 1);
+        hw = (WCHAR)hu - 1;
+        lx = (WCHAR)ch;
+        *hi = 0xD800 | (hw << 6) | (hx >> 10);
+        *lo = (WCHAR)(0xDC00 | (lx & ((1 << 10) - 1)));
+    }
+    return 0;
+}
+
+static inline UINT compose_pair( WCHAR hi, WCHAR lo )
+{
+    UINT x, w, u, c;
+    x = ((hi & ((1 << 6) - 1)) << 10) | (lo & ((1 << 10) - 1));
+    w = (hi >> 6) & ((1 << 5) - 1);
+    u = w + 1;
+    c = (u << 16) | x;
+    return c;
+}
+
+static int decompose( int compat, UINT ch, WCHAR *dst, unsigned int dstlen )
+{
+    const WCHAR *mapping = NULL;
+    WCHAR buffer[4] = {0, 0, 0, 0};
+    int i = 0;
+    int write = 1;
+    if (dstlen == 0 || dst == NULL) write = 0;
+
+    if (ch < 0xa0) /* fast path */
+    {
+        buffer[0] = ch;
+        mapping = buffer;
+    }
+    else if (ch >= 0xac00 && ch <= 0xd7af) /* Hangul */
+    {
+        decompose_hangul(ch, &buffer[0], &buffer[1], &buffer[2]);
+        mapping = buffer;
+    }
+    else
+    {
+        mapping = decomp_lookup(ch, compat);
+    }
+
+    if (!mapping || !*mapping)
+    {
+        decompose_pair(ch, &buffer[0], &buffer[1]);
+        mapping = buffer;
+    }
+
+    do
+    {
+        if (i >= dstlen) write = 0;
+        if (write) dst[i] = mapping[i];
+    }
+    while (mapping[++i] != 0);
+    return i;
+}
+
+static int reorder( WCHAR *str, int len )
+{
+    int i = 0, j, m, p, seqlen;
+    UINT ch1, ch2;
+    BYTE k1, k2;
+
+    while (i < len)
+    {
+        /* Seek to first non-starter */
+        while (i < len)
+        {
+            UINT c;
+            c = str[i];
+            if (c >= 0xd800 && c <= 0xdbff)
+                c = compose_pair(c, str[++i]);
+            if (class_lookup(c)) break;
+            ++i;
+        }
+
+        /* Seek to next starter or end */
+        j = i + 1;
+        while (j < len)
+        {
+            UINT c;
+            c = str[j];
+            if (c >= 0xd800 && c <= 0xdbff)
+                c = compose_pair(c, str[++j]);
+            if (!class_lookup(c)) break;
+            ++j;
+        }
+
+        seqlen = j - i;
+
+        /* Bubble sort */
+        while (seqlen-- > 1)
+        {
+            for (m = 0; m < seqlen; ++m)
             {
-                $table[2 * $j] = ${$decomp_table[($i << 4) + $j]}[0];
-                $table[2 * $j + 1] = ${$decomp_table[($i << 4) + $j]}[1];
+                p = i + m;
+
+                ch1 = str[i + m];
+                if (ch1 >= 0xd800 && ch1 <= 0xdbff)
+                    ch1 = compose_pair(ch1, str[i + ++m]);
+                k1 = class_lookup(ch1);
+
+                ch2 = str[i + m + 1];
+                if (ch2 >= 0xd800 && ch2 <= 0xdbff)
+                    ch2 = compose_pair(ch2, str[i + ++m + 1]);
+                k2 = class_lookup(ch2);
+
+                /* Swap */
+                if (k1 > k2)
+                {
+                    if (ch2 <= 0xffff)
+                    {
+                        str[p++] = ch2;
+                    }
+                    else
+                    {
+                        WCHAR *hi, *lo;
+                        hi = &str[p++];
+                        lo = &str[p++];
+                        decompose_pair(ch2, hi, lo);
+                    }
+
+                    if (ch1 <= 0xffff)
+                    {
+                        str[p++] = ch1;
+                    }
+                    else
+                    {
+                        WCHAR *hi, *lo;
+                        hi = &str[p++];
+                        lo = &str[p++];
+                        decompose_pair(ch1, hi, lo);
+                    }
+                }
             }
         }
-        printf OUTPUT ",\n    /* 0x%03x0 .. 0x%03xf */\n", $i, $i;
-        printf OUTPUT "%s", DUMP_ARRAY( "0x%04x", 0, @table );
+        i = j;
     }
+    return 0;
+}
 
-    printf OUTPUT "\n};\n\n";
-    print OUTPUT <<"EOF";
-unsigned int DECLSPEC_HIDDEN wine_decompose( WCHAR ch, WCHAR *dst, unsigned int dstlen )
+unsigned int wine_decompose ( WCHAR ch, WCHAR *dst, unsigned int dstlen )
+{
+    int r;
+    r = decompose(0, ch, dst, dstlen);
+    if (r <= dstlen) return r;
+    else return 0;
+}
+
+int wine_decompose_string( int compat, const WCHAR *src, int srclen, WCHAR *dst, int dstlen )
 {
-    const WCHAR *ptr = table + table[table[ch >> 8] + ((ch >> 4) & 0x0f)] + 2 * (ch & 0xf);
-    unsigned int res;
-
-    *dst = ch;
-    if (!*ptr) return 1;
-    if (dstlen <= 1) return 0;
-    /* apply the decomposition recursively to the first char */
-    if ((res = wine_decompose( *ptr, dst, dstlen-1 ))) dst[res++] = ptr[1];
-    return res;
+    UINT ch;
+    int srcpos = 0, dstpos = 0, r;
+    if (srclen <= 0 || src == NULL) return 0;
+    if (dstlen < 0) dstlen = 0;
+
+    while (srcpos < srclen)
+    {
+        ch = src[srcpos];
+        if (ch >= 0xd800 && ch <= 0xdbff) /* high surrogate */
+        {
+            WCHAR hi, lo;
+            if (srcpos+1 == srclen) return (-srcpos);
+            hi = (WCHAR)ch;
+            lo = src[++srcpos];
+            if (lo < 0xdc00 || lo > 0xdfff) return (-srcpos);
+            ch = compose_pair(hi, lo);
+        }
+        else if (ch >= 0xdc00 && ch <= 0xdfff) /* low surrogate */
+        {
+            return (-srcpos);
+        }
+
+        r = decompose(compat, ch, dst+dstpos, dstlen);
+        dstpos += r;
+
+        if (dstlen > 0)
+        {
+            dstlen -= r;
+            if (dstlen < 0) dstlen = 0;
+        }
+
+        ++srcpos;
+    }
+
+    if (dstlen) reorder(dst, dstpos+1);
+    return dstpos+1;
 }
 EOF
     close OUTPUT;
